/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_f0g0(Libderiv_t *, prim_data *);

  /* Computes derivatives of (f0|g0) integrals */

void d12hrr_order_f0g0(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][4][11] = int_stack + 0;
 Libderiv->deriv_classes[3][4][10] = int_stack + 150;
 Libderiv->deriv_classes[3][4][9] = int_stack + 300;
 Libderiv->deriv_classes[3][4][8] = int_stack + 450;
 Libderiv->deriv_classes[3][4][7] = int_stack + 600;
 Libderiv->deriv_classes[3][4][6] = int_stack + 750;
 Libderiv->deriv_classes[3][4][2] = int_stack + 900;
 Libderiv->deriv_classes[3][4][1] = int_stack + 1050;
 Libderiv->deriv_classes[3][4][0] = int_stack + 1200;
 Libderiv->deriv2_classes[3][4][143] = int_stack + 1350;
 Libderiv->deriv2_classes[3][4][131] = int_stack + 1500;
 Libderiv->deriv2_classes[3][4][130] = int_stack + 1650;
 Libderiv->deriv2_classes[3][4][119] = int_stack + 1800;
 Libderiv->deriv2_classes[3][4][118] = int_stack + 1950;
 Libderiv->deriv2_classes[3][4][117] = int_stack + 2100;
 Libderiv->deriv2_classes[3][4][107] = int_stack + 2250;
 Libderiv->deriv2_classes[3][4][106] = int_stack + 2400;
 Libderiv->deriv2_classes[3][4][105] = int_stack + 2550;
 Libderiv->deriv2_classes[3][4][104] = int_stack + 2700;
 Libderiv->deriv2_classes[3][4][95] = int_stack + 2850;
 Libderiv->deriv2_classes[3][4][94] = int_stack + 3000;
 Libderiv->deriv2_classes[3][4][93] = int_stack + 3150;
 Libderiv->deriv2_classes[3][4][92] = int_stack + 3300;
 Libderiv->deriv2_classes[3][4][91] = int_stack + 3450;
 Libderiv->deriv2_classes[3][4][83] = int_stack + 3600;
 Libderiv->deriv2_classes[3][4][82] = int_stack + 3750;
 Libderiv->deriv2_classes[3][4][81] = int_stack + 3900;
 Libderiv->deriv2_classes[3][4][80] = int_stack + 4050;
 Libderiv->deriv2_classes[3][4][79] = int_stack + 4200;
 Libderiv->deriv2_classes[3][4][78] = int_stack + 4350;
 Libderiv->deriv2_classes[3][4][35] = int_stack + 4500;
 Libderiv->deriv2_classes[3][4][34] = int_stack + 4650;
 Libderiv->deriv2_classes[3][4][33] = int_stack + 4800;
 Libderiv->deriv2_classes[3][4][32] = int_stack + 4950;
 Libderiv->deriv2_classes[3][4][31] = int_stack + 5100;
 Libderiv->deriv2_classes[3][4][30] = int_stack + 5250;
 Libderiv->deriv2_classes[3][4][26] = int_stack + 5400;
 Libderiv->deriv2_classes[3][4][23] = int_stack + 5550;
 Libderiv->deriv2_classes[3][4][22] = int_stack + 5700;
 Libderiv->deriv2_classes[3][4][21] = int_stack + 5850;
 Libderiv->deriv2_classes[3][4][20] = int_stack + 6000;
 Libderiv->deriv2_classes[3][4][19] = int_stack + 6150;
 Libderiv->deriv2_classes[3][4][18] = int_stack + 6300;
 Libderiv->deriv2_classes[3][4][14] = int_stack + 6450;
 Libderiv->deriv2_classes[3][4][13] = int_stack + 6600;
 Libderiv->deriv2_classes[3][4][11] = int_stack + 6750;
 Libderiv->deriv2_classes[3][4][10] = int_stack + 6900;
 Libderiv->deriv2_classes[3][4][9] = int_stack + 7050;
 Libderiv->deriv2_classes[3][4][8] = int_stack + 7200;
 Libderiv->deriv2_classes[3][4][7] = int_stack + 7350;
 Libderiv->deriv2_classes[3][4][6] = int_stack + 7500;
 Libderiv->deriv2_classes[3][4][2] = int_stack + 7650;
 Libderiv->deriv2_classes[3][4][1] = int_stack + 7800;
 Libderiv->deriv2_classes[3][4][0] = int_stack + 7950;
 memset(int_stack,0,64800);

 Libderiv->dvrr_stack = int_stack + 8100;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_f0g0(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[11] = int_stack + 0;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[10] = int_stack + 150;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[9] = int_stack + 300;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[8] = int_stack + 450;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[7] = int_stack + 600;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[6] = int_stack + 750;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[2] = int_stack + 900;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[1] = int_stack + 1050;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[0] = int_stack + 1200;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[155] = int_stack + 1350;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[143] = int_stack + 1500;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[142] = int_stack + 1650;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[131] = int_stack + 1800;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[130] = int_stack + 1950;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[129] = int_stack + 2100;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[119] = int_stack + 2250;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[118] = int_stack + 2400;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[117] = int_stack + 2550;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[116] = int_stack + 2700;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[107] = int_stack + 2850;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[106] = int_stack + 3000;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[105] = int_stack + 3150;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[104] = int_stack + 3300;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[103] = int_stack + 3450;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[95] = int_stack + 3600;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[94] = int_stack + 3750;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[93] = int_stack + 3900;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[92] = int_stack + 4050;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[91] = int_stack + 4200;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[90] = int_stack + 4350;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[47] = int_stack + 4500;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[46] = int_stack + 4650;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[45] = int_stack + 4800;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[44] = int_stack + 4950;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[43] = int_stack + 5100;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[42] = int_stack + 5250;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[38] = int_stack + 5400;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[35] = int_stack + 5550;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[34] = int_stack + 5700;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[33] = int_stack + 5850;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[32] = int_stack + 6000;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[31] = int_stack + 6150;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[30] = int_stack + 6300;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[26] = int_stack + 6450;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[25] = int_stack + 6600;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[23] = int_stack + 6750;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[22] = int_stack + 6900;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[21] = int_stack + 7050;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[20] = int_stack + 7200;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[19] = int_stack + 7350;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[18] = int_stack + 7500;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[14] = int_stack + 7650;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[13] = int_stack + 7800;
 /*--- compute (f0|g0) ---*/
     Libderiv->ABCD[12] = int_stack + 7950;

}
