/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_f0hd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (f0|hd) integrals */

void d12hrr_order_f0hd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[3][7][11] = int_stack + 0;
 Libderiv->deriv_classes[3][7][10] = int_stack + 360;
 Libderiv->deriv_classes[3][7][9] = int_stack + 720;
 Libderiv->deriv_classes[3][7][8] = int_stack + 1080;
 Libderiv->deriv_classes[3][7][7] = int_stack + 1440;
 Libderiv->dvrr_classes[3][6] = int_stack + 1800;
 Libderiv->deriv_classes[3][7][6] = int_stack + 2080;
 Libderiv->deriv_classes[3][7][2] = int_stack + 2440;
 Libderiv->deriv_classes[3][7][1] = int_stack + 2800;
 Libderiv->deriv_classes[3][7][0] = int_stack + 3160;
 Libderiv->deriv2_classes[3][5][143] = int_stack + 3520;
 Libderiv->deriv2_classes[3][6][143] = int_stack + 3730;
 Libderiv->deriv2_classes[3][7][143] = int_stack + 4010;
 Libderiv->deriv2_classes[3][5][131] = int_stack + 4370;
 Libderiv->deriv2_classes[3][6][131] = int_stack + 4580;
 Libderiv->deriv2_classes[3][7][131] = int_stack + 4860;
 Libderiv->deriv2_classes[3][5][130] = int_stack + 5220;
 Libderiv->deriv2_classes[3][6][130] = int_stack + 5430;
 Libderiv->deriv2_classes[3][7][130] = int_stack + 5710;
 Libderiv->deriv2_classes[3][5][119] = int_stack + 6070;
 Libderiv->deriv2_classes[3][6][119] = int_stack + 6280;
 Libderiv->deriv2_classes[3][7][119] = int_stack + 6560;
 Libderiv->deriv2_classes[3][5][118] = int_stack + 6920;
 Libderiv->deriv2_classes[3][6][118] = int_stack + 7130;
 Libderiv->deriv2_classes[3][7][118] = int_stack + 7410;
 Libderiv->deriv2_classes[3][5][117] = int_stack + 7770;
 Libderiv->deriv2_classes[3][6][117] = int_stack + 7980;
 Libderiv->deriv2_classes[3][7][117] = int_stack + 8260;
 Libderiv->deriv2_classes[3][5][107] = int_stack + 8620;
 Libderiv->deriv2_classes[3][6][107] = int_stack + 8830;
 Libderiv->deriv2_classes[3][7][107] = int_stack + 9110;
 Libderiv->deriv2_classes[3][5][106] = int_stack + 9470;
 Libderiv->deriv2_classes[3][6][106] = int_stack + 9680;
 Libderiv->deriv2_classes[3][7][106] = int_stack + 9960;
 Libderiv->deriv2_classes[3][5][105] = int_stack + 10320;
 Libderiv->deriv2_classes[3][6][105] = int_stack + 10530;
 Libderiv->deriv2_classes[3][7][105] = int_stack + 10810;
 Libderiv->deriv2_classes[3][5][104] = int_stack + 11170;
 Libderiv->deriv2_classes[3][6][104] = int_stack + 11380;
 Libderiv->deriv2_classes[3][7][104] = int_stack + 11660;
 Libderiv->deriv2_classes[3][5][95] = int_stack + 12020;
 Libderiv->deriv2_classes[3][6][95] = int_stack + 12230;
 Libderiv->deriv2_classes[3][7][95] = int_stack + 12510;
 Libderiv->deriv2_classes[3][5][94] = int_stack + 12870;
 Libderiv->deriv2_classes[3][6][94] = int_stack + 13080;
 Libderiv->deriv2_classes[3][7][94] = int_stack + 13360;
 Libderiv->deriv2_classes[3][5][93] = int_stack + 13720;
 Libderiv->deriv2_classes[3][6][93] = int_stack + 13930;
 Libderiv->deriv2_classes[3][7][93] = int_stack + 14210;
 Libderiv->deriv2_classes[3][5][92] = int_stack + 14570;
 Libderiv->deriv2_classes[3][6][92] = int_stack + 14780;
 Libderiv->deriv2_classes[3][7][92] = int_stack + 15060;
 Libderiv->deriv2_classes[3][5][91] = int_stack + 15420;
 Libderiv->deriv2_classes[3][6][91] = int_stack + 15630;
 Libderiv->deriv2_classes[3][7][91] = int_stack + 15910;
 Libderiv->deriv_classes[3][5][11] = int_stack + 16270;
 Libderiv->deriv2_classes[3][5][83] = int_stack + 16480;
 Libderiv->deriv_classes[3][6][11] = int_stack + 16690;
 Libderiv->deriv2_classes[3][6][83] = int_stack + 16970;
 Libderiv->deriv2_classes[3][7][83] = int_stack + 17250;
 Libderiv->deriv_classes[3][5][10] = int_stack + 17610;
 Libderiv->deriv2_classes[3][5][82] = int_stack + 17820;
 Libderiv->deriv_classes[3][6][10] = int_stack + 18030;
 Libderiv->deriv2_classes[3][6][82] = int_stack + 18310;
 Libderiv->deriv2_classes[3][7][82] = int_stack + 18590;
 Libderiv->deriv_classes[3][5][9] = int_stack + 18950;
 Libderiv->deriv2_classes[3][5][81] = int_stack + 19160;
 Libderiv->deriv_classes[3][6][9] = int_stack + 19370;
 Libderiv->deriv2_classes[3][6][81] = int_stack + 19650;
 Libderiv->deriv2_classes[3][7][81] = int_stack + 19930;
 Libderiv->deriv_classes[3][5][8] = int_stack + 20290;
 Libderiv->deriv2_classes[3][5][80] = int_stack + 20500;
 Libderiv->deriv_classes[3][6][8] = int_stack + 20710;
 Libderiv->deriv2_classes[3][6][80] = int_stack + 20990;
 Libderiv->deriv2_classes[3][7][80] = int_stack + 21270;
 Libderiv->deriv_classes[3][5][7] = int_stack + 21630;
 Libderiv->deriv2_classes[3][5][79] = int_stack + 21840;
 Libderiv->deriv_classes[3][6][7] = int_stack + 22050;
 Libderiv->deriv2_classes[3][6][79] = int_stack + 22330;
 Libderiv->deriv2_classes[3][7][79] = int_stack + 22610;
 Libderiv->dvrr_classes[3][5] = int_stack + 22970;
 Libderiv->deriv_classes[3][5][6] = int_stack + 23180;
 Libderiv->deriv2_classes[3][5][78] = int_stack + 23390;
 Libderiv->deriv_classes[3][6][6] = int_stack + 23600;
 Libderiv->deriv2_classes[3][6][78] = int_stack + 23880;
 Libderiv->deriv2_classes[3][7][78] = int_stack + 24160;
 Libderiv->deriv2_classes[3][5][35] = int_stack + 24520;
 Libderiv->deriv2_classes[3][6][35] = int_stack + 24730;
 Libderiv->deriv2_classes[3][7][35] = int_stack + 25010;
 Libderiv->deriv2_classes[3][5][34] = int_stack + 25370;
 Libderiv->deriv2_classes[3][6][34] = int_stack + 25580;
 Libderiv->deriv2_classes[3][7][34] = int_stack + 25860;
 Libderiv->deriv2_classes[3][5][33] = int_stack + 26220;
 Libderiv->deriv2_classes[3][6][33] = int_stack + 26430;
 Libderiv->deriv2_classes[3][7][33] = int_stack + 26710;
 Libderiv->deriv2_classes[3][5][32] = int_stack + 27070;
 Libderiv->deriv2_classes[3][6][32] = int_stack + 27280;
 Libderiv->deriv2_classes[3][7][32] = int_stack + 27560;
 Libderiv->deriv2_classes[3][5][31] = int_stack + 27920;
 Libderiv->deriv2_classes[3][6][31] = int_stack + 28130;
 Libderiv->deriv2_classes[3][7][31] = int_stack + 28410;
 Libderiv->deriv_classes[3][5][2] = int_stack + 28770;
 Libderiv->deriv2_classes[3][5][30] = int_stack + 28980;
 Libderiv->deriv_classes[3][6][2] = int_stack + 29190;
 Libderiv->deriv2_classes[3][6][30] = int_stack + 29470;
 Libderiv->deriv2_classes[3][7][30] = int_stack + 29750;
 Libderiv->deriv2_classes[3][5][26] = int_stack + 30110;
 Libderiv->deriv2_classes[3][6][26] = int_stack + 30320;
 Libderiv->deriv2_classes[3][7][26] = int_stack + 30600;
 Libderiv->deriv2_classes[3][5][23] = int_stack + 30960;
 Libderiv->deriv2_classes[3][6][23] = int_stack + 31170;
 Libderiv->deriv2_classes[3][7][23] = int_stack + 31450;
 Libderiv->deriv2_classes[3][5][22] = int_stack + 31810;
 Libderiv->deriv2_classes[3][6][22] = int_stack + 32020;
 Libderiv->deriv2_classes[3][7][22] = int_stack + 32300;
 Libderiv->deriv2_classes[3][5][21] = int_stack + 32660;
 Libderiv->deriv2_classes[3][6][21] = int_stack + 32870;
 Libderiv->deriv2_classes[3][7][21] = int_stack + 33150;
 Libderiv->deriv2_classes[3][5][20] = int_stack + 33510;
 Libderiv->deriv2_classes[3][6][20] = int_stack + 33720;
 Libderiv->deriv2_classes[3][7][20] = int_stack + 34000;
 Libderiv->deriv2_classes[3][5][19] = int_stack + 34360;
 Libderiv->deriv2_classes[3][6][19] = int_stack + 34570;
 Libderiv->deriv2_classes[3][7][19] = int_stack + 34850;
 Libderiv->deriv_classes[3][5][1] = int_stack + 35210;
 Libderiv->deriv2_classes[3][5][18] = int_stack + 35420;
 Libderiv->deriv_classes[3][6][1] = int_stack + 35630;
 Libderiv->deriv2_classes[3][6][18] = int_stack + 35910;
 Libderiv->deriv2_classes[3][7][18] = int_stack + 36190;
 Libderiv->deriv2_classes[3][5][14] = int_stack + 36550;
 Libderiv->deriv2_classes[3][6][14] = int_stack + 36760;
 Libderiv->deriv2_classes[3][7][14] = int_stack + 37040;
 Libderiv->deriv2_classes[3][5][13] = int_stack + 37400;
 Libderiv->deriv2_classes[3][6][13] = int_stack + 37610;
 Libderiv->deriv2_classes[3][7][13] = int_stack + 37890;
 Libderiv->deriv2_classes[3][5][11] = int_stack + 38250;
 Libderiv->deriv2_classes[3][6][11] = int_stack + 38460;
 Libderiv->deriv2_classes[3][7][11] = int_stack + 38740;
 Libderiv->deriv2_classes[3][5][10] = int_stack + 39100;
 Libderiv->deriv2_classes[3][6][10] = int_stack + 39310;
 Libderiv->deriv2_classes[3][7][10] = int_stack + 39590;
 Libderiv->deriv2_classes[3][5][9] = int_stack + 39950;
 Libderiv->deriv2_classes[3][6][9] = int_stack + 40160;
 Libderiv->deriv2_classes[3][7][9] = int_stack + 40440;
 Libderiv->deriv2_classes[3][5][8] = int_stack + 40800;
 Libderiv->deriv2_classes[3][6][8] = int_stack + 41010;
 Libderiv->deriv2_classes[3][7][8] = int_stack + 41290;
 Libderiv->deriv2_classes[3][5][7] = int_stack + 41650;
 Libderiv->deriv2_classes[3][6][7] = int_stack + 41860;
 Libderiv->deriv2_classes[3][7][7] = int_stack + 42140;
 Libderiv->deriv_classes[3][5][0] = int_stack + 42500;
 Libderiv->deriv2_classes[3][5][6] = int_stack + 42710;
 Libderiv->deriv_classes[3][6][0] = int_stack + 42920;
 Libderiv->deriv2_classes[3][6][6] = int_stack + 43200;
 Libderiv->deriv2_classes[3][7][6] = int_stack + 43480;
 Libderiv->deriv2_classes[3][5][2] = int_stack + 43840;
 Libderiv->deriv2_classes[3][6][2] = int_stack + 44050;
 Libderiv->deriv2_classes[3][7][2] = int_stack + 44330;
 Libderiv->deriv2_classes[3][5][1] = int_stack + 44690;
 Libderiv->deriv2_classes[3][6][1] = int_stack + 44900;
 Libderiv->deriv2_classes[3][7][1] = int_stack + 45180;
 Libderiv->deriv2_classes[3][5][0] = int_stack + 45540;
 Libderiv->deriv2_classes[3][6][0] = int_stack + 45750;
 Libderiv->deriv2_classes[3][7][0] = int_stack + 46030;
 memset(int_stack,0,371120);

 Libderiv->dvrr_stack = int_stack + 87550;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_f0hd(Libderiv, Data);
   Data++;
 }

 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+46390,int_stack+1800,int_stack+22970,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+47020,int_stack+16690,int_stack+16270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22970,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+47650,int_stack+0,int_stack+16690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+48490,int_stack+18030,int_stack+17610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22970, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49120,int_stack+360,int_stack+18030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+19370,int_stack+18950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22970, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+49960,int_stack+720,int_stack+19370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+50800,int_stack+20710,int_stack+20290, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+51430,int_stack+1080,int_stack+20710, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+630,int_stack+22050,int_stack+21630, 0.0, zero_stack, 1.0, int_stack+22970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+52270,int_stack+1440,int_stack+22050, 0.0, zero_stack, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+53110,int_stack+23600,int_stack+23180, 1.0, int_stack+22970, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+53740,int_stack+2080,int_stack+23600, 1.0, int_stack+1800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1260,int_stack+29190,int_stack+28770,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+54580,int_stack+2440,int_stack+29190,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1890,int_stack+35630,int_stack+35210,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+55420,int_stack+2800,int_stack+35630,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+2520,int_stack+42920,int_stack+42500,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+56260,int_stack+3160,int_stack+42920,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+57100,int_stack+3730,int_stack+3520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+16270,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+57730,int_stack+4010,int_stack+3730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+16690,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3150,int_stack+4580,int_stack+4370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16270, 1.0, int_stack+17610,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+58570,int_stack+4860,int_stack+4580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16690, 1.0, int_stack+18030,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+3780,int_stack+5430,int_stack+5220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+17610, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+4410,int_stack+5710,int_stack+5430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+18030, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5250,int_stack+6280,int_stack+6070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16270, 0.0, zero_stack, 1.0, int_stack+18950,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+59410,int_stack+6560,int_stack+6280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16690, 0.0, zero_stack, 1.0, int_stack+19370,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5880,int_stack+7130,int_stack+6920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17610, 1.0, int_stack+18950, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+60250,int_stack+7410,int_stack+7130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18030, 1.0, int_stack+19370, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+6510,int_stack+7980,int_stack+7770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+18950, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7140,int_stack+8260,int_stack+7980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+19370, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7980,int_stack+8830,int_stack+8620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16270, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20290,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+61090,int_stack+9110,int_stack+8830, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+16690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+20710,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+8610,int_stack+9680,int_stack+9470, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+17610, 0.0, zero_stack, 1.0, int_stack+20290, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+61930,int_stack+9960,int_stack+9680, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18030, 0.0, zero_stack, 1.0, int_stack+20710, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9240,int_stack+10530,int_stack+10320, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+18950, 1.0, int_stack+20290, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+62770,int_stack+10810,int_stack+10530, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+19370, 1.0, int_stack+20710, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+9870,int_stack+11380,int_stack+11170, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+20290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+10500,int_stack+11660,int_stack+11380, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+20710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11340,int_stack+12230,int_stack+12020, 0.0, zero_stack, 1.0, int_stack+16270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21630,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+63610,int_stack+12510,int_stack+12230, 0.0, zero_stack, 1.0, int_stack+16690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22050,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+11970,int_stack+13080,int_stack+12870, 0.0, zero_stack, 1.0, int_stack+17610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+21630, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+64450,int_stack+13360,int_stack+13080, 0.0, zero_stack, 1.0, int_stack+18030, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+22050, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+13930,int_stack+13720, 0.0, zero_stack, 1.0, int_stack+18950, 0.0, zero_stack, 1.0, int_stack+21630, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65290,int_stack+14210,int_stack+13930, 0.0, zero_stack, 1.0, int_stack+19370, 0.0, zero_stack, 1.0, int_stack+22050, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13230,int_stack+14780,int_stack+14570, 0.0, zero_stack, 1.0, int_stack+20290, 1.0, int_stack+21630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13860,int_stack+15060,int_stack+14780, 0.0, zero_stack, 1.0, int_stack+20710, 1.0, int_stack+22050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+14700,int_stack+15630,int_stack+15420, 0.0, zero_stack, 2.0, int_stack+21630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+66130,int_stack+15910,int_stack+15630, 0.0, zero_stack, 2.0, int_stack+22050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15330,int_stack+16970,int_stack+16480, 1.0, int_stack+16270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23180,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+66970,int_stack+17250,int_stack+16970, 1.0, int_stack+16690, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23600,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+15960,int_stack+18310,int_stack+17820, 1.0, int_stack+17610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23180, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16590,int_stack+18590,int_stack+18310, 1.0, int_stack+18030, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23600, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+17430,int_stack+19650,int_stack+19160, 1.0, int_stack+18950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23180, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+18060,int_stack+19930,int_stack+19650, 1.0, int_stack+19370, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+23600, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+18900,int_stack+20990,int_stack+20500, 1.0, int_stack+20290, 0.0, zero_stack, 1.0, int_stack+23180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+19530,int_stack+21270,int_stack+20990, 1.0, int_stack+20710, 0.0, zero_stack, 1.0, int_stack+23600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+20370,int_stack+22330,int_stack+21840, 1.0, int_stack+21630, 1.0, int_stack+23180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+21000,int_stack+22610,int_stack+22330, 1.0, int_stack+22050, 1.0, int_stack+23600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+21840,int_stack+23880,int_stack+23390, 2.0, int_stack+23180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+22470,int_stack+24160,int_stack+23880, 2.0, int_stack+23600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23310,int_stack+24730,int_stack+24520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28770,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+67810,int_stack+25010,int_stack+24730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29190,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+23940,int_stack+25580,int_stack+25370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28770, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+24570,int_stack+25860,int_stack+25580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29190, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+25410,int_stack+26430,int_stack+26220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28770, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+68650,int_stack+26710,int_stack+26430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29190, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26040,int_stack+27280,int_stack+27070, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+28770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+69490,int_stack+27560,int_stack+27280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+29190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+26670,int_stack+28130,int_stack+27920, 0.0, zero_stack, 1.0, int_stack+28770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+70330,int_stack+28410,int_stack+28130, 0.0, zero_stack, 1.0, int_stack+29190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+27300,int_stack+29470,int_stack+28980, 1.0, int_stack+28770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+27930,int_stack+29750,int_stack+29470, 1.0, int_stack+29190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+28770,int_stack+30320,int_stack+30110,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+29400,int_stack+30600,int_stack+30320,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30240,int_stack+31170,int_stack+30960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35210,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+71170,int_stack+31450,int_stack+31170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35630,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+30870,int_stack+32020,int_stack+31810, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35210, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+72010,int_stack+32300,int_stack+32020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35630, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+31500,int_stack+32870,int_stack+32660, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35210, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+72850,int_stack+33150,int_stack+32870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35630, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+32130,int_stack+33720,int_stack+33510, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+32760,int_stack+34000,int_stack+33720, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+35630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+33600,int_stack+34570,int_stack+34360, 0.0, zero_stack, 1.0, int_stack+35210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+73690,int_stack+34850,int_stack+34570, 0.0, zero_stack, 1.0, int_stack+35630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+34230,int_stack+35910,int_stack+35420, 1.0, int_stack+35210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+74530,int_stack+36190,int_stack+35910, 1.0, int_stack+35630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+34860,int_stack+36760,int_stack+36550,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+35490,int_stack+37040,int_stack+36760,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+36330,int_stack+37610,int_stack+37400,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+75370,int_stack+37890,int_stack+37610,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+36960,int_stack+38460,int_stack+38250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42500,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+37590,int_stack+38740,int_stack+38460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42920,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+38430,int_stack+39310,int_stack+39100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42500, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+76210,int_stack+39590,int_stack+39310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42920, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39060,int_stack+40160,int_stack+39950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42500, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77050,int_stack+40440,int_stack+40160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42920, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+39690,int_stack+41010,int_stack+40800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+77890,int_stack+41290,int_stack+41010, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+42920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+40320,int_stack+41860,int_stack+41650, 0.0, zero_stack, 1.0, int_stack+42500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+40950,int_stack+42140,int_stack+41860, 0.0, zero_stack, 1.0, int_stack+42920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+41790,int_stack+43200,int_stack+42710, 1.0, int_stack+42500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+78730,int_stack+43480,int_stack+43200, 1.0, int_stack+42920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+42420,int_stack+44050,int_stack+43840,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+43050,int_stack+44330,int_stack+44050,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+43890,int_stack+44900,int_stack+44690,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+79570,int_stack+45180,int_stack+44900,10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+44520,int_stack+45750,int_stack+45540,10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+80410,int_stack+46030,int_stack+45750,10);
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+81250,int_stack+47650,int_stack+47020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46390,10);
     Libderiv->ABCD[11] = int_stack + 81250;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+82510,int_stack+49120,int_stack+48490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46390, 0.0, zero_stack,10);
     Libderiv->ABCD[10] = int_stack + 82510;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+83770,int_stack+49960,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46390, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[9] = int_stack + 83770;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+49120,int_stack+51430,int_stack+50800, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+46390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[8] = int_stack + 49120;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+85030,int_stack+52270,int_stack+630, 0.0, zero_stack, 1.0, int_stack+46390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[7] = int_stack + 85030;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+51430,int_stack+53740,int_stack+53110, 1.0, int_stack+46390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[6] = int_stack + 51430;
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+45150,int_stack+54580,int_stack+1260,10);
     Libderiv->ABCD[2] = int_stack + 45150;
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+53740,int_stack+55420,int_stack+1890,10);
     Libderiv->ABCD[1] = int_stack + 53740;
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+55000,int_stack+56260,int_stack+2520,10);
     Libderiv->ABCD[0] = int_stack + 55000;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+86290,int_stack+57730,int_stack+57100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+47020,10);
     Libderiv->ABCD[155] = int_stack + 86290;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+56260,int_stack+58570,int_stack+3150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47020, 1.0, int_stack+48490,10);
     Libderiv->ABCD[143] = int_stack + 56260;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+57520,int_stack+4410,int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+48490, 0.0, zero_stack,10);
     Libderiv->ABCD[142] = int_stack + 57520;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+3150,int_stack+59410,int_stack+5250, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47020, 0.0, zero_stack, 1.0, int_stack+0,10);
     Libderiv->ABCD[131] = int_stack + 3150;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4410,int_stack+60250,int_stack+5880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48490, 1.0, int_stack+0, 0.0, zero_stack,10);
     Libderiv->ABCD[130] = int_stack + 4410;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+58780,int_stack+7140,int_stack+6510, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[129] = int_stack + 58780;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+5670,int_stack+61090,int_stack+7980, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+47020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+50800,10);
     Libderiv->ABCD[119] = int_stack + 5670;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+6930,int_stack+61930,int_stack+8610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+48490, 0.0, zero_stack, 1.0, int_stack+50800, 0.0, zero_stack,10);
     Libderiv->ABCD[118] = int_stack + 6930;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+60040,int_stack+62770,int_stack+9240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+50800, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[117] = int_stack + 60040;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8190,int_stack+10500,int_stack+9870, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+50800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[116] = int_stack + 8190;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+9450,int_stack+63610,int_stack+11340, 0.0, zero_stack, 1.0, int_stack+47020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630,10);
     Libderiv->ABCD[107] = int_stack + 9450;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10710,int_stack+64450,int_stack+11970, 0.0, zero_stack, 1.0, int_stack+48490, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+630, 0.0, zero_stack,10);
     Libderiv->ABCD[106] = int_stack + 10710;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+61300,int_stack+65290,int_stack+12600, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+630, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[105] = int_stack + 61300;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+11970,int_stack+13860,int_stack+13230, 0.0, zero_stack, 1.0, int_stack+50800, 1.0, int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[104] = int_stack + 11970;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+13230,int_stack+66130,int_stack+14700, 0.0, zero_stack, 2.0, int_stack+630, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[103] = int_stack + 13230;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+62560,int_stack+66970,int_stack+15330, 1.0, int_stack+47020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53110,10);
     Libderiv->ABCD[95] = int_stack + 62560;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+14490,int_stack+16590,int_stack+15960, 1.0, int_stack+48490, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53110, 0.0, zero_stack,10);
     Libderiv->ABCD[94] = int_stack + 14490;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15750,int_stack+18060,int_stack+17430, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+53110, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[93] = int_stack + 15750;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+17010,int_stack+19530,int_stack+18900, 1.0, int_stack+50800, 0.0, zero_stack, 1.0, int_stack+53110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[92] = int_stack + 17010;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18270,int_stack+21000,int_stack+20370, 1.0, int_stack+630, 1.0, int_stack+53110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[91] = int_stack + 18270;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+22470,int_stack+21840, 2.0, int_stack+53110, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[90] = int_stack + 0;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+19530,int_stack+67810,int_stack+23310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260,10);
     Libderiv->ABCD[47] = int_stack + 19530;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+20790,int_stack+24570,int_stack+23940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack,10);
     Libderiv->ABCD[46] = int_stack + 20790;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22050,int_stack+68650,int_stack+25410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[45] = int_stack + 22050;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+23310,int_stack+69490,int_stack+26040, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[44] = int_stack + 23310;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+24570,int_stack+70330,int_stack+26670, 0.0, zero_stack, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[43] = int_stack + 24570;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+25830,int_stack+27930,int_stack+27300, 1.0, int_stack+1260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[42] = int_stack + 25830;
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+27090,int_stack+29400,int_stack+28770,10);
     Libderiv->ABCD[38] = int_stack + 27090;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+28350,int_stack+71170,int_stack+30240, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890,10);
     Libderiv->ABCD[35] = int_stack + 28350;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+29610,int_stack+72010,int_stack+30870, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890, 0.0, zero_stack,10);
     Libderiv->ABCD[34] = int_stack + 29610;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+63820,int_stack+72850,int_stack+31500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[33] = int_stack + 63820;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+30870,int_stack+32760,int_stack+32130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[32] = int_stack + 30870;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+32130,int_stack+73690,int_stack+33600, 0.0, zero_stack, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[31] = int_stack + 32130;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+65080,int_stack+74530,int_stack+34230, 1.0, int_stack+1890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[30] = int_stack + 65080;
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1260,int_stack+35490,int_stack+34860,10);
     Libderiv->ABCD[26] = int_stack + 1260;
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+33390,int_stack+75370,int_stack+36330,10);
     Libderiv->ABCD[25] = int_stack + 33390;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+34650,int_stack+37590,int_stack+36960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520,10);
     Libderiv->ABCD[23] = int_stack + 34650;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+35910,int_stack+76210,int_stack+38430, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack,10);
     Libderiv->ABCD[22] = int_stack + 35910;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+37170,int_stack+77050,int_stack+39060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[21] = int_stack + 37170;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+38430,int_stack+77890,int_stack+39690, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[20] = int_stack + 38430;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+66340,int_stack+40950,int_stack+40320, 0.0, zero_stack, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[19] = int_stack + 66340;
 /*--- compute (f0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+39690,int_stack+78730,int_stack+41790, 1.0, int_stack+2520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,10);
     Libderiv->ABCD[18] = int_stack + 39690;
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+40950,int_stack+43050,int_stack+42420,10);
     Libderiv->ABCD[14] = int_stack + 40950;
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+42210,int_stack+79570,int_stack+43890,10);
     Libderiv->ABCD[13] = int_stack + 42210;
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+67600,int_stack+80410,int_stack+44520,10);
     Libderiv->ABCD[12] = int_stack + 67600;

}
