/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (00|hf) integrals */

void d12vrr_order_00hf(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+0, dvrr_stack+6, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+9, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+31, dvrr_stack+3, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+34, dvrr_stack+15, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+50, dvrr_stack+6, dvrr_stack+3, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+56, dvrr_stack+9, dvrr_stack+50, dvrr_stack+0, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+66, dvrr_stack+21, dvrr_stack+56, dvrr_stack+15, dvrr_stack+9, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+81, dvrr_stack+40, dvrr_stack+21, dvrr_stack+34, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+96, dvrr_stack+81, dvrr_stack+66, dvrr_stack+40, dvrr_stack+21, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+0, dvrr_stack+31, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+117, dvrr_stack+15, dvrr_stack+34, dvrr_stack+0, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+127, dvrr_stack+117, dvrr_stack+40, dvrr_stack+15, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+142, dvrr_stack+127, dvrr_stack+81, dvrr_stack+117, dvrr_stack+40, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+3, dvrr_stack+31, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+163, dvrr_stack+50, dvrr_stack+34, dvrr_stack+6, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+173, dvrr_stack+56, dvrr_stack+163, dvrr_stack+9, dvrr_stack+50, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+188, dvrr_stack+66, dvrr_stack+173, dvrr_stack+21, dvrr_stack+56, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+209, dvrr_stack+96, dvrr_stack+188, dvrr_stack+81, dvrr_stack+66, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+237, dvrr_stack+142, dvrr_stack+96, dvrr_stack+127, dvrr_stack+81, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+265, dvrr_stack+237, dvrr_stack+209, dvrr_stack+142, dvrr_stack+96, NULL);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+21, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+24, dvrr_stack+31, dvrr_stack+21, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+301, dvrr_stack+34, dvrr_stack+24, dvrr_stack+3, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+311, dvrr_stack+163, dvrr_stack+301, dvrr_stack+50, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+326, dvrr_stack+173, dvrr_stack+311, dvrr_stack+56, dvrr_stack+163, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+347, dvrr_stack+188, dvrr_stack+326, dvrr_stack+66, dvrr_stack+173, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+375, dvrr_stack+209, dvrr_stack+347, dvrr_stack+96, dvrr_stack+188, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+411, dvrr_stack+265, dvrr_stack+375, dvrr_stack+237, dvrr_stack+209, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+50, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+53, dvrr_stack+50, dvrr_stack+0, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+59, dvrr_stack+53, dvrr_stack+15, dvrr_stack+50, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+0, dvrr_stack+59, dvrr_stack+117, dvrr_stack+53, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+456, dvrr_stack+0, dvrr_stack+127, dvrr_stack+59, dvrr_stack+117, NULL);
 tmp = dvrr_stack + 456;
 target_ptr = Libderiv->dvrr_classes[0][5];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+477, dvrr_stack+456, dvrr_stack+142, dvrr_stack+0, dvrr_stack+127, NULL);
 tmp = dvrr_stack + 477;
 target_ptr = Libderiv->dvrr_classes[0][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+505, dvrr_stack+477, dvrr_stack+237, dvrr_stack+456, dvrr_stack+142, NULL);
 tmp = dvrr_stack + 505;
 target_ptr = Libderiv->dvrr_classes[0][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+541, dvrr_stack+505, dvrr_stack+265, dvrr_stack+477, dvrr_stack+237, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+586, dvrr_stack+541, dvrr_stack+411, NULL, NULL, dvrr_stack+265);

 /* compute (0 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+721,dvrr_stack+477,dvrr_stack+456,1);


 /* compute (0 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+784,dvrr_stack+505,dvrr_stack+477,1);


 /* compute (0 0 | 5 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hd(Libderiv->CD,dvrr_stack+868,dvrr_stack+784,dvrr_stack+721,1);


 /* compute (0 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,21,dvrr_stack+994, dvrr_stack+868, dvrr_stack+456);

 /* compute (0 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+1057,dvrr_stack+541,dvrr_stack+505,1);


 /* compute (0 0 | 6 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_id(Libderiv->CD,dvrr_stack+1165,dvrr_stack+1057,dvrr_stack+784,1);


 /* compute (0 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,28,dvrr_stack+1333, dvrr_stack+1165, dvrr_stack+477);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1417, dvrr_stack+541, dvrr_stack+411, dvrr_stack+505, dvrr_stack+265, NULL);

 /* compute (0 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+1472,dvrr_stack+1417,dvrr_stack+541,1);


 /* compute (0 0 | 7 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kd(Libderiv->CD,dvrr_stack+1607,dvrr_stack+1472,dvrr_stack+1057,1);


 /* compute (0 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,36,dvrr_stack+1823, dvrr_stack+1607, dvrr_stack+505);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+15, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+50, dvrr_stack+21, dvrr_stack+15, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+69, dvrr_stack+24, dvrr_stack+50, dvrr_stack+31, dvrr_stack+21, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1931, dvrr_stack+301, dvrr_stack+69, dvrr_stack+34, dvrr_stack+24, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+15, dvrr_stack+311, dvrr_stack+1931, dvrr_stack+163, dvrr_stack+301, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1931, dvrr_stack+326, dvrr_stack+15, dvrr_stack+173, dvrr_stack+311, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1959, dvrr_stack+347, dvrr_stack+1931, dvrr_stack+188, dvrr_stack+326, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+301, dvrr_stack+375, dvrr_stack+1959, dvrr_stack+209, dvrr_stack+347, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1931, dvrr_stack+411, dvrr_stack+301, dvrr_stack+265, dvrr_stack+375, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+1986, dvrr_stack+1417, dvrr_stack+1931, dvrr_stack+541, dvrr_stack+411, NULL);

 /* compute (0 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+2052,dvrr_stack+1986,dvrr_stack+1417,1);


 /* compute (0 0 | 8 2) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ld(Libderiv->CD,dvrr_stack+2217,dvrr_stack+2052,dvrr_stack+1472,1);


 /* compute (0 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_p(Data,45,dvrr_stack+2487, dvrr_stack+2217, dvrr_stack+541);

 /* compute (0 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,21,dvrr_stack+2622, dvrr_stack+868, dvrr_stack+456);

 /* compute (0 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,28,dvrr_stack+2685, dvrr_stack+1165, dvrr_stack+477);

 /* compute (0 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,36,dvrr_stack+2769, dvrr_stack+1607, dvrr_stack+505);

 /* compute (0 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_p(Data,45,dvrr_stack+2877, dvrr_stack+2217, dvrr_stack+541);

 /* compute (0 0 | 5 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,21,dvrr_stack+3012, dvrr_stack+868, dvrr_stack+456);

 /* compute (0 0 | 6 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,28,dvrr_stack+868, dvrr_stack+1165, dvrr_stack+477);

 /* compute (0 0 | 7 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,36,dvrr_stack+1165, dvrr_stack+1607, dvrr_stack+505);

 /* compute (0 0 | 8 1) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_p(Data,45,dvrr_stack+1607, dvrr_stack+2217, dvrr_stack+541);

 /* compute (0 0 | 4 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_gp(Libderiv->CD,dvrr_stack+2217,dvrr_stack+456,dvrr_stack+0,1);


 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,15,dvrr_stack+2262, dvrr_stack+2217, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,28,dvrr_stack+2277, dvrr_stack+784, NULL);
 tmp = dvrr_stack + 2277;
 target_ptr = Libderiv->deriv_classes[0][6][11];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,21,dvrr_stack+2305, dvrr_stack+721, NULL);
 tmp = dvrr_stack + 2305;
 target_ptr = Libderiv->deriv_classes[0][5][11];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,36,dvrr_stack+2326, dvrr_stack+1057, NULL);
 tmp = dvrr_stack + 2326;
 target_ptr = Libderiv->deriv_classes[0][7][11];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,45,dvrr_stack+2362, dvrr_stack+1472, NULL);
 tmp = dvrr_stack + 2362;
 target_ptr = Libderiv->deriv_classes[0][8][11];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,55,dvrr_stack+2407, dvrr_stack+2052, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,15,dvrr_stack+2462, dvrr_stack+2217, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,28,dvrr_stack+1742, dvrr_stack+784, NULL);
 tmp = dvrr_stack + 1742;
 target_ptr = Libderiv->deriv_classes[0][6][10];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,21,dvrr_stack+1770, dvrr_stack+721, NULL);
 tmp = dvrr_stack + 1770;
 target_ptr = Libderiv->deriv_classes[0][5][10];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,36,dvrr_stack+1273, dvrr_stack+1057, NULL);
 tmp = dvrr_stack + 1273;
 target_ptr = Libderiv->deriv_classes[0][7][10];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+3075, dvrr_stack+1472, NULL);
 tmp = dvrr_stack + 3075;
 target_ptr = Libderiv->deriv_classes[0][8][10];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,55,dvrr_stack+3120, dvrr_stack+2052, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,15,dvrr_stack+1791, dvrr_stack+2217, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+2217, dvrr_stack+784, NULL);
 tmp = dvrr_stack + 2217;
 target_ptr = Libderiv->deriv_classes[0][6][9];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+784, dvrr_stack+721, NULL);
 tmp = dvrr_stack + 784;
 target_ptr = Libderiv->deriv_classes[0][5][9];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+721, dvrr_stack+1057, NULL);
 tmp = dvrr_stack + 721;
 target_ptr = Libderiv->deriv_classes[0][7][9];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+1057, dvrr_stack+1472, NULL);
 tmp = dvrr_stack + 1057;
 target_ptr = Libderiv->deriv_classes[0][8][9];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,55,dvrr_stack+1472, dvrr_stack+2052, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_g(Data,1,1,dvrr_stack+2052, dvrr_stack+456, dvrr_stack+59);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+2067, dvrr_stack+505, dvrr_stack+456);
 tmp = dvrr_stack + 2067;
 target_ptr = Libderiv->deriv_classes[0][6][8];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+2095, dvrr_stack+477, dvrr_stack+0);
 tmp = dvrr_stack + 2095;
 target_ptr = Libderiv->deriv_classes[0][5][8];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+2116, dvrr_stack+541, dvrr_stack+477);
 tmp = dvrr_stack + 2116;
 target_ptr = Libderiv->deriv_classes[0][7][8];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+2152, dvrr_stack+1417, dvrr_stack+505);
 tmp = dvrr_stack + 2152;
 target_ptr = Libderiv->deriv_classes[0][8][8];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,1,1,dvrr_stack+1527, dvrr_stack+1986, dvrr_stack+541);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_g(Data,1,1,dvrr_stack+2197, dvrr_stack+456, dvrr_stack+59);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+1102, dvrr_stack+505, dvrr_stack+456);
 tmp = dvrr_stack + 1102;
 target_ptr = Libderiv->deriv_classes[0][6][7];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+1582, dvrr_stack+477, dvrr_stack+0);
 tmp = dvrr_stack + 1582;
 target_ptr = Libderiv->deriv_classes[0][5][7];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+805, dvrr_stack+541, dvrr_stack+477);
 tmp = dvrr_stack + 805;
 target_ptr = Libderiv->deriv_classes[0][7][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+3175, dvrr_stack+1417, dvrr_stack+505);
 tmp = dvrr_stack + 3175;
 target_ptr = Libderiv->deriv_classes[0][8][7];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,1,1,dvrr_stack+3220, dvrr_stack+1986, dvrr_stack+541);

 /* compute (0 0 | 4 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_g(Data,1,1,dvrr_stack+1130, dvrr_stack+456, dvrr_stack+59);

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+952, dvrr_stack+505, dvrr_stack+456);
 tmp = dvrr_stack + 952;
 target_ptr = Libderiv->deriv_classes[0][6][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+757, dvrr_stack+477, dvrr_stack+0);
 tmp = dvrr_stack + 757;
 target_ptr = Libderiv->deriv_classes[0][5][6];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+3275, dvrr_stack+541, dvrr_stack+477);
 tmp = dvrr_stack + 3275;
 target_ptr = Libderiv->deriv_classes[0][7][6];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+3311, dvrr_stack+1417, dvrr_stack+505);
 tmp = dvrr_stack + 3311;
 target_ptr = Libderiv->deriv_classes[0][8][6];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,1,1,dvrr_stack+3356, dvrr_stack+1986, dvrr_stack+541);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1986, dvrr_stack+456, dvrr_stack+142, NULL, NULL, dvrr_stack+127);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3411, dvrr_stack+477, dvrr_stack+237, NULL, NULL, dvrr_stack+142);

 /* compute (1 0 | 5 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_hp(Libderiv->CD,dvrr_stack+3495,dvrr_stack+3411,dvrr_stack+1986,3);


 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,63,dvrr_stack+3684, dvrr_stack+3495, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3747, dvrr_stack+505, dvrr_stack+265, NULL, NULL, dvrr_stack+237);

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+3855,dvrr_stack+3747,dvrr_stack+3411,3);


 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+4107, dvrr_stack+3855, NULL);

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+4191,dvrr_stack+586,dvrr_stack+3747,3);


 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+4515, dvrr_stack+4191, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+4623, dvrr_stack+1417, dvrr_stack+1931, NULL, NULL, dvrr_stack+411);

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+4788,dvrr_stack+4623,dvrr_stack+586,3);


 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+5193, dvrr_stack+4788, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,63,dvrr_stack+5328, dvrr_stack+3495, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+5391, dvrr_stack+3855, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+5475, dvrr_stack+4191, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+5583, dvrr_stack+4788, NULL);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,63,dvrr_stack+5718, dvrr_stack+3495, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+3495, dvrr_stack+3855, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+3855, dvrr_stack+4191, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+4191, dvrr_stack+4788, NULL);

 /* compute (1 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+4788, dvrr_stack+0, dvrr_stack+127, NULL, NULL, dvrr_stack+117);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_h(Data,3,1,dvrr_stack+4833, dvrr_stack+3411, dvrr_stack+4788);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+4896, dvrr_stack+3747, dvrr_stack+1986);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+4980, dvrr_stack+586, dvrr_stack+3411);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+4326, dvrr_stack+4623, dvrr_stack+3747);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_h(Data,3,1,dvrr_stack+5088, dvrr_stack+3411, dvrr_stack+4788);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+3963, dvrr_stack+3747, dvrr_stack+1986);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+5781, dvrr_stack+586, dvrr_stack+3411);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+5889, dvrr_stack+4623, dvrr_stack+3747);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_h(Data,3,1,dvrr_stack+3579, dvrr_stack+3411, dvrr_stack+4788);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+6024, dvrr_stack+3747, dvrr_stack+1986);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+6108, dvrr_stack+586, dvrr_stack+3411);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+6216, dvrr_stack+4623, dvrr_stack+3747);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+4623, dvrr_stack+127, dvrr_stack+81, NULL, NULL, dvrr_stack+40);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+4668, dvrr_stack+142, dvrr_stack+96, NULL, NULL, dvrr_stack+81);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+6351, dvrr_stack+1986, dvrr_stack+4668, dvrr_stack+456, dvrr_stack+142, dvrr_stack+4623);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,21,dvrr_stack+4731, dvrr_stack+6351, dvrr_stack+456);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+117, dvrr_stack+237, dvrr_stack+209, NULL, NULL, dvrr_stack+96);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+6477, dvrr_stack+3411, dvrr_stack+117, dvrr_stack+477, dvrr_stack+237, dvrr_stack+4668);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+4623, dvrr_stack+6477, dvrr_stack+477);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+0, dvrr_stack+265, dvrr_stack+375, NULL, NULL, dvrr_stack+209);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6645, dvrr_stack+3747, dvrr_stack+0, dvrr_stack+505, dvrr_stack+265, dvrr_stack+117);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+108, dvrr_stack+6645, dvrr_stack+505);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6861, dvrr_stack+411, dvrr_stack+301, NULL, NULL, dvrr_stack+375);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6996, dvrr_stack+586, dvrr_stack+6861, dvrr_stack+541, dvrr_stack+411, dvrr_stack+0);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+6861, dvrr_stack+6996, dvrr_stack+541);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,21,dvrr_stack+0, dvrr_stack+6351, dvrr_stack+456);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+216, dvrr_stack+6477, dvrr_stack+477);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+300, dvrr_stack+6645, dvrr_stack+505);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+7266, dvrr_stack+6996, dvrr_stack+541);

 /* compute (1 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,21,dvrr_stack+7401, dvrr_stack+6351, dvrr_stack+456);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+6351, dvrr_stack+6477, dvrr_stack+477);

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+6435, dvrr_stack+6645, dvrr_stack+505);

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+6543, dvrr_stack+6996, dvrr_stack+541);

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+63, dvrr_stack+586, NULL);
 tmp = dvrr_stack + 63;
 target_ptr = Libderiv->deriv_classes[0][8][2];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+6996, dvrr_stack+586, NULL);
 tmp = dvrr_stack + 6996;
 target_ptr = Libderiv->deriv_classes[0][8][1];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+7041, dvrr_stack+586, NULL);
 tmp = dvrr_stack + 7041;
 target_ptr = Libderiv->deriv_classes[0][8][0];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,21,dvrr_stack+7086, dvrr_stack+994, NULL);
 tmp = dvrr_stack + 7086;
 target_ptr = Libderiv->deriv2_classes[0][5][143];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,28,dvrr_stack+7107, dvrr_stack+1333, NULL);
 tmp = dvrr_stack + 7107;
 target_ptr = Libderiv->deriv2_classes[0][6][143];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,36,dvrr_stack+7135, dvrr_stack+1823, NULL);
 tmp = dvrr_stack + 7135;
 target_ptr = Libderiv->deriv2_classes[0][7][143];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 2 */
 deriv_build_DZ_0(Data,45,dvrr_stack+7171, dvrr_stack+2487, NULL);
 tmp = dvrr_stack + 7171;
 target_ptr = Libderiv->deriv2_classes[0][8][143];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,21,dvrr_stack+7216, dvrr_stack+994, NULL);
 tmp = dvrr_stack + 7216;
 target_ptr = Libderiv->deriv2_classes[0][5][131];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,28,dvrr_stack+7237, dvrr_stack+1333, NULL);
 tmp = dvrr_stack + 7237;
 target_ptr = Libderiv->deriv2_classes[0][6][131];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,36,dvrr_stack+6678, dvrr_stack+1823, NULL);
 tmp = dvrr_stack + 6678;
 target_ptr = Libderiv->deriv2_classes[0][7][131];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 1 */
 deriv_build_DY_0(Data,45,dvrr_stack+6714, dvrr_stack+2487, NULL);
 tmp = dvrr_stack + 6714;
 target_ptr = Libderiv->deriv2_classes[0][8][131];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,21,dvrr_stack+6759, dvrr_stack+2622, NULL);
 tmp = dvrr_stack + 6759;
 target_ptr = Libderiv->deriv2_classes[0][5][130];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,28,dvrr_stack+6780, dvrr_stack+2685, NULL);
 tmp = dvrr_stack + 6780;
 target_ptr = Libderiv->deriv2_classes[0][6][130];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,36,dvrr_stack+6808, dvrr_stack+2769, NULL);
 tmp = dvrr_stack + 6808;
 target_ptr = Libderiv->deriv2_classes[0][7][130];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 2 0 */
 deriv_build_DY_0(Data,45,dvrr_stack+408, dvrr_stack+2877, NULL);
 tmp = dvrr_stack + 408;
 target_ptr = Libderiv->deriv2_classes[0][8][130];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,21,dvrr_stack+4707, dvrr_stack+994, NULL);
 tmp = dvrr_stack + 4707;
 target_ptr = Libderiv->deriv2_classes[0][5][119];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,28,dvrr_stack+4794, dvrr_stack+1333, NULL);
 tmp = dvrr_stack + 4794;
 target_ptr = Libderiv->deriv2_classes[0][6][119];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,36,dvrr_stack+453, dvrr_stack+1823, NULL);
 tmp = dvrr_stack + 453;
 target_ptr = Libderiv->deriv2_classes[0][7][119];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 1 */
 deriv_build_DX_0(Data,45,dvrr_stack+489, dvrr_stack+2487, NULL);
 tmp = dvrr_stack + 489;
 target_ptr = Libderiv->deriv2_classes[0][8][119];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+534, dvrr_stack+2622, NULL);
 tmp = dvrr_stack + 534;
 target_ptr = Libderiv->deriv2_classes[0][5][118];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+555, dvrr_stack+2685, NULL);
 tmp = dvrr_stack + 555;
 target_ptr = Libderiv->deriv2_classes[0][6][118];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+583, dvrr_stack+2769, NULL);
 tmp = dvrr_stack + 583;
 target_ptr = Libderiv->deriv2_classes[0][7][118];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 1 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+619, dvrr_stack+2877, NULL);
 tmp = dvrr_stack + 619;
 target_ptr = Libderiv->deriv2_classes[0][8][118];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,21,dvrr_stack+664, dvrr_stack+3012, NULL);
 tmp = dvrr_stack + 664;
 target_ptr = Libderiv->deriv2_classes[0][5][117];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,28,dvrr_stack+685, dvrr_stack+868, NULL);
 tmp = dvrr_stack + 685;
 target_ptr = Libderiv->deriv2_classes[0][6][117];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,36,dvrr_stack+5151, dvrr_stack+1165, NULL);
 tmp = dvrr_stack + 5151;
 target_ptr = Libderiv->deriv2_classes[0][7][117];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  2 0 0 */
 deriv_build_DX_0(Data,45,dvrr_stack+4461, dvrr_stack+1607, NULL);
 tmp = dvrr_stack + 4461;
 target_ptr = Libderiv->deriv2_classes[0][8][117];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+4047, dvrr_stack+2277, dvrr_stack+2262);
 tmp = dvrr_stack + 4047;
 target_ptr = Libderiv->deriv2_classes[0][5][107];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+4068, dvrr_stack+2326, dvrr_stack+2305);
 tmp = dvrr_stack + 4068;
 target_ptr = Libderiv->deriv2_classes[0][6][107];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+3642, dvrr_stack+2362, dvrr_stack+2277);
 tmp = dvrr_stack + 3642;
 target_ptr = Libderiv->deriv2_classes[0][7][107];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 1 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+1603, dvrr_stack+2407, dvrr_stack+2326);
 tmp = dvrr_stack + 1603;
 target_ptr = Libderiv->deriv2_classes[0][8][107];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+1648, dvrr_stack+1742, dvrr_stack+2462);
 tmp = dvrr_stack + 1648;
 target_ptr = Libderiv->deriv2_classes[0][5][106];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+1669, dvrr_stack+1273, dvrr_stack+1770);
 tmp = dvrr_stack + 1669;
 target_ptr = Libderiv->deriv2_classes[0][6][106];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+1697, dvrr_stack+3075, dvrr_stack+1742);
 tmp = dvrr_stack + 1697;
 target_ptr = Libderiv->deriv2_classes[0][7][106];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 1 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+1145, dvrr_stack+3120, dvrr_stack+1273);
 tmp = dvrr_stack + 1145;
 target_ptr = Libderiv->deriv2_classes[0][8][106];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+1190, dvrr_stack+2217, dvrr_stack+1791);
 tmp = dvrr_stack + 1190;
 target_ptr = Libderiv->deriv2_classes[0][5][105];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+1211, dvrr_stack+721, dvrr_stack+784);
 tmp = dvrr_stack + 1211;
 target_ptr = Libderiv->deriv2_classes[0][6][105];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+841, dvrr_stack+1057, dvrr_stack+2217);
 tmp = dvrr_stack + 841;
 target_ptr = Libderiv->deriv2_classes[0][7][105];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  1 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+877, dvrr_stack+1472, dvrr_stack+721);
 tmp = dvrr_stack + 877;
 target_ptr = Libderiv->deriv2_classes[0][8][105];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_h(Data,1,1,dvrr_stack+1239, dvrr_stack+2067, dvrr_stack+2052);
 tmp = dvrr_stack + 1239;
 target_ptr = Libderiv->deriv2_classes[0][5][104];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_i(Data,1,1,dvrr_stack+922, dvrr_stack+2116, dvrr_stack+2095);
 tmp = dvrr_stack + 922;
 target_ptr = Libderiv->deriv2_classes[0][6][104];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_k(Data,1,1,dvrr_stack+2477, dvrr_stack+2152, dvrr_stack+2067);
 tmp = dvrr_stack + 2477;
 target_ptr = Libderiv->deriv2_classes[0][7][104];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 2  0 0 0 */
 deriv_build_CZ_l(Data,1,1,dvrr_stack+2513, dvrr_stack+1527, dvrr_stack+2116);
 tmp = dvrr_stack + 2513;
 target_ptr = Libderiv->deriv2_classes[0][8][104];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+2558, dvrr_stack+2277, dvrr_stack+2262);
 tmp = dvrr_stack + 2558;
 target_ptr = Libderiv->deriv2_classes[0][5][95];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+2579, dvrr_stack+2326, dvrr_stack+2305);
 tmp = dvrr_stack + 2579;
 target_ptr = Libderiv->deriv2_classes[0][6][95];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+2607, dvrr_stack+2362, dvrr_stack+2277);
 tmp = dvrr_stack + 2607;
 target_ptr = Libderiv->deriv2_classes[0][7][95];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 1 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+2643, dvrr_stack+2407, dvrr_stack+2326);
 tmp = dvrr_stack + 2643;
 target_ptr = Libderiv->deriv2_classes[0][8][95];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+2688, dvrr_stack+1742, dvrr_stack+2462);
 tmp = dvrr_stack + 2688;
 target_ptr = Libderiv->deriv2_classes[0][5][94];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+2709, dvrr_stack+1273, dvrr_stack+1770);
 tmp = dvrr_stack + 2709;
 target_ptr = Libderiv->deriv2_classes[0][6][94];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+2737, dvrr_stack+3075, dvrr_stack+1742);
 tmp = dvrr_stack + 2737;
 target_ptr = Libderiv->deriv2_classes[0][7][94];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 1 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+2773, dvrr_stack+3120, dvrr_stack+1273);
 tmp = dvrr_stack + 2773;
 target_ptr = Libderiv->deriv2_classes[0][8][94];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+2818, dvrr_stack+2217, dvrr_stack+1791);
 tmp = dvrr_stack + 2818;
 target_ptr = Libderiv->deriv2_classes[0][5][93];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+2839, dvrr_stack+721, dvrr_stack+784);
 tmp = dvrr_stack + 2839;
 target_ptr = Libderiv->deriv2_classes[0][6][93];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+2867, dvrr_stack+1057, dvrr_stack+2217);
 tmp = dvrr_stack + 2867;
 target_ptr = Libderiv->deriv2_classes[0][7][93];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  1 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+2903, dvrr_stack+1472, dvrr_stack+721);
 tmp = dvrr_stack + 2903;
 target_ptr = Libderiv->deriv2_classes[0][8][93];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+2948, dvrr_stack+2067, dvrr_stack+2052);
 tmp = dvrr_stack + 2948;
 target_ptr = Libderiv->deriv2_classes[0][5][92];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+2969, dvrr_stack+2116, dvrr_stack+2095);
 tmp = dvrr_stack + 2969;
 target_ptr = Libderiv->deriv2_classes[0][6][92];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+2997, dvrr_stack+2152, dvrr_stack+2067);
 tmp = dvrr_stack + 2997;
 target_ptr = Libderiv->deriv2_classes[0][7][92];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 1  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+1806, dvrr_stack+1527, dvrr_stack+2116);
 tmp = dvrr_stack + 1806;
 target_ptr = Libderiv->deriv2_classes[0][8][92];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_h(Data,1,1,dvrr_stack+3033, dvrr_stack+1102, dvrr_stack+2197);
 tmp = dvrr_stack + 3033;
 target_ptr = Libderiv->deriv2_classes[0][5][91];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_i(Data,1,1,dvrr_stack+1851, dvrr_stack+805, dvrr_stack+1582);
 tmp = dvrr_stack + 1851;
 target_ptr = Libderiv->deriv2_classes[0][6][91];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_k(Data,1,1,dvrr_stack+1879, dvrr_stack+3175, dvrr_stack+1102);
 tmp = dvrr_stack + 1879;
 target_ptr = Libderiv->deriv2_classes[0][7][91];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  0 2 0  0 0 0 */
 deriv_build_CY_l(Data,1,1,dvrr_stack+1915, dvrr_stack+3220, dvrr_stack+805);
 tmp = dvrr_stack + 1915;
 target_ptr = Libderiv->deriv2_classes[0][8][91];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+3054, dvrr_stack+2277, dvrr_stack+2262);
 tmp = dvrr_stack + 3054;
 target_ptr = Libderiv->deriv2_classes[0][5][83];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+2245, dvrr_stack+2326, dvrr_stack+2305);
 tmp = dvrr_stack + 2245;
 target_ptr = Libderiv->deriv2_classes[0][6][83];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+1309, dvrr_stack+2362, dvrr_stack+2277);
 tmp = dvrr_stack + 1309;
 target_ptr = Libderiv->deriv2_classes[0][7][83];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 1 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+2362, dvrr_stack+2407, dvrr_stack+2326);
 tmp = dvrr_stack + 2362;
 target_ptr = Libderiv->deriv2_classes[0][8][83];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+2407, dvrr_stack+1742, dvrr_stack+2462);
 tmp = dvrr_stack + 2407;
 target_ptr = Libderiv->deriv2_classes[0][5][82];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+2428, dvrr_stack+1273, dvrr_stack+1770);
 tmp = dvrr_stack + 2428;
 target_ptr = Libderiv->deriv2_classes[0][6][82];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+2273, dvrr_stack+3075, dvrr_stack+1742);
 tmp = dvrr_stack + 2273;
 target_ptr = Libderiv->deriv2_classes[0][7][82];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 1 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+3075, dvrr_stack+3120, dvrr_stack+1273);
 tmp = dvrr_stack + 3075;
 target_ptr = Libderiv->deriv2_classes[0][8][82];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+2456, dvrr_stack+2217, dvrr_stack+1791);
 tmp = dvrr_stack + 2456;
 target_ptr = Libderiv->deriv2_classes[0][5][81];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+3120, dvrr_stack+721, dvrr_stack+784);
 tmp = dvrr_stack + 3120;
 target_ptr = Libderiv->deriv2_classes[0][6][81];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+1733, dvrr_stack+1057, dvrr_stack+2217);
 tmp = dvrr_stack + 1733;
 target_ptr = Libderiv->deriv2_classes[0][7][81];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  1 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+1260, dvrr_stack+1472, dvrr_stack+721);
 tmp = dvrr_stack + 1260;
 target_ptr = Libderiv->deriv2_classes[0][8][81];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+3148, dvrr_stack+2067, dvrr_stack+2052);
 tmp = dvrr_stack + 3148;
 target_ptr = Libderiv->deriv2_classes[0][5][80];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+713, dvrr_stack+2116, dvrr_stack+2095);
 tmp = dvrr_stack + 713;
 target_ptr = Libderiv->deriv2_classes[0][6][80];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+1769, dvrr_stack+2152, dvrr_stack+2067);
 tmp = dvrr_stack + 1769;
 target_ptr = Libderiv->deriv2_classes[0][7][80];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 1  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+2152, dvrr_stack+1527, dvrr_stack+2116);
 tmp = dvrr_stack + 2152;
 target_ptr = Libderiv->deriv2_classes[0][8][80];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+2049, dvrr_stack+1102, dvrr_stack+2197);
 tmp = dvrr_stack + 2049;
 target_ptr = Libderiv->deriv2_classes[0][5][79];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+2197, dvrr_stack+805, dvrr_stack+1582);
 tmp = dvrr_stack + 2197;
 target_ptr = Libderiv->deriv2_classes[0][6][79];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+2070, dvrr_stack+3175, dvrr_stack+1102);
 tmp = dvrr_stack + 2070;
 target_ptr = Libderiv->deriv2_classes[0][7][79];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  1 1 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+3169, dvrr_stack+3220, dvrr_stack+805);
 tmp = dvrr_stack + 3169;
 target_ptr = Libderiv->deriv2_classes[0][8][79];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_h(Data,1,1,dvrr_stack+3214, dvrr_stack+952, dvrr_stack+1130);
 tmp = dvrr_stack + 3214;
 target_ptr = Libderiv->deriv2_classes[0][5][78];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_i(Data,1,1,dvrr_stack+3235, dvrr_stack+3275, dvrr_stack+757);
 tmp = dvrr_stack + 3235;
 target_ptr = Libderiv->deriv2_classes[0][6][78];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_k(Data,1,1,dvrr_stack+741, dvrr_stack+3311, dvrr_stack+952);
 tmp = dvrr_stack + 741;
 target_ptr = Libderiv->deriv2_classes[0][7][78];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 0  0 0 0  2 0 0  0 0 0 */
 deriv_build_CX_l(Data,1,1,dvrr_stack+3311, dvrr_stack+3356, dvrr_stack+3275);
 tmp = dvrr_stack + 3311;
 target_ptr = Libderiv->deriv2_classes[0][8][78];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,21,dvrr_stack+3356, dvrr_stack+3684, NULL);
 tmp = dvrr_stack + 3356;
 target_ptr = Libderiv->deriv2_classes[0][5][35];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,28,dvrr_stack+3377, dvrr_stack+4107, NULL);
 tmp = dvrr_stack + 3377;
 target_ptr = Libderiv->deriv2_classes[0][6][35];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,36,dvrr_stack+3263, dvrr_stack+4515, NULL);
 tmp = dvrr_stack + 3263;
 target_ptr = Libderiv->deriv2_classes[0][7][35];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 1 */
 deriv_build_AZ_0(Data,45,dvrr_stack+777, dvrr_stack+5193, NULL);
 tmp = dvrr_stack + 777;
 target_ptr = Libderiv->deriv2_classes[0][8][35];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+2106, dvrr_stack+5328, NULL);
 tmp = dvrr_stack + 2106;
 target_ptr = Libderiv->deriv2_classes[0][5][34];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+950, dvrr_stack+5391, NULL);
 tmp = dvrr_stack + 950;
 target_ptr = Libderiv->deriv2_classes[0][6][34];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+978, dvrr_stack+5475, NULL);
 tmp = dvrr_stack + 978;
 target_ptr = Libderiv->deriv2_classes[0][7][34];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 1 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+1014, dvrr_stack+5583, NULL);
 tmp = dvrr_stack + 1014;
 target_ptr = Libderiv->deriv2_classes[0][8][34];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+2127, dvrr_stack+5718, NULL);
 tmp = dvrr_stack + 2127;
 target_ptr = Libderiv->deriv2_classes[0][5][33];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+1059, dvrr_stack+3495, NULL);
 tmp = dvrr_stack + 1059;
 target_ptr = Libderiv->deriv2_classes[0][6][33];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+1087, dvrr_stack+3855, NULL);
 tmp = dvrr_stack + 1087;
 target_ptr = Libderiv->deriv2_classes[0][7][33];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  1 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+2309, dvrr_stack+4191, NULL);
 tmp = dvrr_stack + 2309;
 target_ptr = Libderiv->deriv2_classes[0][8][33];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+1123, dvrr_stack+4833, NULL);
 tmp = dvrr_stack + 1123;
 target_ptr = Libderiv->deriv2_classes[0][5][32];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+1345, dvrr_stack+4896, NULL);
 tmp = dvrr_stack + 1345;
 target_ptr = Libderiv->deriv2_classes[0][6][32];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+1373, dvrr_stack+4980, NULL);
 tmp = dvrr_stack + 1373;
 target_ptr = Libderiv->deriv2_classes[0][7][32];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 1  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+1409, dvrr_stack+4326, NULL);
 tmp = dvrr_stack + 1409;
 target_ptr = Libderiv->deriv2_classes[0][8][32];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+1960, dvrr_stack+5088, NULL);
 tmp = dvrr_stack + 1960;
 target_ptr = Libderiv->deriv2_classes[0][5][31];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+1454, dvrr_stack+3963, NULL);
 tmp = dvrr_stack + 1454;
 target_ptr = Libderiv->deriv2_classes[0][6][31];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+1482, dvrr_stack+5781, NULL);
 tmp = dvrr_stack + 1482;
 target_ptr = Libderiv->deriv2_classes[0][7][31];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  0 1 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+1518, dvrr_stack+5889, NULL);
 tmp = dvrr_stack + 1518;
 target_ptr = Libderiv->deriv2_classes[0][8][31];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+1563, dvrr_stack+1986, NULL);
 tmp = dvrr_stack + 1563;
 target_ptr = Libderiv->deriv_classes[0][5][2];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+7464, dvrr_stack+3579, NULL);
 tmp = dvrr_stack + 7464;
 target_ptr = Libderiv->deriv2_classes[0][5][30];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+7485, dvrr_stack+3411, NULL);
 tmp = dvrr_stack + 7485;
 target_ptr = Libderiv->deriv_classes[0][6][2];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+7513, dvrr_stack+6024, NULL);
 tmp = dvrr_stack + 7513;
 target_ptr = Libderiv->deriv2_classes[0][6][30];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+7541, dvrr_stack+3747, NULL);
 tmp = dvrr_stack + 7541;
 target_ptr = Libderiv->deriv_classes[0][7][2];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+7577, dvrr_stack+6108, NULL);
 tmp = dvrr_stack + 7577;
 target_ptr = Libderiv->deriv2_classes[0][7][30];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 1  0 0 0  1 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+7613, dvrr_stack+6216, NULL);
 tmp = dvrr_stack + 7613;
 target_ptr = Libderiv->deriv2_classes[0][8][30];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,21,dvrr_stack+7658, dvrr_stack+4731, NULL);
 tmp = dvrr_stack + 7658;
 target_ptr = Libderiv->deriv2_classes[0][5][26];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,28,dvrr_stack+7679, dvrr_stack+4623, NULL);
 tmp = dvrr_stack + 7679;
 target_ptr = Libderiv->deriv2_classes[0][6][26];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,36,dvrr_stack+7707, dvrr_stack+108, NULL);
 tmp = dvrr_stack + 7707;
 target_ptr = Libderiv->deriv2_classes[0][7][26];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 0 2  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_0(Data,45,dvrr_stack+7743, dvrr_stack+6861, NULL);
 tmp = dvrr_stack + 7743;
 target_ptr = Libderiv->deriv2_classes[0][8][26];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,21,dvrr_stack+7788, dvrr_stack+3684, NULL);
 tmp = dvrr_stack + 7788;
 target_ptr = Libderiv->deriv2_classes[0][5][23];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,28,dvrr_stack+7809, dvrr_stack+4107, NULL);
 tmp = dvrr_stack + 7809;
 target_ptr = Libderiv->deriv2_classes[0][6][23];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,36,dvrr_stack+7837, dvrr_stack+4515, NULL);
 tmp = dvrr_stack + 7837;
 target_ptr = Libderiv->deriv2_classes[0][7][23];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AY_0(Data,45,dvrr_stack+7873, dvrr_stack+5193, NULL);
 tmp = dvrr_stack + 7873;
 target_ptr = Libderiv->deriv2_classes[0][8][23];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+7918, dvrr_stack+5328, NULL);
 tmp = dvrr_stack + 7918;
 target_ptr = Libderiv->deriv2_classes[0][5][22];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+7939, dvrr_stack+5391, NULL);
 tmp = dvrr_stack + 7939;
 target_ptr = Libderiv->deriv2_classes[0][6][22];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+7967, dvrr_stack+5475, NULL);
 tmp = dvrr_stack + 7967;
 target_ptr = Libderiv->deriv2_classes[0][7][22];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+8003, dvrr_stack+5583, NULL);
 tmp = dvrr_stack + 8003;
 target_ptr = Libderiv->deriv2_classes[0][8][22];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+8048, dvrr_stack+5718, NULL);
 tmp = dvrr_stack + 8048;
 target_ptr = Libderiv->deriv2_classes[0][5][21];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+8069, dvrr_stack+3495, NULL);
 tmp = dvrr_stack + 8069;
 target_ptr = Libderiv->deriv2_classes[0][6][21];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+8097, dvrr_stack+3855, NULL);
 tmp = dvrr_stack + 8097;
 target_ptr = Libderiv->deriv2_classes[0][7][21];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+8133, dvrr_stack+4191, NULL);
 tmp = dvrr_stack + 8133;
 target_ptr = Libderiv->deriv2_classes[0][8][21];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+8178, dvrr_stack+4833, NULL);
 tmp = dvrr_stack + 8178;
 target_ptr = Libderiv->deriv2_classes[0][5][20];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+8199, dvrr_stack+4896, NULL);
 tmp = dvrr_stack + 8199;
 target_ptr = Libderiv->deriv2_classes[0][6][20];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+8227, dvrr_stack+4980, NULL);
 tmp = dvrr_stack + 8227;
 target_ptr = Libderiv->deriv2_classes[0][7][20];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+8263, dvrr_stack+4326, NULL);
 tmp = dvrr_stack + 8263;
 target_ptr = Libderiv->deriv2_classes[0][8][20];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+8308, dvrr_stack+5088, NULL);
 tmp = dvrr_stack + 8308;
 target_ptr = Libderiv->deriv2_classes[0][5][19];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+8329, dvrr_stack+3963, NULL);
 tmp = dvrr_stack + 8329;
 target_ptr = Libderiv->deriv2_classes[0][6][19];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+8357, dvrr_stack+5781, NULL);
 tmp = dvrr_stack + 8357;
 target_ptr = Libderiv->deriv2_classes[0][7][19];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+8393, dvrr_stack+5889, NULL);
 tmp = dvrr_stack + 8393;
 target_ptr = Libderiv->deriv2_classes[0][8][19];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+8438, dvrr_stack+1986, NULL);
 tmp = dvrr_stack + 8438;
 target_ptr = Libderiv->deriv_classes[0][5][1];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+8459, dvrr_stack+3579, NULL);
 tmp = dvrr_stack + 8459;
 target_ptr = Libderiv->deriv2_classes[0][5][18];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+8480, dvrr_stack+3411, NULL);
 tmp = dvrr_stack + 8480;
 target_ptr = Libderiv->deriv_classes[0][6][1];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+8508, dvrr_stack+6024, NULL);
 tmp = dvrr_stack + 8508;
 target_ptr = Libderiv->deriv2_classes[0][6][18];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+8536, dvrr_stack+3747, NULL);
 tmp = dvrr_stack + 8536;
 target_ptr = Libderiv->deriv_classes[0][7][1];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+8572, dvrr_stack+6108, NULL);
 tmp = dvrr_stack + 8572;
 target_ptr = Libderiv->deriv2_classes[0][7][18];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+8608, dvrr_stack+6216, NULL);
 tmp = dvrr_stack + 8608;
 target_ptr = Libderiv->deriv2_classes[0][8][18];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+8653, dvrr_stack+4731, NULL);
 tmp = dvrr_stack + 8653;
 target_ptr = Libderiv->deriv2_classes[0][5][14];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+8674, dvrr_stack+4623, NULL);
 tmp = dvrr_stack + 8674;
 target_ptr = Libderiv->deriv2_classes[0][6][14];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+8702, dvrr_stack+108, NULL);
 tmp = dvrr_stack + 8702;
 target_ptr = Libderiv->deriv2_classes[0][7][14];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 1 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+8738, dvrr_stack+6861, NULL);
 tmp = dvrr_stack + 8738;
 target_ptr = Libderiv->deriv2_classes[0][8][14];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,21,dvrr_stack+8783, dvrr_stack+0, NULL);
 tmp = dvrr_stack + 8783;
 target_ptr = Libderiv->deriv2_classes[0][5][13];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,28,dvrr_stack+8804, dvrr_stack+216, NULL);
 tmp = dvrr_stack + 8804;
 target_ptr = Libderiv->deriv2_classes[0][6][13];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,36,dvrr_stack+8832, dvrr_stack+300, NULL);
 tmp = dvrr_stack + 8832;
 target_ptr = Libderiv->deriv2_classes[0][7][13];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 0 2 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_0(Data,45,dvrr_stack+8868, dvrr_stack+7266, NULL);
 tmp = dvrr_stack + 8868;
 target_ptr = Libderiv->deriv2_classes[0][8][13];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,21,dvrr_stack+8913, dvrr_stack+3684, NULL);
 tmp = dvrr_stack + 8913;
 target_ptr = Libderiv->deriv2_classes[0][5][11];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,28,dvrr_stack+3678, dvrr_stack+4107, NULL);
 tmp = dvrr_stack + 3678;
 target_ptr = Libderiv->deriv2_classes[0][6][11];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,36,dvrr_stack+4096, dvrr_stack+4515, NULL);
 tmp = dvrr_stack + 4096;
 target_ptr = Libderiv->deriv2_classes[0][7][11];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_AX_0(Data,45,dvrr_stack+4506, dvrr_stack+5193, NULL);
 tmp = dvrr_stack + 4506;
 target_ptr = Libderiv->deriv2_classes[0][8][11];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+5187, dvrr_stack+5328, NULL);
 tmp = dvrr_stack + 5187;
 target_ptr = Libderiv->deriv2_classes[0][5][10];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+5208, dvrr_stack+5391, NULL);
 tmp = dvrr_stack + 5208;
 target_ptr = Libderiv->deriv2_classes[0][6][10];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+5236, dvrr_stack+5475, NULL);
 tmp = dvrr_stack + 5236;
 target_ptr = Libderiv->deriv2_classes[0][7][10];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+5272, dvrr_stack+5583, NULL);
 tmp = dvrr_stack + 5272;
 target_ptr = Libderiv->deriv2_classes[0][8][10];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+5317, dvrr_stack+5718, NULL);
 tmp = dvrr_stack + 5317;
 target_ptr = Libderiv->deriv2_classes[0][5][9];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+5338, dvrr_stack+3495, NULL);
 tmp = dvrr_stack + 5338;
 target_ptr = Libderiv->deriv2_classes[0][6][9];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+3495, dvrr_stack+3855, NULL);
 tmp = dvrr_stack + 3495;
 target_ptr = Libderiv->deriv2_classes[0][7][9];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+3855, dvrr_stack+4191, NULL);
 tmp = dvrr_stack + 3855;
 target_ptr = Libderiv->deriv2_classes[0][8][9];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+3900, dvrr_stack+4833, NULL);
 tmp = dvrr_stack + 3900;
 target_ptr = Libderiv->deriv2_classes[0][5][8];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+3921, dvrr_stack+4896, NULL);
 tmp = dvrr_stack + 3921;
 target_ptr = Libderiv->deriv2_classes[0][6][8];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+3531, dvrr_stack+4980, NULL);
 tmp = dvrr_stack + 3531;
 target_ptr = Libderiv->deriv2_classes[0][7][8];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+4822, dvrr_stack+4326, NULL);
 tmp = dvrr_stack + 4822;
 target_ptr = Libderiv->deriv2_classes[0][8][8];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+4867, dvrr_stack+5088, NULL);
 tmp = dvrr_stack + 4867;
 target_ptr = Libderiv->deriv2_classes[0][5][7];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+4888, dvrr_stack+3963, NULL);
 tmp = dvrr_stack + 4888;
 target_ptr = Libderiv->deriv2_classes[0][6][7];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+3949, dvrr_stack+5781, NULL);
 tmp = dvrr_stack + 3949;
 target_ptr = Libderiv->deriv2_classes[0][7][7];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+3985, dvrr_stack+5889, NULL);
 tmp = dvrr_stack + 3985;
 target_ptr = Libderiv->deriv2_classes[0][8][7];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+4916, dvrr_stack+1986, NULL);
 tmp = dvrr_stack + 4916;
 target_ptr = Libderiv->deriv_classes[0][5][0];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+4937, dvrr_stack+3579, NULL);
 tmp = dvrr_stack + 4937;
 target_ptr = Libderiv->deriv2_classes[0][5][6];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+3567, dvrr_stack+3411, NULL);
 tmp = dvrr_stack + 3567;
 target_ptr = Libderiv->deriv_classes[0][6][0];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+3595, dvrr_stack+6024, NULL);
 tmp = dvrr_stack + 3595;
 target_ptr = Libderiv->deriv2_classes[0][6][6];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+3405, dvrr_stack+3747, NULL);
 tmp = dvrr_stack + 3405;
 target_ptr = Libderiv->deriv_classes[0][7][0];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+3441, dvrr_stack+6108, NULL);
 tmp = dvrr_stack + 3441;
 target_ptr = Libderiv->deriv2_classes[0][7][6];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+4958, dvrr_stack+6216, NULL);
 tmp = dvrr_stack + 4958;
 target_ptr = Libderiv->deriv2_classes[0][8][6];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+5003, dvrr_stack+4731, NULL);
 tmp = dvrr_stack + 5003;
 target_ptr = Libderiv->deriv2_classes[0][5][2];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+4728, dvrr_stack+4623, NULL);
 tmp = dvrr_stack + 4728;
 target_ptr = Libderiv->deriv2_classes[0][6][2];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+4756, dvrr_stack+108, NULL);
 tmp = dvrr_stack + 4756;
 target_ptr = Libderiv->deriv2_classes[0][7][2];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+108, dvrr_stack+6861, NULL);
 tmp = dvrr_stack + 108;
 target_ptr = Libderiv->deriv2_classes[0][8][2];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+153, dvrr_stack+0, NULL);
 tmp = dvrr_stack + 153;
 target_ptr = Libderiv->deriv2_classes[0][5][1];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+0, dvrr_stack+216, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv2_classes[0][6][1];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+174, dvrr_stack+300, NULL);
 tmp = dvrr_stack + 174;
 target_ptr = Libderiv->deriv2_classes[0][7][1];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 1 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+210, dvrr_stack+7266, NULL);
 tmp = dvrr_stack + 210;
 target_ptr = Libderiv->deriv2_classes[0][8][1];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 5 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,21,dvrr_stack+28, dvrr_stack+7401, NULL);
 tmp = dvrr_stack + 28;
 target_ptr = Libderiv->deriv2_classes[0][5][0];
 for(i=0;i<21;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 6 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,28,dvrr_stack+255, dvrr_stack+6351, NULL);
 tmp = dvrr_stack + 255;
 target_ptr = Libderiv->deriv2_classes[0][6][0];
 for(i=0;i<28;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,36,dvrr_stack+283, dvrr_stack+6435, NULL);
 tmp = dvrr_stack + 283;
 target_ptr = Libderiv->deriv2_classes[0][7][0];
 for(i=0;i<36;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 8 0) m=0 deriv level 2 */
 /* deriv_ind: 2 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_0(Data,45,dvrr_stack+319, dvrr_stack+6543, NULL);
 tmp = dvrr_stack + 319;
 target_ptr = Libderiv->deriv2_classes[0][8][0];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];


}

