/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_idih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (id|ih) integrals */

void d1hrr_order_idih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][6][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][11] = int_stack + 784;
 Libderiv->deriv_classes[6][8][11] = int_stack + 1792;
 Libderiv->deriv_classes[6][9][11] = int_stack + 3052;
 Libderiv->deriv_classes[6][10][11] = int_stack + 4592;
 Libderiv->deriv_classes[6][11][11] = int_stack + 6440;
 Libderiv->deriv_classes[7][6][11] = int_stack + 8624;
 Libderiv->deriv_classes[7][7][11] = int_stack + 9632;
 Libderiv->deriv_classes[7][8][11] = int_stack + 10928;
 Libderiv->deriv_classes[7][9][11] = int_stack + 12548;
 Libderiv->deriv_classes[7][10][11] = int_stack + 14528;
 Libderiv->deriv_classes[7][11][11] = int_stack + 16904;
 Libderiv->deriv_classes[8][6][11] = int_stack + 19712;
 Libderiv->deriv_classes[8][7][11] = int_stack + 20972;
 Libderiv->deriv_classes[8][8][11] = int_stack + 22592;
 Libderiv->deriv_classes[8][9][11] = int_stack + 24617;
 Libderiv->deriv_classes[8][10][11] = int_stack + 27092;
 Libderiv->deriv_classes[8][11][11] = int_stack + 30062;
 Libderiv->deriv_classes[6][6][10] = int_stack + 33572;
 Libderiv->deriv_classes[6][7][10] = int_stack + 34356;
 Libderiv->deriv_classes[6][8][10] = int_stack + 35364;
 Libderiv->deriv_classes[6][9][10] = int_stack + 36624;
 Libderiv->deriv_classes[6][10][10] = int_stack + 38164;
 Libderiv->deriv_classes[6][11][10] = int_stack + 40012;
 Libderiv->deriv_classes[7][6][10] = int_stack + 42196;
 Libderiv->deriv_classes[7][7][10] = int_stack + 43204;
 Libderiv->deriv_classes[7][8][10] = int_stack + 44500;
 Libderiv->deriv_classes[7][9][10] = int_stack + 46120;
 Libderiv->deriv_classes[7][10][10] = int_stack + 48100;
 Libderiv->deriv_classes[7][11][10] = int_stack + 50476;
 Libderiv->deriv_classes[8][6][10] = int_stack + 53284;
 Libderiv->deriv_classes[8][7][10] = int_stack + 54544;
 Libderiv->deriv_classes[8][8][10] = int_stack + 56164;
 Libderiv->deriv_classes[8][9][10] = int_stack + 58189;
 Libderiv->deriv_classes[8][10][10] = int_stack + 60664;
 Libderiv->deriv_classes[8][11][10] = int_stack + 63634;
 Libderiv->deriv_classes[6][6][9] = int_stack + 67144;
 Libderiv->deriv_classes[6][7][9] = int_stack + 67928;
 Libderiv->deriv_classes[6][8][9] = int_stack + 68936;
 Libderiv->deriv_classes[6][9][9] = int_stack + 70196;
 Libderiv->deriv_classes[6][10][9] = int_stack + 71736;
 Libderiv->deriv_classes[6][11][9] = int_stack + 73584;
 Libderiv->deriv_classes[7][6][9] = int_stack + 75768;
 Libderiv->deriv_classes[7][7][9] = int_stack + 76776;
 Libderiv->deriv_classes[7][8][9] = int_stack + 78072;
 Libderiv->deriv_classes[7][9][9] = int_stack + 79692;
 Libderiv->deriv_classes[7][10][9] = int_stack + 81672;
 Libderiv->deriv_classes[7][11][9] = int_stack + 84048;
 Libderiv->deriv_classes[8][6][9] = int_stack + 86856;
 Libderiv->deriv_classes[8][7][9] = int_stack + 88116;
 Libderiv->deriv_classes[8][8][9] = int_stack + 89736;
 Libderiv->deriv_classes[8][9][9] = int_stack + 91761;
 Libderiv->deriv_classes[8][10][9] = int_stack + 94236;
 Libderiv->deriv_classes[8][11][9] = int_stack + 97206;
 Libderiv->deriv_classes[6][6][8] = int_stack + 100716;
 Libderiv->deriv_classes[6][7][8] = int_stack + 101500;
 Libderiv->deriv_classes[6][8][8] = int_stack + 102508;
 Libderiv->deriv_classes[6][9][8] = int_stack + 103768;
 Libderiv->deriv_classes[6][10][8] = int_stack + 105308;
 Libderiv->deriv_classes[6][11][8] = int_stack + 107156;
 Libderiv->deriv_classes[7][6][8] = int_stack + 109340;
 Libderiv->deriv_classes[7][7][8] = int_stack + 110348;
 Libderiv->deriv_classes[7][8][8] = int_stack + 111644;
 Libderiv->deriv_classes[7][9][8] = int_stack + 113264;
 Libderiv->deriv_classes[7][10][8] = int_stack + 115244;
 Libderiv->deriv_classes[7][11][8] = int_stack + 117620;
 Libderiv->deriv_classes[8][6][8] = int_stack + 120428;
 Libderiv->deriv_classes[8][7][8] = int_stack + 121688;
 Libderiv->deriv_classes[8][8][8] = int_stack + 123308;
 Libderiv->deriv_classes[8][9][8] = int_stack + 125333;
 Libderiv->deriv_classes[8][10][8] = int_stack + 127808;
 Libderiv->deriv_classes[8][11][8] = int_stack + 130778;
 Libderiv->deriv_classes[6][6][7] = int_stack + 134288;
 Libderiv->deriv_classes[6][7][7] = int_stack + 135072;
 Libderiv->deriv_classes[6][8][7] = int_stack + 136080;
 Libderiv->deriv_classes[6][9][7] = int_stack + 137340;
 Libderiv->deriv_classes[6][10][7] = int_stack + 138880;
 Libderiv->deriv_classes[6][11][7] = int_stack + 140728;
 Libderiv->deriv_classes[7][6][7] = int_stack + 142912;
 Libderiv->deriv_classes[7][7][7] = int_stack + 143920;
 Libderiv->deriv_classes[7][8][7] = int_stack + 145216;
 Libderiv->deriv_classes[7][9][7] = int_stack + 146836;
 Libderiv->deriv_classes[7][10][7] = int_stack + 148816;
 Libderiv->deriv_classes[7][11][7] = int_stack + 151192;
 Libderiv->deriv_classes[8][6][7] = int_stack + 154000;
 Libderiv->deriv_classes[8][7][7] = int_stack + 155260;
 Libderiv->deriv_classes[8][8][7] = int_stack + 156880;
 Libderiv->deriv_classes[8][9][7] = int_stack + 158905;
 Libderiv->deriv_classes[8][10][7] = int_stack + 161380;
 Libderiv->deriv_classes[8][11][7] = int_stack + 164350;
 Libderiv->deriv_classes[6][6][6] = int_stack + 167860;
 Libderiv->deriv_classes[6][7][6] = int_stack + 168644;
 Libderiv->deriv_classes[6][8][6] = int_stack + 169652;
 Libderiv->deriv_classes[6][9][6] = int_stack + 170912;
 Libderiv->deriv_classes[6][10][6] = int_stack + 172452;
 Libderiv->deriv_classes[6][11][6] = int_stack + 174300;
 Libderiv->deriv_classes[7][6][6] = int_stack + 176484;
 Libderiv->deriv_classes[7][7][6] = int_stack + 177492;
 Libderiv->deriv_classes[7][8][6] = int_stack + 178788;
 Libderiv->deriv_classes[7][9][6] = int_stack + 180408;
 Libderiv->deriv_classes[7][10][6] = int_stack + 182388;
 Libderiv->deriv_classes[7][11][6] = int_stack + 184764;
 Libderiv->dvrr_classes[8][6] = int_stack + 187572;
 Libderiv->deriv_classes[8][6][6] = int_stack + 188832;
 Libderiv->dvrr_classes[8][7] = int_stack + 190092;
 Libderiv->deriv_classes[8][7][6] = int_stack + 191712;
 Libderiv->dvrr_classes[8][8] = int_stack + 193332;
 Libderiv->deriv_classes[8][8][6] = int_stack + 195357;
 Libderiv->dvrr_classes[8][9] = int_stack + 197382;
 Libderiv->deriv_classes[8][9][6] = int_stack + 199857;
 Libderiv->dvrr_classes[8][10] = int_stack + 202332;
 Libderiv->deriv_classes[8][10][6] = int_stack + 205302;
 Libderiv->deriv_classes[8][11][6] = int_stack + 208272;
 Libderiv->deriv_classes[6][6][2] = int_stack + 211782;
 Libderiv->deriv_classes[6][7][2] = int_stack + 212566;
 Libderiv->deriv_classes[6][8][2] = int_stack + 213574;
 Libderiv->deriv_classes[6][9][2] = int_stack + 214834;
 Libderiv->deriv_classes[6][10][2] = int_stack + 216374;
 Libderiv->deriv_classes[6][11][2] = int_stack + 218222;
 Libderiv->deriv_classes[7][6][2] = int_stack + 220406;
 Libderiv->deriv_classes[7][7][2] = int_stack + 221414;
 Libderiv->deriv_classes[7][8][2] = int_stack + 222710;
 Libderiv->deriv_classes[7][9][2] = int_stack + 224330;
 Libderiv->deriv_classes[7][10][2] = int_stack + 226310;
 Libderiv->deriv_classes[7][11][2] = int_stack + 228686;
 Libderiv->deriv_classes[8][6][2] = int_stack + 231494;
 Libderiv->deriv_classes[8][7][2] = int_stack + 232754;
 Libderiv->deriv_classes[8][8][2] = int_stack + 234374;
 Libderiv->deriv_classes[8][9][2] = int_stack + 236399;
 Libderiv->deriv_classes[8][10][2] = int_stack + 238874;
 Libderiv->deriv_classes[8][11][2] = int_stack + 241844;
 Libderiv->deriv_classes[6][6][1] = int_stack + 245354;
 Libderiv->deriv_classes[6][7][1] = int_stack + 246138;
 Libderiv->deriv_classes[6][8][1] = int_stack + 247146;
 Libderiv->deriv_classes[6][9][1] = int_stack + 248406;
 Libderiv->deriv_classes[6][10][1] = int_stack + 249946;
 Libderiv->deriv_classes[6][11][1] = int_stack + 251794;
 Libderiv->deriv_classes[7][6][1] = int_stack + 253978;
 Libderiv->deriv_classes[7][7][1] = int_stack + 254986;
 Libderiv->deriv_classes[7][8][1] = int_stack + 256282;
 Libderiv->deriv_classes[7][9][1] = int_stack + 257902;
 Libderiv->deriv_classes[7][10][1] = int_stack + 259882;
 Libderiv->deriv_classes[7][11][1] = int_stack + 262258;
 Libderiv->deriv_classes[8][6][1] = int_stack + 265066;
 Libderiv->deriv_classes[8][7][1] = int_stack + 266326;
 Libderiv->deriv_classes[8][8][1] = int_stack + 267946;
 Libderiv->deriv_classes[8][9][1] = int_stack + 269971;
 Libderiv->deriv_classes[8][10][1] = int_stack + 272446;
 Libderiv->deriv_classes[8][11][1] = int_stack + 275416;
 Libderiv->dvrr_classes[6][6] = int_stack + 278926;
 Libderiv->dvrr_classes[6][7] = int_stack + 279710;
 Libderiv->dvrr_classes[6][8] = int_stack + 280718;
 Libderiv->dvrr_classes[6][9] = int_stack + 281978;
 Libderiv->dvrr_classes[6][10] = int_stack + 283518;
 Libderiv->dvrr_classes[6][11] = int_stack + 285366;
 Libderiv->deriv_classes[6][6][0] = int_stack + 287550;
 Libderiv->deriv_classes[6][7][0] = int_stack + 288334;
 Libderiv->deriv_classes[6][8][0] = int_stack + 289342;
 Libderiv->deriv_classes[6][9][0] = int_stack + 290602;
 Libderiv->deriv_classes[6][10][0] = int_stack + 292142;
 Libderiv->deriv_classes[6][11][0] = int_stack + 293990;
 Libderiv->dvrr_classes[7][6] = int_stack + 296174;
 Libderiv->dvrr_classes[7][7] = int_stack + 297182;
 Libderiv->dvrr_classes[7][8] = int_stack + 298478;
 Libderiv->dvrr_classes[7][9] = int_stack + 300098;
 Libderiv->dvrr_classes[7][10] = int_stack + 302078;
 Libderiv->dvrr_classes[7][11] = int_stack + 304454;
 Libderiv->deriv_classes[7][6][0] = int_stack + 307262;
 Libderiv->deriv_classes[7][7][0] = int_stack + 308270;
 Libderiv->deriv_classes[7][8][0] = int_stack + 309566;
 Libderiv->deriv_classes[7][9][0] = int_stack + 311186;
 Libderiv->deriv_classes[7][10][0] = int_stack + 313166;
 Libderiv->deriv_classes[7][11][0] = int_stack + 315542;
 Libderiv->deriv_classes[8][6][0] = int_stack + 318350;
 Libderiv->deriv_classes[8][7][0] = int_stack + 319610;
 Libderiv->deriv_classes[8][8][0] = int_stack + 321230;
 Libderiv->deriv_classes[8][9][0] = int_stack + 323255;
 Libderiv->deriv_classes[8][10][0] = int_stack + 325730;
 Libderiv->deriv_classes[8][11][0] = int_stack + 328700;
 memset(int_stack,0,2657680);

 Libderiv->dvrr_stack = int_stack + 1538133;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_idih(Libderiv, Data);
   Data++;
 }

 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+332210,int_stack+279710,int_stack+278926,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+334562,int_stack+280718,int_stack+279710,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+337586,int_stack+334562,int_stack+332210,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+342290,int_stack+281978,int_stack+280718,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+346070,int_stack+342290,int_stack+334562,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+352118,int_stack+346070,int_stack+337586,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+359958,int_stack+283518,int_stack+281978,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+364578,int_stack+359958,int_stack+342290,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+372138,int_stack+364578,int_stack+346070,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+382218,int_stack+372138,int_stack+352118,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+393978,int_stack+784,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278926,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+396330,int_stack+1792,int_stack+784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279710,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+399354,int_stack+396330,int_stack+393978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332210,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+404058,int_stack+3052,int_stack+1792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280718,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+407838,int_stack+404058,int_stack+396330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334562,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+413886,int_stack+407838,int_stack+399354, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337586,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+393978,int_stack+4592,int_stack+3052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281978,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+421726,int_stack+393978,int_stack+404058, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342290,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+429286,int_stack+421726,int_stack+407838, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346070,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+398598,int_stack+429286,int_stack+413886, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352118,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+410358,int_stack+6440,int_stack+4592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283518,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+439366,int_stack+410358,int_stack+393978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359958,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+448606,int_stack+439366,int_stack+421726, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364578,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+410358,int_stack+448606,int_stack+429286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+372138,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+425478,int_stack+410358,int_stack+398598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382218,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+393978,int_stack+297182,int_stack+296174,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+397002,int_stack+298478,int_stack+297182,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+400890,int_stack+397002,int_stack+393978,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+406938,int_stack+300098,int_stack+298478,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+411798,int_stack+406938,int_stack+397002,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+441942,int_stack+411798,int_stack+400890,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+452022,int_stack+302078,int_stack+300098,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+457962,int_stack+452022,int_stack+406938,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+467682,int_stack+457962,int_stack+411798,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+480642,int_stack+467682,int_stack+441942,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+419574,int_stack+9632,int_stack+8624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296174,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+10928,int_stack+9632, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297182,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+3888,int_stack+0,int_stack+419574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393978,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+419574,int_stack+12548,int_stack+10928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298478,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+495762,int_stack+419574,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397002,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+503538,int_stack+495762,int_stack+3888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400890,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+14528,int_stack+12548, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300098,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+513618,int_stack+0,int_stack+419574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406938,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+523338,int_stack+513618,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411798,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+536298,int_stack+523338,int_stack+503538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441942,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+495762,int_stack+16904,int_stack+14528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302078,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+5940,int_stack+495762,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452022,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+495762,int_stack+5940,int_stack+513618, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457962,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+0,int_stack+495762,int_stack+523338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467682,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+495762,int_stack+0,int_stack+536298, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480642,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+516930,int_stack+495762,int_stack+425478,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+190092,int_stack+187572,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3780,int_stack+193332,int_stack+190092,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8640,int_stack+3780,int_stack+0,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+419574,int_stack+197382,int_stack+193332,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+425649,int_stack+419574,int_stack+3780,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+566322,int_stack+425649,int_stack+8640,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+578922,int_stack+202332,int_stack+197382,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+586347,int_stack+578922,int_stack+419574,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+598497,int_stack+586347,int_stack+425649,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+614697,int_stack+598497,int_stack+566322,45);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435369,int_stack+20972,int_stack+19712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187572,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+633597,int_stack+22592,int_stack+20972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190092,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+638457,int_stack+633597,int_stack+435369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+435369,int_stack+24617,int_stack+22592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193332,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+646017,int_stack+435369,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+655737,int_stack+646017,int_stack+638457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+633597,int_stack+27092,int_stack+24617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197382,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+668337,int_stack+633597,int_stack+435369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419574,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+680487,int_stack+668337,int_stack+646017, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425649,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+696687,int_stack+680487,int_stack+655737, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566322,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+641022,int_stack+30062,int_stack+27092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202332,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+649932,int_stack+641022,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578922,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+715587,int_stack+649932,int_stack+668337, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586347,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+633597,int_stack+715587,int_stack+680487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+598497,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+657897,int_stack+633597,int_stack+696687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614697,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+684357,int_stack+657897,int_stack+495762,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+495762,int_stack+34356,int_stack+33572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278926, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+498114,int_stack+35364,int_stack+34356, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279710, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+501138,int_stack+498114,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332210, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+505842,int_stack+36624,int_stack+35364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280718, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+509622,int_stack+505842,int_stack+498114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334562, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+633597,int_stack+509622,int_stack+501138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337586, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+495762,int_stack+38164,int_stack+36624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281978, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+641437,int_stack+495762,int_stack+505842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342290, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+648997,int_stack+641437,int_stack+509622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346070, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+500382,int_stack+648997,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352118, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+633597,int_stack+40012,int_stack+38164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283518, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+659077,int_stack+633597,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359958, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+668317,int_stack+659077,int_stack+641437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364578, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+633597,int_stack+668317,int_stack+648997, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+372138, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+648717,int_stack+633597,int_stack+500382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382218, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+633597,int_stack+43204,int_stack+42196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296174, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+636621,int_stack+44500,int_stack+43204, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297182, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+640509,int_stack+636621,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393978, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+495762,int_stack+46120,int_stack+44500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298478, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+500622,int_stack+495762,int_stack+636621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397002, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+665181,int_stack+500622,int_stack+640509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400890, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+633597,int_stack+48100,int_stack+46120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300098, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+16200,int_stack+633597,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406938, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+25920,int_stack+16200,int_stack+500622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411798, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+495762,int_stack+25920,int_stack+665181, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441942, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+665181,int_stack+50476,int_stack+48100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302078, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+672309,int_stack+665181,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452022, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+747861,int_stack+672309,int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457962, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+764061,int_stack+747861,int_stack+25920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467682, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+16200,int_stack+764061,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480642, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+747861,int_stack+16200,int_stack+648717,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+495762,int_stack+54544,int_stack+53284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187572, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+499542,int_stack+56164,int_stack+54544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190092, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+504402,int_stack+499542,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+37368,int_stack+58189,int_stack+56164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193332, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+43443,int_stack+37368,int_stack+499542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+633597,int_stack+43443,int_stack+504402, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+495762,int_stack+60664,int_stack+58189, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197382, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+503187,int_stack+495762,int_stack+37368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419574, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+646197,int_stack+503187,int_stack+43443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425649, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+37368,int_stack+646197,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566322, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+633597,int_stack+63634,int_stack+60664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202332, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+662397,int_stack+633597,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578922, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+797253,int_stack+662397,int_stack+503187, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586347, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+817503,int_stack+797253,int_stack+646197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+598497, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+633597,int_stack+817503,int_stack+37368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614697, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+797253,int_stack+633597,int_stack+16200,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16200,int_stack+67928,int_stack+67144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278926, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18552,int_stack+68936,int_stack+67928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279710, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+21576,int_stack+18552,int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332210, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26280,int_stack+70196,int_stack+68936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280718, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30060,int_stack+26280,int_stack+18552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334562, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+36108,int_stack+30060,int_stack+21576, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337586, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+16200,int_stack+71736,int_stack+70196, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281978, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+43948,int_stack+16200,int_stack+26280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342290, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+51508,int_stack+43948,int_stack+30060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346070, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+20820,int_stack+51508,int_stack+36108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352118, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+32580,int_stack+73584,int_stack+71736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283518, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+61588,int_stack+32580,int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359958, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+633597,int_stack+61588,int_stack+43948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364578, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+32580,int_stack+633597,int_stack+51508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+372138, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+633597,int_stack+32580,int_stack+20820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382218, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+650061,int_stack+76776,int_stack+75768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296174, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+653085,int_stack+78072,int_stack+76776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297182, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+656973,int_stack+653085,int_stack+650061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393978, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+663021,int_stack+79692,int_stack+78072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298478, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+667881,int_stack+663021,int_stack+653085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397002, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+16200,int_stack+667881,int_stack+656973, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400890, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+650061,int_stack+81672,int_stack+79692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300098, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+26280,int_stack+650061,int_stack+663021, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406938, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+36000,int_stack+26280,int_stack+667881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411798, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+656001,int_stack+36000,int_stack+16200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441942, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+16200,int_stack+84048,int_stack+81672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302078, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+671121,int_stack+16200,int_stack+650061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452022, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+48960,int_stack+671121,int_stack+26280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457962, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+16200,int_stack+48960,int_stack+36000, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467682, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+495762,int_stack+16200,int_stack+656001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480642, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+16200,int_stack+495762,int_stack+633597,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+633597,int_stack+88116,int_stack+86856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187572, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+637377,int_stack+89736,int_stack+88116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190092, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+642237,int_stack+637377,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+649797,int_stack+91761,int_stack+89736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193332, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+655872,int_stack+649797,int_stack+637377, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+665592,int_stack+655872,int_stack+642237, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+633597,int_stack+94236,int_stack+91761, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197382, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+65592,int_stack+633597,int_stack+649797, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419574, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+77742,int_stack+65592,int_stack+655872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425649, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+641022,int_stack+77742,int_stack+665592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566322, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+659922,int_stack+97206,int_stack+94236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202332, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+668832,int_stack+659922,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578922, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+860757,int_stack+668832,int_stack+65592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586347, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+659922,int_stack+860757,int_stack+77742, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+598497, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+65592,int_stack+659922,int_stack+641022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614697, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+860757,int_stack+65592,int_stack+495762,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+495762,int_stack+101500,int_stack+100716, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+498114,int_stack+102508,int_stack+101500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+501138,int_stack+498114,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+505842,int_stack+103768,int_stack+102508, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+509622,int_stack+505842,int_stack+498114, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+65592,int_stack+509622,int_stack+501138, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+337586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+495762,int_stack+105308,int_stack+103768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+73432,int_stack+495762,int_stack+505842, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+80992,int_stack+73432,int_stack+509622, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+346070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+500382,int_stack+80992,int_stack+65592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+352118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+65592,int_stack+107156,int_stack+105308, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+283518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+91072,int_stack+65592,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+633597,int_stack+91072,int_stack+73432, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+91072,int_stack+633597,int_stack+80992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+372138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+633597,int_stack+91072,int_stack+500382, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+650061,int_stack+110348,int_stack+109340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+296174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+653085,int_stack+111644,int_stack+110348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+297182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+656973,int_stack+653085,int_stack+650061, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+663021,int_stack+113264,int_stack+111644, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+667881,int_stack+663021,int_stack+653085, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+495762,int_stack+667881,int_stack+656973, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+650061,int_stack+115244,int_stack+113264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+300098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+505842,int_stack+650061,int_stack+663021, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+406938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+65592,int_stack+505842,int_stack+667881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+656001,int_stack+65592,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+495762,int_stack+117620,int_stack+115244, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+302078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+671121,int_stack+495762,int_stack+650061, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+452022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+78552,int_stack+671121,int_stack+505842, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+495762,int_stack+78552,int_stack+65592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+65592,int_stack+495762,int_stack+656001, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+480642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+924261,int_stack+65592,int_stack+633597,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+633597,int_stack+121688,int_stack+120428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+187572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+637377,int_stack+123308,int_stack+121688, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+642237,int_stack+637377,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+649797,int_stack+125333,int_stack+123308, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+193332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+655872,int_stack+649797,int_stack+637377, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+665592,int_stack+655872,int_stack+642237, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+633597,int_stack+127808,int_stack+125333, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+197382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+495762,int_stack+633597,int_stack+649797, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+419574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+86760,int_stack+495762,int_stack+655872, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+641022,int_stack+86760,int_stack+665592, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+566322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+659922,int_stack+130778,int_stack+127808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+202332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+668832,int_stack+659922,int_stack+633597, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+578922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+102960,int_stack+668832,int_stack+495762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+659922,int_stack+102960,int_stack+86760, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+598497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+86760,int_stack+659922,int_stack+641022, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+973653,int_stack+86760,int_stack+65592,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65592,int_stack+135072,int_stack+134288, 0.0, zero_stack, 1.0, int_stack+278926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+67944,int_stack+136080,int_stack+135072, 0.0, zero_stack, 1.0, int_stack+279710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+70968,int_stack+67944,int_stack+65592, 0.0, zero_stack, 1.0, int_stack+332210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+75672,int_stack+137340,int_stack+136080, 0.0, zero_stack, 1.0, int_stack+280718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+79452,int_stack+75672,int_stack+67944, 0.0, zero_stack, 1.0, int_stack+334562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+85500,int_stack+79452,int_stack+70968, 0.0, zero_stack, 1.0, int_stack+337586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+65592,int_stack+138880,int_stack+137340, 0.0, zero_stack, 1.0, int_stack+281978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+93340,int_stack+65592,int_stack+75672, 0.0, zero_stack, 1.0, int_stack+342290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+100900,int_stack+93340,int_stack+79452, 0.0, zero_stack, 1.0, int_stack+346070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+70212,int_stack+100900,int_stack+85500, 0.0, zero_stack, 1.0, int_stack+352118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+81972,int_stack+140728,int_stack+138880, 0.0, zero_stack, 1.0, int_stack+283518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+110980,int_stack+81972,int_stack+65592, 0.0, zero_stack, 1.0, int_stack+359958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+120220,int_stack+110980,int_stack+93340, 0.0, zero_stack, 1.0, int_stack+364578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+81972,int_stack+120220,int_stack+100900, 0.0, zero_stack, 1.0, int_stack+372138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+97092,int_stack+81972,int_stack+70212, 0.0, zero_stack, 1.0, int_stack+382218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+65592,int_stack+143920,int_stack+142912, 0.0, zero_stack, 1.0, int_stack+296174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+68616,int_stack+145216,int_stack+143920, 0.0, zero_stack, 1.0, int_stack+297182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+72504,int_stack+68616,int_stack+65592, 0.0, zero_stack, 1.0, int_stack+393978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+78552,int_stack+146836,int_stack+145216, 0.0, zero_stack, 1.0, int_stack+298478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+83412,int_stack+78552,int_stack+68616, 0.0, zero_stack, 1.0, int_stack+397002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+113556,int_stack+83412,int_stack+72504, 0.0, zero_stack, 1.0, int_stack+400890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+65592,int_stack+148816,int_stack+146836, 0.0, zero_stack, 1.0, int_stack+300098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+123636,int_stack+65592,int_stack+78552, 0.0, zero_stack, 1.0, int_stack+406938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+133356,int_stack+123636,int_stack+83412, 0.0, zero_stack, 1.0, int_stack+411798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+71532,int_stack+133356,int_stack+113556, 0.0, zero_stack, 1.0, int_stack+441942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+113556,int_stack+151192,int_stack+148816, 0.0, zero_stack, 1.0, int_stack+302078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+495762,int_stack+113556,int_stack+65592, 0.0, zero_stack, 1.0, int_stack+452022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+633597,int_stack+495762,int_stack+123636, 0.0, zero_stack, 1.0, int_stack+457962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+495762,int_stack+633597,int_stack+133356, 0.0, zero_stack, 1.0, int_stack+467682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+633597,int_stack+495762,int_stack+71532, 0.0, zero_stack, 1.0, int_stack+480642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1037157,int_stack+633597,int_stack+97092,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+495762,int_stack+155260,int_stack+154000, 0.0, zero_stack, 1.0, int_stack+187572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+499542,int_stack+156880,int_stack+155260, 0.0, zero_stack, 1.0, int_stack+190092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+504402,int_stack+499542,int_stack+495762, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+654765,int_stack+158905,int_stack+156880, 0.0, zero_stack, 1.0, int_stack+193332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+660840,int_stack+654765,int_stack+499542, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+670560,int_stack+660840,int_stack+504402, 0.0, zero_stack, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+495762,int_stack+161380,int_stack+158905, 0.0, zero_stack, 1.0, int_stack+197382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+503187,int_stack+495762,int_stack+654765, 0.0, zero_stack, 1.0, int_stack+419574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+65592,int_stack+503187,int_stack+660840, 0.0, zero_stack, 1.0, int_stack+425649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+81792,int_stack+65592,int_stack+670560, 0.0, zero_stack, 1.0, int_stack+566322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+654765,int_stack+164350,int_stack+161380, 0.0, zero_stack, 1.0, int_stack+202332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+663675,int_stack+654765,int_stack+495762, 0.0, zero_stack, 1.0, int_stack+578922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+100692,int_stack+663675,int_stack+503187, 0.0, zero_stack, 1.0, int_stack+586347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+654765,int_stack+100692,int_stack+65592, 0.0, zero_stack, 1.0, int_stack+598497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+100692,int_stack+654765,int_stack+81792, 0.0, zero_stack, 1.0, int_stack+614697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+1086549,int_stack+100692,int_stack+633597,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+633597,int_stack+168644,int_stack+167860, 1.0, int_stack+278926, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+635949,int_stack+169652,int_stack+168644, 1.0, int_stack+279710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+638973,int_stack+635949,int_stack+633597, 1.0, int_stack+332210, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+643677,int_stack+170912,int_stack+169652, 1.0, int_stack+280718, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+647457,int_stack+643677,int_stack+635949, 1.0, int_stack+334562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+653505,int_stack+647457,int_stack+638973, 1.0, int_stack+337586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+332210,int_stack+172452,int_stack+170912, 1.0, int_stack+281978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+633597,int_stack+332210,int_stack+643677, 1.0, int_stack+342290, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+661345,int_stack+633597,int_stack+647457, 1.0, int_stack+346070, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+336830,int_stack+661345,int_stack+653505, 1.0, int_stack+352118, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+348590,int_stack+174300,int_stack+172452, 1.0, int_stack+283518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+641157,int_stack+348590,int_stack+332210, 1.0, int_stack+359958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+671425,int_stack+641157,int_stack+633597, 1.0, int_stack+364578, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+633597,int_stack+671425,int_stack+661345, 1.0, int_stack+372138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+648717,int_stack+633597,int_stack+336830, 1.0, int_stack+382218, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+633597,int_stack+177492,int_stack+176484, 1.0, int_stack+296174, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+636621,int_stack+178788,int_stack+177492, 1.0, int_stack+297182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+640509,int_stack+636621,int_stack+633597, 1.0, int_stack+393978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+665181,int_stack+180408,int_stack+178788, 1.0, int_stack+298478, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+670041,int_stack+665181,int_stack+636621, 1.0, int_stack+397002, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+332210,int_stack+670041,int_stack+640509, 1.0, int_stack+400890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+393978,int_stack+182388,int_stack+180408, 1.0, int_stack+300098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+633597,int_stack+393978,int_stack+665181, 1.0, int_stack+406938, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+342290,int_stack+633597,int_stack+670041, 1.0, int_stack+411798, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+665181,int_stack+342290,int_stack+332210, 1.0, int_stack+441942, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+332210,int_stack+184764,int_stack+182388, 1.0, int_stack+302078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+399918,int_stack+332210,int_stack+393978, 1.0, int_stack+452022, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+65592,int_stack+399918,int_stack+633597, 1.0, int_stack+457962, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+393978,int_stack+65592,int_stack+342290, 1.0, int_stack+467682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+495762,int_stack+393978,int_stack+665181, 1.0, int_stack+480642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+65592,int_stack+495762,int_stack+648717,588);
 /*--- compute (l0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+393978,int_stack+191712,int_stack+188832, 1.0, int_stack+187572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+397758,int_stack+195357,int_stack+191712, 1.0, int_stack+190092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+402618,int_stack+397758,int_stack+393978, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+410178,int_stack+199857,int_stack+195357, 1.0, int_stack+193332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+114984,int_stack+410178,int_stack+397758, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+124704,int_stack+114984,int_stack+402618, 1.0, int_stack+8640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+205302,int_stack+199857, 1.0, int_stack+197382, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+393978,int_stack+0,int_stack+410178, 1.0, int_stack+419574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+406128,int_stack+393978,int_stack+114984, 1.0, int_stack+425649, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+422328,int_stack+406128,int_stack+124704, 1.0, int_stack+566322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+566322,int_stack+208272,int_stack+205302, 1.0, int_stack+202332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+114984,int_stack+566322,int_stack+0, 1.0, int_stack+578922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+129834,int_stack+114984,int_stack+393978, 1.0, int_stack+586347, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+566322,int_stack+129834,int_stack+406128, 1.0, int_stack+598497, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (l0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+393978,int_stack+566322,int_stack+422328, 1.0, int_stack+614697, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,45);
 /*--- compute (kp|ih) ---*/
   hrr1_build_kp(Libderiv->AB,int_stack+566322,int_stack+393978,int_stack+495762,588);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+495762,int_stack+285366,int_stack+283518,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+501306,int_stack+495762,int_stack+359958,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+393978,int_stack+501306,int_stack+364578,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+495762,int_stack+393978,int_stack+372138,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+393978,int_stack+495762,int_stack+382218,28);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+495762,int_stack+304454,int_stack+302078,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+502890,int_stack+495762,int_stack+452022,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+502890,int_stack+457962,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+495762,int_stack+0,int_stack+467682,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+410442,int_stack+495762,int_stack+480642,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+431610,int_stack+410442,int_stack+393978,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+212566,int_stack+211782,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+2352,int_stack+213574,int_stack+212566,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+5376,int_stack+2352,int_stack+0,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+10080,int_stack+214834,int_stack+213574,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+481002,int_stack+10080,int_stack+2352,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+487050,int_stack+481002,int_stack+5376,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+216374,int_stack+214834,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+494890,int_stack+0,int_stack+10080,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+4620,int_stack+494890,int_stack+481002,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+502450,int_stack+4620,int_stack+487050,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+481002,int_stack+218222,int_stack+216374,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+629826,int_stack+481002,int_stack+0,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+481002,int_stack+629826,int_stack+494890,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+629826,int_stack+481002,int_stack+4620,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+481002,int_stack+629826,int_stack+502450,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+629826,int_stack+221414,int_stack+220406,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+632850,int_stack+222710,int_stack+221414,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+636738,int_stack+632850,int_stack+629826,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+642786,int_stack+224330,int_stack+222710,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+647646,int_stack+642786,int_stack+632850,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+655422,int_stack+647646,int_stack+636738,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+629826,int_stack+226310,int_stack+224330,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+665502,int_stack+629826,int_stack+642786,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+497466,int_stack+665502,int_stack+647646,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+635766,int_stack+497466,int_stack+655422,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+650886,int_stack+228686,int_stack+226310,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+0,int_stack+650886,int_stack+629826,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+114984,int_stack+0,int_stack+665502,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+650886,int_stack+114984,int_stack+497466,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+114984,int_stack+650886,int_stack+635766,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+136152,int_stack+114984,int_stack+481002, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+393978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+481002,int_stack+232754,int_stack+231494,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+484782,int_stack+234374,int_stack+232754,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+489642,int_stack+484782,int_stack+481002,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+497202,int_stack+236399,int_stack+234374,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+503277,int_stack+497202,int_stack+484782,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+185544,int_stack+503277,int_stack+489642,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+481002,int_stack+238874,int_stack+236399,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+198144,int_stack+481002,int_stack+497202,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+198144,int_stack+503277,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+488427,int_stack+0,int_stack+185544,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+185544,int_stack+241844,int_stack+238874,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+210294,int_stack+185544,int_stack+481002,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+629826,int_stack+210294,int_stack+198144,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+185544,int_stack+629826,int_stack+0,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+629826,int_stack+185544,int_stack+488427,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1150053,int_stack+629826,int_stack+114984, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+114984,int_stack+246138,int_stack+245354,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+117336,int_stack+247146,int_stack+246138,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+120360,int_stack+117336,int_stack+114984,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+125064,int_stack+248406,int_stack+247146,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+128844,int_stack+125064,int_stack+117336,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+629826,int_stack+128844,int_stack+120360,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+114984,int_stack+249946,int_stack+248406,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+637666,int_stack+114984,int_stack+125064,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+645226,int_stack+637666,int_stack+128844,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+119604,int_stack+645226,int_stack+629826,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+629826,int_stack+251794,int_stack+249946,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+655306,int_stack+629826,int_stack+114984,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+664546,int_stack+655306,int_stack+637666,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+629826,int_stack+664546,int_stack+645226,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+644946,int_stack+629826,int_stack+119604,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+629826,int_stack+254986,int_stack+253978,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+632850,int_stack+256282,int_stack+254986,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+636738,int_stack+632850,int_stack+629826,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+114984,int_stack+257902,int_stack+256282,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+119844,int_stack+114984,int_stack+632850,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+661410,int_stack+119844,int_stack+636738,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+629826,int_stack+259882,int_stack+257902,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+671490,int_stack+629826,int_stack+114984,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+185544,int_stack+671490,int_stack+119844,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+114984,int_stack+185544,int_stack+661410,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+661410,int_stack+262258,int_stack+259882,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+198504,int_stack+661410,int_stack+629826,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+198504,int_stack+671490,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+198504,int_stack+0,int_stack+185544,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+217944,int_stack+198504,int_stack+114984,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+332210,int_stack+217944,int_stack+644946, 0.0, zero_stack, 1.0, int_stack+393978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+114984,int_stack+266326,int_stack+265066,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+118764,int_stack+267946,int_stack+266326,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+123624,int_stack+118764,int_stack+114984,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+185544,int_stack+269971,int_stack+267946,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+191619,int_stack+185544,int_stack+118764,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+201339,int_stack+191619,int_stack+123624,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+114984,int_stack+272446,int_stack+269971,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+122409,int_stack+114984,int_stack+185544,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+122409,int_stack+191619,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+239112,int_stack+0,int_stack+201339,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+185544,int_stack+275416,int_stack+272446,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+194454,int_stack+185544,int_stack+114984,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+258012,int_stack+194454,int_stack+122409,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+185544,int_stack+258012,int_stack+0,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+258012,int_stack+185544,int_stack+239112,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1213557,int_stack+258012,int_stack+217944, 0.0, zero_stack, 1.0, int_stack+410442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+185544,int_stack+288334,int_stack+287550,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+187896,int_stack+289342,int_stack+288334,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+190920,int_stack+187896,int_stack+185544,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+195624,int_stack+290602,int_stack+289342,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+199404,int_stack+195624,int_stack+187896,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+205452,int_stack+199404,int_stack+190920,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+185544,int_stack+292142,int_stack+290602,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+213292,int_stack+185544,int_stack+195624,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+220852,int_stack+213292,int_stack+199404,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+190164,int_stack+220852,int_stack+205452,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+201924,int_stack+293990,int_stack+292142,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+230932,int_stack+201924,int_stack+185544,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+240172,int_stack+230932,int_stack+213292,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+201924,int_stack+240172,int_stack+220852,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+217044,int_stack+201924,int_stack+190164,28);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+185544,int_stack+308270,int_stack+307262,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+188568,int_stack+309566,int_stack+308270,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+192456,int_stack+188568,int_stack+185544,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+198504,int_stack+311186,int_stack+309566,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+203364,int_stack+198504,int_stack+188568,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+233508,int_stack+203364,int_stack+192456,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+185544,int_stack+313166,int_stack+311186,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+243588,int_stack+185544,int_stack+198504,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+253308,int_stack+243588,int_stack+203364,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+191484,int_stack+253308,int_stack+233508,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+233508,int_stack+315542,int_stack+313166,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+266268,int_stack+233508,int_stack+185544,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+266268,int_stack+243588,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+266268,int_stack+0,int_stack+253308,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+114984,int_stack+266268,int_stack+191484,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+233508,int_stack+114984,int_stack+217044, 1.0, int_stack+393978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (l0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+319610,int_stack+318350,45);
 /*--- compute (l0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+3780,int_stack+321230,int_stack+319610,45);
 /*--- compute (l0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+8640,int_stack+3780,int_stack+0,45);
 /*--- compute (l0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+185544,int_stack+323255,int_stack+321230,45);
 /*--- compute (l0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+191619,int_stack+185544,int_stack+3780,45);
 /*--- compute (l0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+201339,int_stack+191619,int_stack+8640,45);
 /*--- compute (l0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+325730,int_stack+323255,45);
 /*--- compute (l0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+213939,int_stack+0,int_stack+185544,45);
 /*--- compute (l0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+282900,int_stack+213939,int_stack+191619,45);
 /*--- compute (l0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+299100,int_stack+282900,int_stack+201339,45);
 /*--- compute (l0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+185544,int_stack+328700,int_stack+325730,45);
 /*--- compute (l0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+194454,int_stack+185544,int_stack+0,45);
 /*--- compute (l0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+629826,int_stack+194454,int_stack+213939,45);
 /*--- compute (l0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+185544,int_stack+629826,int_stack+282900,45);
 /*--- compute (l0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+629826,int_stack+185544,int_stack+299100,45);
 /*--- compute (kp|ih) ---*/
   d1hrr1_build_kp(Libderiv->AB,int_stack+1277061,int_stack+629826,int_stack+114984, 1.0, int_stack+410442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1340565,int_stack+684357,int_stack+516930,588);
     Libderiv->ABCD[11] = int_stack + 1340565;
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+629826,int_stack+797253,int_stack+747861,588);
     Libderiv->ABCD[10] = int_stack + 629826;
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+728610,int_stack+860757,int_stack+16200,588);
     Libderiv->ABCD[9] = int_stack + 728610;
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+1439349,int_stack+973653,int_stack+924261,588);
     Libderiv->ABCD[8] = int_stack + 1439349;
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+827394,int_stack+1086549,int_stack+1037157,588);
     Libderiv->ABCD[7] = int_stack + 827394;
 /*--- compute (id|ih) ---*/
   hrr1_build_id(Libderiv->AB,int_stack+926178,int_stack+566322,int_stack+65592,588);
     Libderiv->ABCD[6] = int_stack + 926178;
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1024962,int_stack+1150053,int_stack+136152, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+431610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 1024962;
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+0,int_stack+1213557,int_stack+332210, 0.0, zero_stack, 1.0, int_stack+431610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 0;
 /*--- compute (id|ih) ---*/
   d1hrr1_build_id(Libderiv->AB,int_stack+1123746,int_stack+1277061,int_stack+233508, 1.0, int_stack+431610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 1123746;

}
