/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (pp|ii) integrals */

void d1vrr_order_ppii(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+0, dvrr_stack+6, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+9, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+31, dvrr_stack+3, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+40, dvrr_stack+34, dvrr_stack+15, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+50, dvrr_stack+6, dvrr_stack+3, Data->F+4, Data->F+5, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+56, dvrr_stack+9, dvrr_stack+50, dvrr_stack+0, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+66, dvrr_stack+21, dvrr_stack+56, dvrr_stack+15, dvrr_stack+9, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+81, dvrr_stack+40, dvrr_stack+21, dvrr_stack+34, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+96, dvrr_stack+81, dvrr_stack+66, dvrr_stack+40, dvrr_stack+21, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+3, dvrr_stack+0, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+117, dvrr_stack+50, dvrr_stack+15, dvrr_stack+6, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+127, dvrr_stack+56, dvrr_stack+117, dvrr_stack+9, dvrr_stack+50, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+142, dvrr_stack+66, dvrr_stack+127, dvrr_stack+21, dvrr_stack+56, NULL);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+163, dvrr_stack+96, dvrr_stack+142, dvrr_stack+81, dvrr_stack+66, NULL);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+9, dvrr_stack+6, dvrr_stack+31, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+191, dvrr_stack+9, dvrr_stack+34, dvrr_stack+6, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+201, dvrr_stack+191, dvrr_stack+40, dvrr_stack+9, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+216, dvrr_stack+201, dvrr_stack+81, dvrr_stack+191, dvrr_stack+40, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+237, dvrr_stack+216, dvrr_stack+96, dvrr_stack+201, dvrr_stack+81, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+265, dvrr_stack+237, dvrr_stack+163, NULL, NULL, dvrr_stack+96);
 tmp = dvrr_stack + 265;
 target_ptr = Libderiv->dvrr_classes[1][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+191, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+194, dvrr_stack+0, dvrr_stack+191, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+200, dvrr_stack+15, dvrr_stack+194, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+31, dvrr_stack+117, dvrr_stack+200, dvrr_stack+50, dvrr_stack+15, NULL);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+349, dvrr_stack+127, dvrr_stack+31, dvrr_stack+56, dvrr_stack+117, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+370, dvrr_stack+142, dvrr_stack+349, dvrr_stack+66, dvrr_stack+127, NULL);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+398, dvrr_stack+163, dvrr_stack+370, dvrr_stack+96, dvrr_stack+142, NULL);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+434, dvrr_stack+237, dvrr_stack+163, dvrr_stack+216, dvrr_stack+96, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+470, dvrr_stack+434, dvrr_stack+398, NULL, NULL, dvrr_stack+163);
 tmp = dvrr_stack + 470;
 target_ptr = Libderiv->dvrr_classes[1][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+578,dvrr_stack+470,dvrr_stack+265,3);


 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+210, dvrr_stack+191, dvrr_stack+3, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+46, dvrr_stack+194, dvrr_stack+210, dvrr_stack+0, dvrr_stack+191, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+830, dvrr_stack+200, dvrr_stack+46, dvrr_stack+15, dvrr_stack+194, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+845, dvrr_stack+31, dvrr_stack+830, dvrr_stack+117, dvrr_stack+200, NULL);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+866, dvrr_stack+349, dvrr_stack+845, dvrr_stack+127, dvrr_stack+31, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+894, dvrr_stack+370, dvrr_stack+866, dvrr_stack+142, dvrr_stack+349, NULL);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+930, dvrr_stack+398, dvrr_stack+894, dvrr_stack+163, dvrr_stack+370, NULL);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+975, dvrr_stack+434, dvrr_stack+398, dvrr_stack+237, dvrr_stack+163, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1020, dvrr_stack+975, dvrr_stack+930, NULL, NULL, dvrr_stack+398);
 tmp = dvrr_stack + 1020;
 target_ptr = Libderiv->dvrr_classes[1][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+1155,dvrr_stack+1020,dvrr_stack+470,3);


 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+117, dvrr_stack+3, dvrr_stack+0, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6, dvrr_stack+210, dvrr_stack+117, dvrr_stack+191, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1479, dvrr_stack+46, dvrr_stack+6, dvrr_stack+194, dvrr_stack+210, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1494, dvrr_stack+830, dvrr_stack+1479, dvrr_stack+200, dvrr_stack+46, NULL);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+1515, dvrr_stack+845, dvrr_stack+1494, dvrr_stack+31, dvrr_stack+830, NULL);

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+1543, dvrr_stack+866, dvrr_stack+1515, dvrr_stack+349, dvrr_stack+845, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+1579, dvrr_stack+894, dvrr_stack+1543, dvrr_stack+370, dvrr_stack+866, NULL);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1624, dvrr_stack+930, dvrr_stack+1579, dvrr_stack+398, dvrr_stack+894, NULL);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1679, dvrr_stack+975, dvrr_stack+930, dvrr_stack+434, dvrr_stack+398, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1734, dvrr_stack+1679, dvrr_stack+1624, NULL, NULL, dvrr_stack+930);
 tmp = dvrr_stack + 1734;
 target_ptr = Libderiv->dvrr_classes[1][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+1899,dvrr_stack+1734,dvrr_stack+1020,3);


 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+31, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+34, dvrr_stack+0, dvrr_stack+31, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+191, dvrr_stack+117, dvrr_stack+34, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2304, dvrr_stack+6, dvrr_stack+191, dvrr_stack+210, dvrr_stack+117, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2319, dvrr_stack+1479, dvrr_stack+2304, dvrr_stack+46, dvrr_stack+6, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2340, dvrr_stack+1494, dvrr_stack+2319, dvrr_stack+830, dvrr_stack+1479, NULL);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2368, dvrr_stack+1515, dvrr_stack+2340, dvrr_stack+845, dvrr_stack+1494, NULL);

 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2404, dvrr_stack+1543, dvrr_stack+2368, dvrr_stack+866, dvrr_stack+1515, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2449, dvrr_stack+1579, dvrr_stack+2404, dvrr_stack+894, dvrr_stack+1543, NULL);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+2504, dvrr_stack+1624, dvrr_stack+2449, dvrr_stack+930, dvrr_stack+1579, NULL);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+2570, dvrr_stack+1679, dvrr_stack+1624, dvrr_stack+975, dvrr_stack+930, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+2636, dvrr_stack+2570, dvrr_stack+2504, NULL, NULL, dvrr_stack+1624);
 tmp = dvrr_stack + 2636;
 target_ptr = Libderiv->dvrr_classes[1][10];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+2834,dvrr_stack+2636,dvrr_stack+1734,3);


 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+830, dvrr_stack+31, dvrr_stack+3, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+836, dvrr_stack+34, dvrr_stack+830, dvrr_stack+0, dvrr_stack+31, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+201, dvrr_stack+191, dvrr_stack+836, dvrr_stack+117, dvrr_stack+34, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3329, dvrr_stack+2304, dvrr_stack+201, dvrr_stack+6, dvrr_stack+191, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3350, dvrr_stack+2319, dvrr_stack+3329, dvrr_stack+1479, dvrr_stack+2304, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3378, dvrr_stack+2340, dvrr_stack+3350, dvrr_stack+1494, dvrr_stack+2319, NULL);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3414, dvrr_stack+2368, dvrr_stack+3378, dvrr_stack+1515, dvrr_stack+2340, NULL);

 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+1479, dvrr_stack+2404, dvrr_stack+3414, dvrr_stack+1543, dvrr_stack+2368, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+3459, dvrr_stack+2449, dvrr_stack+1479, dvrr_stack+1579, dvrr_stack+2404, NULL);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+3525, dvrr_stack+2504, dvrr_stack+3459, dvrr_stack+1624, dvrr_stack+2449, NULL);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+3603, dvrr_stack+2570, dvrr_stack+2504, dvrr_stack+1679, dvrr_stack+1624, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+3681, dvrr_stack+3603, dvrr_stack+3525, NULL, NULL, dvrr_stack+2504);
 tmp = dvrr_stack + 3681;
 target_ptr = Libderiv->dvrr_classes[1][11];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+3915,dvrr_stack+3681,dvrr_stack+2636,3);


 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1534, dvrr_stack+3, dvrr_stack+0, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+117, dvrr_stack+830, dvrr_stack+1534, dvrr_stack+31, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6, dvrr_stack+836, dvrr_stack+117, dvrr_stack+34, dvrr_stack+830, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+31, dvrr_stack+201, dvrr_stack+6, dvrr_stack+191, dvrr_stack+836, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+4509, dvrr_stack+3329, dvrr_stack+31, dvrr_stack+2304, dvrr_stack+201, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+4537, dvrr_stack+3350, dvrr_stack+4509, dvrr_stack+2319, dvrr_stack+3329, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+4573, dvrr_stack+3378, dvrr_stack+4537, dvrr_stack+2340, dvrr_stack+3350, NULL);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2304, dvrr_stack+3414, dvrr_stack+4573, dvrr_stack+2368, dvrr_stack+3378, NULL);

 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+4618, dvrr_stack+1479, dvrr_stack+2304, dvrr_stack+2404, dvrr_stack+3414, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+4684, dvrr_stack+3459, dvrr_stack+4618, dvrr_stack+2449, dvrr_stack+1479, NULL);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+4762, dvrr_stack+3525, dvrr_stack+4684, dvrr_stack+2504, dvrr_stack+3459, NULL);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+4853, dvrr_stack+3603, dvrr_stack+3525, dvrr_stack+2570, dvrr_stack+2504, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+4944, dvrr_stack+4853, dvrr_stack+4762, NULL, NULL, dvrr_stack+3525);
 tmp = dvrr_stack + 4944;
 target_ptr = Libderiv->dvrr_classes[1][12];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+5217,dvrr_stack+4944,dvrr_stack+3681,3);


 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1540, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+2359, dvrr_stack+0, dvrr_stack+1540, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+191, dvrr_stack+1534, dvrr_stack+2359, dvrr_stack+3, dvrr_stack+0, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2365, dvrr_stack+117, dvrr_stack+191, dvrr_stack+830, dvrr_stack+1534, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2380, dvrr_stack+6, dvrr_stack+2365, dvrr_stack+836, dvrr_stack+117, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+830, dvrr_stack+31, dvrr_stack+2380, dvrr_stack+201, dvrr_stack+6, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5919, dvrr_stack+4509, dvrr_stack+830, dvrr_stack+3329, dvrr_stack+31, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5955, dvrr_stack+4537, dvrr_stack+5919, dvrr_stack+3350, dvrr_stack+4509, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6000, dvrr_stack+4573, dvrr_stack+5955, dvrr_stack+3378, dvrr_stack+4537, NULL);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+3329, dvrr_stack+2304, dvrr_stack+6000, dvrr_stack+3414, dvrr_stack+4573, NULL);

 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+6055, dvrr_stack+4618, dvrr_stack+3329, dvrr_stack+1479, dvrr_stack+2304, NULL);

 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+6133, dvrr_stack+4684, dvrr_stack+6055, dvrr_stack+3459, dvrr_stack+4618, NULL);

 /* compute (0 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+6224, dvrr_stack+4762, dvrr_stack+6133, dvrr_stack+3525, dvrr_stack+4684, NULL);

 /* compute (0 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+6329, dvrr_stack+4853, dvrr_stack+4762, dvrr_stack+3603, dvrr_stack+3525, NULL);

 /* compute (1 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+6434, dvrr_stack+6329, dvrr_stack+6224, NULL, NULL, dvrr_stack+4762);

 /* compute (1 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+6749,dvrr_stack+6434,dvrr_stack+4944,3);


 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+3395, dvrr_stack+96, dvrr_stack+142, NULL, NULL, dvrr_stack+66);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+7568, dvrr_stack+163, dvrr_stack+370, NULL, NULL, dvrr_stack+142);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+7652, dvrr_stack+265, dvrr_stack+7568, dvrr_stack+237, dvrr_stack+163, dvrr_stack+3395);
 tmp = dvrr_stack + 7652;
 target_ptr = Libderiv->dvrr_classes[2][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7820, dvrr_stack+398, dvrr_stack+894, NULL, NULL, dvrr_stack+370);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7928, dvrr_stack+470, dvrr_stack+7820, dvrr_stack+434, dvrr_stack+398, dvrr_stack+7568);
 tmp = dvrr_stack + 7928;
 target_ptr = Libderiv->dvrr_classes[2][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+8144,dvrr_stack+7928,dvrr_stack+7652,6);


 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8648, dvrr_stack+930, dvrr_stack+1579, NULL, NULL, dvrr_stack+894);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+8783, dvrr_stack+1020, dvrr_stack+8648, dvrr_stack+975, dvrr_stack+930, dvrr_stack+7820);
 tmp = dvrr_stack + 8783;
 target_ptr = Libderiv->dvrr_classes[2][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+9053,dvrr_stack+8783,dvrr_stack+7928,6);


 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+9701, dvrr_stack+1624, dvrr_stack+2449, NULL, NULL, dvrr_stack+1579);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+9866, dvrr_stack+1734, dvrr_stack+9701, dvrr_stack+1679, dvrr_stack+1624, dvrr_stack+8648);
 tmp = dvrr_stack + 9866;
 target_ptr = Libderiv->dvrr_classes[2][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+10196,dvrr_stack+9866,dvrr_stack+8783,6);


 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11006, dvrr_stack+2504, dvrr_stack+3459, NULL, NULL, dvrr_stack+2449);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11204, dvrr_stack+2636, dvrr_stack+11006, dvrr_stack+2570, dvrr_stack+2504, dvrr_stack+9701);
 tmp = dvrr_stack + 11204;
 target_ptr = Libderiv->dvrr_classes[2][10];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+11600,dvrr_stack+11204,dvrr_stack+9866,6);


 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12590, dvrr_stack+3525, dvrr_stack+4684, NULL, NULL, dvrr_stack+3459);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12824, dvrr_stack+3681, dvrr_stack+12590, dvrr_stack+3603, dvrr_stack+3525, dvrr_stack+11006);
 tmp = dvrr_stack + 12824;
 target_ptr = Libderiv->dvrr_classes[2][11];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+13292,dvrr_stack+12824,dvrr_stack+11204,6);


 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+14480, dvrr_stack+4762, dvrr_stack+6133, NULL, NULL, dvrr_stack+4684);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+14753, dvrr_stack+4944, dvrr_stack+14480, dvrr_stack+4853, dvrr_stack+4762, dvrr_stack+12590);

 /* compute (2 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+15299,dvrr_stack+14753,dvrr_stack+12824,6);


 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+201, dvrr_stack+1540, dvrr_stack+3, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+16703, dvrr_stack+2359, dvrr_stack+201, dvrr_stack+0, dvrr_stack+1540, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+201, dvrr_stack+191, dvrr_stack+16703, dvrr_stack+1534, dvrr_stack+2359, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+16703, dvrr_stack+2365, dvrr_stack+201, dvrr_stack+117, dvrr_stack+191, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+16724, dvrr_stack+2380, dvrr_stack+16703, dvrr_stack+6, dvrr_stack+2365, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+16752, dvrr_stack+830, dvrr_stack+16724, dvrr_stack+31, dvrr_stack+2380, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2359, dvrr_stack+5919, dvrr_stack+16752, dvrr_stack+4509, dvrr_stack+830, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+16703, dvrr_stack+5955, dvrr_stack+2359, dvrr_stack+4537, dvrr_stack+5919, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+16758, dvrr_stack+6000, dvrr_stack+16703, dvrr_stack+4573, dvrr_stack+5955, NULL);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+5919, dvrr_stack+3329, dvrr_stack+16758, dvrr_stack+2304, dvrr_stack+6000, NULL);

 /* compute (0 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+2304, dvrr_stack+6055, dvrr_stack+5919, dvrr_stack+4618, dvrr_stack+3329, NULL);

 /* compute (0 0 | 13 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+5919, dvrr_stack+6133, dvrr_stack+2304, dvrr_stack+4684, dvrr_stack+6055, NULL);

 /* compute (1 0 | 13 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+16703, dvrr_stack+6224, dvrr_stack+5919, NULL, NULL, dvrr_stack+6133);

 /* compute (2 0 | 13 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 13;
 vrr_build_xxxx(am,Data,dvrr_stack+17018, dvrr_stack+6434, dvrr_stack+16703, dvrr_stack+6329, dvrr_stack+6224, dvrr_stack+14480);

 /* compute (2 0 | 12 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_qp(Libderiv->CD,dvrr_stack+17648,dvrr_stack+17018,dvrr_stack+14753,6);


 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+6224, dvrr_stack+216, dvrr_stack+96, NULL, NULL, dvrr_stack+81);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+6287, dvrr_stack+81, dvrr_stack+66, NULL, NULL, dvrr_stack+21);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+16703, dvrr_stack+6224, dvrr_stack+3395, dvrr_stack+216, dvrr_stack+96, dvrr_stack+6287);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+6287, dvrr_stack+66, dvrr_stack+127, NULL, NULL, dvrr_stack+56);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+6332, dvrr_stack+142, dvrr_stack+349, NULL, NULL, dvrr_stack+127);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+16829, dvrr_stack+3395, dvrr_stack+6332, dvrr_stack+96, dvrr_stack+142, dvrr_stack+6287);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+5919, dvrr_stack+370, dvrr_stack+866, NULL, NULL, dvrr_stack+349);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+19286, dvrr_stack+7568, dvrr_stack+5919, dvrr_stack+163, dvrr_stack+370, dvrr_stack+6332);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+19454, dvrr_stack+7652, dvrr_stack+19286, dvrr_stack+265, dvrr_stack+7568, dvrr_stack+16829);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+16829, dvrr_stack+894, dvrr_stack+1543, NULL, NULL, dvrr_stack+866);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19734, dvrr_stack+7820, dvrr_stack+16829, dvrr_stack+398, dvrr_stack+894, dvrr_stack+5919);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19950, dvrr_stack+7928, dvrr_stack+19734, dvrr_stack+470, dvrr_stack+7820, dvrr_stack+19286);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19286, dvrr_stack+1579, dvrr_stack+2404, NULL, NULL, dvrr_stack+1543);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20310, dvrr_stack+8648, dvrr_stack+19286, dvrr_stack+930, dvrr_stack+1579, dvrr_stack+16829);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+20580, dvrr_stack+8783, dvrr_stack+20310, dvrr_stack+1020, dvrr_stack+8648, dvrr_stack+19734);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19734, dvrr_stack+2449, dvrr_stack+1479, NULL, NULL, dvrr_stack+2404);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21030, dvrr_stack+9701, dvrr_stack+19734, dvrr_stack+1624, dvrr_stack+2449, dvrr_stack+19286);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21360, dvrr_stack+9866, dvrr_stack+21030, dvrr_stack+1734, dvrr_stack+9701, dvrr_stack+20310);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20310, dvrr_stack+3459, dvrr_stack+4618, NULL, NULL, dvrr_stack+1479);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+21910, dvrr_stack+11006, dvrr_stack+20310, dvrr_stack+2504, dvrr_stack+3459, dvrr_stack+19734);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+22306, dvrr_stack+11204, dvrr_stack+21910, dvrr_stack+2636, dvrr_stack+11006, dvrr_stack+21030);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+21030, dvrr_stack+4684, dvrr_stack+6055, NULL, NULL, dvrr_stack+4618);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+22966, dvrr_stack+12590, dvrr_stack+21030, dvrr_stack+3525, dvrr_stack+4684, dvrr_stack+20310);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+23434, dvrr_stack+12824, dvrr_stack+22966, dvrr_stack+3681, dvrr_stack+12590, dvrr_stack+21910);

 /* compute (1 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+21910, dvrr_stack+6133, dvrr_stack+2304, NULL, NULL, dvrr_stack+6055);

 /* compute (2 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+24214, dvrr_stack+14480, dvrr_stack+21910, dvrr_stack+4762, dvrr_stack+6133, dvrr_stack+21030);

 /* compute (3 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+24760, dvrr_stack+14753, dvrr_stack+24214, dvrr_stack+4944, dvrr_stack+14480, dvrr_stack+22966);

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,84,dvrr_stack+7568, dvrr_stack+578, NULL);
 tmp = dvrr_stack + 7568;
 target_ptr = Libderiv->deriv_classes[1][6][11];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,108,dvrr_stack+7820, dvrr_stack+1155, NULL);
 tmp = dvrr_stack + 7820;
 target_ptr = Libderiv->deriv_classes[1][7][11];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,135,dvrr_stack+8648, dvrr_stack+1899, NULL);
 tmp = dvrr_stack + 8648;
 target_ptr = Libderiv->deriv_classes[1][8][11];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,165,dvrr_stack+9701, dvrr_stack+2834, NULL);
 tmp = dvrr_stack + 9701;
 target_ptr = Libderiv->deriv_classes[1][9][11];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,198,dvrr_stack+11006, dvrr_stack+3915, NULL);
 tmp = dvrr_stack + 11006;
 target_ptr = Libderiv->deriv_classes[1][10][11];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,234,dvrr_stack+12590, dvrr_stack+5217, NULL);
 tmp = dvrr_stack + 12590;
 target_ptr = Libderiv->deriv_classes[1][11][11];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,273,dvrr_stack+14480, dvrr_stack+6749, NULL);
 tmp = dvrr_stack + 14480;
 target_ptr = Libderiv->deriv_classes[1][12][11];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,168,dvrr_stack+19286, dvrr_stack+8144, NULL);
 tmp = dvrr_stack + 19286;
 target_ptr = Libderiv->deriv_classes[2][6][11];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,216,dvrr_stack+19734, dvrr_stack+9053, NULL);
 tmp = dvrr_stack + 19734;
 target_ptr = Libderiv->deriv_classes[2][7][11];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,270,dvrr_stack+20310, dvrr_stack+10196, NULL);
 tmp = dvrr_stack + 20310;
 target_ptr = Libderiv->deriv_classes[2][8][11];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,330,dvrr_stack+21030, dvrr_stack+11600, NULL);
 tmp = dvrr_stack + 21030;
 target_ptr = Libderiv->deriv_classes[2][9][11];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,396,dvrr_stack+21910, dvrr_stack+13292, NULL);
 tmp = dvrr_stack + 21910;
 target_ptr = Libderiv->deriv_classes[2][10][11];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,468,dvrr_stack+22966, dvrr_stack+15299, NULL);
 tmp = dvrr_stack + 22966;
 target_ptr = Libderiv->deriv_classes[2][11][11];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,546,dvrr_stack+24214, dvrr_stack+17648, NULL);
 tmp = dvrr_stack + 24214;
 target_ptr = Libderiv->deriv_classes[2][12][11];
 for(i=0;i<546;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,84,dvrr_stack+2304, dvrr_stack+578, NULL);
 tmp = dvrr_stack + 2304;
 target_ptr = Libderiv->deriv_classes[1][6][10];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,108,dvrr_stack+2388, dvrr_stack+1155, NULL);
 tmp = dvrr_stack + 2388;
 target_ptr = Libderiv->deriv_classes[1][7][10];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,135,dvrr_stack+1479, dvrr_stack+1899, NULL);
 tmp = dvrr_stack + 1479;
 target_ptr = Libderiv->deriv_classes[1][8][10];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,165,dvrr_stack+16829, dvrr_stack+2834, NULL);
 tmp = dvrr_stack + 16829;
 target_ptr = Libderiv->deriv_classes[1][9][10];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,198,dvrr_stack+5919, dvrr_stack+3915, NULL);
 tmp = dvrr_stack + 5919;
 target_ptr = Libderiv->deriv_classes[1][10][10];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,234,dvrr_stack+3329, dvrr_stack+5217, NULL);
 tmp = dvrr_stack + 3329;
 target_ptr = Libderiv->deriv_classes[1][11][10];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,273,dvrr_stack+25670, dvrr_stack+6749, NULL);
 tmp = dvrr_stack + 25670;
 target_ptr = Libderiv->deriv_classes[1][12][10];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,168,dvrr_stack+4509, dvrr_stack+8144, NULL);
 tmp = dvrr_stack + 4509;
 target_ptr = Libderiv->deriv_classes[2][6][10];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,216,dvrr_stack+0, dvrr_stack+9053, NULL);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[2][7][10];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,270,dvrr_stack+25943, dvrr_stack+10196, NULL);
 tmp = dvrr_stack + 25943;
 target_ptr = Libderiv->deriv_classes[2][8][10];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,330,dvrr_stack+26213, dvrr_stack+11600, NULL);
 tmp = dvrr_stack + 26213;
 target_ptr = Libderiv->deriv_classes[2][9][10];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,396,dvrr_stack+26543, dvrr_stack+13292, NULL);
 tmp = dvrr_stack + 26543;
 target_ptr = Libderiv->deriv_classes[2][10][10];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,468,dvrr_stack+26939, dvrr_stack+15299, NULL);
 tmp = dvrr_stack + 26939;
 target_ptr = Libderiv->deriv_classes[2][11][10];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,546,dvrr_stack+27407, dvrr_stack+17648, NULL);
 tmp = dvrr_stack + 27407;
 target_ptr = Libderiv->deriv_classes[2][12][10];
 for(i=0;i<546;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,84,dvrr_stack+6117, dvrr_stack+578, NULL);
 tmp = dvrr_stack + 6117;
 target_ptr = Libderiv->deriv_classes[1][6][9];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,108,dvrr_stack+578, dvrr_stack+1155, NULL);
 tmp = dvrr_stack + 578;
 target_ptr = Libderiv->deriv_classes[1][7][9];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,135,dvrr_stack+1155, dvrr_stack+1899, NULL);
 tmp = dvrr_stack + 1155;
 target_ptr = Libderiv->deriv_classes[1][8][9];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,165,dvrr_stack+1899, dvrr_stack+2834, NULL);
 tmp = dvrr_stack + 1899;
 target_ptr = Libderiv->deriv_classes[1][9][9];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,198,dvrr_stack+2834, dvrr_stack+3915, NULL);
 tmp = dvrr_stack + 2834;
 target_ptr = Libderiv->deriv_classes[1][10][9];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,234,dvrr_stack+3915, dvrr_stack+5217, NULL);
 tmp = dvrr_stack + 3915;
 target_ptr = Libderiv->deriv_classes[1][11][9];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,273,dvrr_stack+5217, dvrr_stack+6749, NULL);
 tmp = dvrr_stack + 5217;
 target_ptr = Libderiv->deriv_classes[1][12][9];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,168,dvrr_stack+6749, dvrr_stack+8144, NULL);
 tmp = dvrr_stack + 6749;
 target_ptr = Libderiv->deriv_classes[2][6][9];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,216,dvrr_stack+8144, dvrr_stack+9053, NULL);
 tmp = dvrr_stack + 8144;
 target_ptr = Libderiv->deriv_classes[2][7][9];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,270,dvrr_stack+9053, dvrr_stack+10196, NULL);
 tmp = dvrr_stack + 9053;
 target_ptr = Libderiv->deriv_classes[2][8][9];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,330,dvrr_stack+10196, dvrr_stack+11600, NULL);
 tmp = dvrr_stack + 10196;
 target_ptr = Libderiv->deriv_classes[2][9][9];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,396,dvrr_stack+11600, dvrr_stack+13292, NULL);
 tmp = dvrr_stack + 11600;
 target_ptr = Libderiv->deriv_classes[2][10][9];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,468,dvrr_stack+13292, dvrr_stack+15299, NULL);
 tmp = dvrr_stack + 13292;
 target_ptr = Libderiv->deriv_classes[2][11][9];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,546,dvrr_stack+15299, dvrr_stack+17648, NULL);
 tmp = dvrr_stack + 15299;
 target_ptr = Libderiv->deriv_classes[2][12][9];
 for(i=0;i<546;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,3,1,dvrr_stack+17648, dvrr_stack+470, dvrr_stack+6224);
 tmp = dvrr_stack + 17648;
 target_ptr = Libderiv->deriv_classes[1][6][8];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,3,1,dvrr_stack+17732, dvrr_stack+1020, dvrr_stack+265);
 tmp = dvrr_stack + 17732;
 target_ptr = Libderiv->deriv_classes[1][7][8];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,3,1,dvrr_stack+17840, dvrr_stack+1734, dvrr_stack+470);
 tmp = dvrr_stack + 17840;
 target_ptr = Libderiv->deriv_classes[1][8][8];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,3,1,dvrr_stack+17975, dvrr_stack+2636, dvrr_stack+1020);
 tmp = dvrr_stack + 17975;
 target_ptr = Libderiv->deriv_classes[1][9][8];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,3,1,dvrr_stack+18140, dvrr_stack+3681, dvrr_stack+1734);
 tmp = dvrr_stack + 18140;
 target_ptr = Libderiv->deriv_classes[1][10][8];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,3,1,dvrr_stack+18338, dvrr_stack+4944, dvrr_stack+2636);
 tmp = dvrr_stack + 18338;
 target_ptr = Libderiv->deriv_classes[1][11][8];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,3,1,dvrr_stack+18572, dvrr_stack+6434, dvrr_stack+3681);
 tmp = dvrr_stack + 18572;
 target_ptr = Libderiv->deriv_classes[1][12][8];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,6,1,dvrr_stack+18845, dvrr_stack+7928, dvrr_stack+16703);
 tmp = dvrr_stack + 18845;
 target_ptr = Libderiv->deriv_classes[2][6][8];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,6,1,dvrr_stack+19013, dvrr_stack+8783, dvrr_stack+7652);
 tmp = dvrr_stack + 19013;
 target_ptr = Libderiv->deriv_classes[2][7][8];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,6,1,dvrr_stack+15845, dvrr_stack+9866, dvrr_stack+7928);
 tmp = dvrr_stack + 15845;
 target_ptr = Libderiv->deriv_classes[2][8][8];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,6,1,dvrr_stack+16115, dvrr_stack+11204, dvrr_stack+8783);
 tmp = dvrr_stack + 16115;
 target_ptr = Libderiv->deriv_classes[2][9][8];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,6,1,dvrr_stack+13760, dvrr_stack+12824, dvrr_stack+9866);
 tmp = dvrr_stack + 13760;
 target_ptr = Libderiv->deriv_classes[2][10][8];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,6,1,dvrr_stack+11996, dvrr_stack+14753, dvrr_stack+11204);
 tmp = dvrr_stack + 11996;
 target_ptr = Libderiv->deriv_classes[2][11][8];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_q(Data,6,1,dvrr_stack+6917, dvrr_stack+17018, dvrr_stack+12824);
 tmp = dvrr_stack + 6917;
 target_ptr = Libderiv->deriv_classes[2][12][8];
 for(i=0;i<546;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,3,1,dvrr_stack+16445, dvrr_stack+470, dvrr_stack+6224);
 tmp = dvrr_stack + 16445;
 target_ptr = Libderiv->deriv_classes[1][6][7];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,3,1,dvrr_stack+16529, dvrr_stack+1020, dvrr_stack+265);
 tmp = dvrr_stack + 16529;
 target_ptr = Libderiv->deriv_classes[1][7][7];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,3,1,dvrr_stack+14156, dvrr_stack+1734, dvrr_stack+470);
 tmp = dvrr_stack + 14156;
 target_ptr = Libderiv->deriv_classes[1][8][7];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,3,1,dvrr_stack+14291, dvrr_stack+2636, dvrr_stack+1020);
 tmp = dvrr_stack + 14291;
 target_ptr = Libderiv->deriv_classes[1][9][7];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,3,1,dvrr_stack+10526, dvrr_stack+3681, dvrr_stack+1734);
 tmp = dvrr_stack + 10526;
 target_ptr = Libderiv->deriv_classes[1][10][7];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,3,1,dvrr_stack+10724, dvrr_stack+4944, dvrr_stack+2636);
 tmp = dvrr_stack + 10724;
 target_ptr = Libderiv->deriv_classes[1][11][7];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,3,1,dvrr_stack+9323, dvrr_stack+6434, dvrr_stack+3681);
 tmp = dvrr_stack + 9323;
 target_ptr = Libderiv->deriv_classes[1][12][7];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,6,1,dvrr_stack+8360, dvrr_stack+7928, dvrr_stack+16703);
 tmp = dvrr_stack + 8360;
 target_ptr = Libderiv->deriv_classes[2][6][7];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,6,1,dvrr_stack+5490, dvrr_stack+8783, dvrr_stack+7652);
 tmp = dvrr_stack + 5490;
 target_ptr = Libderiv->deriv_classes[2][7][7];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,6,1,dvrr_stack+4149, dvrr_stack+9866, dvrr_stack+7928);
 tmp = dvrr_stack + 4149;
 target_ptr = Libderiv->deriv_classes[2][8][7];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,6,1,dvrr_stack+27953, dvrr_stack+11204, dvrr_stack+8783);
 tmp = dvrr_stack + 27953;
 target_ptr = Libderiv->deriv_classes[2][9][7];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,6,1,dvrr_stack+28283, dvrr_stack+12824, dvrr_stack+9866);
 tmp = dvrr_stack + 28283;
 target_ptr = Libderiv->deriv_classes[2][10][7];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,6,1,dvrr_stack+28679, dvrr_stack+14753, dvrr_stack+11204);
 tmp = dvrr_stack + 28679;
 target_ptr = Libderiv->deriv_classes[2][11][7];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_q(Data,6,1,dvrr_stack+29147, dvrr_stack+17018, dvrr_stack+12824);
 tmp = dvrr_stack + 29147;
 target_ptr = Libderiv->deriv_classes[2][12][7];
 for(i=0;i<546;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,3,1,dvrr_stack+12464, dvrr_stack+470, dvrr_stack+6224);
 tmp = dvrr_stack + 12464;
 target_ptr = Libderiv->deriv_classes[1][6][6];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,3,1,dvrr_stack+8528, dvrr_stack+1020, dvrr_stack+265);
 tmp = dvrr_stack + 8528;
 target_ptr = Libderiv->deriv_classes[1][7][6];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,3,1,dvrr_stack+5706, dvrr_stack+1734, dvrr_stack+470);
 tmp = dvrr_stack + 5706;
 target_ptr = Libderiv->deriv_classes[1][8][6];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,3,1,dvrr_stack+3032, dvrr_stack+2636, dvrr_stack+1020);
 tmp = dvrr_stack + 3032;
 target_ptr = Libderiv->deriv_classes[1][9][6];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,3,1,dvrr_stack+2064, dvrr_stack+3681, dvrr_stack+1734);
 tmp = dvrr_stack + 2064;
 target_ptr = Libderiv->deriv_classes[1][10][6];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,3,1,dvrr_stack+686, dvrr_stack+4944, dvrr_stack+2636);
 tmp = dvrr_stack + 686;
 target_ptr = Libderiv->deriv_classes[1][11][6];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,3,1,dvrr_stack+29693, dvrr_stack+6434, dvrr_stack+3681);
 tmp = dvrr_stack + 29693;
 target_ptr = Libderiv->deriv_classes[1][12][6];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,6,1,dvrr_stack+1290, dvrr_stack+7928, dvrr_stack+16703);
 tmp = dvrr_stack + 1290;
 target_ptr = Libderiv->deriv_classes[2][6][6];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,6,1,dvrr_stack+6201, dvrr_stack+8783, dvrr_stack+7652);
 tmp = dvrr_stack + 6201;
 target_ptr = Libderiv->deriv_classes[2][7][6];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,6,1,dvrr_stack+6417, dvrr_stack+9866, dvrr_stack+7928);
 tmp = dvrr_stack + 6417;
 target_ptr = Libderiv->deriv_classes[2][8][6];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,6,1,dvrr_stack+29966, dvrr_stack+11204, dvrr_stack+8783);
 tmp = dvrr_stack + 29966;
 target_ptr = Libderiv->deriv_classes[2][9][6];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,6,1,dvrr_stack+30296, dvrr_stack+12824, dvrr_stack+9866);
 tmp = dvrr_stack + 30296;
 target_ptr = Libderiv->deriv_classes[2][10][6];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,6,1,dvrr_stack+30692, dvrr_stack+14753, dvrr_stack+11204);
 tmp = dvrr_stack + 30692;
 target_ptr = Libderiv->deriv_classes[2][11][6];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_q(Data,6,1,dvrr_stack+31160, dvrr_stack+17018, dvrr_stack+12824);
 tmp = dvrr_stack + 31160;
 target_ptr = Libderiv->deriv_classes[2][12][6];
 for(i=0;i<546;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,28,dvrr_stack+16637, dvrr_stack+7652, dvrr_stack+237);
 tmp = dvrr_stack + 16637;
 target_ptr = Libderiv->deriv_classes[1][6][2];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,36,dvrr_stack+16721, dvrr_stack+7928, dvrr_stack+434);
 tmp = dvrr_stack + 16721;
 target_ptr = Libderiv->deriv_classes[1][7][2];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,45,dvrr_stack+16994, dvrr_stack+8783, dvrr_stack+975);
 tmp = dvrr_stack + 16994;
 target_ptr = Libderiv->deriv_classes[1][8][2];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,55,dvrr_stack+17129, dvrr_stack+9866, dvrr_stack+1679);
 tmp = dvrr_stack + 17129;
 target_ptr = Libderiv->deriv_classes[1][9][2];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,66,dvrr_stack+17294, dvrr_stack+11204, dvrr_stack+2570);
 tmp = dvrr_stack + 17294;
 target_ptr = Libderiv->deriv_classes[1][10][2];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,78,dvrr_stack+31706, dvrr_stack+12824, dvrr_stack+3603);
 tmp = dvrr_stack + 31706;
 target_ptr = Libderiv->deriv_classes[1][11][2];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_p(Data,91,dvrr_stack+31940, dvrr_stack+14753, dvrr_stack+4853);
 tmp = dvrr_stack + 31940;
 target_ptr = Libderiv->deriv_classes[1][12][2];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,28,dvrr_stack+32213, dvrr_stack+19454, dvrr_stack+265);
 tmp = dvrr_stack + 32213;
 target_ptr = Libderiv->deriv_classes[2][6][2];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,36,dvrr_stack+32381, dvrr_stack+19950, dvrr_stack+470);
 tmp = dvrr_stack + 32381;
 target_ptr = Libderiv->deriv_classes[2][7][2];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,45,dvrr_stack+32597, dvrr_stack+20580, dvrr_stack+1020);
 tmp = dvrr_stack + 32597;
 target_ptr = Libderiv->deriv_classes[2][8][2];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,55,dvrr_stack+32867, dvrr_stack+21360, dvrr_stack+1734);
 tmp = dvrr_stack + 32867;
 target_ptr = Libderiv->deriv_classes[2][9][2];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,66,dvrr_stack+33197, dvrr_stack+22306, dvrr_stack+2636);
 tmp = dvrr_stack + 33197;
 target_ptr = Libderiv->deriv_classes[2][10][2];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,78,dvrr_stack+33593, dvrr_stack+23434, dvrr_stack+3681);
 tmp = dvrr_stack + 33593;
 target_ptr = Libderiv->deriv_classes[2][11][2];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_d(Data,91,dvrr_stack+34061, dvrr_stack+24760, dvrr_stack+4944);
 tmp = dvrr_stack + 34061;
 target_ptr = Libderiv->deriv_classes[2][12][2];
 for(i=0;i<546;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,28,dvrr_stack+9596, dvrr_stack+7652, dvrr_stack+237);
 tmp = dvrr_stack + 9596;
 target_ptr = Libderiv->deriv_classes[1][6][1];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,36,dvrr_stack+3197, dvrr_stack+7928, dvrr_stack+434);
 tmp = dvrr_stack + 3197;
 target_ptr = Libderiv->deriv_classes[1][7][1];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,45,dvrr_stack+17492, dvrr_stack+8783, dvrr_stack+975);
 tmp = dvrr_stack + 17492;
 target_ptr = Libderiv->deriv_classes[1][8][1];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,55,dvrr_stack+34607, dvrr_stack+9866, dvrr_stack+1679);
 tmp = dvrr_stack + 34607;
 target_ptr = Libderiv->deriv_classes[1][9][1];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,66,dvrr_stack+34772, dvrr_stack+11204, dvrr_stack+2570);
 tmp = dvrr_stack + 34772;
 target_ptr = Libderiv->deriv_classes[1][10][1];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,78,dvrr_stack+34970, dvrr_stack+12824, dvrr_stack+3603);
 tmp = dvrr_stack + 34970;
 target_ptr = Libderiv->deriv_classes[1][11][1];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_p(Data,91,dvrr_stack+35204, dvrr_stack+14753, dvrr_stack+4853);
 tmp = dvrr_stack + 35204;
 target_ptr = Libderiv->deriv_classes[1][12][1];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,28,dvrr_stack+35477, dvrr_stack+19454, dvrr_stack+265);
 tmp = dvrr_stack + 35477;
 target_ptr = Libderiv->deriv_classes[2][6][1];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,36,dvrr_stack+35645, dvrr_stack+19950, dvrr_stack+470);
 tmp = dvrr_stack + 35645;
 target_ptr = Libderiv->deriv_classes[2][7][1];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,45,dvrr_stack+35861, dvrr_stack+20580, dvrr_stack+1020);
 tmp = dvrr_stack + 35861;
 target_ptr = Libderiv->deriv_classes[2][8][1];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,55,dvrr_stack+36131, dvrr_stack+21360, dvrr_stack+1734);
 tmp = dvrr_stack + 36131;
 target_ptr = Libderiv->deriv_classes[2][9][1];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,66,dvrr_stack+36461, dvrr_stack+22306, dvrr_stack+2636);
 tmp = dvrr_stack + 36461;
 target_ptr = Libderiv->deriv_classes[2][10][1];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,78,dvrr_stack+36857, dvrr_stack+23434, dvrr_stack+3681);
 tmp = dvrr_stack + 36857;
 target_ptr = Libderiv->deriv_classes[2][11][1];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_d(Data,91,dvrr_stack+37325, dvrr_stack+24760, dvrr_stack+4944);
 tmp = dvrr_stack + 37325;
 target_ptr = Libderiv->deriv_classes[2][12][1];
 for(i=0;i<546;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,28,dvrr_stack+7463, dvrr_stack+7652, dvrr_stack+237);
 tmp = dvrr_stack + 7463;
 target_ptr = Libderiv->deriv_classes[1][6][0];
 for(i=0;i<84;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,36,dvrr_stack+7652, dvrr_stack+7928, dvrr_stack+434);
 tmp = dvrr_stack + 7652;
 target_ptr = Libderiv->deriv_classes[1][7][0];
 for(i=0;i<108;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,45,dvrr_stack+7928, dvrr_stack+8783, dvrr_stack+975);
 tmp = dvrr_stack + 7928;
 target_ptr = Libderiv->deriv_classes[1][8][0];
 for(i=0;i<135;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,55,dvrr_stack+8783, dvrr_stack+9866, dvrr_stack+1679);
 tmp = dvrr_stack + 8783;
 target_ptr = Libderiv->deriv_classes[1][9][0];
 for(i=0;i<165;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,66,dvrr_stack+9866, dvrr_stack+11204, dvrr_stack+2570);
 tmp = dvrr_stack + 9866;
 target_ptr = Libderiv->deriv_classes[1][10][0];
 for(i=0;i<198;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,78,dvrr_stack+11204, dvrr_stack+12824, dvrr_stack+3603);
 tmp = dvrr_stack + 11204;
 target_ptr = Libderiv->deriv_classes[1][11][0];
 for(i=0;i<234;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_p(Data,91,dvrr_stack+12824, dvrr_stack+14753, dvrr_stack+4853);
 tmp = dvrr_stack + 12824;
 target_ptr = Libderiv->deriv_classes[1][12][0];
 for(i=0;i<273;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,28,dvrr_stack+14753, dvrr_stack+19454, dvrr_stack+265);
 tmp = dvrr_stack + 14753;
 target_ptr = Libderiv->deriv_classes[2][6][0];
 for(i=0;i<168;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,36,dvrr_stack+19454, dvrr_stack+19950, dvrr_stack+470);
 tmp = dvrr_stack + 19454;
 target_ptr = Libderiv->deriv_classes[2][7][0];
 for(i=0;i<216;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,45,dvrr_stack+19950, dvrr_stack+20580, dvrr_stack+1020);
 tmp = dvrr_stack + 19950;
 target_ptr = Libderiv->deriv_classes[2][8][0];
 for(i=0;i<270;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,55,dvrr_stack+20580, dvrr_stack+21360, dvrr_stack+1734);
 tmp = dvrr_stack + 20580;
 target_ptr = Libderiv->deriv_classes[2][9][0];
 for(i=0;i<330;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,66,dvrr_stack+21360, dvrr_stack+22306, dvrr_stack+2636);
 tmp = dvrr_stack + 21360;
 target_ptr = Libderiv->deriv_classes[2][10][0];
 for(i=0;i<396;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,78,dvrr_stack+22306, dvrr_stack+23434, dvrr_stack+3681);
 tmp = dvrr_stack + 22306;
 target_ptr = Libderiv->deriv_classes[2][11][0];
 for(i=0;i<468;i++)
   target_ptr[i] += tmp[i];

 /* compute (2 0 | 12 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_d(Data,91,dvrr_stack+23434, dvrr_stack+24760, dvrr_stack+4944);
 tmp = dvrr_stack + 23434;
 target_ptr = Libderiv->deriv_classes[2][12][0];
 for(i=0;i<546;i++)
   target_ptr[i] += tmp[i];


}

