/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ddgd(Libr12_t *, prim_data *);

  /* Computes (dd|gd) integrals for linear R12-methods */

void hrr_grt_order_ddgd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][4] = int_stack + 0;
 Libr12->t2vrr_classes[2][5] = int_stack + 90;
 Libr12->t2vrr_classes[2][6] = int_stack + 216;
 Libr12->t2vrr_classes[3][4] = int_stack + 384;
 Libr12->t2vrr_classes[3][5] = int_stack + 534;
 Libr12->t2vrr_classes[3][6] = int_stack + 744;
 Libr12->gvrr_classes[5][4] = int_stack + 1024;
 Libr12->t2vrr_classes[4][4] = int_stack + 1339;
 Libr12->gvrr_classes[5][5] = int_stack + 1564;
 Libr12->t2vrr_classes[4][5] = int_stack + 2005;
 Libr12->t2vrr_classes[4][6] = int_stack + 2320;
 Libr12->gvrr_classes[2][7] = int_stack + 2740;
 Libr12->t1vrr_classes[2][4] = int_stack + 2956;
 Libr12->t1vrr_classes[2][5] = int_stack + 3046;
 Libr12->t1vrr_classes[2][6] = int_stack + 3172;
 Libr12->gvrr_classes[3][7] = int_stack + 3340;
 Libr12->t1vrr_classes[3][4] = int_stack + 3700;
 Libr12->t1vrr_classes[3][5] = int_stack + 3850;
 Libr12->t1vrr_classes[3][6] = int_stack + 4060;
 Libr12->t1vrr_classes[4][4] = int_stack + 4340;
 Libr12->t1vrr_classes[4][5] = int_stack + 4565;
 Libr12->t1vrr_classes[4][6] = int_stack + 4880;
 Libr12->rvrr_classes[2][4] = int_stack + 5300;
 Libr12->rvrr_classes[2][5] = int_stack + 5390;
 Libr12->rvrr_classes[2][6] = int_stack + 5516;
 Libr12->rvrr_classes[3][4] = int_stack + 5684;
 Libr12->rvrr_classes[3][5] = int_stack + 5834;
 Libr12->rvrr_classes[3][6] = int_stack + 6044;
 Libr12->rvrr_classes[4][4] = int_stack + 6324;
 Libr12->rvrr_classes[4][5] = int_stack + 6549;
 Libr12->rvrr_classes[4][6] = int_stack + 6864;
 Libr12->gvrr_classes[2][4] = int_stack + 7284;
 Libr12->gvrr_classes[2][5] = int_stack + 7374;
 Libr12->gvrr_classes[2][6] = int_stack + 7500;
 Libr12->gvrr_classes[3][4] = int_stack + 7668;
 Libr12->gvrr_classes[3][5] = int_stack + 7818;
 Libr12->gvrr_classes[3][6] = int_stack + 8028;
 Libr12->gvrr_classes[4][4] = int_stack + 8308;
 Libr12->gvrr_classes[4][5] = int_stack + 8533;
 Libr12->gvrr_classes[4][6] = int_stack + 8848;
 memset(int_stack,0,9268*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 9268;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ddgd(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9268, int_stack+7374, int_stack+7284, 6);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9538, int_stack+7818, int_stack+7668, 10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9988, int_stack+7500, int_stack+7374, 6);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10366, int_stack+90, int_stack+0, int_stack+7374, int_stack+7668, int_stack+7284, 2, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10636, int_stack+216, int_stack+90, int_stack+7500, int_stack+7818, int_stack+7374, 2, 0);
 /*--- compute (d0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+11014, int_stack+10636, int_stack+10366, int_stack+9988, int_stack+9538, int_stack+9268, 2, 0);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+11554, int_stack+8533, int_stack+8308, 15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+10366, int_stack+8028, int_stack+7818, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12229, int_stack+534, int_stack+384, int_stack+7818, int_stack+8308, int_stack+7668, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12679, int_stack+744, int_stack+534, int_stack+8028, int_stack+8533, int_stack+7818, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+12679, int_stack+12229, int_stack+10366, int_stack+11554, int_stack+9538, 3, 0);
 /*--- compute (dp|[r12,T2]|gd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+12229, int_stack+0, int_stack+11014, 90);
 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+13849, int_stack+1564, int_stack+1024, 21);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14794, int_stack+8848, int_stack+8533, 15);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+15739, int_stack+2005, int_stack+1339, int_stack+8533, int_stack+1024, int_stack+8308, 4, 0);
 /*--- compute (g0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16414, int_stack+2320, int_stack+2005, int_stack+8848, int_stack+1564, int_stack+8533, 4, 0);
 /*--- compute (g0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+900, int_stack+16414, int_stack+15739, int_stack+14794, int_stack+13849, int_stack+11554, 4, 0);
 /*--- compute (fp|[r12,T2]|gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+15739, int_stack+900, int_stack+0, 90);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+9988, int_stack+9268, 6);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+540, int_stack+10366, int_stack+9538, 10);
 /*--- compute (dp|gd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+8308, int_stack+540, int_stack+0, 90);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+1440, int_stack+2740, int_stack+7500, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1944, int_stack+1440, int_stack+9988, 6);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+13849, int_stack+3340, int_stack+8028, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+18439, int_stack+13849, int_stack+10366, 10);
 /*--- compute (dp|hd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+19699, int_stack+18439, int_stack+1944, 126);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+9928, int_stack+14794, int_stack+11554, 15);
 /*--- compute (fp|gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+21967, int_stack+9928, int_stack+540, 90);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+13849, int_stack+3046, int_stack+2956, 6);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14119, int_stack+3172, int_stack+3046, 6);
 /*--- compute (d0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+14497, int_stack+14119, int_stack+13849, 6);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+13849, int_stack+3850, int_stack+3700, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15037, int_stack+4060, int_stack+3850, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2700, int_stack+15037, int_stack+13849, 10);
 /*--- compute (dp|[r12,T1]|gd) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+24667, int_stack+2700, int_stack+14497, int_stack+540, int_stack+1944, int_stack+0, 4, 2);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+13849, int_stack+4565, int_stack+4340, 15);
 /*--- compute (g0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14524, int_stack+4880, int_stack+4565, 15);
 /*--- compute (g0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+3600, int_stack+14524, int_stack+13849, 15);
 /*--- compute (fp|[r12,T1]|gd) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+26287, int_stack+3600, int_stack+2700, int_stack+9928, int_stack+18439, int_stack+540, 4, 2);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+18439, int_stack+5390, int_stack+5300, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18709, int_stack+5516, int_stack+5390, 6);
 /*--- compute (d0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+19087, int_stack+18709, int_stack+18439, 6);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+18439, int_stack+5834, int_stack+5684, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9928, int_stack+6044, int_stack+5834, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+10558, int_stack+9928, int_stack+18439, 10);
 /*--- compute (dp||gd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+13849, int_stack+10558, int_stack+19087, 90);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+18439, int_stack+6549, int_stack+6324, 15);
 /*--- compute (g0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+6864, int_stack+6549, 15);
 /*--- compute (g0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+945, int_stack+0, int_stack+18439, 15);
 /*--- compute (fp||gd) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+2295, int_stack+945, int_stack+10558, 90);
 /*--- compute (dd|[r12,T2]|gd) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+4995, int_stack+15739, int_stack+12229, 90);
     Libr12->te_ptr[3] = int_stack + 4995;
 /*--- compute (dd|[r12,T1]|gd) ---*/
   t1hrr1_build_dd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+9928, int_stack+26287, int_stack+24667, int_stack+21967, int_stack+19699, int_stack+8308, 4, 2);
     Libr12->te_ptr[2] = int_stack + 9928;
 /*--- compute (dd||gd) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+24667, int_stack+2295, int_stack+13849, 90);
     Libr12->te_ptr[1] = int_stack + 24667;
 /*--- compute (dd|gd) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+21967, int_stack+8308, 90);
     Libr12->te_ptr[0] = int_stack + 0;

}
