/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ddgp(Libr12_t *, prim_data *);

  /* Computes (dd|gp) integrals for linear R12-methods */

void hrr_grt_order_ddgp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][4] = int_stack + 0;
 Libr12->t2vrr_classes[2][5] = int_stack + 90;
 Libr12->t2vrr_classes[3][4] = int_stack + 216;
 Libr12->t2vrr_classes[3][5] = int_stack + 366;
 Libr12->gvrr_classes[5][4] = int_stack + 576;
 Libr12->t2vrr_classes[4][4] = int_stack + 891;
 Libr12->t2vrr_classes[4][5] = int_stack + 1116;
 Libr12->gvrr_classes[2][6] = int_stack + 1431;
 Libr12->t1vrr_classes[2][4] = int_stack + 1599;
 Libr12->t1vrr_classes[2][5] = int_stack + 1689;
 Libr12->gvrr_classes[3][6] = int_stack + 1815;
 Libr12->t1vrr_classes[3][4] = int_stack + 2095;
 Libr12->t1vrr_classes[3][5] = int_stack + 2245;
 Libr12->t1vrr_classes[4][4] = int_stack + 2455;
 Libr12->t1vrr_classes[4][5] = int_stack + 2680;
 Libr12->rvrr_classes[2][4] = int_stack + 2995;
 Libr12->rvrr_classes[2][5] = int_stack + 3085;
 Libr12->rvrr_classes[3][4] = int_stack + 3211;
 Libr12->rvrr_classes[3][5] = int_stack + 3361;
 Libr12->rvrr_classes[4][4] = int_stack + 3571;
 Libr12->rvrr_classes[4][5] = int_stack + 3796;
 Libr12->gvrr_classes[2][4] = int_stack + 4111;
 Libr12->gvrr_classes[2][5] = int_stack + 4201;
 Libr12->gvrr_classes[3][4] = int_stack + 4327;
 Libr12->gvrr_classes[3][5] = int_stack + 4477;
 Libr12->gvrr_classes[4][4] = int_stack + 4687;
 Libr12->gvrr_classes[4][5] = int_stack + 4912;
 memset(int_stack,0,5227*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 5227;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ddgp(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5227, int_stack+90, int_stack+0, int_stack+4201, int_stack+4327, int_stack+4111, 2, 0);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5497, int_stack+366, int_stack+216, int_stack+4477, int_stack+4687, int_stack+4327, 3, 0);
 /*--- compute (dp|[r12,T2]|gp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+5947, int_stack+5497, int_stack+5227, 45);
 /*--- compute (g0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6757, int_stack+1116, int_stack+891, int_stack+4912, int_stack+576, int_stack+4687, 4, 0);
 /*--- compute (fp|[r12,T2]|gp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+6757, int_stack+5497, 45);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6757, int_stack+4201, int_stack+4111, 6);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7027, int_stack+4477, int_stack+4327, 10);
 /*--- compute (dp|gp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+7477, int_stack+7027, int_stack+6757, 45);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+8287, int_stack+1431, int_stack+4201, 6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+5227, int_stack+1815, int_stack+4477, 10);
 /*--- compute (dp|hp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+8665, int_stack+5227, int_stack+8287, 63);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9799, int_stack+4912, int_stack+4687, 15);
 /*--- compute (fp|gp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+10474, int_stack+9799, int_stack+7027, 45);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1815, int_stack+1689, int_stack+1599, 6);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4111, int_stack+2245, int_stack+2095, 10);
 /*--- compute (dp|[r12,T1]|gp) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+11824, int_stack+4111, int_stack+1815, int_stack+7027, int_stack+8287, int_stack+6757, 4, 1);
 /*--- compute (g0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+1350, int_stack+2680, int_stack+2455, 15);
 /*--- compute (fp|[r12,T1]|gp) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+12634, int_stack+1350, int_stack+4111, int_stack+9799, int_stack+5227, int_stack+7027, 4, 1);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9799, int_stack+3085, int_stack+2995, 6);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4111, int_stack+3361, int_stack+3211, 10);
 /*--- compute (dp||gp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+4561, int_stack+4111, int_stack+9799, 45);
 /*--- compute (g0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9799, int_stack+3796, int_stack+3571, 15);
 /*--- compute (fp||gp) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+1350, int_stack+9799, int_stack+4111, 45);
 /*--- compute (dd|[r12,T2]|gp) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+2700, int_stack+0, int_stack+5947, 45);
     Libr12->te_ptr[3] = int_stack + 2700;
 /*--- compute (dd|[r12,T1]|gp) ---*/
   t1hrr1_build_dd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+5371, int_stack+12634, int_stack+11824, int_stack+10474, int_stack+8665, int_stack+7477, 4, 1);
     Libr12->te_ptr[2] = int_stack + 5371;
 /*--- compute (dd||gp) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+11824, int_stack+1350, int_stack+4561, 45);
     Libr12->te_ptr[1] = int_stack + 11824;
 /*--- compute (dd|gp) ---*/
   hrr1_build_dd(Libr12->ShellQuartet.AB,int_stack+0, int_stack+10474, int_stack+7477, 45);
     Libr12->te_ptr[0] = int_stack + 0;

}
