/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dpdp(Libr12_t *, prim_data *);

  /* Computes (dp|dp) integrals for linear R12-methods */

void hrr_grt_order_dpdp(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][2] = int_stack + 0;
 Libr12->t2vrr_classes[2][3] = int_stack + 36;
 Libr12->gvrr_classes[4][2] = int_stack + 96;
 Libr12->t2vrr_classes[3][2] = int_stack + 186;
 Libr12->t2vrr_classes[3][3] = int_stack + 246;
 Libr12->gvrr_classes[2][4] = int_stack + 346;
 Libr12->t1vrr_classes[2][2] = int_stack + 436;
 Libr12->t1vrr_classes[2][3] = int_stack + 472;
 Libr12->t1vrr_classes[3][2] = int_stack + 532;
 Libr12->t1vrr_classes[3][3] = int_stack + 592;
 Libr12->rvrr_classes[2][2] = int_stack + 692;
 Libr12->rvrr_classes[2][3] = int_stack + 728;
 Libr12->rvrr_classes[3][2] = int_stack + 788;
 Libr12->rvrr_classes[3][3] = int_stack + 848;
 Libr12->gvrr_classes[2][2] = int_stack + 948;
 Libr12->gvrr_classes[2][3] = int_stack + 984;
 Libr12->gvrr_classes[3][2] = int_stack + 1044;
 Libr12->gvrr_classes[3][3] = int_stack + 1104;
 memset(int_stack,0,1204*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 1204;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dpdp(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|[r12,T2]|dp) ---*/
   t2hrr3_build_dp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1204, int_stack+36, int_stack+0, int_stack+984, int_stack+1044, int_stack+948, 2, 0);
 /*--- compute (f0|[r12,T2]|dp) ---*/
   t2hrr3_build_dp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1312, int_stack+246, int_stack+186, int_stack+1104, int_stack+96, int_stack+1044, 3, 0);
 /*--- compute (d0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+984, int_stack+948, 6);
 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+108, int_stack+346, int_stack+984, 6);
 /*--- compute (f0|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1492, int_stack+1104, int_stack+1044, 10);
 /*--- compute (d0|[r12,T1]|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+948, int_stack+472, int_stack+436, 6);
 /*--- compute (f0|[r12,T1]|dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+288, int_stack+592, int_stack+532, 10);
 /*--- compute (d0||dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+1056, int_stack+728, int_stack+692, 6);
 /*--- compute (f0||dp) ---*/
   hrr3_build_dp(Libr12->ShellQuartet.CD,int_stack+468, int_stack+848, int_stack+788, 10);
 /*--- compute (dp|[r12,T2]|dp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+1672, int_stack+1312, int_stack+1204, 18);
     Libr12->te_ptr[3] = int_stack + 1672;
 /*--- compute (dp|[r12,T1]|dp) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+1164, int_stack+288, int_stack+948, int_stack+1492, int_stack+108, int_stack+0, 2, 1);
     Libr12->te_ptr[2] = int_stack + 1164;
 /*--- compute (dp||dp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+108, int_stack+468, int_stack+1056, 18);
     Libr12->te_ptr[1] = int_stack + 108;
 /*--- compute (dp|dp) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+432, int_stack+1492, int_stack+0, 18);
     Libr12->te_ptr[0] = int_stack + 432;

}
