/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dpgd(Libr12_t *, prim_data *);

  /* Computes (dp|gd) integrals for linear R12-methods */

void hrr_grt_order_dpgd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][4] = int_stack + 0;
 Libr12->t2vrr_classes[2][5] = int_stack + 90;
 Libr12->t2vrr_classes[2][6] = int_stack + 216;
 Libr12->gvrr_classes[4][4] = int_stack + 384;
 Libr12->t2vrr_classes[3][4] = int_stack + 609;
 Libr12->gvrr_classes[4][5] = int_stack + 759;
 Libr12->t2vrr_classes[3][5] = int_stack + 1074;
 Libr12->t2vrr_classes[3][6] = int_stack + 1284;
 Libr12->gvrr_classes[2][7] = int_stack + 1564;
 Libr12->t1vrr_classes[2][4] = int_stack + 1780;
 Libr12->t1vrr_classes[2][5] = int_stack + 1870;
 Libr12->t1vrr_classes[2][6] = int_stack + 1996;
 Libr12->t1vrr_classes[3][4] = int_stack + 2164;
 Libr12->t1vrr_classes[3][5] = int_stack + 2314;
 Libr12->t1vrr_classes[3][6] = int_stack + 2524;
 Libr12->rvrr_classes[2][4] = int_stack + 2804;
 Libr12->rvrr_classes[2][5] = int_stack + 2894;
 Libr12->rvrr_classes[2][6] = int_stack + 3020;
 Libr12->rvrr_classes[3][4] = int_stack + 3188;
 Libr12->rvrr_classes[3][5] = int_stack + 3338;
 Libr12->rvrr_classes[3][6] = int_stack + 3548;
 Libr12->gvrr_classes[2][4] = int_stack + 3828;
 Libr12->gvrr_classes[2][5] = int_stack + 3918;
 Libr12->gvrr_classes[2][6] = int_stack + 4044;
 Libr12->gvrr_classes[3][4] = int_stack + 4212;
 Libr12->gvrr_classes[3][5] = int_stack + 4362;
 Libr12->gvrr_classes[3][6] = int_stack + 4572;
 memset(int_stack,0,4852*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 4852;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dpgd(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4852, int_stack+3918, int_stack+3828, 6);
 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+5122, int_stack+4362, int_stack+4212, 10);
 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+5572, int_stack+4044, int_stack+3918, 6);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+5950, int_stack+90, int_stack+0, int_stack+3918, int_stack+4212, int_stack+3828, 2, 0);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6220, int_stack+216, int_stack+90, int_stack+4044, int_stack+4362, int_stack+3918, 2, 0);
 /*--- compute (d0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+6598, int_stack+6220, int_stack+5950, int_stack+5572, int_stack+5122, int_stack+4852, 2, 0);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7138, int_stack+759, int_stack+384, 15);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+5950, int_stack+4572, int_stack+4362, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+7813, int_stack+1074, int_stack+609, int_stack+4362, int_stack+384, int_stack+4212, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+1284, int_stack+1074, int_stack+4572, int_stack+759, int_stack+4362, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+630, int_stack+0, int_stack+7813, int_stack+5950, int_stack+7138, int_stack+5122, 3, 0);
 /*--- compute (d0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+7138, int_stack+5572, int_stack+4852, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+7678, int_stack+1564, int_stack+4044, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+8182, int_stack+7678, int_stack+5572, 6);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+3828, int_stack+5950, int_stack+5122, 10);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7678, int_stack+1870, int_stack+1780, 6);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1996, int_stack+1870, 6);
 /*--- compute (d0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+4728, int_stack+0, int_stack+7678, 6);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7678, int_stack+2314, int_stack+2164, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2524, int_stack+2314, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+5268, int_stack+0, int_stack+7678, 10);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7678, int_stack+2894, int_stack+2804, 6);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3020, int_stack+2894, 6);
 /*--- compute (d0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1530, int_stack+0, int_stack+7678, 6);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+7678, int_stack+3338, int_stack+3188, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+3548, int_stack+3338, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2070, int_stack+0, int_stack+7678, 10);
 /*--- compute (dp|[r12,T2]|gd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+8938, int_stack+630, int_stack+6598, 90);
     Libr12->te_ptr[3] = int_stack + 8938;
 /*--- compute (dp|[r12,T1]|gd) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+10558, int_stack+5268, int_stack+4728, int_stack+3828, int_stack+8182, int_stack+7138, 4, 2);
     Libr12->te_ptr[2] = int_stack + 10558;
 /*--- compute (dp||gd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+4728, int_stack+2070, int_stack+1530, 90);
     Libr12->te_ptr[1] = int_stack + 4728;
 /*--- compute (dp|gd) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+3828, int_stack+7138, 90);
     Libr12->te_ptr[0] = int_stack + 0;

}
