/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_dphg(Libr12_t *, prim_data *);

  /* Computes (dp|hg) integrals for linear R12-methods */

void hrr_grt_order_dphg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[2][5] = int_stack + 0;
 Libr12->t2vrr_classes[2][6] = int_stack + 126;
 Libr12->t2vrr_classes[2][7] = int_stack + 294;
 Libr12->t2vrr_classes[2][8] = int_stack + 510;
 Libr12->t2vrr_classes[2][9] = int_stack + 780;
 Libr12->gvrr_classes[4][5] = int_stack + 1110;
 Libr12->t2vrr_classes[3][5] = int_stack + 1425;
 Libr12->gvrr_classes[4][6] = int_stack + 1635;
 Libr12->t2vrr_classes[3][6] = int_stack + 2055;
 Libr12->gvrr_classes[4][7] = int_stack + 2335;
 Libr12->t2vrr_classes[3][7] = int_stack + 2875;
 Libr12->gvrr_classes[4][8] = int_stack + 3235;
 Libr12->t2vrr_classes[3][8] = int_stack + 3910;
 Libr12->t2vrr_classes[3][9] = int_stack + 4360;
 Libr12->gvrr_classes[2][10] = int_stack + 4910;
 Libr12->t1vrr_classes[2][5] = int_stack + 5306;
 Libr12->t1vrr_classes[2][6] = int_stack + 5432;
 Libr12->t1vrr_classes[2][7] = int_stack + 5600;
 Libr12->t1vrr_classes[2][8] = int_stack + 5816;
 Libr12->t1vrr_classes[2][9] = int_stack + 6086;
 Libr12->t1vrr_classes[3][5] = int_stack + 6416;
 Libr12->t1vrr_classes[3][6] = int_stack + 6626;
 Libr12->t1vrr_classes[3][7] = int_stack + 6906;
 Libr12->t1vrr_classes[3][8] = int_stack + 7266;
 Libr12->t1vrr_classes[3][9] = int_stack + 7716;
 Libr12->rvrr_classes[2][5] = int_stack + 8266;
 Libr12->rvrr_classes[2][6] = int_stack + 8392;
 Libr12->rvrr_classes[2][7] = int_stack + 8560;
 Libr12->rvrr_classes[2][8] = int_stack + 8776;
 Libr12->rvrr_classes[2][9] = int_stack + 9046;
 Libr12->rvrr_classes[3][5] = int_stack + 9376;
 Libr12->rvrr_classes[3][6] = int_stack + 9586;
 Libr12->rvrr_classes[3][7] = int_stack + 9866;
 Libr12->rvrr_classes[3][8] = int_stack + 10226;
 Libr12->rvrr_classes[3][9] = int_stack + 10676;
 Libr12->gvrr_classes[2][5] = int_stack + 11226;
 Libr12->gvrr_classes[2][6] = int_stack + 11352;
 Libr12->gvrr_classes[2][7] = int_stack + 11520;
 Libr12->gvrr_classes[2][8] = int_stack + 11736;
 Libr12->gvrr_classes[2][9] = int_stack + 12006;
 Libr12->gvrr_classes[3][5] = int_stack + 12336;
 Libr12->gvrr_classes[3][6] = int_stack + 12546;
 Libr12->gvrr_classes[3][7] = int_stack + 12826;
 Libr12->gvrr_classes[3][8] = int_stack + 13186;
 Libr12->gvrr_classes[3][9] = int_stack + 13636;
 memset(int_stack,0,14186*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 14186;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_dphg(Libr12, Data);
   Data++;
 }

 /*--- compute (d0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14186, int_stack+11352, int_stack+11226, 6);
 /*--- compute (d0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+14564, int_stack+11520, int_stack+11352, 6);
 /*--- compute (d0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+15068, int_stack+14564, int_stack+14186, 6);
 /*--- compute (d0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+15824, int_stack+11736, int_stack+11520, 6);
 /*--- compute (d0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+16472, int_stack+15824, int_stack+14564, 6);
 /*--- compute (d0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+17480, int_stack+16472, int_stack+15068, 6);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+18740, int_stack+12546, int_stack+12336, 10);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19370, int_stack+12826, int_stack+12546, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+20210, int_stack+19370, int_stack+18740, 10);
 /*--- compute (f0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+21470, int_stack+13186, int_stack+12826, 10);
 /*--- compute (f0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+22550, int_stack+21470, int_stack+19370, 10);
 /*--- compute (f0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+24230, int_stack+22550, int_stack+20210, 10);
 /*--- compute (d0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+26330, int_stack+12006, int_stack+11736, 6);
 /*--- compute (d0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+27140, int_stack+26330, int_stack+15824, 6);
 /*--- compute (d0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+28436, int_stack+27140, int_stack+16472, 6);
 /*--- compute (d0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30116, int_stack+126, int_stack+0, int_stack+11352, int_stack+12336, int_stack+11226, 2, 0);
 /*--- compute (d0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30494, int_stack+294, int_stack+126, int_stack+11520, int_stack+12546, int_stack+11352, 2, 0);
 /*--- compute (d0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30998, int_stack+30494, int_stack+30116, int_stack+14564, int_stack+18740, int_stack+14186, 2, 0);
 /*--- compute (d0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+31754, int_stack+510, int_stack+294, int_stack+11736, int_stack+12826, int_stack+11520, 2, 0);
 /*--- compute (d0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32402, int_stack+31754, int_stack+30494, int_stack+15824, int_stack+19370, int_stack+14564, 2, 0);
 /*--- compute (d0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+33410, int_stack+32402, int_stack+30998, int_stack+16472, int_stack+20210, int_stack+15068, 2, 0);
 /*--- compute (d0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14186, int_stack+780, int_stack+510, int_stack+12006, int_stack+13186, int_stack+11736, 2, 0);
 /*--- compute (d0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30116, int_stack+14186, int_stack+31754, int_stack+26330, int_stack+21470, int_stack+15824, 2, 0);
 /*--- compute (d0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14186, int_stack+30116, int_stack+32402, int_stack+27140, int_stack+22550, int_stack+16472, 2, 0);
 /*--- compute (d0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+30116, int_stack+14186, int_stack+33410, int_stack+28436, int_stack+24230, int_stack+17480, 2, 0);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+14186, int_stack+1635, int_stack+1110, 15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+15131, int_stack+2335, int_stack+1635, 15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+32006, int_stack+15131, int_stack+14186, 15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+33896, int_stack+3235, int_stack+2335, 15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+35516, int_stack+33896, int_stack+15131, 15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+38036, int_stack+35516, int_stack+32006, 15);
 /*--- compute (f0|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+41186, int_stack+13636, int_stack+13186, 10);
 /*--- compute (f0|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+42536, int_stack+41186, int_stack+21470, 10);
 /*--- compute (f0|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+44696, int_stack+42536, int_stack+22550, 10);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16391, int_stack+2055, int_stack+1425, int_stack+12546, int_stack+1110, int_stack+12336, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+2875, int_stack+2055, int_stack+12826, int_stack+1635, int_stack+12546, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+840, int_stack+0, int_stack+16391, int_stack+19370, int_stack+14186, int_stack+18740, 3, 0);
 /*--- compute (f0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+16391, int_stack+3910, int_stack+2875, int_stack+13186, int_stack+2335, int_stack+12826, 3, 0);
 /*--- compute (f0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+47496, int_stack+16391, int_stack+0, int_stack+21470, int_stack+15131, int_stack+19370, 3, 0);
 /*--- compute (f0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14186, int_stack+47496, int_stack+840, int_stack+22550, int_stack+32006, int_stack+20210, 3, 0);
 /*--- compute (f0|[r12,T2]|lp) ---*/
   t2hrr3_build_lp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32006, int_stack+4360, int_stack+3910, int_stack+13636, int_stack+3235, int_stack+13186, 3, 0);
 /*--- compute (f0|[r12,T2]|kd) ---*/
   t2hrr3_build_kd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+32006, int_stack+16391, int_stack+41186, int_stack+33896, int_stack+21470, 3, 0);
 /*--- compute (f0|[r12,T2]|if) ---*/
   t2hrr3_build_if(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32006, int_stack+0, int_stack+47496, int_stack+42536, int_stack+35516, int_stack+22550, 3, 0);
 /*--- compute (f0|[r12,T2]|hg) ---*/
   t2hrr3_build_hg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+32006, int_stack+14186, int_stack+44696, int_stack+38036, int_stack+24230, 3, 0);
 /*--- compute (d0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+32006, int_stack+28436, int_stack+17480, 6);
 /*--- compute (d0|mp) ---*/
   hrr3_build_mp(Libr12->ShellQuartet.CD,int_stack+33896, int_stack+4910, int_stack+12006, 6);
 /*--- compute (d0|ld) ---*/
   hrr3_build_ld(Libr12->ShellQuartet.CD,int_stack+34886, int_stack+33896, int_stack+26330, 6);
 /*--- compute (d0|kf) ---*/
   hrr3_build_kf(Libr12->ShellQuartet.CD,int_stack+36506, int_stack+34886, int_stack+27140, 6);
 /*--- compute (d0|ig) ---*/
   hrr3_build_ig(Libr12->ShellQuartet.CD,int_stack+33896, int_stack+36506, int_stack+28436, 6);
 /*--- compute (f0|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+26330, int_stack+44696, int_stack+24230, 10);
 /*--- compute (d0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+29480, int_stack+5432, int_stack+5306, 6);
 /*--- compute (d0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+5600, int_stack+5432, 6);
 /*--- compute (d0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+36920, int_stack+36416, int_stack+29480, 6);
 /*--- compute (d0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+37676, int_stack+5816, int_stack+5600, 6);
 /*--- compute (d0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+38324, int_stack+37676, int_stack+36416, 6);
 /*--- compute (d0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+39332, int_stack+38324, int_stack+36920, 6);
 /*--- compute (d0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+6086, int_stack+5816, 6);
 /*--- compute (d0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+40592, int_stack+36416, int_stack+37676, 6);
 /*--- compute (d0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+40592, int_stack+38324, 6);
 /*--- compute (d0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+40592, int_stack+36416, int_stack+39332, 6);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+6626, int_stack+6416, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+37046, int_stack+6906, int_stack+6626, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+37886, int_stack+37046, int_stack+36416, 10);
 /*--- compute (f0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+39146, int_stack+7266, int_stack+6906, 10);
 /*--- compute (f0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+42482, int_stack+39146, int_stack+37046, 10);
 /*--- compute (f0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+44162, int_stack+42482, int_stack+37886, 10);
 /*--- compute (f0|[r12,T1]|lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+7716, int_stack+7266, 10);
 /*--- compute (f0|[r12,T1]|kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+46262, int_stack+36416, int_stack+39146, 10);
 /*--- compute (f0|[r12,T1]|if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+46262, int_stack+42482, 10);
 /*--- compute (f0|[r12,T1]|hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+46262, int_stack+36416, int_stack+44162, 10);
 /*--- compute (d0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+8392, int_stack+8266, 6);
 /*--- compute (d0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+36794, int_stack+8560, int_stack+8392, 6);
 /*--- compute (d0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+37298, int_stack+36794, int_stack+36416, 6);
 /*--- compute (d0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+38054, int_stack+8776, int_stack+8560, 6);
 /*--- compute (d0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+38702, int_stack+38054, int_stack+36794, 6);
 /*--- compute (d0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+42482, int_stack+38702, int_stack+37298, 6);
 /*--- compute (d0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+9046, int_stack+8776, 6);
 /*--- compute (d0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+43742, int_stack+36416, int_stack+38054, 6);
 /*--- compute (d0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+43742, int_stack+38702, 6);
 /*--- compute (d0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+43742, int_stack+36416, int_stack+42482, 6);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+45632, int_stack+9586, int_stack+9376, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+42482, int_stack+9866, int_stack+9586, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+36416, int_stack+42482, int_stack+45632, 10);
 /*--- compute (f0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+37676, int_stack+10226, int_stack+9866, 10);
 /*--- compute (f0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+38756, int_stack+37676, int_stack+42482, 10);
 /*--- compute (f0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+3150, int_stack+38756, int_stack+36416, 10);
 /*--- compute (f0||lp) ---*/
   hrr3_build_lp(Libr12->ShellQuartet.CD,int_stack+5250, int_stack+10676, int_stack+10226, 10);
 /*--- compute (f0||kd) ---*/
   hrr3_build_kd(Libr12->ShellQuartet.CD,int_stack+6600, int_stack+5250, int_stack+37676, 10);
 /*--- compute (f0||if) ---*/
   hrr3_build_if(Libr12->ShellQuartet.CD,int_stack+8760, int_stack+6600, int_stack+38756, 10);
 /*--- compute (f0||hg) ---*/
   hrr3_build_hg(Libr12->ShellQuartet.CD,int_stack+5250, int_stack+8760, int_stack+3150, 10);
 /*--- compute (dp|[r12,T2]|hg) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+8400, int_stack+0, int_stack+30116, 315);
     Libr12->te_ptr[3] = int_stack + 8400;
 /*--- compute (dp|[r12,T1]|hg) ---*/
   t1hrr1_build_dp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+14070, int_stack+46262, int_stack+40592, int_stack+26330, int_stack+33896, int_stack+32006, 5, 4);
     Libr12->te_ptr[2] = int_stack + 14070;
 /*--- compute (dp||hg) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+33896, int_stack+5250, int_stack+43742, 315);
     Libr12->te_ptr[1] = int_stack + 33896;
 /*--- compute (dp|hg) ---*/
   hrr1_build_dp(Libr12->ShellQuartet.AB,int_stack+39566, int_stack+26330, int_stack+32006, 315);
     Libr12->te_ptr[0] = int_stack + 39566;

}
