/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_f0gf(Libr12_t *, prim_data *);

  /* Computes (f0|gf) integrals for linear R12-methods */

void hrr_grt_order_f0gf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[4][4] = int_stack + 0;
 Libr12->t2vrr_classes[3][4] = int_stack + 225;
 Libr12->gvrr_classes[4][5] = int_stack + 375;
 Libr12->t2vrr_classes[3][5] = int_stack + 690;
 Libr12->gvrr_classes[4][6] = int_stack + 900;
 Libr12->t2vrr_classes[3][6] = int_stack + 1320;
 Libr12->t2vrr_classes[3][7] = int_stack + 1600;
 Libr12->t1vrr_classes[3][4] = int_stack + 1960;
 Libr12->t1vrr_classes[3][5] = int_stack + 2110;
 Libr12->t1vrr_classes[3][6] = int_stack + 2320;
 Libr12->t1vrr_classes[3][7] = int_stack + 2600;
 Libr12->rvrr_classes[3][4] = int_stack + 2960;
 Libr12->rvrr_classes[3][5] = int_stack + 3110;
 Libr12->rvrr_classes[3][6] = int_stack + 3320;
 Libr12->rvrr_classes[3][7] = int_stack + 3600;
 Libr12->gvrr_classes[3][4] = int_stack + 3960;
 Libr12->gvrr_classes[3][5] = int_stack + 4110;
 Libr12->gvrr_classes[3][6] = int_stack + 4320;
 Libr12->gvrr_classes[3][7] = int_stack + 4600;
 memset(int_stack,0,4960*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 4960;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_f0gf(Libr12, Data);
   Data++;
 }

 /*--- compute (f0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+4960, int_stack+4110, int_stack+3960, 10);
 /*--- compute (f0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+5410, int_stack+4320, int_stack+4110, 10);
 /*--- compute (f0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+6040, int_stack+5410, int_stack+4960, 10);
 /*--- compute (g0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+6940, int_stack+375, int_stack+0, 15);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+7615, int_stack+900, int_stack+375, 15);
 /*--- compute (g0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+8560, int_stack+7615, int_stack+6940, 15);
 /*--- compute (f0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9910, int_stack+4600, int_stack+4320, 10);
 /*--- compute (f0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+10750, int_stack+9910, int_stack+5410, 10);
 /*--- compute (f0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12010, int_stack+690, int_stack+225, int_stack+4110, int_stack+0, int_stack+3960, 3, 0);
 /*--- compute (f0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+12460, int_stack+1320, int_stack+690, int_stack+4320, int_stack+375, int_stack+4110, 3, 0);
 /*--- compute (f0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+12460, int_stack+12010, int_stack+5410, int_stack+6940, int_stack+4960, 3, 0);
 /*--- compute (f0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+13090, int_stack+1600, int_stack+1320, int_stack+4600, int_stack+900, int_stack+4320, 3, 0);
 /*--- compute (f0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+3960, int_stack+13090, int_stack+12460, int_stack+9910, int_stack+7615, int_stack+5410, 3, 0);
 /*--- compute (f0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+9910, int_stack+2110, int_stack+1960, 10);
 /*--- compute (f0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+900, int_stack+2320, int_stack+2110, 10);
 /*--- compute (f0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+6940, int_stack+900, int_stack+9910, 10);
 /*--- compute (f0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+9910, int_stack+2600, int_stack+2320, 10);
 /*--- compute (f0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1530, int_stack+9910, int_stack+900, 10);
 /*--- compute (f0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+900, int_stack+3110, int_stack+2960, 10);
 /*--- compute (f0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+9910, int_stack+3320, int_stack+3110, 10);
 /*--- compute (f0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+12010, int_stack+9910, int_stack+900, 10);
 /*--- compute (f0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+12910, int_stack+3600, int_stack+3320, 10);
 /*--- compute (f0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+13750, int_stack+12910, int_stack+9910, 10);
 /*--- compute (f0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+15010, int_stack+3960, int_stack+0, int_stack+10750, int_stack+8560, int_stack+6040, 3, 0);
     Libr12->te_ptr[3] = int_stack + 15010;
 /*--- compute (f0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+1530, int_stack+6940, 10);
     Libr12->te_ptr[2] = int_stack + 0;
 /*--- compute (f0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+6940, int_stack+13750, int_stack+12010, 10);
     Libr12->te_ptr[1] = int_stack + 6940;
 /*--- compute (f0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+12010, int_stack+10750, int_stack+6040, 10);
     Libr12->te_ptr[0] = int_stack + 12010;

}
