/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_fdh0(Libr12_t *, prim_data *);

  /* Computes (fd|h0) integrals for linear R12-methods */

void hrr_grt_order_fdh0(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[3][5] = int_stack + 0;
 Libr12->t2vrr_classes[4][5] = int_stack + 210;
 Libr12->t2vrr_classes[5][5] = int_stack + 525;
 Libr12->gvrr_classes[3][6] = int_stack + 966;
 Libr12->t1vrr_classes[3][5] = int_stack + 1246;
 Libr12->gvrr_classes[4][6] = int_stack + 1456;
 Libr12->t1vrr_classes[4][5] = int_stack + 1876;
 Libr12->t1vrr_classes[5][5] = int_stack + 2191;
 Libr12->rvrr_classes[3][5] = int_stack + 2632;
 Libr12->rvrr_classes[4][5] = int_stack + 2842;
 Libr12->rvrr_classes[5][5] = int_stack + 3157;
 Libr12->gvrr_classes[3][5] = int_stack + 3598;
 Libr12->gvrr_classes[4][5] = int_stack + 3808;
 Libr12->gvrr_classes[5][5] = int_stack + 4123;
 memset(int_stack,0,4564*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 4564;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_fdh0(Libr12, Data);
   Data++;
 }

 /*--- compute (fp|[r12,T2]|h0) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+4564, int_stack+210, int_stack+0, 21);
 /*--- compute (gp|[r12,T2]|h0) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+5194, int_stack+525, int_stack+210, 21);
 /*--- compute (fp|h0) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+3808, int_stack+3598, 21);
 /*--- compute (fp|i0) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+6139, int_stack+1456, int_stack+966, 28);
 /*--- compute (gp|h0) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+6979, int_stack+4123, int_stack+3808, 21);
 /*--- compute (fp|[r12,T1]|h0) ---*/
   t1hrr1_build_fp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+7924, int_stack+1876, int_stack+1246, int_stack+3808, int_stack+966, int_stack+3598, 5, 0);
 /*--- compute (gp|[r12,T1]|h0) ---*/
   t1hrr1_build_gp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+8554, int_stack+2191, int_stack+1876, int_stack+4123, int_stack+1456, int_stack+3808, 5, 0);
 /*--- compute (fp||h0) ---*/
   hrr1_build_fp(Libr12->ShellQuartet.AB,int_stack+3598, int_stack+2842, int_stack+2632, 21);
 /*--- compute (gp||h0) ---*/
   hrr1_build_gp(Libr12->ShellQuartet.AB,int_stack+630, int_stack+3157, int_stack+2842, 21);
 /*--- compute (fd|[r12,T2]|h0) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+1575, int_stack+5194, int_stack+4564, 21);
     Libr12->te_ptr[3] = int_stack + 1575;
 /*--- compute (fd|[r12,T1]|h0) ---*/
   t1hrr1_build_fd(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+4228, int_stack+8554, int_stack+7924, int_stack+6979, int_stack+6139, int_stack+0, 5, 0);
     Libr12->te_ptr[2] = int_stack + 4228;
 /*--- compute (fd||h0) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+7924, int_stack+630, int_stack+3598, 21);
     Libr12->te_ptr[1] = int_stack + 7924;
 /*--- compute (fd|h0) ---*/
   hrr1_build_fd(Libr12->ShellQuartet.AB,int_stack+5488, int_stack+6979, int_stack+0, 21);
     Libr12->te_ptr[0] = int_stack + 5488;

}
