/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_h0gf(Libr12_t *, prim_data *);

  /* Computes (h0|gf) integrals for linear R12-methods */

void hrr_grt_order_h0gf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[6][4] = int_stack + 0;
 Libr12->t2vrr_classes[5][4] = int_stack + 420;
 Libr12->gvrr_classes[6][5] = int_stack + 735;
 Libr12->t2vrr_classes[5][5] = int_stack + 1323;
 Libr12->gvrr_classes[6][6] = int_stack + 1764;
 Libr12->t2vrr_classes[5][6] = int_stack + 2548;
 Libr12->t2vrr_classes[5][7] = int_stack + 3136;
 Libr12->t1vrr_classes[5][4] = int_stack + 3892;
 Libr12->t1vrr_classes[5][5] = int_stack + 4207;
 Libr12->t1vrr_classes[5][6] = int_stack + 4648;
 Libr12->t1vrr_classes[5][7] = int_stack + 5236;
 Libr12->rvrr_classes[5][4] = int_stack + 5992;
 Libr12->rvrr_classes[5][5] = int_stack + 6307;
 Libr12->rvrr_classes[5][6] = int_stack + 6748;
 Libr12->rvrr_classes[5][7] = int_stack + 7336;
 Libr12->gvrr_classes[5][4] = int_stack + 8092;
 Libr12->gvrr_classes[5][5] = int_stack + 8407;
 Libr12->gvrr_classes[5][6] = int_stack + 8848;
 Libr12->gvrr_classes[5][7] = int_stack + 9436;
 memset(int_stack,0,10192*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 10192;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_h0gf(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+10192, int_stack+8407, int_stack+8092, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+11137, int_stack+8848, int_stack+8407, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+12460, int_stack+11137, int_stack+10192, 21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+14350, int_stack+735, int_stack+0, 28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15610, int_stack+1764, int_stack+735, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+17374, int_stack+15610, int_stack+14350, 28);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19894, int_stack+9436, int_stack+8848, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+21658, int_stack+19894, int_stack+11137, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+24304, int_stack+1323, int_stack+420, int_stack+8407, int_stack+0, int_stack+8092, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+25249, int_stack+2548, int_stack+1323, int_stack+8848, int_stack+735, int_stack+8407, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+26572, int_stack+25249, int_stack+24304, int_stack+11137, int_stack+14350, int_stack+10192, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+3136, int_stack+2548, int_stack+9436, int_stack+1764, int_stack+8848, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8092, int_stack+0, int_stack+25249, int_stack+19894, int_stack+15610, int_stack+11137, 5, 0);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+19894, int_stack+4207, int_stack+3892, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+4648, int_stack+4207, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+1323, int_stack+0, int_stack+19894, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19894, int_stack+5236, int_stack+4648, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+3213, int_stack+19894, int_stack+0, 21);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+6307, int_stack+5992, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+19894, int_stack+6748, int_stack+6307, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+14350, int_stack+19894, int_stack+0, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+24304, int_stack+7336, int_stack+6748, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+28462, int_stack+24304, int_stack+19894, 21);
 /*--- compute (h0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+31108, int_stack+8092, int_stack+26572, int_stack+21658, int_stack+17374, int_stack+12460, 5, 0);
     Libr12->te_ptr[3] = int_stack + 31108;
 /*--- compute (h0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+24304, int_stack+3213, int_stack+1323, 21);
     Libr12->te_ptr[2] = int_stack + 24304;
 /*--- compute (h0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+28462, int_stack+14350, 21);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+14350, int_stack+21658, int_stack+12460, 21);
     Libr12->te_ptr[0] = int_stack + 14350;

}
