/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_h0gg(Libr12_t *, prim_data *);

  /* Computes (h0|gg) integrals for linear R12-methods */

void hrr_grt_order_h0gg(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[6][4] = int_stack + 0;
 Libr12->t2vrr_classes[5][4] = int_stack + 420;
 Libr12->gvrr_classes[6][5] = int_stack + 735;
 Libr12->t2vrr_classes[5][5] = int_stack + 1323;
 Libr12->gvrr_classes[6][6] = int_stack + 1764;
 Libr12->t2vrr_classes[5][6] = int_stack + 2548;
 Libr12->gvrr_classes[6][7] = int_stack + 3136;
 Libr12->t2vrr_classes[5][7] = int_stack + 4144;
 Libr12->t2vrr_classes[5][8] = int_stack + 4900;
 Libr12->t1vrr_classes[5][4] = int_stack + 5845;
 Libr12->t1vrr_classes[5][5] = int_stack + 6160;
 Libr12->t1vrr_classes[5][6] = int_stack + 6601;
 Libr12->t1vrr_classes[5][7] = int_stack + 7189;
 Libr12->t1vrr_classes[5][8] = int_stack + 7945;
 Libr12->rvrr_classes[5][4] = int_stack + 8890;
 Libr12->rvrr_classes[5][5] = int_stack + 9205;
 Libr12->rvrr_classes[5][6] = int_stack + 9646;
 Libr12->rvrr_classes[5][7] = int_stack + 10234;
 Libr12->rvrr_classes[5][8] = int_stack + 10990;
 Libr12->gvrr_classes[5][4] = int_stack + 11935;
 Libr12->gvrr_classes[5][5] = int_stack + 12250;
 Libr12->gvrr_classes[5][6] = int_stack + 12691;
 Libr12->gvrr_classes[5][7] = int_stack + 13279;
 Libr12->gvrr_classes[5][8] = int_stack + 14035;
 memset(int_stack,0,14980*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 14980;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_h0gg(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+14980, int_stack+12250, int_stack+11935, 21);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+15925, int_stack+12691, int_stack+12250, 21);
 /*--- compute (h0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+17248, int_stack+15925, int_stack+14980, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+19138, int_stack+13279, int_stack+12691, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+20902, int_stack+19138, int_stack+15925, 21);
 /*--- compute (h0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+23548, int_stack+20902, int_stack+17248, 21);
 /*--- compute (i0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+26698, int_stack+735, int_stack+0, 28);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+27958, int_stack+1764, int_stack+735, 28);
 /*--- compute (i0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+29722, int_stack+27958, int_stack+26698, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+32242, int_stack+3136, int_stack+1764, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+34594, int_stack+32242, int_stack+27958, 28);
 /*--- compute (i0|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+38122, int_stack+34594, int_stack+29722, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+42322, int_stack+14035, int_stack+13279, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+44590, int_stack+42322, int_stack+19138, 21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+48118, int_stack+44590, int_stack+20902, 21);
 /*--- compute (h0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+52528, int_stack+1323, int_stack+420, int_stack+12250, int_stack+0, int_stack+11935, 5, 0);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+53473, int_stack+2548, int_stack+1323, int_stack+12691, int_stack+735, int_stack+12250, 5, 0);
 /*--- compute (h0|[r12,T2]|gd) ---*/
   t2hrr3_build_gd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+54796, int_stack+53473, int_stack+52528, int_stack+15925, int_stack+26698, int_stack+14980, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+4144, int_stack+2548, int_stack+13279, int_stack+1764, int_stack+12691, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+56686, int_stack+0, int_stack+53473, int_stack+19138, int_stack+27958, int_stack+15925, 5, 0);
 /*--- compute (h0|[r12,T2]|gf) ---*/
   t2hrr3_build_gf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+59332, int_stack+56686, int_stack+54796, int_stack+20902, int_stack+29722, int_stack+17248, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+14980, int_stack+4900, int_stack+4144, int_stack+14035, int_stack+3136, int_stack+13279, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+1764, int_stack+14980, int_stack+0, int_stack+42322, int_stack+32242, int_stack+19138, 5, 0);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+26698, int_stack+1764, int_stack+56686, int_stack+44590, int_stack+34594, int_stack+20902, 5, 0);
 /*--- compute (h0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+42322, int_stack+6160, int_stack+5845, 21);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+43267, int_stack+6601, int_stack+6160, 21);
 /*--- compute (h0|[r12,T1]|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+44590, int_stack+43267, int_stack+42322, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+7189, int_stack+6601, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1764, int_stack+0, int_stack+43267, 21);
 /*--- compute (h0|[r12,T1]|gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+31108, int_stack+1764, int_stack+44590, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+42322, int_stack+7945, int_stack+7189, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+44590, int_stack+42322, int_stack+0, 21);
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+4410, int_stack+44590, int_stack+1764, 21);
 /*--- compute (h0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+9205, int_stack+8890, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+945, int_stack+9646, int_stack+9205, 21);
 /*--- compute (h0||gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+2268, int_stack+945, int_stack+0, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+42322, int_stack+10234, int_stack+9646, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+44086, int_stack+42322, int_stack+945, 21);
 /*--- compute (h0||gf) ---*/
   hrr3_build_gf(Libr12->ShellQuartet.CD,int_stack+34258, int_stack+44086, int_stack+2268, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+10990, int_stack+10234, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+8820, int_stack+0, int_stack+42322, 21);
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+8820, int_stack+44086, 21);
 /*--- compute (h0|[r12,T2]|gg) ---*/
   t2hrr3_build_gg(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+8820, int_stack+26698, int_stack+59332, int_stack+48118, int_stack+38122, int_stack+23548, 5, 0);
     Libr12->te_ptr[3] = int_stack + 8820;
 /*--- compute (h0|[r12,T1]|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+13545, int_stack+4410, int_stack+31108, 21);
     Libr12->te_ptr[2] = int_stack + 13545;
 /*--- compute (h0||gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+26698, int_stack+0, int_stack+34258, 21);
     Libr12->te_ptr[1] = int_stack + 26698;
 /*--- compute (h0|gg) ---*/
   hrr3_build_gg(Libr12->ShellQuartet.CD,int_stack+0, int_stack+48118, int_stack+23548, 21);
     Libr12->te_ptr[0] = int_stack + 0;

}
