/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_h0hf(Libr12_t *, prim_data *);

  /* Computes (h0|hf) integrals for linear R12-methods */

void hrr_grt_order_h0hf(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->gvrr_classes[6][5] = int_stack + 0;
 Libr12->t2vrr_classes[5][5] = int_stack + 588;
 Libr12->gvrr_classes[6][6] = int_stack + 1029;
 Libr12->t2vrr_classes[5][6] = int_stack + 1813;
 Libr12->gvrr_classes[6][7] = int_stack + 2401;
 Libr12->t2vrr_classes[5][7] = int_stack + 3409;
 Libr12->t2vrr_classes[5][8] = int_stack + 4165;
 Libr12->t1vrr_classes[5][5] = int_stack + 5110;
 Libr12->t1vrr_classes[5][6] = int_stack + 5551;
 Libr12->t1vrr_classes[5][7] = int_stack + 6139;
 Libr12->t1vrr_classes[5][8] = int_stack + 6895;
 Libr12->rvrr_classes[5][5] = int_stack + 7840;
 Libr12->rvrr_classes[5][6] = int_stack + 8281;
 Libr12->rvrr_classes[5][7] = int_stack + 8869;
 Libr12->rvrr_classes[5][8] = int_stack + 9625;
 Libr12->gvrr_classes[5][5] = int_stack + 10570;
 Libr12->gvrr_classes[5][6] = int_stack + 11011;
 Libr12->gvrr_classes[5][7] = int_stack + 11599;
 Libr12->gvrr_classes[5][8] = int_stack + 12355;
 memset(int_stack,0,13300*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 13300;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_h0hf(Libr12, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+13300, int_stack+11011, int_stack+10570, 21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+14623, int_stack+11599, int_stack+11011, 21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+16387, int_stack+14623, int_stack+13300, 21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+19033, int_stack+1029, int_stack+0, 28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+20797, int_stack+2401, int_stack+1029, 28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+23149, int_stack+20797, int_stack+19033, 28);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+26677, int_stack+12355, int_stack+11599, 21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+28945, int_stack+26677, int_stack+14623, 21);
 /*--- compute (h0|[r12,T2]|hp) ---*/
   t2hrr3_build_hp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+32473, int_stack+1813, int_stack+588, int_stack+11011, int_stack+0, int_stack+10570, 5, 0);
 /*--- compute (h0|[r12,T2]|ip) ---*/
   t2hrr3_build_ip(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+33796, int_stack+3409, int_stack+1813, int_stack+11599, int_stack+1029, int_stack+11011, 5, 0);
 /*--- compute (h0|[r12,T2]|hd) ---*/
   t2hrr3_build_hd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+35560, int_stack+33796, int_stack+32473, int_stack+14623, int_stack+19033, int_stack+13300, 5, 0);
 /*--- compute (h0|[r12,T2]|kp) ---*/
   t2hrr3_build_kp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+4165, int_stack+3409, int_stack+12355, int_stack+2401, int_stack+11599, 5, 0);
 /*--- compute (h0|[r12,T2]|id) ---*/
   t2hrr3_build_id(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+10570, int_stack+0, int_stack+33796, int_stack+26677, int_stack+20797, int_stack+14623, 5, 0);
 /*--- compute (h0|[r12,T1]|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+26677, int_stack+5551, int_stack+5110, 21);
 /*--- compute (h0|[r12,T1]|ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+0, int_stack+6139, int_stack+5551, 21);
 /*--- compute (h0|[r12,T1]|hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+1764, int_stack+0, int_stack+26677, 21);
 /*--- compute (h0|[r12,T1]|kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+26677, int_stack+6895, int_stack+6139, 21);
 /*--- compute (h0|[r12,T1]|id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+19033, int_stack+26677, int_stack+0, 21);
 /*--- compute (h0||hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+0, int_stack+8281, int_stack+7840, 21);
 /*--- compute (h0||ip) ---*/
   hrr3_build_ip(Libr12->ShellQuartet.CD,int_stack+26677, int_stack+8869, int_stack+8281, 21);
 /*--- compute (h0||hd) ---*/
   hrr3_build_hd(Libr12->ShellQuartet.CD,int_stack+4410, int_stack+26677, int_stack+0, 21);
 /*--- compute (h0||kp) ---*/
   hrr3_build_kp(Libr12->ShellQuartet.CD,int_stack+32473, int_stack+9625, int_stack+8869, 21);
 /*--- compute (h0||id) ---*/
   hrr3_build_id(Libr12->ShellQuartet.CD,int_stack+38206, int_stack+32473, int_stack+26677, 21);
 /*--- compute (h0|[r12,T2]|hf) ---*/
   t2hrr3_build_hf(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+41734, int_stack+10570, int_stack+35560, int_stack+28945, int_stack+23149, int_stack+16387, 5, 0);
     Libr12->te_ptr[3] = int_stack + 41734;
 /*--- compute (h0|[r12,T1]|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+32473, int_stack+19033, int_stack+1764, 21);
     Libr12->te_ptr[2] = int_stack + 32473;
 /*--- compute (h0||hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+0, int_stack+38206, int_stack+4410, 21);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libr12->ShellQuartet.CD,int_stack+4410, int_stack+28945, int_stack+16387, 21);
     Libr12->te_ptr[0] = int_stack + 4410;

}
