/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/hrr_header.h>

#include "r12_hrr_header.h"

extern void vrr_grt_order_ppfd(Libr12_t *, prim_data *);

  /* Computes (pp|fd) integrals for linear R12-methods */

void hrr_grt_order_ppfd(Libr12_t *Libr12, int num_prim_comb)
{
 prim_data *Data = Libr12->PrimQuartet;
 REALTYPE *int_stack = Libr12->int_stack;
 int i,j;
 REALTYPE tmp, *target;

 Libr12->t2vrr_classes[1][3] = int_stack + 0;
 Libr12->t2vrr_classes[1][4] = int_stack + 30;
 Libr12->t2vrr_classes[1][5] = int_stack + 75;
 Libr12->gvrr_classes[3][3] = int_stack + 138;
 Libr12->t2vrr_classes[2][3] = int_stack + 238;
 Libr12->gvrr_classes[3][4] = int_stack + 298;
 Libr12->t2vrr_classes[2][4] = int_stack + 448;
 Libr12->t2vrr_classes[2][5] = int_stack + 538;
 Libr12->gvrr_classes[1][6] = int_stack + 664;
 Libr12->t1vrr_classes[1][3] = int_stack + 748;
 Libr12->t1vrr_classes[1][4] = int_stack + 778;
 Libr12->t1vrr_classes[1][5] = int_stack + 823;
 Libr12->t1vrr_classes[2][3] = int_stack + 886;
 Libr12->t1vrr_classes[2][4] = int_stack + 946;
 Libr12->t1vrr_classes[2][5] = int_stack + 1036;
 Libr12->rvrr_classes[1][3] = int_stack + 1162;
 Libr12->rvrr_classes[1][4] = int_stack + 1192;
 Libr12->rvrr_classes[1][5] = int_stack + 1237;
 Libr12->rvrr_classes[2][3] = int_stack + 1300;
 Libr12->rvrr_classes[2][4] = int_stack + 1360;
 Libr12->rvrr_classes[2][5] = int_stack + 1450;
 Libr12->gvrr_classes[1][3] = int_stack + 1576;
 Libr12->gvrr_classes[1][4] = int_stack + 1606;
 Libr12->gvrr_classes[1][5] = int_stack + 1651;
 Libr12->gvrr_classes[2][3] = int_stack + 1714;
 Libr12->gvrr_classes[2][4] = int_stack + 1774;
 Libr12->gvrr_classes[2][5] = int_stack + 1864;
 memset(int_stack,0,1990*sizeof(REALTYPE));

 Libr12->r12vrr_stack = int_stack + 1990;
 for(i=0;i<num_prim_comb;i++) {
   vrr_grt_order_ppfd(Libr12, Data);
   Data++;
 }

 /*--- compute (p0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+1990, int_stack+1606, int_stack+1576, 3);
 /*--- compute (d0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2080, int_stack+1774, int_stack+1714, 6);
 /*--- compute (p0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+2260, int_stack+1651, int_stack+1606, 3);
 /*--- compute (p0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2395, int_stack+30, int_stack+0, int_stack+1606, int_stack+1714, int_stack+1576, 1, 0);
 /*--- compute (p0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2485, int_stack+75, int_stack+30, int_stack+1651, int_stack+1774, int_stack+1606, 1, 0);
 /*--- compute (p0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2620, int_stack+2485, int_stack+2395, int_stack+2260, int_stack+2080, int_stack+1990, 1, 0);
 /*--- compute (f0|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2800, int_stack+298, int_stack+138, 10);
 /*--- compute (d0|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3100, int_stack+1864, int_stack+1774, 6);
 /*--- compute (d0|[r12,T2]|fp) ---*/
   t2hrr3_build_fp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+2395, int_stack+448, int_stack+238, int_stack+1774, int_stack+138, int_stack+1714, 2, 0);
 /*--- compute (d0|[r12,T2]|gp) ---*/
   t2hrr3_build_gp(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+0, int_stack+538, int_stack+448, int_stack+1864, int_stack+298, int_stack+1774, 2, 0);
 /*--- compute (d0|[r12,T2]|fd) ---*/
   t2hrr3_build_fd(Libr12->ShellQuartet.CD,Libr12->ShellQuartet.AC,int_stack+270, int_stack+0, int_stack+2395, int_stack+3100, int_stack+2800, int_stack+2080, 2, 0);
 /*--- compute (p0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+2800, int_stack+2260, int_stack+1990, 3);
 /*--- compute (p0|hp) ---*/
   hrr3_build_hp(Libr12->ShellQuartet.CD,int_stack+2395, int_stack+664, int_stack+1651, 3);
 /*--- compute (p0|gd) ---*/
   hrr3_build_gd(Libr12->ShellQuartet.CD,int_stack+0, int_stack+2395, int_stack+2260, 3);
 /*--- compute (d0|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+2260, int_stack+3100, int_stack+2080, 6);
 /*--- compute (p0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2980, int_stack+778, int_stack+748, 3);
 /*--- compute (p0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3070, int_stack+823, int_stack+778, 3);
 /*--- compute (p0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+3205, int_stack+3070, int_stack+2980, 3);
 /*--- compute (d0|[r12,T1]|fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2980, int_stack+946, int_stack+886, 6);
 /*--- compute (d0|[r12,T1]|gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3385, int_stack+1036, int_stack+946, 6);
 /*--- compute (d0|[r12,T1]|fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+1576, int_stack+3385, int_stack+2980, 6);
 /*--- compute (p0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2980, int_stack+1192, int_stack+1162, 3);
 /*--- compute (p0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3070, int_stack+1237, int_stack+1192, 3);
 /*--- compute (p0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+3385, int_stack+3070, int_stack+2980, 3);
 /*--- compute (d0||fp) ---*/
   hrr3_build_fp(Libr12->ShellQuartet.CD,int_stack+2980, int_stack+1360, int_stack+1300, 6);
 /*--- compute (d0||gp) ---*/
   hrr3_build_gp(Libr12->ShellQuartet.CD,int_stack+3565, int_stack+1450, int_stack+1360, 6);
 /*--- compute (d0||fd) ---*/
   hrr3_build_fd(Libr12->ShellQuartet.CD,int_stack+630, int_stack+3565, int_stack+2980, 6);
 /*--- compute (pp|[r12,T2]|fd) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+990, int_stack+270, int_stack+2620, 60);
     Libr12->te_ptr[3] = int_stack + 990;
 /*--- compute (pp|[r12,T1]|fd) ---*/
   t1hrr1_build_pp(Libr12->ShellQuartet.AB,Libr12->ShellQuartet.AC,int_stack+3565, int_stack+1576, int_stack+3205, int_stack+2260, int_stack+0, int_stack+2800, 3, 2);
     Libr12->te_ptr[2] = int_stack + 3565;
 /*--- compute (pp||fd) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+0, int_stack+630, int_stack+3385, 60);
     Libr12->te_ptr[1] = int_stack + 0;
 /*--- compute (pp|fd) ---*/
   hrr1_build_pp(Libr12->ShellQuartet.AB,int_stack+2980, int_stack+2260, int_stack+2800, 60);
     Libr12->te_ptr[0] = int_stack + 2980;

}
