/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_fdhh(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+0, r12vrr_stack+3, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^2 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+6, NULL, NULL, r12vrr_stack+0);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+49, r12vrr_stack+12, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+12, NULL);

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+68, r12vrr_stack+3, r12vrr_stack+12, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+74, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (p0|f0)^2 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+84, r12vrr_stack+39, r12vrr_stack+74, NULL, NULL, r12vrr_stack+6);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+114, r12vrr_stack+58, r12vrr_stack+39, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^1 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+144, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+21);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+204, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+15, r12vrr_stack+6, NULL);

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+219, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+234, r12vrr_stack+219, r12vrr_stack+204, NULL, NULL, r12vrr_stack+39);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+279, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+282, r12vrr_stack+279, r12vrr_stack+49, Data->F+0, Data->F+1, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+52, r12vrr_stack+279, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+58, r12vrr_stack+282, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+313, r12vrr_stack+298, r12vrr_stack+219, NULL, NULL, r12vrr_stack+58);

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+49, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+52, r12vrr_stack+12, r12vrr_stack+49, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+358, r12vrr_stack+68, r12vrr_stack+52, r12vrr_stack+3, r12vrr_stack+12, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+368, r12vrr_stack+74, r12vrr_stack+358, r12vrr_stack+6, r12vrr_stack+68, NULL);

 /*--- compute (p0|g0)^2 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+383, r12vrr_stack+204, r12vrr_stack+368, NULL, NULL, r12vrr_stack+74);

 /*--- compute (d0|g0)^1 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+428, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+84);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+518, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+114);

 /*--- compute (f0|g0)^0 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+608, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+313, r12vrr_stack+234, r12vrr_stack+144);

 /*--- compute (p0|p0)^3 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+758, r12vrr_stack+0, r12vrr_stack+3, NULL, NULL, Data->F+4);

 /*--- compute (p0|d0)^3 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+767, r12vrr_stack+6, r12vrr_stack+68, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^2 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+785, r12vrr_stack+21, r12vrr_stack+767, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+758);

 /*--- compute (p0|f0)^3 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+821, r12vrr_stack+74, r12vrr_stack+358, NULL, NULL, r12vrr_stack+68);

 /*--- compute (d0|f0)^2 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+851, r12vrr_stack+84, r12vrr_stack+821, r12vrr_stack+39, r12vrr_stack+74, r12vrr_stack+767);

 /*--- compute (f0|f0)^1 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+911, r12vrr_stack+144, r12vrr_stack+851, r12vrr_stack+114, r12vrr_stack+84, r12vrr_stack+785);

 /*--- compute (00|p0)^7 ---*/
 _BUILD_00p0(Data,r12vrr_stack+114, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /*--- compute (00|d0)^6 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+49, r12vrr_stack+114, Data->F+6, Data->F+7, NULL);

 /*--- compute (00|f0)^5 ---*/
 _BUILD_00f0(Data,r12vrr_stack+117, r12vrr_stack+52, r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+49, NULL);

 /*--- compute (00|g0)^4 ---*/
 _BUILD_00g0(Data,r12vrr_stack+127, r12vrr_stack+358, r12vrr_stack+117, r12vrr_stack+68, r12vrr_stack+52, NULL);

 /*--- compute (p0|g0)^3 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+1011, r12vrr_stack+368, r12vrr_stack+127, NULL, NULL, r12vrr_stack+358);

 /*--- compute (d0|g0)^2 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+1056, r12vrr_stack+383, r12vrr_stack+1011, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+821);

 /*--- compute (f0|g0)^1 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+1146, r12vrr_stack+428, r12vrr_stack+1056, r12vrr_stack+234, r12vrr_stack+383, r12vrr_stack+851);

 /*--- compute (g0|g0)^0 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+1296, r12vrr_stack+608, r12vrr_stack+1146, r12vrr_stack+518, r12vrr_stack+428, r12vrr_stack+911);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1521, r12vrr_stack+204, r12vrr_stack+368, r12vrr_stack+39, r12vrr_stack+74, NULL);

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1542, r12vrr_stack+219, r12vrr_stack+204, r12vrr_stack+58, r12vrr_stack+39, NULL);

 /*--- compute (00|h0)^3 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1563, r12vrr_stack+368, r12vrr_stack+127, r12vrr_stack+74, r12vrr_stack+358, NULL);

 /*--- compute (p0|h0)^2 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1584, r12vrr_stack+1521, r12vrr_stack+1563, NULL, NULL, r12vrr_stack+368);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1647, r12vrr_stack+1542, r12vrr_stack+1521, NULL, NULL, r12vrr_stack+204);

 /*--- compute (d0|h0)^1 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1710, r12vrr_stack+1647, r12vrr_stack+1584, r12vrr_stack+1542, r12vrr_stack+1521, r12vrr_stack+383);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1836, r12vrr_stack+298, r12vrr_stack+219, r12vrr_stack+288, r12vrr_stack+58, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+1857, r12vrr_stack+1836, r12vrr_stack+1542, NULL, NULL, r12vrr_stack+219);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+1647, r12vrr_stack+1836, r12vrr_stack+1542, r12vrr_stack+234);

 /*--- compute (00|p0)^8 ---*/
 _BUILD_00p0(Data,r12vrr_stack+234, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /*--- compute (00|d0)^7 ---*/
 _BUILD_00d0(Data,r12vrr_stack+237, r12vrr_stack+114, r12vrr_stack+234, Data->F+7, Data->F+8, NULL);

 /*--- compute (00|f0)^6 ---*/
 _BUILD_00f0(Data,r12vrr_stack+58, r12vrr_stack+15, r12vrr_stack+237, r12vrr_stack+49, r12vrr_stack+114, NULL);

 /*--- compute (00|g0)^5 ---*/
 _BUILD_00g0(Data,r12vrr_stack+243, r12vrr_stack+117, r12vrr_stack+58, r12vrr_stack+52, r12vrr_stack+15, NULL);

 /*--- compute (00|h0)^4 ---*/
 _BUILD_00h0(Data,r12vrr_stack+258, r12vrr_stack+127, r12vrr_stack+243, r12vrr_stack+358, r12vrr_stack+117, NULL);

 /*--- compute (p0|h0)^3 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+2046, r12vrr_stack+1563, r12vrr_stack+258, NULL, NULL, r12vrr_stack+127);

 /*--- compute (d0|h0)^2 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+2109, r12vrr_stack+1584, r12vrr_stack+2046, r12vrr_stack+1521, r12vrr_stack+1563, r12vrr_stack+1011);

 /*--- compute (f0|h0)^1 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2235, r12vrr_stack+1710, r12vrr_stack+2109, r12vrr_stack+1647, r12vrr_stack+1584, r12vrr_stack+1056);

 /*--- compute (f0|h0)^0 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+1710, r12vrr_stack+1857, r12vrr_stack+1647, r12vrr_stack+428);
 tmp = r12vrr_stack + 2445;
 target_ptr = Libr12->gvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|h0)^0 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+2235, r12vrr_stack+1920, r12vrr_stack+1710, r12vrr_stack+1146);
 tmp = r12vrr_stack + 2655;
 target_ptr = Libr12->gvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|i0)^2 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2970, r12vrr_stack+1521, r12vrr_stack+1563, r12vrr_stack+204, r12vrr_stack+368, NULL);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+2998, r12vrr_stack+1542, r12vrr_stack+1521, r12vrr_stack+219, r12vrr_stack+204, NULL);

 /*--- compute (p0|i0)^1 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3026, r12vrr_stack+2998, r12vrr_stack+2970, NULL, NULL, r12vrr_stack+1521);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3110, r12vrr_stack+1836, r12vrr_stack+1542, r12vrr_stack+298, r12vrr_stack+219, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3138, r12vrr_stack+3110, r12vrr_stack+2998, NULL, NULL, r12vrr_stack+1542);

 /*--- compute (00|i0)^3 ---*/
 _BUILD_00i0(Data,r12vrr_stack+204, r12vrr_stack+1563, r12vrr_stack+258, r12vrr_stack+368, r12vrr_stack+127, NULL);

 /*--- compute (p0|i0)^2 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3222, r12vrr_stack+2970, r12vrr_stack+204, NULL, NULL, r12vrr_stack+1563);

 /*--- compute (d0|i0)^1 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3306, r12vrr_stack+3026, r12vrr_stack+3222, r12vrr_stack+2998, r12vrr_stack+2970, r12vrr_stack+1584);

 /*--- compute (d0|i0)^0 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+3026, r12vrr_stack+3110, r12vrr_stack+2998, r12vrr_stack+1647);

 /*--- compute (f0|i0)^0 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+3306, r12vrr_stack+3138, r12vrr_stack+3026, r12vrr_stack+1710);
 tmp = r12vrr_stack + 3642;
 target_ptr = Libr12->gvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^9 ---*/
 _BUILD_00p0(Data,r12vrr_stack+1647, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /*--- compute (00|d0)^8 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1650, r12vrr_stack+234, r12vrr_stack+1647, Data->F+8, Data->F+9, NULL);

 /*--- compute (00|f0)^7 ---*/
 _BUILD_00f0(Data,r12vrr_stack+39, r12vrr_stack+237, r12vrr_stack+1650, r12vrr_stack+114, r12vrr_stack+234, NULL);

 /*--- compute (00|g0)^6 ---*/
 _BUILD_00g0(Data,r12vrr_stack+1656, r12vrr_stack+58, r12vrr_stack+39, r12vrr_stack+15, r12vrr_stack+237, NULL);

 /*--- compute (00|h0)^5 ---*/
 _BUILD_00h0(Data,r12vrr_stack+1671, r12vrr_stack+243, r12vrr_stack+1656, r12vrr_stack+117, r12vrr_stack+58, NULL);

 /*--- compute (00|i0)^4 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3922, r12vrr_stack+258, r12vrr_stack+1671, r12vrr_stack+127, r12vrr_stack+243, NULL);

 /*--- compute (p0|i0)^3 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+3950, r12vrr_stack+204, r12vrr_stack+3922, NULL, NULL, r12vrr_stack+258);

 /*--- compute (d0|i0)^2 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+4034, r12vrr_stack+3222, r12vrr_stack+3950, r12vrr_stack+2970, r12vrr_stack+204, r12vrr_stack+2046);

 /*--- compute (f0|i0)^1 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+4202, r12vrr_stack+3306, r12vrr_stack+4034, r12vrr_stack+3026, r12vrr_stack+3222, r12vrr_stack+2109);

 /*--- compute (g0|i0)^0 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+4202, r12vrr_stack+3474, r12vrr_stack+3306, r12vrr_stack+2235);
 tmp = r12vrr_stack + 4482;
 target_ptr = Libr12->gvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|k0)^2 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4902, r12vrr_stack+2970, r12vrr_stack+204, r12vrr_stack+1521, r12vrr_stack+1563, NULL);

 /*--- compute (00|k0)^1 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4938, r12vrr_stack+2998, r12vrr_stack+2970, r12vrr_stack+1542, r12vrr_stack+1521, NULL);

 /*--- compute (p0|k0)^1 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+4974, r12vrr_stack+4938, r12vrr_stack+4902, NULL, NULL, r12vrr_stack+2970);

 /*--- compute (00|k0)^0 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5082, r12vrr_stack+3110, r12vrr_stack+2998, r12vrr_stack+1836, r12vrr_stack+1542, NULL);

 /*--- compute (p0|k0)^0 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5118, r12vrr_stack+5082, r12vrr_stack+4938, NULL, NULL, r12vrr_stack+2998);

 /*--- compute (00|k0)^3 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1521, r12vrr_stack+204, r12vrr_stack+3922, r12vrr_stack+1563, r12vrr_stack+258, NULL);

 /*--- compute (p0|k0)^2 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5226, r12vrr_stack+4902, r12vrr_stack+1521, NULL, NULL, r12vrr_stack+204);

 /*--- compute (d0|k0)^1 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5334, r12vrr_stack+4974, r12vrr_stack+5226, r12vrr_stack+4938, r12vrr_stack+4902, r12vrr_stack+3222);

 /*--- compute (d0|k0)^0 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5550, r12vrr_stack+5118, r12vrr_stack+4974, r12vrr_stack+5082, r12vrr_stack+4938, r12vrr_stack+3026);

 /*--- compute (f0|k0)^0 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+5334, r12vrr_stack+5118, r12vrr_stack+4974, r12vrr_stack+3306);
 tmp = r12vrr_stack + 5766;
 target_ptr = Libr12->gvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^10 ---*/
 _BUILD_00p0(Data,r12vrr_stack+114, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /*--- compute (00|d0)^9 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1557, r12vrr_stack+1647, r12vrr_stack+114, Data->F+9, Data->F+10, NULL);

 /*--- compute (00|f0)^8 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3026, r12vrr_stack+1650, r12vrr_stack+1557, r12vrr_stack+234, r12vrr_stack+1647, NULL);

 /*--- compute (00|g0)^7 ---*/
 _BUILD_00g0(Data,r12vrr_stack+3036, r12vrr_stack+39, r12vrr_stack+3026, r12vrr_stack+237, r12vrr_stack+1650, NULL);

 /*--- compute (00|h0)^6 ---*/
 _BUILD_00h0(Data,r12vrr_stack+3051, r12vrr_stack+1656, r12vrr_stack+3036, r12vrr_stack+58, r12vrr_stack+39, NULL);

 /*--- compute (00|i0)^5 ---*/
 _BUILD_00i0(Data,r12vrr_stack+3072, r12vrr_stack+1671, r12vrr_stack+3051, r12vrr_stack+243, r12vrr_stack+1656, NULL);

 /*--- compute (00|k0)^4 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6126, r12vrr_stack+3922, r12vrr_stack+3072, r12vrr_stack+258, r12vrr_stack+1671, NULL);

 /*--- compute (p0|k0)^3 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6162, r12vrr_stack+1521, r12vrr_stack+6126, NULL, NULL, r12vrr_stack+3922);

 /*--- compute (d0|k0)^2 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6270, r12vrr_stack+5226, r12vrr_stack+6162, r12vrr_stack+4902, r12vrr_stack+1521, r12vrr_stack+3950);

 /*--- compute (f0|k0)^1 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6486, r12vrr_stack+5334, r12vrr_stack+6270, r12vrr_stack+4974, r12vrr_stack+5226, r12vrr_stack+4034);

 /*--- compute (g0|k0)^0 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+6846, r12vrr_stack+5766, r12vrr_stack+6486, r12vrr_stack+5550, r12vrr_stack+5334, r12vrr_stack+4202);
 tmp = r12vrr_stack + 6846;
 target_ptr = Libr12->gvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|l0)^2 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7386, r12vrr_stack+4902, r12vrr_stack+1521, r12vrr_stack+2970, r12vrr_stack+204, NULL);

 /*--- compute (00|l0)^1 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7431, r12vrr_stack+4938, r12vrr_stack+4902, r12vrr_stack+2998, r12vrr_stack+2970, NULL);

 /*--- compute (p0|l0)^1 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7476, r12vrr_stack+7431, r12vrr_stack+7386, NULL, NULL, r12vrr_stack+4902);

 /*--- compute (00|l0)^0 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7611, r12vrr_stack+5082, r12vrr_stack+4938, r12vrr_stack+3110, r12vrr_stack+2998, NULL);

 /*--- compute (p0|l0)^0 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7656, r12vrr_stack+7611, r12vrr_stack+7431, NULL, NULL, r12vrr_stack+4938);

 /*--- compute (00|l0)^3 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2970, r12vrr_stack+1521, r12vrr_stack+6126, r12vrr_stack+204, r12vrr_stack+3922, NULL);

 /*--- compute (p0|l0)^2 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7791, r12vrr_stack+7386, r12vrr_stack+2970, NULL, NULL, r12vrr_stack+1521);

 /*--- compute (d0|l0)^1 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7926, r12vrr_stack+7476, r12vrr_stack+7791, r12vrr_stack+7431, r12vrr_stack+7386, r12vrr_stack+5226);

 /*--- compute (d0|l0)^0 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8196, r12vrr_stack+7656, r12vrr_stack+7476, r12vrr_stack+7611, r12vrr_stack+7431, r12vrr_stack+4974);

 /*--- compute (f0|l0)^0 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8466, r12vrr_stack+8196, r12vrr_stack+7926, r12vrr_stack+7656, r12vrr_stack+7476, r12vrr_stack+5334);
 tmp = r12vrr_stack + 8466;
 target_ptr = Libr12->gvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^11 ---*/
 _BUILD_00p0(Data,r12vrr_stack+4974, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /*--- compute (00|d0)^10 ---*/
 _BUILD_00d0(Data,r12vrr_stack+4977, r12vrr_stack+114, r12vrr_stack+4974, Data->F+10, Data->F+11, NULL);

 /*--- compute (00|f0)^9 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3100, r12vrr_stack+1557, r12vrr_stack+4977, r12vrr_stack+1647, r12vrr_stack+114, NULL);

 /*--- compute (00|g0)^8 ---*/
 _BUILD_00g0(Data,r12vrr_stack+4983, r12vrr_stack+3026, r12vrr_stack+3100, r12vrr_stack+1650, r12vrr_stack+1557, NULL);

 /*--- compute (00|h0)^7 ---*/
 _BUILD_00h0(Data,r12vrr_stack+4998, r12vrr_stack+3036, r12vrr_stack+4983, r12vrr_stack+39, r12vrr_stack+3026, NULL);

 /*--- compute (00|i0)^6 ---*/
 _BUILD_00i0(Data,r12vrr_stack+5019, r12vrr_stack+3051, r12vrr_stack+4998, r12vrr_stack+1656, r12vrr_stack+3036, NULL);

 /*--- compute (00|k0)^5 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+8916, r12vrr_stack+3072, r12vrr_stack+5019, r12vrr_stack+1671, r12vrr_stack+3051, NULL);

 /*--- compute (00|l0)^4 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8952, r12vrr_stack+6126, r12vrr_stack+8916, r12vrr_stack+3922, r12vrr_stack+3072, NULL);

 /*--- compute (p0|l0)^3 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+8997, r12vrr_stack+2970, r12vrr_stack+8952, NULL, NULL, r12vrr_stack+6126);

 /*--- compute (d0|l0)^2 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9132, r12vrr_stack+7791, r12vrr_stack+8997, r12vrr_stack+7386, r12vrr_stack+2970, r12vrr_stack+6162);

 /*--- compute (f0|l0)^1 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9402, r12vrr_stack+7926, r12vrr_stack+9132, r12vrr_stack+7476, r12vrr_stack+7791, r12vrr_stack+6270);

 /*--- compute (g0|l0)^0 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+9852, r12vrr_stack+8466, r12vrr_stack+9402, r12vrr_stack+8196, r12vrr_stack+7926, r12vrr_stack+6486);
 tmp = r12vrr_stack + 9852;
 target_ptr = Libr12->gvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|m0)^2 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10527, r12vrr_stack+7386, r12vrr_stack+2970, r12vrr_stack+4902, r12vrr_stack+1521, NULL);

 /*--- compute (00|m0)^1 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10582, r12vrr_stack+7431, r12vrr_stack+7386, r12vrr_stack+4938, r12vrr_stack+4902, NULL);

 /*--- compute (p0|m0)^1 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10637, r12vrr_stack+10582, r12vrr_stack+10527, NULL, NULL, r12vrr_stack+7386);

 /*--- compute (00|m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10802, r12vrr_stack+7611, r12vrr_stack+7431, r12vrr_stack+5082, r12vrr_stack+4938, NULL);

 /*--- compute (p0|m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+10857, r12vrr_stack+10802, r12vrr_stack+10582, NULL, NULL, r12vrr_stack+7431);

 /*--- compute (00|m0)^3 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+4902, r12vrr_stack+2970, r12vrr_stack+8952, r12vrr_stack+1521, r12vrr_stack+6126, NULL);

 /*--- compute (p0|m0)^2 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+11022, r12vrr_stack+10527, r12vrr_stack+4902, NULL, NULL, r12vrr_stack+2970);

 /*--- compute (d0|m0)^1 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+11187, r12vrr_stack+10637, r12vrr_stack+11022, r12vrr_stack+10582, r12vrr_stack+10527, r12vrr_stack+7791);

 /*--- compute (d0|m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+11517, r12vrr_stack+10857, r12vrr_stack+10637, r12vrr_stack+10802, r12vrr_stack+10582, r12vrr_stack+7476);

 /*--- compute (f0|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+11847, r12vrr_stack+11517, r12vrr_stack+11187, r12vrr_stack+10857, r12vrr_stack+10637, r12vrr_stack+7926);
 tmp = r12vrr_stack + 11847;
 target_ptr = Libr12->gvrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^12 ---*/
 _BUILD_00p0(Data,r12vrr_stack+7476, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /*--- compute (00|d0)^11 ---*/
 _BUILD_00d0(Data,r12vrr_stack+7479, r12vrr_stack+4974, r12vrr_stack+7476, Data->F+11, Data->F+12, NULL);

 /*--- compute (00|f0)^10 ---*/
 _BUILD_00f0(Data,r12vrr_stack+39, r12vrr_stack+4977, r12vrr_stack+7479, r12vrr_stack+114, r12vrr_stack+4974, NULL);

 /*--- compute (00|g0)^9 ---*/
 _BUILD_00g0(Data,r12vrr_stack+7485, r12vrr_stack+3100, r12vrr_stack+39, r12vrr_stack+1557, r12vrr_stack+4977, NULL);

 /*--- compute (00|h0)^8 ---*/
 _BUILD_00h0(Data,r12vrr_stack+7500, r12vrr_stack+4983, r12vrr_stack+7485, r12vrr_stack+3026, r12vrr_stack+3100, NULL);

 /*--- compute (00|i0)^7 ---*/
 _BUILD_00i0(Data,r12vrr_stack+7521, r12vrr_stack+4998, r12vrr_stack+7500, r12vrr_stack+3036, r12vrr_stack+4983, NULL);

 /*--- compute (00|k0)^6 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3015, r12vrr_stack+5019, r12vrr_stack+7521, r12vrr_stack+3051, r12vrr_stack+4998, NULL);

 /*--- compute (00|l0)^5 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+7549, r12vrr_stack+8916, r12vrr_stack+3015, r12vrr_stack+3072, r12vrr_stack+5019, NULL);

 /*--- compute (00|m0)^4 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12397, r12vrr_stack+8952, r12vrr_stack+7549, r12vrr_stack+6126, r12vrr_stack+8916, NULL);

 /*--- compute (p0|m0)^3 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12452, r12vrr_stack+4902, r12vrr_stack+12397, NULL, NULL, r12vrr_stack+8952);

 /*--- compute (d0|m0)^2 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12617, r12vrr_stack+11022, r12vrr_stack+12452, r12vrr_stack+10527, r12vrr_stack+4902, r12vrr_stack+8997);

 /*--- compute (f0|m0)^1 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+12947, r12vrr_stack+11187, r12vrr_stack+12617, r12vrr_stack+10637, r12vrr_stack+11022, r12vrr_stack+9132);

 /*--- compute (g0|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+13497, r12vrr_stack+11847, r12vrr_stack+12947, r12vrr_stack+11517, r12vrr_stack+11187, r12vrr_stack+9402);
 tmp = r12vrr_stack + 13497;
 target_ptr = Libr12->gvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|n0)^2 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+14322, r12vrr_stack+10527, r12vrr_stack+4902, r12vrr_stack+7386, r12vrr_stack+2970, NULL);

 /*--- compute (00|n0)^1 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+14388, r12vrr_stack+10582, r12vrr_stack+10527, r12vrr_stack+7431, r12vrr_stack+7386, NULL);

 /*--- compute (p0|n0)^1 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+14454, r12vrr_stack+14388, r12vrr_stack+14322, NULL, NULL, r12vrr_stack+10527);

 /*--- compute (00|n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+14652, r12vrr_stack+10802, r12vrr_stack+10582, r12vrr_stack+7611, r12vrr_stack+7431, NULL);

 /*--- compute (p0|n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+14718, r12vrr_stack+14652, r12vrr_stack+14388, NULL, NULL, r12vrr_stack+10582);

 /*--- compute (00|n0)^3 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+7386, r12vrr_stack+4902, r12vrr_stack+12397, r12vrr_stack+2970, r12vrr_stack+8952, NULL);

 /*--- compute (p0|n0)^2 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+14916, r12vrr_stack+14322, r12vrr_stack+7386, NULL, NULL, r12vrr_stack+4902);

 /*--- compute (d0|n0)^1 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+15114, r12vrr_stack+14454, r12vrr_stack+14916, r12vrr_stack+14388, r12vrr_stack+14322, r12vrr_stack+11022);

 /*--- compute (d0|n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+15510, r12vrr_stack+14718, r12vrr_stack+14454, r12vrr_stack+14652, r12vrr_stack+14388, r12vrr_stack+10637);

 /*--- compute (f0|n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+15906, r12vrr_stack+15510, r12vrr_stack+15114, r12vrr_stack+14718, r12vrr_stack+14454, r12vrr_stack+11187);
 tmp = r12vrr_stack + 15906;
 target_ptr = Libr12->gvrr_classes[3][10];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^13 ---*/
 _BUILD_00p0(Data,r12vrr_stack+114, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /*--- compute (00|d0)^12 ---*/
 _BUILD_00d0(Data,r12vrr_stack+1557, r12vrr_stack+7476, r12vrr_stack+114, Data->F+12, Data->F+13, NULL);

 /*--- compute (00|f0)^11 ---*/
 _BUILD_00f0(Data,r12vrr_stack+10637, r12vrr_stack+7479, r12vrr_stack+1557, r12vrr_stack+4974, r12vrr_stack+7476, NULL);

 /*--- compute (00|g0)^10 ---*/
 _BUILD_00g0(Data,r12vrr_stack+10647, r12vrr_stack+39, r12vrr_stack+10637, r12vrr_stack+4977, r12vrr_stack+7479, NULL);

 /*--- compute (00|h0)^9 ---*/
 _BUILD_00h0(Data,r12vrr_stack+10662, r12vrr_stack+7485, r12vrr_stack+10647, r12vrr_stack+3100, r12vrr_stack+39, NULL);

 /*--- compute (00|i0)^8 ---*/
 _BUILD_00i0(Data,r12vrr_stack+10683, r12vrr_stack+7500, r12vrr_stack+10662, r12vrr_stack+4983, r12vrr_stack+7485, NULL);

 /*--- compute (00|k0)^7 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+10711, r12vrr_stack+7521, r12vrr_stack+10683, r12vrr_stack+4998, r12vrr_stack+7500, NULL);

 /*--- compute (00|l0)^6 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+10747, r12vrr_stack+3015, r12vrr_stack+10711, r12vrr_stack+5019, r12vrr_stack+7521, NULL);

 /*--- compute (00|m0)^5 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+4957, r12vrr_stack+7549, r12vrr_stack+10747, r12vrr_stack+8916, r12vrr_stack+3015, NULL);

 /*--- compute (00|n0)^4 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+16566, r12vrr_stack+12397, r12vrr_stack+4957, r12vrr_stack+8952, r12vrr_stack+7549, NULL);

 /*--- compute (p0|n0)^3 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+16632, r12vrr_stack+7386, r12vrr_stack+16566, NULL, NULL, r12vrr_stack+12397);

 /*--- compute (d0|n0)^2 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+16830, r12vrr_stack+14916, r12vrr_stack+16632, r12vrr_stack+14322, r12vrr_stack+7386, r12vrr_stack+12452);

 /*--- compute (f0|n0)^1 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+17226, r12vrr_stack+15114, r12vrr_stack+16830, r12vrr_stack+14454, r12vrr_stack+14916, r12vrr_stack+12617);

 /*--- compute (g0|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+17886, r12vrr_stack+15906, r12vrr_stack+17226, r12vrr_stack+15510, r12vrr_stack+15114, r12vrr_stack+12947);
 tmp = r12vrr_stack + 17886;
 target_ptr = Libr12->gvrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|o0)^2 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+18876, r12vrr_stack+14322, r12vrr_stack+7386, r12vrr_stack+10527, r12vrr_stack+4902, NULL);

 /*--- compute (00|o0)^1 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+18954, r12vrr_stack+14388, r12vrr_stack+14322, r12vrr_stack+10582, r12vrr_stack+10527, NULL);

 /*--- compute (p0|o0)^1 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+19032, r12vrr_stack+18954, r12vrr_stack+18876, NULL, NULL, r12vrr_stack+14322);

 /*--- compute (00|o0)^0 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+19266, r12vrr_stack+14652, r12vrr_stack+14388, r12vrr_stack+10802, r12vrr_stack+10582, NULL);

 /*--- compute (p0|o0)^0 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+19344, r12vrr_stack+19266, r12vrr_stack+18954, NULL, NULL, r12vrr_stack+14388);

 /*--- compute (00|o0)^3 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+14322, r12vrr_stack+7386, r12vrr_stack+16566, r12vrr_stack+4902, r12vrr_stack+12397, NULL);

 /*--- compute (p0|o0)^2 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+19578, r12vrr_stack+18876, r12vrr_stack+14322, NULL, NULL, r12vrr_stack+7386);

 /*--- compute (d0|o0)^1 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+19812, r12vrr_stack+19032, r12vrr_stack+19578, r12vrr_stack+18954, r12vrr_stack+18876, r12vrr_stack+14916);

 /*--- compute (d0|o0)^0 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+20280, r12vrr_stack+19344, r12vrr_stack+19032, r12vrr_stack+19266, r12vrr_stack+18954, r12vrr_stack+14454);

 /*--- compute (f0|o0)^0 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+20748, r12vrr_stack+20280, r12vrr_stack+19812, r12vrr_stack+19344, r12vrr_stack+19032, r12vrr_stack+15114);
 tmp = r12vrr_stack + 20748;
 target_ptr = Libr12->gvrr_classes[3][11];
 for(i=0;i<780;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^4 ---*/
 _BUILD_p000(Data,r12vrr_stack+18954, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (p0|p0)^4 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+1647, r12vrr_stack+3, r12vrr_stack+12, NULL, NULL, Data->F+5);

 /*--- compute (d0|p0)^3 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+1692, r12vrr_stack+758, r12vrr_stack+1647, r12vrr_stack+0, r12vrr_stack+3, r12vrr_stack+18954);

 /*--- compute (p0|d0)^4 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+18957, r12vrr_stack+68, r12vrr_stack+52, NULL, NULL, r12vrr_stack+12);

 /*--- compute (d0|d0)^3 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+18975, r12vrr_stack+767, r12vrr_stack+18957, r12vrr_stack+6, r12vrr_stack+68, r12vrr_stack+1647);

 /*--- compute (f0|d0)^2 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+19266, r12vrr_stack+785, r12vrr_stack+18975, r12vrr_stack+21, r12vrr_stack+767, r12vrr_stack+1692);

 /*--- compute (p0|f0)^4 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+19326, r12vrr_stack+358, r12vrr_stack+117, NULL, NULL, r12vrr_stack+52);

 /*--- compute (d0|f0)^3 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+19356, r12vrr_stack+821, r12vrr_stack+19326, r12vrr_stack+74, r12vrr_stack+358, r12vrr_stack+18957);

 /*--- compute (f0|f0)^2 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+19416, r12vrr_stack+851, r12vrr_stack+19356, r12vrr_stack+84, r12vrr_stack+821, r12vrr_stack+18975);

 /*--- compute (g0|f0)^1 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+14400, r12vrr_stack+911, r12vrr_stack+19416, r12vrr_stack+144, r12vrr_stack+851, r12vrr_stack+19266);

 /*--- compute (p0|g0)^4 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+19516, r12vrr_stack+127, r12vrr_stack+243, NULL, NULL, r12vrr_stack+117);

 /*--- compute (d0|g0)^3 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+14550, r12vrr_stack+1011, r12vrr_stack+19516, r12vrr_stack+368, r12vrr_stack+127, r12vrr_stack+19326);

 /*--- compute (f0|g0)^2 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+21528, r12vrr_stack+1056, r12vrr_stack+14550, r12vrr_stack+383, r12vrr_stack+1011, r12vrr_stack+19356);

 /*--- compute (g0|g0)^1 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+21678, r12vrr_stack+1146, r12vrr_stack+21528, r12vrr_stack+428, r12vrr_stack+1056, r12vrr_stack+19416);

 /*--- compute (h0|g0)^0 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+21903, r12vrr_stack+1296, r12vrr_stack+21678, r12vrr_stack+608, r12vrr_stack+1146, r12vrr_stack+14400);

 /*--- compute (p0|h0)^4 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+368, r12vrr_stack+258, r12vrr_stack+1671, NULL, NULL, r12vrr_stack+243);

 /*--- compute (d0|h0)^3 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+22218, r12vrr_stack+2046, r12vrr_stack+368, r12vrr_stack+1563, r12vrr_stack+258, r12vrr_stack+19516);

 /*--- compute (f0|h0)^2 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+22344, r12vrr_stack+2109, r12vrr_stack+22218, r12vrr_stack+1584, r12vrr_stack+2046, r12vrr_stack+14550);

 /*--- compute (g0|h0)^1 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+22554, r12vrr_stack+2235, r12vrr_stack+22344, r12vrr_stack+1710, r12vrr_stack+2109, r12vrr_stack+21528);

 /*--- compute (h0|h0)^0 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+22869, r12vrr_stack+2655, r12vrr_stack+22554, r12vrr_stack+2445, r12vrr_stack+2235, r12vrr_stack+21678);
 tmp = r12vrr_stack + 22869;
 target_ptr = Libr12->gvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^4 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+1563, r12vrr_stack+3922, r12vrr_stack+3072, NULL, NULL, r12vrr_stack+1671);

 /*--- compute (d0|i0)^3 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+23310, r12vrr_stack+3950, r12vrr_stack+1563, r12vrr_stack+204, r12vrr_stack+3922, r12vrr_stack+368);

 /*--- compute (f0|i0)^2 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+23478, r12vrr_stack+4034, r12vrr_stack+23310, r12vrr_stack+3222, r12vrr_stack+3950, r12vrr_stack+22218);

 /*--- compute (g0|i0)^1 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+23758, r12vrr_stack+4202, r12vrr_stack+23478, r12vrr_stack+3306, r12vrr_stack+4034, r12vrr_stack+22344);

 /*--- compute (h0|i0)^0 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+24178, r12vrr_stack+4482, r12vrr_stack+23758, r12vrr_stack+3642, r12vrr_stack+4202, r12vrr_stack+22554);
 tmp = r12vrr_stack + 24178;
 target_ptr = Libr12->gvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^4 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+3222, r12vrr_stack+6126, r12vrr_stack+8916, NULL, NULL, r12vrr_stack+3072);

 /*--- compute (d0|k0)^3 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+24766, r12vrr_stack+6162, r12vrr_stack+3222, r12vrr_stack+1521, r12vrr_stack+6126, r12vrr_stack+1563);

 /*--- compute (f0|k0)^2 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+24982, r12vrr_stack+6270, r12vrr_stack+24766, r12vrr_stack+5226, r12vrr_stack+6162, r12vrr_stack+23310);

 /*--- compute (g0|k0)^1 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+25342, r12vrr_stack+6486, r12vrr_stack+24982, r12vrr_stack+5334, r12vrr_stack+6270, r12vrr_stack+23478);

 /*--- compute (h0|k0)^0 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+25882, r12vrr_stack+6846, r12vrr_stack+25342, r12vrr_stack+5766, r12vrr_stack+6486, r12vrr_stack+23758);
 tmp = r12vrr_stack + 25882;
 target_ptr = Libr12->gvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^4 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+5226, r12vrr_stack+8952, r12vrr_stack+7549, NULL, NULL, r12vrr_stack+8916);

 /*--- compute (d0|l0)^3 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+26638, r12vrr_stack+8997, r12vrr_stack+5226, r12vrr_stack+2970, r12vrr_stack+8952, r12vrr_stack+3222);

 /*--- compute (f0|l0)^2 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+26908, r12vrr_stack+9132, r12vrr_stack+26638, r12vrr_stack+7791, r12vrr_stack+8997, r12vrr_stack+24766);

 /*--- compute (g0|l0)^1 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+27358, r12vrr_stack+9402, r12vrr_stack+26908, r12vrr_stack+7926, r12vrr_stack+9132, r12vrr_stack+24982);

 /*--- compute (h0|l0)^0 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+28033, r12vrr_stack+9852, r12vrr_stack+27358, r12vrr_stack+8466, r12vrr_stack+9402, r12vrr_stack+25342);
 tmp = r12vrr_stack + 28033;
 target_ptr = Libr12->gvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|m0)^4 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+7791, r12vrr_stack+12397, r12vrr_stack+4957, NULL, NULL, r12vrr_stack+7549);

 /*--- compute (d0|m0)^3 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+28978, r12vrr_stack+12452, r12vrr_stack+7791, r12vrr_stack+4902, r12vrr_stack+12397, r12vrr_stack+5226);

 /*--- compute (f0|m0)^2 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29308, r12vrr_stack+12617, r12vrr_stack+28978, r12vrr_stack+11022, r12vrr_stack+12452, r12vrr_stack+26638);

 /*--- compute (g0|m0)^1 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+29858, r12vrr_stack+12947, r12vrr_stack+29308, r12vrr_stack+11187, r12vrr_stack+12617, r12vrr_stack+26908);

 /*--- compute (h0|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+30683, r12vrr_stack+13497, r12vrr_stack+29858, r12vrr_stack+11847, r12vrr_stack+12947, r12vrr_stack+27358);
 tmp = r12vrr_stack + 30683;
 target_ptr = Libr12->gvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^14 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /*--- compute (00|d0)^13 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+114, r12vrr_stack+0, Data->F+13, Data->F+14, NULL);

 /*--- compute (00|f0)^12 ---*/
 _BUILD_00f0(Data,r12vrr_stack+3100, r12vrr_stack+1557, r12vrr_stack+6, r12vrr_stack+7476, r12vrr_stack+114, NULL);

 /*--- compute (00|g0)^11 ---*/
 _BUILD_00g0(Data,r12vrr_stack+11022, r12vrr_stack+10637, r12vrr_stack+3100, r12vrr_stack+7479, r12vrr_stack+1557, NULL);

 /*--- compute (00|h0)^10 ---*/
 _BUILD_00h0(Data,r12vrr_stack+19011, r12vrr_stack+10647, r12vrr_stack+11022, r12vrr_stack+39, r12vrr_stack+10637, NULL);

 /*--- compute (00|i0)^9 ---*/
 _BUILD_00i0(Data,r12vrr_stack+21, r12vrr_stack+10662, r12vrr_stack+19011, r12vrr_stack+7485, r12vrr_stack+10647, NULL);

 /*--- compute (00|k0)^8 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+1521, r12vrr_stack+10683, r12vrr_stack+21, r12vrr_stack+7500, r12vrr_stack+10662, NULL);

 /*--- compute (00|l0)^7 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+2970, r12vrr_stack+10711, r12vrr_stack+1521, r12vrr_stack+7521, r12vrr_stack+10683, NULL);

 /*--- compute (00|m0)^6 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+4902, r12vrr_stack+10747, r12vrr_stack+2970, r12vrr_stack+3015, r12vrr_stack+10711, NULL);

 /*--- compute (00|n0)^5 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+11037, r12vrr_stack+4957, r12vrr_stack+4902, r12vrr_stack+7549, r12vrr_stack+10747, NULL);

 /*--- compute (p0|n0)^4 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+11103, r12vrr_stack+16566, r12vrr_stack+11037, NULL, NULL, r12vrr_stack+4957);

 /*--- compute (d0|n0)^3 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+31838, r12vrr_stack+16632, r12vrr_stack+11103, r12vrr_stack+7386, r12vrr_stack+16566, r12vrr_stack+7791);

 /*--- compute (f0|n0)^2 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+32234, r12vrr_stack+16830, r12vrr_stack+31838, r12vrr_stack+14916, r12vrr_stack+16632, r12vrr_stack+28978);

 /*--- compute (g0|n0)^1 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+32894, r12vrr_stack+17226, r12vrr_stack+32234, r12vrr_stack+15114, r12vrr_stack+16830, r12vrr_stack+29308);

 /*--- compute (h0|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+33884, r12vrr_stack+17886, r12vrr_stack+32894, r12vrr_stack+15906, r12vrr_stack+17226, r12vrr_stack+29858);
 tmp = r12vrr_stack + 33884;
 target_ptr = Libr12->gvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|o0)^4 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+14916, r12vrr_stack+16566, r12vrr_stack+11037, r12vrr_stack+12397, r12vrr_stack+4957, NULL);

 /*--- compute (p0|o0)^3 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+14994, r12vrr_stack+14322, r12vrr_stack+14916, NULL, NULL, r12vrr_stack+16566);

 /*--- compute (d0|o0)^2 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+35270, r12vrr_stack+19578, r12vrr_stack+14994, r12vrr_stack+18876, r12vrr_stack+14322, r12vrr_stack+16632);

 /*--- compute (f0|o0)^1 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+35738, r12vrr_stack+19812, r12vrr_stack+35270, r12vrr_stack+19032, r12vrr_stack+19578, r12vrr_stack+16830);

 /*--- compute (g0|o0)^0 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+36518, r12vrr_stack+20748, r12vrr_stack+35738, r12vrr_stack+20280, r12vrr_stack+19812, r12vrr_stack+17226);
 tmp = r12vrr_stack + 36518;
 target_ptr = Libr12->gvrr_classes[4][11];
 for(i=0;i<1170;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|00)^5 ---*/
 _BUILD_p000(Data,r12vrr_stack+19032, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (d0|00)^4 ---*/
 _BUILD_d000(Data,r12vrr_stack+19035, r12vrr_stack+18954, r12vrr_stack+19032, Data->F+4, Data->F+5, NULL);

 /*--- compute (p0|p0)^5 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+19041, r12vrr_stack+12, r12vrr_stack+49, NULL, NULL, Data->F+6);

 /*--- compute (d0|p0)^4 ---*/
 _BUILD_d0p0(Data,r12vrr_stack+19050, r12vrr_stack+1647, r12vrr_stack+19041, r12vrr_stack+3, r12vrr_stack+12, r12vrr_stack+19032);

 /*--- compute (f0|p0)^3 ---*/
 _BUILD_f0p0(Data,r12vrr_stack+19068, r12vrr_stack+1692, r12vrr_stack+19050, r12vrr_stack+758, r12vrr_stack+1647, r12vrr_stack+19035);

 /*--- compute (p0|d0)^5 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+1692, r12vrr_stack+52, r12vrr_stack+15, NULL, NULL, r12vrr_stack+49);

 /*--- compute (d0|d0)^4 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+1710, r12vrr_stack+18957, r12vrr_stack+1692, r12vrr_stack+68, r12vrr_stack+52, r12vrr_stack+19041);

 /*--- compute (f0|d0)^3 ---*/
 _BUILD_f0d0(Data,r12vrr_stack+1746, r12vrr_stack+18975, r12vrr_stack+1710, r12vrr_stack+767, r12vrr_stack+18957, r12vrr_stack+19050);

 /*--- compute (g0|d0)^2 ---*/
 _BUILD_g0d0(Data,r12vrr_stack+19098, r12vrr_stack+19266, r12vrr_stack+1746, r12vrr_stack+785, r12vrr_stack+18975, r12vrr_stack+19068);

 /*--- compute (p0|f0)^5 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+1806, r12vrr_stack+117, r12vrr_stack+58, NULL, NULL, r12vrr_stack+15);

 /*--- compute (d0|f0)^4 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+758, r12vrr_stack+19326, r12vrr_stack+1806, r12vrr_stack+358, r12vrr_stack+117, r12vrr_stack+1692);

 /*--- compute (f0|f0)^3 ---*/
 _BUILD_f0f0(Data,r12vrr_stack+19188, r12vrr_stack+19356, r12vrr_stack+758, r12vrr_stack+821, r12vrr_stack+19326, r12vrr_stack+1710);

 /*--- compute (g0|f0)^2 ---*/
 _BUILD_g0f0(Data,r12vrr_stack+15228, r12vrr_stack+19416, r12vrr_stack+19188, r12vrr_stack+851, r12vrr_stack+19356, r12vrr_stack+1746);

 /*--- compute (h0|f0)^1 ---*/
 _BUILD_h0f0(Data,r12vrr_stack+11301, r12vrr_stack+14400, r12vrr_stack+15228, r12vrr_stack+911, r12vrr_stack+19416, r12vrr_stack+19098);

 /*--- compute (p0|g0)^5 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+14400, r12vrr_stack+243, r12vrr_stack+1656, NULL, NULL, r12vrr_stack+58);

 /*--- compute (d0|g0)^4 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+14445, r12vrr_stack+19516, r12vrr_stack+14400, r12vrr_stack+127, r12vrr_stack+243, r12vrr_stack+1806);

 /*--- compute (f0|g0)^3 ---*/
 _BUILD_f0g0(Data,r12vrr_stack+818, r12vrr_stack+14550, r12vrr_stack+14445, r12vrr_stack+1011, r12vrr_stack+19516, r12vrr_stack+758);

 /*--- compute (g0|g0)^2 ---*/
 _BUILD_g0g0(Data,r12vrr_stack+19288, r12vrr_stack+21528, r12vrr_stack+818, r12vrr_stack+1056, r12vrr_stack+14550, r12vrr_stack+19188);

 /*--- compute (h0|g0)^1 ---*/
 _BUILD_h0g0(Data,r12vrr_stack+37688, r12vrr_stack+21678, r12vrr_stack+19288, r12vrr_stack+1146, r12vrr_stack+21528, r12vrr_stack+15228);

 /*--- compute (i0|g0)^0 ---*/
 _BUILD_i0g0(Data,r12vrr_stack+38003, r12vrr_stack+21903, r12vrr_stack+37688, r12vrr_stack+1296, r12vrr_stack+21678, r12vrr_stack+11301);

 /*--- compute (p0|h0)^5 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+11301, r12vrr_stack+1671, r12vrr_stack+3051, NULL, NULL, r12vrr_stack+1656);

 /*--- compute (d0|h0)^4 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+11364, r12vrr_stack+368, r12vrr_stack+11301, r12vrr_stack+258, r12vrr_stack+1671, r12vrr_stack+14400);

 /*--- compute (f0|h0)^3 ---*/
 _BUILD_f0h0(Data,r12vrr_stack+15228, r12vrr_stack+22218, r12vrr_stack+11364, r12vrr_stack+2046, r12vrr_stack+368, r12vrr_stack+14445);

 /*--- compute (g0|h0)^2 ---*/
 _BUILD_g0h0(Data,r12vrr_stack+21528, r12vrr_stack+22344, r12vrr_stack+15228, r12vrr_stack+2109, r12vrr_stack+22218, r12vrr_stack+818);

 /*--- compute (h0|h0)^1 ---*/
 _BUILD_h0h0(Data,r12vrr_stack+758, r12vrr_stack+22554, r12vrr_stack+21528, r12vrr_stack+2235, r12vrr_stack+22344, r12vrr_stack+19288);

 /*--- compute (i0|h0)^0 ---*/
 _BUILD_i0h0(Data,r12vrr_stack+38423, r12vrr_stack+22869, r12vrr_stack+758, r12vrr_stack+2655, r12vrr_stack+22554, r12vrr_stack+37688);
 tmp = r12vrr_stack + 38423;
 target_ptr = Libr12->gvrr_classes[6][5];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|i0)^5 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+37688, r12vrr_stack+3072, r12vrr_stack+5019, NULL, NULL, r12vrr_stack+3051);

 /*--- compute (d0|i0)^4 ---*/
 _BUILD_d0i0(Data,r12vrr_stack+37772, r12vrr_stack+1563, r12vrr_stack+37688, r12vrr_stack+3922, r12vrr_stack+3072, r12vrr_stack+11301);

 /*--- compute (f0|i0)^3 ---*/
 _BUILD_f0i0(Data,r12vrr_stack+22218, r12vrr_stack+23310, r12vrr_stack+37772, r12vrr_stack+3950, r12vrr_stack+1563, r12vrr_stack+11364);

 /*--- compute (g0|i0)^2 ---*/
 _BUILD_g0i0(Data,r12vrr_stack+19032, r12vrr_stack+23478, r12vrr_stack+22218, r12vrr_stack+4034, r12vrr_stack+23310, r12vrr_stack+15228);

 /*--- compute (h0|i0)^1 ---*/
 _BUILD_h0i0(Data,r12vrr_stack+39011, r12vrr_stack+23758, r12vrr_stack+19032, r12vrr_stack+4202, r12vrr_stack+23478, r12vrr_stack+21528);

 /*--- compute (i0|i0)^0 ---*/
 _BUILD_i0i0(Data,r12vrr_stack+39599, r12vrr_stack+24178, r12vrr_stack+39011, r12vrr_stack+4482, r12vrr_stack+23758, r12vrr_stack+758);
 tmp = r12vrr_stack + 39599;
 target_ptr = Libr12->gvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|k0)^5 ---*/
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+758, r12vrr_stack+8916, r12vrr_stack+3015, NULL, NULL, r12vrr_stack+5019);

 /*--- compute (d0|k0)^4 ---*/
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+11301, r12vrr_stack+3222, r12vrr_stack+758, r12vrr_stack+6126, r12vrr_stack+8916, r12vrr_stack+37688);

 /*--- compute (f0|k0)^3 ---*/
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+866, r12vrr_stack+24766, r12vrr_stack+11301, r12vrr_stack+6162, r12vrr_stack+3222, r12vrr_stack+37772);

 /*--- compute (g0|k0)^2 ---*/
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+23310, r12vrr_stack+24982, r12vrr_stack+866, r12vrr_stack+6270, r12vrr_stack+24766, r12vrr_stack+22218);

 /*--- compute (h0|k0)^1 ---*/
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+40383, r12vrr_stack+25342, r12vrr_stack+23310, r12vrr_stack+6486, r12vrr_stack+24982, r12vrr_stack+19032);

 /*--- compute (i0|k0)^0 ---*/
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+41139, r12vrr_stack+25882, r12vrr_stack+40383, r12vrr_stack+6846, r12vrr_stack+25342, r12vrr_stack+39011);
 tmp = r12vrr_stack + 41139;
 target_ptr = Libr12->gvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|l0)^5 ---*/
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+18876, r12vrr_stack+7549, r12vrr_stack+10747, NULL, NULL, r12vrr_stack+3015);

 /*--- compute (d0|l0)^4 ---*/
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+39011, r12vrr_stack+5226, r12vrr_stack+18876, r12vrr_stack+8952, r12vrr_stack+7549, r12vrr_stack+758);

 /*--- compute (f0|l0)^3 ---*/
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+19032, r12vrr_stack+26638, r12vrr_stack+39011, r12vrr_stack+8997, r12vrr_stack+5226, r12vrr_stack+11301);

 /*--- compute (g0|l0)^2 ---*/
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+24766, r12vrr_stack+26908, r12vrr_stack+19032, r12vrr_stack+9132, r12vrr_stack+26638, r12vrr_stack+866);

 /*--- compute (h0|l0)^1 ---*/
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+42147, r12vrr_stack+27358, r12vrr_stack+24766, r12vrr_stack+9402, r12vrr_stack+26908, r12vrr_stack+23310);

 /*--- compute (i0|l0)^0 ---*/
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+43092, r12vrr_stack+28033, r12vrr_stack+42147, r12vrr_stack+9852, r12vrr_stack+27358, r12vrr_stack+40383);
 tmp = r12vrr_stack + 43092;
 target_ptr = Libr12->gvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|m0)^5 ---*/
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+40383, r12vrr_stack+4957, r12vrr_stack+4902, NULL, NULL, r12vrr_stack+10747);

 /*--- compute (d0|m0)^4 ---*/
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+40548, r12vrr_stack+7791, r12vrr_stack+40383, r12vrr_stack+12397, r12vrr_stack+4957, r12vrr_stack+18876);

 /*--- compute (f0|m0)^3 ---*/
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+23310, r12vrr_stack+28978, r12vrr_stack+40548, r12vrr_stack+12452, r12vrr_stack+7791, r12vrr_stack+39011);

 /*--- compute (g0|m0)^2 ---*/
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+26638, r12vrr_stack+29308, r12vrr_stack+23310, r12vrr_stack+12617, r12vrr_stack+28978, r12vrr_stack+19032);

 /*--- compute (h0|m0)^1 ---*/
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+44352, r12vrr_stack+29858, r12vrr_stack+26638, r12vrr_stack+12947, r12vrr_stack+29308, r12vrr_stack+24766);

 /*--- compute (i0|m0)^0 ---*/
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+45507, r12vrr_stack+30683, r12vrr_stack+44352, r12vrr_stack+13497, r12vrr_stack+29858, r12vrr_stack+42147);
 tmp = r12vrr_stack + 45507;
 target_ptr = Libr12->gvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^15 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /*--- compute (00|d0)^14 ---*/
 _BUILD_00d0(Data,r12vrr_stack+42147, r12vrr_stack+0, r12vrr_stack+3, Data->F+14, Data->F+15, NULL);

 /*--- compute (00|f0)^13 ---*/
 _BUILD_00f0(Data,r12vrr_stack+10792, r12vrr_stack+6, r12vrr_stack+42147, r12vrr_stack+114, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^12 ---*/
 _BUILD_00g0(Data,r12vrr_stack+42147, r12vrr_stack+3100, r12vrr_stack+10792, r12vrr_stack+1557, r12vrr_stack+6, NULL);

 /*--- compute (00|h0)^11 ---*/
 _BUILD_00h0(Data,r12vrr_stack+0, r12vrr_stack+11022, r12vrr_stack+42147, r12vrr_stack+10637, r12vrr_stack+3100, NULL);

 /*--- compute (00|i0)^10 ---*/
 _BUILD_00i0(Data,r12vrr_stack+42147, r12vrr_stack+19011, r12vrr_stack+0, r12vrr_stack+10647, r12vrr_stack+11022, NULL);

 /*--- compute (00|k0)^9 ---*/
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,r12vrr_stack+42175, r12vrr_stack+21, r12vrr_stack+42147, r12vrr_stack+10662, r12vrr_stack+19011, NULL);

 /*--- compute (00|l0)^8 ---*/
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,r12vrr_stack+42211, r12vrr_stack+1521, r12vrr_stack+42175, r12vrr_stack+10683, r12vrr_stack+21, NULL);

 /*--- compute (00|m0)^7 ---*/
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,r12vrr_stack+42147, r12vrr_stack+2970, r12vrr_stack+42211, r12vrr_stack+10711, r12vrr_stack+1521, NULL);

 /*--- compute (00|n0)^6 ---*/
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+1521, r12vrr_stack+4902, r12vrr_stack+42147, r12vrr_stack+10747, r12vrr_stack+2970, NULL);

 /*--- compute (p0|n0)^5 ---*/
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+42147, r12vrr_stack+11037, r12vrr_stack+1521, NULL, NULL, r12vrr_stack+4902);

 /*--- compute (d0|n0)^4 ---*/
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+42345, r12vrr_stack+11103, r12vrr_stack+42147, r12vrr_stack+16566, r12vrr_stack+11037, r12vrr_stack+40383);

 /*--- compute (f0|n0)^3 ---*/
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+24766, r12vrr_stack+31838, r12vrr_stack+42345, r12vrr_stack+16632, r12vrr_stack+11103, r12vrr_stack+40548);

 /*--- compute (g0|n0)^2 ---*/
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+28978, r12vrr_stack+32234, r12vrr_stack+24766, r12vrr_stack+16830, r12vrr_stack+31838, r12vrr_stack+23310);

 /*--- compute (h0|n0)^1 ---*/
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+47047, r12vrr_stack+32894, r12vrr_stack+28978, r12vrr_stack+17226, r12vrr_stack+32234, r12vrr_stack+26638);

 /*--- compute (i0|n0)^0 ---*/
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,r12vrr_stack+48433, r12vrr_stack+33884, r12vrr_stack+47047, r12vrr_stack+17886, r12vrr_stack+32894, r12vrr_stack+44352);

 /*--- compute (00|o0)^5 ---*/
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+44352, r12vrr_stack+11037, r12vrr_stack+1521, r12vrr_stack+4957, r12vrr_stack+4902, NULL);

 /*--- compute (p0|o0)^4 ---*/
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+1521, r12vrr_stack+14916, r12vrr_stack+44352, NULL, NULL, r12vrr_stack+11037);

 /*--- compute (d0|o0)^3 ---*/
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+44352, r12vrr_stack+14994, r12vrr_stack+1521, r12vrr_stack+14322, r12vrr_stack+14916, r12vrr_stack+11103);

 /*--- compute (f0|o0)^2 ---*/
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+47047, r12vrr_stack+35270, r12vrr_stack+44352, r12vrr_stack+19578, r12vrr_stack+14994, r12vrr_stack+31838);

 /*--- compute (g0|o0)^1 ---*/
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+26638, r12vrr_stack+35738, r12vrr_stack+47047, r12vrr_stack+19812, r12vrr_stack+35270, r12vrr_stack+32234);

 /*--- compute (h0|o0)^0 ---*/
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,r12vrr_stack+28978, r12vrr_stack+36518, r12vrr_stack+26638, r12vrr_stack+20748, r12vrr_stack+35738, r12vrr_stack+32894);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+26638, &(Data->ss_r12_ss), NULL, r12vrr_stack+279, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+26641, r12vrr_stack+26638, &(Data->ss_r12_ss), r12vrr_stack+282, r12vrr_stack+279, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+26647, r12vrr_stack+26641, r12vrr_stack+26638, r12vrr_stack+288, r12vrr_stack+282, r12vrr_stack+279, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+26657, r12vrr_stack+26647, r12vrr_stack+26641, r12vrr_stack+298, r12vrr_stack+288, r12vrr_stack+282, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+26672, r12vrr_stack+26657, r12vrr_stack+26647, r12vrr_stack+1836, r12vrr_stack+298, r12vrr_stack+288, NULL);

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+26693, r12vrr_stack+26672, NULL, r12vrr_stack+1857, r12vrr_stack+1836, NULL, r12vrr_stack+298);

 /*--- compute (d0||h0)^0 ---*/
 _R_BUILD_d0h0(Data,r12vrr_stack+26756, r12vrr_stack+26693, r12vrr_stack+26672, r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+1836, r12vrr_stack+313);

 /*--- compute (f0||h0)^0 ---*/
 _R_BUILD_f0h0(Data,r12vrr_stack+26882, r12vrr_stack+26756, r12vrr_stack+26693, r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+1857, r12vrr_stack+518);
 tmp = r12vrr_stack + 26882;
 target_ptr = Libr12->rvrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||h0)^0 ---*/
 _R_BUILD_g0h0(Data,r12vrr_stack+1521, r12vrr_stack+26882, r12vrr_stack+26756, r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+1920, r12vrr_stack+608);
 tmp = r12vrr_stack + 1521;
 target_ptr = Libr12->rvrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||i0)^0 ---*/
 _R_BUILD_00i0(Data,r12vrr_stack+26693, r12vrr_stack+26672, r12vrr_stack+26657, r12vrr_stack+3110, r12vrr_stack+1836, r12vrr_stack+298, NULL);

 /*--- compute (p0||i0)^0 ---*/
 _R_BUILD_p0i0(Data,r12vrr_stack+26721, r12vrr_stack+26693, NULL, r12vrr_stack+3138, r12vrr_stack+3110, NULL, r12vrr_stack+1836);

 /*--- compute (d0||i0)^0 ---*/
 _R_BUILD_d0i0(Data,r12vrr_stack+27092, r12vrr_stack+26721, r12vrr_stack+26693, r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+3110, r12vrr_stack+1857);

 /*--- compute (f0||i0)^0 ---*/
 _R_BUILD_f0i0(Data,r12vrr_stack+27260, r12vrr_stack+27092, r12vrr_stack+26721, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+3138, r12vrr_stack+1920);
 tmp = r12vrr_stack + 27260;
 target_ptr = Libr12->rvrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||i0)^0 ---*/
 _R_BUILD_g0i0(Data,r12vrr_stack+27540, r12vrr_stack+27260, r12vrr_stack+27092, r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+2445);
 tmp = r12vrr_stack + 27540;
 target_ptr = Libr12->rvrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||k0)^0 ---*/
 _R_BUILD_00k0(Data,r12vrr_stack+27092, r12vrr_stack+26693, r12vrr_stack+26672, r12vrr_stack+5082, r12vrr_stack+3110, r12vrr_stack+1836, NULL);

 /*--- compute (p0||k0)^0 ---*/
 _R_BUILD_p0k0(Data,r12vrr_stack+27128, r12vrr_stack+27092, NULL, r12vrr_stack+5118, r12vrr_stack+5082, NULL, r12vrr_stack+3110);

 /*--- compute (d0||k0)^0 ---*/
 _R_BUILD_d0k0(Data,r12vrr_stack+35270, r12vrr_stack+27128, r12vrr_stack+27092, r12vrr_stack+5550, r12vrr_stack+5118, r12vrr_stack+5082, r12vrr_stack+3138);

 /*--- compute (f0||k0)^0 ---*/
 _R_BUILD_f0k0(Data,r12vrr_stack+35486, r12vrr_stack+35270, r12vrr_stack+27128, r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+5118, r12vrr_stack+3474);
 tmp = r12vrr_stack + 35486;
 target_ptr = Libr12->rvrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||k0)^0 ---*/
 _R_BUILD_g0k0(Data,r12vrr_stack+35846, r12vrr_stack+35486, r12vrr_stack+35270, r12vrr_stack+6846, r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+3642);
 tmp = r12vrr_stack + 35846;
 target_ptr = Libr12->rvrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||l0)^0 ---*/
 _R_BUILD_00l0(Data,r12vrr_stack+35270, r12vrr_stack+27092, r12vrr_stack+26693, r12vrr_stack+7611, r12vrr_stack+5082, r12vrr_stack+3110, NULL);

 /*--- compute (p0||l0)^0 ---*/
 _R_BUILD_p0l0(Data,r12vrr_stack+35315, r12vrr_stack+35270, NULL, r12vrr_stack+7656, r12vrr_stack+7611, NULL, r12vrr_stack+5082);

 /*--- compute (d0||l0)^0 ---*/
 _R_BUILD_d0l0(Data,r12vrr_stack+47047, r12vrr_stack+35315, r12vrr_stack+35270, r12vrr_stack+8196, r12vrr_stack+7656, r12vrr_stack+7611, r12vrr_stack+5118);

 /*--- compute (f0||l0)^0 ---*/
 _R_BUILD_f0l0(Data,r12vrr_stack+47317, r12vrr_stack+47047, r12vrr_stack+35315, r12vrr_stack+8466, r12vrr_stack+8196, r12vrr_stack+7656, r12vrr_stack+5550);
 tmp = r12vrr_stack + 47317;
 target_ptr = Libr12->rvrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||l0)^0 ---*/
 _R_BUILD_g0l0(Data,r12vrr_stack+31838, r12vrr_stack+47317, r12vrr_stack+47047, r12vrr_stack+9852, r12vrr_stack+8466, r12vrr_stack+8196, r12vrr_stack+5766);
 tmp = r12vrr_stack + 31838;
 target_ptr = Libr12->rvrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||m0)^0 ---*/
 am[0] = 0;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+47047, r12vrr_stack+35270, r12vrr_stack+27092, r12vrr_stack+10802, r12vrr_stack+7611, r12vrr_stack+5082, NULL);

 /*--- compute (p0||m0)^0 ---*/
 am[0] = 1;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+27092, r12vrr_stack+47047, NULL, r12vrr_stack+10857, r12vrr_stack+10802, NULL, r12vrr_stack+7611);

 /*--- compute (d0||m0)^0 ---*/
 am[0] = 2;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+14322, r12vrr_stack+27092, r12vrr_stack+47047, r12vrr_stack+11517, r12vrr_stack+10857, r12vrr_stack+10802, r12vrr_stack+7656);

 /*--- compute (f0||m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+47767, r12vrr_stack+14322, r12vrr_stack+27092, r12vrr_stack+11847, r12vrr_stack+11517, r12vrr_stack+10857, r12vrr_stack+8196);
 tmp = r12vrr_stack + 47767;
 target_ptr = Libr12->rvrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+32513, r12vrr_stack+47767, r12vrr_stack+14322, r12vrr_stack+13497, r12vrr_stack+11847, r12vrr_stack+11517, r12vrr_stack+8466);
 tmp = r12vrr_stack + 32513;
 target_ptr = Libr12->rvrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00||n0)^0 ---*/
 am[0] = 0;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+14322, r12vrr_stack+47047, r12vrr_stack+35270, r12vrr_stack+14652, r12vrr_stack+10802, r12vrr_stack+7611, NULL);

 /*--- compute (p0||n0)^0 ---*/
 am[0] = 1;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+35270, r12vrr_stack+14322, NULL, r12vrr_stack+14718, r12vrr_stack+14652, NULL, r12vrr_stack+10802);

 /*--- compute (d0||n0)^0 ---*/
 am[0] = 2;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+33338, r12vrr_stack+35270, r12vrr_stack+14322, r12vrr_stack+15510, r12vrr_stack+14718, r12vrr_stack+14652, r12vrr_stack+10857);

 /*--- compute (f0||n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+44352, r12vrr_stack+33338, r12vrr_stack+35270, r12vrr_stack+15906, r12vrr_stack+15510, r12vrr_stack+14718, r12vrr_stack+11517);
 tmp = r12vrr_stack + 44352;
 target_ptr = Libr12->rvrr_classes[3][10];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0||n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+10527, r12vrr_stack+44352, r12vrr_stack+33338, r12vrr_stack+17886, r12vrr_stack+15906, r12vrr_stack+15510, r12vrr_stack+11847);
 tmp = r12vrr_stack + 10527;
 target_ptr = Libr12->rvrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+33338, r12vrr_stack+2445, r12vrr_stack+3642, r12vrr_stack+2655, r12vrr_stack+1296, r12vrr_stack+608);
 tmp = r12vrr_stack + 33338;
 target_ptr = Libr12->t2vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+33548, r12vrr_stack+3642, r12vrr_stack+5766, r12vrr_stack+4482, r12vrr_stack+2655, r12vrr_stack+2445);
 tmp = r12vrr_stack + 33548;
 target_ptr = Libr12->t2vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_f0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14322, r12vrr_stack+5766, r12vrr_stack+8466, r12vrr_stack+6846, r12vrr_stack+4482, r12vrr_stack+3642);
 tmp = r12vrr_stack + 14322;
 target_ptr = Libr12->t2vrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_f0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+14682, r12vrr_stack+8466, r12vrr_stack+11847, r12vrr_stack+9852, r12vrr_stack+6846, r12vrr_stack+5766);
 tmp = r12vrr_stack + 14682;
 target_ptr = Libr12->t2vrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+4902, r12vrr_stack+11847, r12vrr_stack+15906, r12vrr_stack+13497, r12vrr_stack+9852, r12vrr_stack+8466);
 tmp = r12vrr_stack + 4902;
 target_ptr = Libr12->t2vrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T2]|n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+23310, r12vrr_stack+15906, r12vrr_stack+20748, r12vrr_stack+17886, r12vrr_stack+13497, r12vrr_stack+11847);
 tmp = r12vrr_stack + 23310;
 target_ptr = Libr12->t2vrr_classes[3][10];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+37688, r12vrr_stack+2655, r12vrr_stack+4482, r12vrr_stack+22869, r12vrr_stack+21903, r12vrr_stack+1296);
 tmp = r12vrr_stack + 37688;
 target_ptr = Libr12->t2vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+45012, r12vrr_stack+4482, r12vrr_stack+6846, r12vrr_stack+24178, r12vrr_stack+22869, r12vrr_stack+2655);
 tmp = r12vrr_stack + 45012;
 target_ptr = Libr12->t2vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+24766, r12vrr_stack+6846, r12vrr_stack+9852, r12vrr_stack+25882, r12vrr_stack+24178, r12vrr_stack+4482);
 tmp = r12vrr_stack + 24766;
 target_ptr = Libr12->t2vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+40383, r12vrr_stack+9852, r12vrr_stack+13497, r12vrr_stack+28033, r12vrr_stack+25882, r12vrr_stack+6846);
 tmp = r12vrr_stack + 40383;
 target_ptr = Libr12->t2vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+16566, r12vrr_stack+13497, r12vrr_stack+17886, r12vrr_stack+30683, r12vrr_stack+28033, r12vrr_stack+9852);
 tmp = r12vrr_stack + 16566;
 target_ptr = Libr12->t2vrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T2]|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+0, r12vrr_stack+17886, r12vrr_stack+36518, r12vrr_stack+33884, r12vrr_stack+30683, r12vrr_stack+13497);
 tmp = r12vrr_stack + 0;
 target_ptr = Libr12->t2vrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+25306, r12vrr_stack+22869, r12vrr_stack+24178, r12vrr_stack+38423, r12vrr_stack+38003, r12vrr_stack+21903);
 tmp = r12vrr_stack + 25306;
 target_ptr = Libr12->t2vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|i0)^0 ---*/
 _T2_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+39011, r12vrr_stack+24178, r12vrr_stack+25882, r12vrr_stack+39599, r12vrr_stack+38423, r12vrr_stack+22869);
 tmp = r12vrr_stack + 39011;
 target_ptr = Libr12->t2vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|k0)^0 ---*/
 _T2_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+42147, r12vrr_stack+25882, r12vrr_stack+28033, r12vrr_stack+41139, r12vrr_stack+39599, r12vrr_stack+24178);
 tmp = r12vrr_stack + 42147;
 target_ptr = Libr12->t2vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|l0)^0 ---*/
 _T2_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+18876, r12vrr_stack+28033, r12vrr_stack+30683, r12vrr_stack+43092, r12vrr_stack+41139, r12vrr_stack+25882);
 tmp = r12vrr_stack + 18876;
 target_ptr = Libr12->t2vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+21528, r12vrr_stack+30683, r12vrr_stack+33884, r12vrr_stack+45507, r12vrr_stack+43092, r12vrr_stack+28033);
 tmp = r12vrr_stack + 21528;
 target_ptr = Libr12->t2vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T2]|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 t2_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+50281, r12vrr_stack+33884, r12vrr_stack+28978, r12vrr_stack+48433, r12vrr_stack+45507, r12vrr_stack+30683);
 tmp = r12vrr_stack + 50281;
 target_ptr = Libr12->t2vrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_f0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+38003, r12vrr_stack+2445, r12vrr_stack+2655, r12vrr_stack+3642, r12vrr_stack+3474, r12vrr_stack+1920);
 tmp = r12vrr_stack + 38003;
 target_ptr = Libr12->t1vrr_classes[3][5];
 for(i=0;i<210;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_f0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+15132, r12vrr_stack+3642, r12vrr_stack+4482, r12vrr_stack+5766, r12vrr_stack+5550, r12vrr_stack+3474);
 tmp = r12vrr_stack + 15132;
 target_ptr = Libr12->t1vrr_classes[3][6];
 for(i=0;i<280;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_f0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+1836, r12vrr_stack+5766, r12vrr_stack+6846, r12vrr_stack+8466, r12vrr_stack+8196, r12vrr_stack+5550);
 tmp = r12vrr_stack + 1836;
 target_ptr = Libr12->t1vrr_classes[3][7];
 for(i=0;i<360;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_f0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+17391, r12vrr_stack+8466, r12vrr_stack+9852, r12vrr_stack+11847, r12vrr_stack+11517, r12vrr_stack+8196);
 tmp = r12vrr_stack + 17391;
 target_ptr = Libr12->t1vrr_classes[3][8];
 for(i=0;i<450;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|m0)^0 ---*/
 am[0] = 3;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+2970, r12vrr_stack+11847, r12vrr_stack+13497, r12vrr_stack+15906, r12vrr_stack+15510, r12vrr_stack+11517);
 tmp = r12vrr_stack + 2970;
 target_ptr = Libr12->t1vrr_classes[3][9];
 for(i=0;i<550;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (f0|[r12,T1]|n0)^0 ---*/
 am[0] = 3;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+12397, r12vrr_stack+15906, r12vrr_stack+17886, r12vrr_stack+20748, r12vrr_stack+20280, r12vrr_stack+15510);
 tmp = r12vrr_stack + 12397;
 target_ptr = Libr12->t1vrr_classes[3][10];
 for(i=0;i<660;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_g0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+11517, r12vrr_stack+2655, r12vrr_stack+22869, r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+2445);
 tmp = r12vrr_stack + 11517;
 target_ptr = Libr12->t1vrr_classes[4][5];
 for(i=0;i<315;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_g0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+15412, r12vrr_stack+4482, r12vrr_stack+24178, r12vrr_stack+6846, r12vrr_stack+5766, r12vrr_stack+3642);
 tmp = r12vrr_stack + 15412;
 target_ptr = Libr12->t1vrr_classes[4][6];
 for(i=0;i<420;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_g0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+19821, r12vrr_stack+6846, r12vrr_stack+25882, r12vrr_stack+9852, r12vrr_stack+8466, r12vrr_stack+5766);
 tmp = r12vrr_stack + 19821;
 target_ptr = Libr12->t1vrr_classes[4][7];
 for(i=0;i<540;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_g0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+8916, r12vrr_stack+9852, r12vrr_stack+28033, r12vrr_stack+13497, r12vrr_stack+11847, r12vrr_stack+8466);
 tmp = r12vrr_stack + 8916;
 target_ptr = Libr12->t1vrr_classes[4][8];
 for(i=0;i<675;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|m0)^0 ---*/
 am[0] = 4;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+7386, r12vrr_stack+13497, r12vrr_stack+30683, r12vrr_stack+17886, r12vrr_stack+15906, r12vrr_stack+11847);
 tmp = r12vrr_stack + 7386;
 target_ptr = Libr12->t1vrr_classes[4][9];
 for(i=0;i<825;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (g0|[r12,T1]|n0)^0 ---*/
 am[0] = 4;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+51667, r12vrr_stack+17886, r12vrr_stack+33884, r12vrr_stack+36518, r12vrr_stack+20748, r12vrr_stack+15906);
 tmp = r12vrr_stack + 51667;
 target_ptr = Libr12->t1vrr_classes[4][10];
 for(i=0;i<990;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_h0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+20361, r12vrr_stack+22869, r12vrr_stack+38423, r12vrr_stack+24178, r12vrr_stack+4482, r12vrr_stack+2655);
 tmp = r12vrr_stack + 20361;
 target_ptr = Libr12->t1vrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|i0)^0 ---*/
 _T1_BUILD_h0i0(Data,&(Libr12->ShellQuartet),r12vrr_stack+38213, r12vrr_stack+24178, r12vrr_stack+39599, r12vrr_stack+25882, r12vrr_stack+6846, r12vrr_stack+4482);
 tmp = r12vrr_stack + 38213;
 target_ptr = Libr12->t1vrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|k0)^0 ---*/
 _T1_BUILD_h0k0(Data,&(Libr12->ShellQuartet),r12vrr_stack+39599, r12vrr_stack+25882, r12vrr_stack+41139, r12vrr_stack+28033, r12vrr_stack+9852, r12vrr_stack+6846);
 tmp = r12vrr_stack + 39599;
 target_ptr = Libr12->t1vrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|l0)^0 ---*/
 _T1_BUILD_h0l0(Data,&(Libr12->ShellQuartet),r12vrr_stack+41058, r12vrr_stack+28033, r12vrr_stack+43092, r12vrr_stack+30683, r12vrr_stack+13497, r12vrr_stack+9852);
 tmp = r12vrr_stack + 41058;
 target_ptr = Libr12->t1vrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+42903, r12vrr_stack+30683, r12vrr_stack+45507, r12vrr_stack+33884, r12vrr_stack+17886, r12vrr_stack+13497);
 tmp = r12vrr_stack + 42903;
 target_ptr = Libr12->t1vrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0|[r12,T1]|n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 t1_vrr_build_xxxx(am,Data,&(Libr12->ShellQuartet),r12vrr_stack+45432, r12vrr_stack+33884, r12vrr_stack+48433, r12vrr_stack+28978, r12vrr_stack+36518, r12vrr_stack+17886);
 tmp = r12vrr_stack + 45432;
 target_ptr = Libr12->t1vrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||h0)^0 ---*/
 _R_BUILD_h0h0(Data,r12vrr_stack+28978, r12vrr_stack+1521, r12vrr_stack+26882, r12vrr_stack+22869, r12vrr_stack+2655, r12vrr_stack+2445, r12vrr_stack+1296);
 tmp = r12vrr_stack + 28978;
 target_ptr = Libr12->rvrr_classes[5][5];
 for(i=0;i<441;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||i0)^0 ---*/
 _R_BUILD_h0i0(Data,r12vrr_stack+29419, r12vrr_stack+27540, r12vrr_stack+27260, r12vrr_stack+24178, r12vrr_stack+4482, r12vrr_stack+3642, r12vrr_stack+2655);
 tmp = r12vrr_stack + 29419;
 target_ptr = Libr12->rvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||k0)^0 ---*/
 _R_BUILD_h0k0(Data,r12vrr_stack+2196, r12vrr_stack+35846, r12vrr_stack+35486, r12vrr_stack+25882, r12vrr_stack+6846, r12vrr_stack+5766, r12vrr_stack+4482);
 tmp = r12vrr_stack + 2196;
 target_ptr = Libr12->rvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||l0)^0 ---*/
 _R_BUILD_h0l0(Data,r12vrr_stack+35270, r12vrr_stack+31838, r12vrr_stack+47317, r12vrr_stack+28033, r12vrr_stack+9852, r12vrr_stack+8466, r12vrr_stack+6846);
 tmp = r12vrr_stack + 35270;
 target_ptr = Libr12->rvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||m0)^0 ---*/
 am[0] = 5;  am[1] = 9;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+36215, r12vrr_stack+32513, r12vrr_stack+47767, r12vrr_stack+30683, r12vrr_stack+13497, r12vrr_stack+11847, r12vrr_stack+9852);
 tmp = r12vrr_stack + 36215;
 target_ptr = Libr12->rvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (h0||n0)^0 ---*/
 am[0] = 5;  am[1] = 10;
 r_vrr_build_xxxx(am,Data,r12vrr_stack+30007, r12vrr_stack+10527, r12vrr_stack+44352, r12vrr_stack+33884, r12vrr_stack+17886, r12vrr_stack+15906, r12vrr_stack+13497);
 tmp = r12vrr_stack + 30007;
 target_ptr = Libr12->rvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];


}

