/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libr12.h"
#include <libint/vrr_header.h>
#include "r12_vrr_header.h"

void vrr_grt_order_p0fd(Libr12_t *Libr12, prim_data *Data)
{
 REALTYPE *r12vrr_stack = Libr12->r12vrr_stack;
 REALTYPE *tmp, *target_ptr;
 int i, am[2];

 /*--- compute (00|p0)^1 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /*--- compute (00|p0)^2 ---*/
 _BUILD_00p0(Data,r12vrr_stack+3, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /*--- compute (00|d0)^1 ---*/
 _BUILD_00d0(Data,r12vrr_stack+6, r12vrr_stack+0, r12vrr_stack+3, Data->F+1, Data->F+2, NULL);

 /*--- compute (00|p0)^0 ---*/
 _BUILD_00p0(Data,r12vrr_stack+12, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /*--- compute (00|d0)^0 ---*/
 _BUILD_00d0(Data,r12vrr_stack+15, r12vrr_stack+12, r12vrr_stack+0, Data->F+0, Data->F+1, NULL);

 /*--- compute (p0|d0)^0 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+21, r12vrr_stack+15, r12vrr_stack+6, NULL, NULL, r12vrr_stack+0);

 /*--- compute (p0|p0)^1 ---*/
 _BUILD_p0p0(Data,r12vrr_stack+39, r12vrr_stack+0, r12vrr_stack+3, NULL, NULL, Data->F+2);

 /*--- compute (00|p0)^3 ---*/
 _BUILD_00p0(Data,r12vrr_stack+48, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /*--- compute (00|d0)^2 ---*/
 _BUILD_00d0(Data,r12vrr_stack+51, r12vrr_stack+3, r12vrr_stack+48, Data->F+2, Data->F+3, NULL);

 /*--- compute (p0|d0)^1 ---*/
 _BUILD_p0d0(Data,r12vrr_stack+57, r12vrr_stack+6, r12vrr_stack+51, NULL, NULL, r12vrr_stack+3);

 /*--- compute (d0|d0)^0 ---*/
 _BUILD_d0d0(Data,r12vrr_stack+75, r12vrr_stack+21, r12vrr_stack+57, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+39);

 /*--- compute (00|f0)^1 ---*/
 _BUILD_00f0(Data,r12vrr_stack+111, r12vrr_stack+6, r12vrr_stack+51, r12vrr_stack+0, r12vrr_stack+3, NULL);

 /*--- compute (00|f0)^0 ---*/
 _BUILD_00f0(Data,r12vrr_stack+121, r12vrr_stack+15, r12vrr_stack+6, r12vrr_stack+12, r12vrr_stack+0, NULL);

 /*--- compute (00|p0)^4 ---*/
 _BUILD_00p0(Data,r12vrr_stack+0, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /*--- compute (00|d0)^3 ---*/
 _BUILD_00d0(Data,r12vrr_stack+39, r12vrr_stack+48, r12vrr_stack+0, Data->F+3, Data->F+4, NULL);

 /*--- compute (00|f0)^2 ---*/
 _BUILD_00f0(Data,r12vrr_stack+131, r12vrr_stack+51, r12vrr_stack+39, r12vrr_stack+3, r12vrr_stack+48, NULL);

 /*--- compute (p0|f0)^1 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+141, r12vrr_stack+111, r12vrr_stack+131, NULL, NULL, r12vrr_stack+51);

 /*--- compute (p0|f0)^0 ---*/
 _BUILD_p0f0(Data,r12vrr_stack+171, r12vrr_stack+121, r12vrr_stack+111, NULL, NULL, r12vrr_stack+6);
 tmp = r12vrr_stack + 171;
 target_ptr = Libr12->gvrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (d0|f0)^0 ---*/
 _BUILD_d0f0(Data,r12vrr_stack+201, r12vrr_stack+171, r12vrr_stack+141, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+57);
 tmp = r12vrr_stack + 201;
 target_ptr = Libr12->gvrr_classes[2][3];
 for(i=0;i<60;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|g0)^1 ---*/
 _BUILD_00g0(Data,r12vrr_stack+57, r12vrr_stack+111, r12vrr_stack+131, r12vrr_stack+6, r12vrr_stack+51, NULL);

 /*--- compute (00|g0)^0 ---*/
 _BUILD_00g0(Data,r12vrr_stack+261, r12vrr_stack+121, r12vrr_stack+111, r12vrr_stack+15, r12vrr_stack+6, NULL);

 /*--- compute (p0|g0)^0 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+276, r12vrr_stack+261, r12vrr_stack+57, NULL, NULL, r12vrr_stack+111);
 tmp = r12vrr_stack + 276;
 target_ptr = Libr12->gvrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^5 ---*/
 _BUILD_00p0(Data,r12vrr_stack+72, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /*--- compute (00|d0)^4 ---*/
 _BUILD_00d0(Data,r12vrr_stack+3, r12vrr_stack+0, r12vrr_stack+72, Data->F+4, Data->F+5, NULL);

 /*--- compute (00|f0)^3 ---*/
 _BUILD_00f0(Data,r12vrr_stack+321, r12vrr_stack+39, r12vrr_stack+3, r12vrr_stack+48, r12vrr_stack+0, NULL);

 /*--- compute (00|g0)^2 ---*/
 _BUILD_00g0(Data,r12vrr_stack+331, r12vrr_stack+131, r12vrr_stack+321, r12vrr_stack+51, r12vrr_stack+39, NULL);

 /*--- compute (p0|g0)^1 ---*/
 _BUILD_p0g0(Data,r12vrr_stack+346, r12vrr_stack+57, r12vrr_stack+331, NULL, NULL, r12vrr_stack+131);

 /*--- compute (d0|g0)^0 ---*/
 _BUILD_d0g0(Data,r12vrr_stack+391, r12vrr_stack+276, r12vrr_stack+346, r12vrr_stack+261, r12vrr_stack+57, r12vrr_stack+141);
 tmp = r12vrr_stack + 391;
 target_ptr = Libr12->gvrr_classes[2][4];
 for(i=0;i<90;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|h0)^1 ---*/
 _BUILD_00h0(Data,r12vrr_stack+141, r12vrr_stack+57, r12vrr_stack+331, r12vrr_stack+111, r12vrr_stack+131, NULL);

 /*--- compute (00|h0)^0 ---*/
 _BUILD_00h0(Data,r12vrr_stack+481, r12vrr_stack+261, r12vrr_stack+57, r12vrr_stack+121, r12vrr_stack+111, NULL);

 /*--- compute (p0|h0)^0 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+502, r12vrr_stack+481, r12vrr_stack+141, NULL, NULL, r12vrr_stack+57);
 tmp = r12vrr_stack + 502;
 target_ptr = Libr12->gvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (00|p0)^6 ---*/
 _BUILD_00p0(Data,r12vrr_stack+9, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /*--- compute (00|d0)^5 ---*/
 _BUILD_00d0(Data,r12vrr_stack+111, r12vrr_stack+72, r12vrr_stack+9, Data->F+5, Data->F+6, NULL);

 /*--- compute (00|f0)^4 ---*/
 _BUILD_00f0(Data,r12vrr_stack+45, r12vrr_stack+3, r12vrr_stack+111, r12vrr_stack+0, r12vrr_stack+72, NULL);

 /*--- compute (00|g0)^3 ---*/
 _BUILD_00g0(Data,r12vrr_stack+565, r12vrr_stack+321, r12vrr_stack+45, r12vrr_stack+39, r12vrr_stack+3, NULL);

 /*--- compute (00|h0)^2 ---*/
 _BUILD_00h0(Data,r12vrr_stack+580, r12vrr_stack+331, r12vrr_stack+565, r12vrr_stack+131, r12vrr_stack+321, NULL);

 /*--- compute (p0|h0)^1 ---*/
 _BUILD_p0h0(Data,r12vrr_stack+601, r12vrr_stack+141, r12vrr_stack+580, NULL, NULL, r12vrr_stack+331);

 /*--- compute (d0|h0)^0 ---*/
 _BUILD_d0h0(Data,r12vrr_stack+664, r12vrr_stack+502, r12vrr_stack+601, r12vrr_stack+481, r12vrr_stack+141, r12vrr_stack+346);

 /*--- compute (00|i0)^1 ---*/
 _BUILD_00i0(Data,r12vrr_stack+346, r12vrr_stack+141, r12vrr_stack+580, r12vrr_stack+57, r12vrr_stack+331, NULL);

 /*--- compute (00|i0)^0 ---*/
 _BUILD_00i0(Data,r12vrr_stack+565, r12vrr_stack+481, r12vrr_stack+141, r12vrr_stack+261, r12vrr_stack+57, NULL);

 /*--- compute (p0|i0)^0 ---*/
 _BUILD_p0i0(Data,r12vrr_stack+790, r12vrr_stack+565, r12vrr_stack+346, NULL, NULL, r12vrr_stack+141);

 /*--- compute (00||p0)^0 ---*/
 _R_BUILD_00p0(Data,r12vrr_stack+321, &(Data->ss_r12_ss), NULL, r12vrr_stack+12, Data->F+0, NULL, NULL);

 /*--- compute (00||d0)^0 ---*/
 _R_BUILD_00d0(Data,r12vrr_stack+324, r12vrr_stack+321, &(Data->ss_r12_ss), r12vrr_stack+15, r12vrr_stack+12, Data->F+0, NULL);

 /*--- compute (00||f0)^0 ---*/
 _R_BUILD_00f0(Data,r12vrr_stack+111, r12vrr_stack+324, r12vrr_stack+321, r12vrr_stack+121, r12vrr_stack+15, r12vrr_stack+12, NULL);

 /*--- compute (00||g0)^0 ---*/
 _R_BUILD_00g0(Data,r12vrr_stack+0, r12vrr_stack+111, r12vrr_stack+324, r12vrr_stack+261, r12vrr_stack+121, r12vrr_stack+15, NULL);

 /*--- compute (00||h0)^0 ---*/
 _R_BUILD_00h0(Data,r12vrr_stack+321, r12vrr_stack+0, r12vrr_stack+111, r12vrr_stack+481, r12vrr_stack+261, r12vrr_stack+121, NULL);

 /*--- compute (p0|[r12,T2]|f0)^0 ---*/
 _T2_BUILD_p0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+342, r12vrr_stack+171, r12vrr_stack+276, r12vrr_stack+201, r12vrr_stack+75, r12vrr_stack+21);
 tmp = r12vrr_stack + 342;
 target_ptr = Libr12->t2vrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|g0)^0 ---*/
 _T2_BUILD_p0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+21, r12vrr_stack+276, r12vrr_stack+502, r12vrr_stack+391, r12vrr_stack+201, r12vrr_stack+171);
 tmp = r12vrr_stack + 21;
 target_ptr = Libr12->t2vrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T2]|h0)^0 ---*/
 _T2_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+593, r12vrr_stack+502, r12vrr_stack+790, r12vrr_stack+664, r12vrr_stack+391, r12vrr_stack+276);
 tmp = r12vrr_stack + 593;
 target_ptr = Libr12->t2vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|f0)^0 ---*/
 _T1_BUILD_p0f0(Data,&(Libr12->ShellQuartet),r12vrr_stack+66, r12vrr_stack+171, r12vrr_stack+201, r12vrr_stack+276, r12vrr_stack+261, r12vrr_stack+121);
 tmp = r12vrr_stack + 66;
 target_ptr = Libr12->t1vrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|g0)^0 ---*/
 _T1_BUILD_p0g0(Data,&(Libr12->ShellQuartet),r12vrr_stack+201, r12vrr_stack+276, r12vrr_stack+391, r12vrr_stack+502, r12vrr_stack+481, r12vrr_stack+261);
 tmp = r12vrr_stack + 201;
 target_ptr = Libr12->t1vrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0|[r12,T1]|h0)^0 ---*/
 _T1_BUILD_p0h0(Data,&(Libr12->ShellQuartet),r12vrr_stack+372, r12vrr_stack+502, r12vrr_stack+664, r12vrr_stack+790, r12vrr_stack+565, r12vrr_stack+481);
 tmp = r12vrr_stack + 372;
 target_ptr = Libr12->t1vrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||f0)^0 ---*/
 _R_BUILD_p0f0(Data,r12vrr_stack+435, r12vrr_stack+111, NULL, r12vrr_stack+171, r12vrr_stack+121, NULL, r12vrr_stack+15);
 tmp = r12vrr_stack + 435;
 target_ptr = Libr12->rvrr_classes[1][3];
 for(i=0;i<30;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||g0)^0 ---*/
 _R_BUILD_p0g0(Data,r12vrr_stack+131, r12vrr_stack+0, NULL, r12vrr_stack+276, r12vrr_stack+261, NULL, r12vrr_stack+121);
 tmp = r12vrr_stack + 131;
 target_ptr = Libr12->rvrr_classes[1][4];
 for(i=0;i<45;i++)
   target_ptr[i] += tmp[i];

 /*--- compute (p0||h0)^0 ---*/
 _R_BUILD_p0h0(Data,r12vrr_stack+656, r12vrr_stack+321, NULL, r12vrr_stack+502, r12vrr_stack+481, NULL, r12vrr_stack+261);
 tmp = r12vrr_stack + 656;
 target_ptr = Libr12->rvrr_classes[1][5];
 for(i=0;i<63;i++)
   target_ptr[i] += tmp[i];


}

