/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_gdhd(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gd|hd) integrals */

void d12hrr_order_gdhd(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[6][7][11] = int_stack + 0;
 Libderiv->deriv_classes[6][7][10] = int_stack + 1008;
 Libderiv->deriv_classes[6][7][9] = int_stack + 2016;
 Libderiv->deriv_classes[6][7][8] = int_stack + 3024;
 Libderiv->deriv_classes[6][7][7] = int_stack + 4032;
 Libderiv->dvrr_classes[6][6] = int_stack + 5040;
 Libderiv->deriv_classes[6][7][6] = int_stack + 5824;
 Libderiv->deriv_classes[6][7][2] = int_stack + 6832;
 Libderiv->deriv_classes[6][7][1] = int_stack + 7840;
 Libderiv->dvrr_classes[5][7] = int_stack + 8848;
 Libderiv->deriv_classes[6][7][0] = int_stack + 9604;
 Libderiv->deriv2_classes[4][5][143] = int_stack + 10612;
 Libderiv->deriv2_classes[4][6][143] = int_stack + 10927;
 Libderiv->deriv2_classes[4][7][143] = int_stack + 11347;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 11887;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 12328;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 12916;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 13672;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 14260;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 15044;
 Libderiv->deriv2_classes[4][5][131] = int_stack + 16052;
 Libderiv->deriv2_classes[4][6][131] = int_stack + 16367;
 Libderiv->deriv2_classes[4][7][131] = int_stack + 16787;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 17327;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 17768;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 18356;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 19112;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 19700;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 20484;
 Libderiv->deriv2_classes[4][5][130] = int_stack + 21492;
 Libderiv->deriv2_classes[4][6][130] = int_stack + 21807;
 Libderiv->deriv2_classes[4][7][130] = int_stack + 22227;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 22767;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 23208;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 23796;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 24552;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 25140;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 25924;
 Libderiv->deriv2_classes[4][5][119] = int_stack + 26932;
 Libderiv->deriv2_classes[4][6][119] = int_stack + 27247;
 Libderiv->deriv2_classes[4][7][119] = int_stack + 27667;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 28207;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 28648;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 29236;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 29992;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 30580;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 31364;
 Libderiv->deriv2_classes[4][5][118] = int_stack + 32372;
 Libderiv->deriv2_classes[4][6][118] = int_stack + 32687;
 Libderiv->deriv2_classes[4][7][118] = int_stack + 33107;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 33647;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 34088;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 34676;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 35432;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 36020;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 36804;
 Libderiv->deriv2_classes[4][5][117] = int_stack + 37812;
 Libderiv->deriv2_classes[4][6][117] = int_stack + 38127;
 Libderiv->deriv2_classes[4][7][117] = int_stack + 38547;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 39087;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 39528;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 40116;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 40872;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 41460;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 42244;
 Libderiv->deriv2_classes[4][5][107] = int_stack + 43252;
 Libderiv->deriv2_classes[4][6][107] = int_stack + 43567;
 Libderiv->deriv2_classes[4][7][107] = int_stack + 43987;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 44527;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 44968;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 45556;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 46312;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 46900;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 47684;
 Libderiv->deriv2_classes[4][5][106] = int_stack + 48692;
 Libderiv->deriv2_classes[4][6][106] = int_stack + 49007;
 Libderiv->deriv2_classes[4][7][106] = int_stack + 49427;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 49967;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 50408;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 50996;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 51752;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 52340;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 53124;
 Libderiv->deriv2_classes[4][5][105] = int_stack + 54132;
 Libderiv->deriv2_classes[4][6][105] = int_stack + 54447;
 Libderiv->deriv2_classes[4][7][105] = int_stack + 54867;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 55407;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 55848;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 56436;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 57192;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 57780;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 58564;
 Libderiv->deriv2_classes[4][5][104] = int_stack + 59572;
 Libderiv->deriv2_classes[4][6][104] = int_stack + 59887;
 Libderiv->deriv2_classes[4][7][104] = int_stack + 60307;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 60847;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 61288;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 61876;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 62632;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 63220;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 64004;
 Libderiv->deriv2_classes[4][5][95] = int_stack + 65012;
 Libderiv->deriv2_classes[4][6][95] = int_stack + 65327;
 Libderiv->deriv2_classes[4][7][95] = int_stack + 65747;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 66287;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 66728;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 67316;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 68072;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 68660;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 69444;
 Libderiv->deriv2_classes[4][5][94] = int_stack + 70452;
 Libderiv->deriv2_classes[4][6][94] = int_stack + 70767;
 Libderiv->deriv2_classes[4][7][94] = int_stack + 71187;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 71727;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 72168;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 72756;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 73512;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 74100;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 74884;
 Libderiv->deriv2_classes[4][5][93] = int_stack + 75892;
 Libderiv->deriv2_classes[4][6][93] = int_stack + 76207;
 Libderiv->deriv2_classes[4][7][93] = int_stack + 76627;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 77167;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 77608;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 78196;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 78952;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 79540;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 80324;
 Libderiv->deriv2_classes[4][5][92] = int_stack + 81332;
 Libderiv->deriv2_classes[4][6][92] = int_stack + 81647;
 Libderiv->deriv2_classes[4][7][92] = int_stack + 82067;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 82607;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 83048;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 83636;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 84392;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 84980;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 85764;
 Libderiv->deriv2_classes[4][5][91] = int_stack + 86772;
 Libderiv->deriv2_classes[4][6][91] = int_stack + 87087;
 Libderiv->deriv2_classes[4][7][91] = int_stack + 87507;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 88047;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 88488;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 89076;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 89832;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 90420;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 91204;
 Libderiv->deriv2_classes[4][5][83] = int_stack + 92212;
 Libderiv->deriv2_classes[4][6][83] = int_stack + 92527;
 Libderiv->deriv2_classes[4][7][83] = int_stack + 92947;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 93487;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 93928;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 94516;
 Libderiv->deriv_classes[6][5][11] = int_stack + 95272;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 95860;
 Libderiv->deriv_classes[6][6][11] = int_stack + 96448;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 97232;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 98016;
 Libderiv->deriv2_classes[4][5][82] = int_stack + 99024;
 Libderiv->deriv2_classes[4][6][82] = int_stack + 99339;
 Libderiv->deriv2_classes[4][7][82] = int_stack + 99759;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 100299;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 100740;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 101328;
 Libderiv->deriv_classes[6][5][10] = int_stack + 102084;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 102672;
 Libderiv->deriv_classes[6][6][10] = int_stack + 103260;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 104044;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 104828;
 Libderiv->deriv2_classes[4][5][81] = int_stack + 105836;
 Libderiv->deriv2_classes[4][6][81] = int_stack + 106151;
 Libderiv->deriv2_classes[4][7][81] = int_stack + 106571;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 107111;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 107552;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 108140;
 Libderiv->deriv_classes[6][5][9] = int_stack + 108896;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 109484;
 Libderiv->deriv_classes[6][6][9] = int_stack + 110072;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 110856;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 111640;
 Libderiv->deriv2_classes[4][5][80] = int_stack + 112648;
 Libderiv->deriv2_classes[4][6][80] = int_stack + 112963;
 Libderiv->deriv2_classes[4][7][80] = int_stack + 113383;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 113923;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 114364;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 114952;
 Libderiv->deriv_classes[6][5][8] = int_stack + 115708;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 116296;
 Libderiv->deriv_classes[6][6][8] = int_stack + 116884;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 117668;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 118452;
 Libderiv->deriv2_classes[4][5][79] = int_stack + 119460;
 Libderiv->deriv2_classes[4][6][79] = int_stack + 119775;
 Libderiv->deriv2_classes[4][7][79] = int_stack + 120195;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 120735;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 121176;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 121764;
 Libderiv->deriv_classes[6][5][7] = int_stack + 122520;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 123108;
 Libderiv->deriv_classes[6][6][7] = int_stack + 123696;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 124480;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 125264;
 Libderiv->deriv2_classes[4][5][78] = int_stack + 126272;
 Libderiv->deriv2_classes[4][6][78] = int_stack + 126587;
 Libderiv->deriv2_classes[4][7][78] = int_stack + 127007;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 127547;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 127988;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 128576;
 Libderiv->dvrr_classes[6][5] = int_stack + 129332;
 Libderiv->deriv_classes[6][5][6] = int_stack + 129920;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 130508;
 Libderiv->deriv_classes[6][6][6] = int_stack + 131096;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 131880;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 132664;
 Libderiv->deriv2_classes[4][5][35] = int_stack + 133672;
 Libderiv->deriv2_classes[4][6][35] = int_stack + 133987;
 Libderiv->deriv2_classes[4][7][35] = int_stack + 134407;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 134947;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 135388;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 135976;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 136732;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 137320;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 138104;
 Libderiv->deriv2_classes[4][5][34] = int_stack + 139112;
 Libderiv->deriv2_classes[4][6][34] = int_stack + 139427;
 Libderiv->deriv2_classes[4][7][34] = int_stack + 139847;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 140387;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 140828;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 141416;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 142172;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 142760;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 143544;
 Libderiv->deriv2_classes[4][5][33] = int_stack + 144552;
 Libderiv->deriv2_classes[4][6][33] = int_stack + 144867;
 Libderiv->deriv2_classes[4][7][33] = int_stack + 145287;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 145827;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 146268;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 146856;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 147612;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 148200;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 148984;
 Libderiv->deriv2_classes[4][5][32] = int_stack + 149992;
 Libderiv->deriv2_classes[4][6][32] = int_stack + 150307;
 Libderiv->deriv2_classes[4][7][32] = int_stack + 150727;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 151267;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 151708;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 152296;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 153052;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 153640;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 154424;
 Libderiv->deriv2_classes[4][5][31] = int_stack + 155432;
 Libderiv->deriv2_classes[4][6][31] = int_stack + 155747;
 Libderiv->deriv2_classes[4][7][31] = int_stack + 156167;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 156707;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 157148;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 157736;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 158492;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 159080;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 159864;
 Libderiv->deriv2_classes[4][5][30] = int_stack + 160872;
 Libderiv->deriv2_classes[4][6][30] = int_stack + 161187;
 Libderiv->deriv2_classes[4][7][30] = int_stack + 161607;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 162147;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 162588;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 163176;
 Libderiv->deriv_classes[6][5][2] = int_stack + 163932;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 164520;
 Libderiv->deriv_classes[6][6][2] = int_stack + 165108;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 165892;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 166676;
 Libderiv->deriv2_classes[4][5][26] = int_stack + 167684;
 Libderiv->deriv2_classes[4][6][26] = int_stack + 167999;
 Libderiv->deriv2_classes[4][7][26] = int_stack + 168419;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 168959;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 169400;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 169988;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 170744;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 171332;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 172116;
 Libderiv->deriv2_classes[4][5][23] = int_stack + 173124;
 Libderiv->deriv2_classes[4][6][23] = int_stack + 173439;
 Libderiv->deriv2_classes[4][7][23] = int_stack + 173859;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 174399;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 174840;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 175428;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 176184;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 176772;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 177556;
 Libderiv->deriv2_classes[4][5][22] = int_stack + 178564;
 Libderiv->deriv2_classes[4][6][22] = int_stack + 178879;
 Libderiv->deriv2_classes[4][7][22] = int_stack + 179299;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 179839;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 180280;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 180868;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 181624;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 182212;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 182996;
 Libderiv->deriv2_classes[4][5][21] = int_stack + 184004;
 Libderiv->deriv2_classes[4][6][21] = int_stack + 184319;
 Libderiv->deriv2_classes[4][7][21] = int_stack + 184739;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 185279;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 185720;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 186308;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 187064;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 187652;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 188436;
 Libderiv->deriv2_classes[4][5][20] = int_stack + 189444;
 Libderiv->deriv2_classes[4][6][20] = int_stack + 189759;
 Libderiv->deriv2_classes[4][7][20] = int_stack + 190179;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 190719;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 191160;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 191748;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 192504;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 193092;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 193876;
 Libderiv->deriv2_classes[4][5][19] = int_stack + 194884;
 Libderiv->deriv2_classes[4][6][19] = int_stack + 195199;
 Libderiv->deriv2_classes[4][7][19] = int_stack + 195619;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 196159;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 196600;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 197188;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 197944;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 198532;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 199316;
 Libderiv->deriv2_classes[4][5][18] = int_stack + 200324;
 Libderiv->deriv2_classes[4][6][18] = int_stack + 200639;
 Libderiv->deriv2_classes[4][7][18] = int_stack + 201059;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 201599;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 202040;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 202628;
 Libderiv->deriv_classes[6][5][1] = int_stack + 203384;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 203972;
 Libderiv->deriv_classes[6][6][1] = int_stack + 204560;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 205344;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 206128;
 Libderiv->deriv2_classes[4][5][14] = int_stack + 207136;
 Libderiv->deriv2_classes[4][6][14] = int_stack + 207451;
 Libderiv->deriv2_classes[4][7][14] = int_stack + 207871;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 208411;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 208852;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 209440;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 210196;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 210784;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 211568;
 Libderiv->deriv2_classes[4][5][13] = int_stack + 212576;
 Libderiv->deriv2_classes[4][6][13] = int_stack + 212891;
 Libderiv->deriv2_classes[4][7][13] = int_stack + 213311;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 213851;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 214292;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 214880;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 215636;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 216224;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 217008;
 Libderiv->deriv_classes[4][5][11] = int_stack + 218016;
 Libderiv->deriv_classes[4][6][11] = int_stack + 218331;
 Libderiv->deriv_classes[4][7][11] = int_stack + 218751;
 Libderiv->deriv2_classes[4][5][11] = int_stack + 219291;
 Libderiv->deriv2_classes[4][6][11] = int_stack + 219606;
 Libderiv->deriv2_classes[4][7][11] = int_stack + 220026;
 Libderiv->deriv_classes[5][5][11] = int_stack + 220566;
 Libderiv->deriv_classes[5][6][11] = int_stack + 221007;
 Libderiv->deriv_classes[5][7][11] = int_stack + 221595;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 222351;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 222792;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 223380;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 224136;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 224724;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 225508;
 Libderiv->deriv_classes[4][5][10] = int_stack + 226516;
 Libderiv->deriv_classes[4][6][10] = int_stack + 226831;
 Libderiv->deriv_classes[4][7][10] = int_stack + 227251;
 Libderiv->deriv2_classes[4][5][10] = int_stack + 227791;
 Libderiv->deriv2_classes[4][6][10] = int_stack + 228106;
 Libderiv->deriv2_classes[4][7][10] = int_stack + 228526;
 Libderiv->deriv_classes[5][5][10] = int_stack + 229066;
 Libderiv->deriv_classes[5][6][10] = int_stack + 229507;
 Libderiv->deriv_classes[5][7][10] = int_stack + 230095;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 230851;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 231292;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 231880;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 232636;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 233224;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 234008;
 Libderiv->deriv_classes[4][5][9] = int_stack + 235016;
 Libderiv->deriv_classes[4][6][9] = int_stack + 235331;
 Libderiv->deriv_classes[4][7][9] = int_stack + 235751;
 Libderiv->deriv2_classes[4][5][9] = int_stack + 236291;
 Libderiv->deriv2_classes[4][6][9] = int_stack + 236606;
 Libderiv->deriv2_classes[4][7][9] = int_stack + 237026;
 Libderiv->deriv_classes[5][5][9] = int_stack + 237566;
 Libderiv->deriv_classes[5][6][9] = int_stack + 238007;
 Libderiv->deriv_classes[5][7][9] = int_stack + 238595;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 239351;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 239792;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 240380;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 241136;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 241724;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 242508;
 Libderiv->deriv_classes[4][5][8] = int_stack + 243516;
 Libderiv->deriv_classes[4][6][8] = int_stack + 243831;
 Libderiv->deriv_classes[4][7][8] = int_stack + 244251;
 Libderiv->deriv2_classes[4][5][8] = int_stack + 244791;
 Libderiv->deriv2_classes[4][6][8] = int_stack + 245106;
 Libderiv->deriv2_classes[4][7][8] = int_stack + 245526;
 Libderiv->deriv_classes[5][5][8] = int_stack + 246066;
 Libderiv->deriv_classes[5][6][8] = int_stack + 246507;
 Libderiv->deriv_classes[5][7][8] = int_stack + 247095;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 247851;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 248292;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 248880;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 249636;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 250224;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 251008;
 Libderiv->deriv_classes[4][5][7] = int_stack + 252016;
 Libderiv->deriv_classes[4][6][7] = int_stack + 252331;
 Libderiv->deriv_classes[4][7][7] = int_stack + 252751;
 Libderiv->deriv2_classes[4][5][7] = int_stack + 253291;
 Libderiv->deriv2_classes[4][6][7] = int_stack + 253606;
 Libderiv->deriv2_classes[4][7][7] = int_stack + 254026;
 Libderiv->deriv_classes[5][5][7] = int_stack + 254566;
 Libderiv->deriv_classes[5][6][7] = int_stack + 255007;
 Libderiv->deriv_classes[5][7][7] = int_stack + 255595;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 256351;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 256792;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 257380;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 258136;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 258724;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 259508;
 Libderiv->deriv_classes[4][5][6] = int_stack + 260516;
 Libderiv->deriv_classes[4][6][6] = int_stack + 260831;
 Libderiv->deriv_classes[4][7][6] = int_stack + 261251;
 Libderiv->deriv2_classes[4][5][6] = int_stack + 261791;
 Libderiv->deriv2_classes[4][6][6] = int_stack + 262106;
 Libderiv->deriv2_classes[4][7][6] = int_stack + 262526;
 Libderiv->dvrr_classes[5][5] = int_stack + 263066;
 Libderiv->deriv_classes[5][5][6] = int_stack + 263507;
 Libderiv->dvrr_classes[5][6] = int_stack + 263948;
 Libderiv->deriv_classes[5][6][6] = int_stack + 264536;
 Libderiv->deriv_classes[5][7][6] = int_stack + 265124;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 265880;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 266321;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 266909;
 Libderiv->deriv_classes[6][5][0] = int_stack + 267665;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 268253;
 Libderiv->deriv_classes[6][6][0] = int_stack + 268841;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 269625;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 270409;
 Libderiv->deriv_classes[4][5][2] = int_stack + 271417;
 Libderiv->deriv_classes[4][6][2] = int_stack + 271732;
 Libderiv->deriv_classes[4][7][2] = int_stack + 272152;
 Libderiv->deriv2_classes[4][5][2] = int_stack + 272692;
 Libderiv->deriv2_classes[4][6][2] = int_stack + 273007;
 Libderiv->deriv2_classes[4][7][2] = int_stack + 273427;
 Libderiv->deriv_classes[5][5][2] = int_stack + 273967;
 Libderiv->deriv_classes[5][6][2] = int_stack + 274408;
 Libderiv->deriv_classes[5][7][2] = int_stack + 274996;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 275752;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 276193;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 276781;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 277537;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 278125;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 278909;
 Libderiv->deriv_classes[4][5][1] = int_stack + 279917;
 Libderiv->deriv_classes[4][6][1] = int_stack + 280232;
 Libderiv->deriv_classes[4][7][1] = int_stack + 280652;
 Libderiv->deriv2_classes[4][5][1] = int_stack + 281192;
 Libderiv->deriv2_classes[4][6][1] = int_stack + 281507;
 Libderiv->deriv2_classes[4][7][1] = int_stack + 281927;
 Libderiv->deriv_classes[5][5][1] = int_stack + 282467;
 Libderiv->deriv_classes[5][6][1] = int_stack + 282908;
 Libderiv->deriv_classes[5][7][1] = int_stack + 283496;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 284252;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 284693;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 285281;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 286037;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 286625;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 287409;
 Libderiv->dvrr_classes[4][5] = int_stack + 288417;
 Libderiv->dvrr_classes[4][6] = int_stack + 288732;
 Libderiv->dvrr_classes[4][7] = int_stack + 289152;
 Libderiv->deriv_classes[4][5][0] = int_stack + 289692;
 Libderiv->deriv_classes[4][6][0] = int_stack + 290007;
 Libderiv->deriv_classes[4][7][0] = int_stack + 290427;
 Libderiv->deriv2_classes[4][5][0] = int_stack + 290967;
 Libderiv->deriv2_classes[4][6][0] = int_stack + 291282;
 Libderiv->deriv2_classes[4][7][0] = int_stack + 291702;
 Libderiv->deriv_classes[5][5][0] = int_stack + 292242;
 Libderiv->deriv_classes[5][6][0] = int_stack + 292683;
 Libderiv->deriv_classes[5][7][0] = int_stack + 293271;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 294027;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 294468;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 295056;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 295812;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 296400;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 297184;
 memset(int_stack,0,2385536);

 Libderiv->dvrr_stack = int_stack + 847216;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_gdhd(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+298192,int_stack+288732,int_stack+288417,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+299137,int_stack+218331,int_stack+218016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288417,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+218751,int_stack+218331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288732,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+301342,int_stack+300082,int_stack+299137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298192,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+303232,int_stack+263948,int_stack+263066,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+221007,int_stack+220566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263066,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+305878,int_stack+221595,int_stack+221007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263948,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+307642,int_stack+305878,int_stack+304555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303232,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+310288,int_stack+307642,int_stack+301342,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+305878,int_stack+5040,int_stack+129332,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315958,int_stack+96448,int_stack+95272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129332,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+317722,int_stack+0,int_stack+96448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+320074,int_stack+317722,int_stack+315958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305878,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+323602,int_stack+320074,int_stack+307642,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+317722,int_stack+226831,int_stack+226516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288417, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+227251,int_stack+226831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288732, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+318667,int_stack+300082,int_stack+317722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298192, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+320557,int_stack+229507,int_stack+229066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263066, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+331540,int_stack+230095,int_stack+229507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263948, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+333304,int_stack+331540,int_stack+320557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303232, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+335950,int_stack+333304,int_stack+318667,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+331540,int_stack+103260,int_stack+102084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129332, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+341620,int_stack+1008,int_stack+103260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+343972,int_stack+341620,int_stack+331540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305878, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+347500,int_stack+343972,int_stack+333304,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341620,int_stack+235331,int_stack+235016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288417, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+235751,int_stack+235331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288732, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+342565,int_stack+300082,int_stack+341620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298192, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+344455,int_stack+238007,int_stack+237566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263066, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+238595,int_stack+238007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263948, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+355438,int_stack+0,int_stack+344455, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303232, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+358084,int_stack+355438,int_stack+342565,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+110072,int_stack+108896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129332, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+363754,int_stack+2016,int_stack+110072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+366106,int_stack+363754,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305878, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+369634,int_stack+366106,int_stack+355438,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+363754,int_stack+243831,int_stack+243516, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+244251,int_stack+243831, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+288732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+364699,int_stack+1764,int_stack+363754, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+366589,int_stack+246507,int_stack+246066, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377572,int_stack+247095,int_stack+246507, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+379336,int_stack+377572,int_stack+366589, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+381982,int_stack+379336,int_stack+364699,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+377572,int_stack+116884,int_stack+115708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+387652,int_stack+3024,int_stack+116884, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+390004,int_stack+387652,int_stack+377572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+393532,int_stack+390004,int_stack+379336,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+387652,int_stack+252331,int_stack+252016, 0.0, zero_stack, 1.0, int_stack+288417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+252751,int_stack+252331, 0.0, zero_stack, 1.0, int_stack+288732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+388597,int_stack+300082,int_stack+387652, 0.0, zero_stack, 1.0, int_stack+298192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+390487,int_stack+255007,int_stack+254566, 0.0, zero_stack, 1.0, int_stack+263066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+255595,int_stack+255007, 0.0, zero_stack, 1.0, int_stack+263948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+401470,int_stack+1764,int_stack+390487, 0.0, zero_stack, 1.0, int_stack+303232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+404116,int_stack+401470,int_stack+388597,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1764,int_stack+123696,int_stack+122520, 0.0, zero_stack, 1.0, int_stack+129332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+409786,int_stack+4032,int_stack+123696, 0.0, zero_stack, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+412138,int_stack+409786,int_stack+1764, 0.0, zero_stack, 1.0, int_stack+305878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+415666,int_stack+412138,int_stack+401470,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+260831,int_stack+260516, 1.0, int_stack+288417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+261251,int_stack+260831, 1.0, int_stack+288732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+410731,int_stack+300082,int_stack+409786, 1.0, int_stack+298192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+412621,int_stack+264536,int_stack+263507, 1.0, int_stack+263066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+265124,int_stack+264536, 1.0, int_stack+263948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+425368,int_stack+423604,int_stack+412621, 1.0, int_stack+303232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+428014,int_stack+425368,int_stack+410731,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+131096,int_stack+129920, 1.0, int_stack+129332, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+433684,int_stack+5824,int_stack+131096, 1.0, int_stack+5040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+436036,int_stack+433684,int_stack+423604, 1.0, int_stack+305878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+439564,int_stack+436036,int_stack+425368,126);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+289152,int_stack+288732,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+433684,int_stack+300082,int_stack+298192,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+305878,int_stack+8848,int_stack+263948,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+435574,int_stack+305878,int_stack+303232,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+447502,int_stack+435574,int_stack+433684,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+298192,int_stack+271732,int_stack+271417,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+272152,int_stack+271732,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+3528,int_stack+300082,int_stack+298192,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+303232,int_stack+274408,int_stack+273967,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+305878,int_stack+274996,int_stack+274408,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+453172,int_stack+305878,int_stack+303232,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+455818,int_stack+453172,int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+305878,int_stack+165108,int_stack+163932,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+461488,int_stack+6832,int_stack+165108,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+463840,int_stack+461488,int_stack+305878,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+467368,int_stack+463840,int_stack+453172, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+435574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+461488,int_stack+280232,int_stack+279917,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+280652,int_stack+280232,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+462433,int_stack+300082,int_stack+461488,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+464323,int_stack+282908,int_stack+282467,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5418,int_stack+283496,int_stack+282908,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+475306,int_stack+5418,int_stack+464323,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+477952,int_stack+475306,int_stack+462433, 0.0, zero_stack, 1.0, int_stack+433684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+204560,int_stack+203384,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+483622,int_stack+7840,int_stack+204560,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+485974,int_stack+483622,int_stack+5418,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+489502,int_stack+485974,int_stack+475306, 0.0, zero_stack, 1.0, int_stack+435574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+483622,int_stack+290007,int_stack+289692,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+290427,int_stack+290007,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+484567,int_stack+300082,int_stack+483622,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+486457,int_stack+292683,int_stack+292242,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+293271,int_stack+292683,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+497440,int_stack+7182,int_stack+486457,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+500086,int_stack+497440,int_stack+484567, 1.0, int_stack+433684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+433684,int_stack+268841,int_stack+267665,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+9604,int_stack+268841,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+7182,int_stack+433684,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+509284,int_stack+505756,int_stack+497440, 1.0, int_stack+435574, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+10927,int_stack+10612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+218016,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+11347,int_stack+10927, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+218331,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+506701,int_stack+300082,int_stack+505756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+299137,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+12328,int_stack+11887, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+220566,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+12916,int_stack+12328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+221007,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+304555,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+517222,int_stack+10269,int_stack+506701,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+14260,int_stack+13672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+95272,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+15044,int_stack+14260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+96448,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+315958,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+522892,int_stack+435448,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435448,int_stack+16367,int_stack+16052, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218016, 1.0, int_stack+226516,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+16787,int_stack+16367, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218331, 1.0, int_stack+226831,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+436393,int_stack+300082,int_stack+435448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299137, 1.0, int_stack+317722,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+17768,int_stack+17327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220566, 1.0, int_stack+229066,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+18356,int_stack+17768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221007, 1.0, int_stack+229507,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304555, 1.0, int_stack+320557,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+12915,int_stack+10269,int_stack+436393,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+19700,int_stack+19112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95272, 1.0, int_stack+102084,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+20484,int_stack+19700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96448, 1.0, int_stack+103260,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315958, 1.0, int_stack+331540,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+530830,int_stack+505756,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+21807,int_stack+21492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+226516, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+22227,int_stack+21807, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+226831, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+506701,int_stack+300082,int_stack+505756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+317722, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+23208,int_stack+22767, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+229066, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+23796,int_stack+23208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+229507, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+320557, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+18585,int_stack+10269,int_stack+506701,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+25140,int_stack+24552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+102084, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+25924,int_stack+25140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+103260, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+331540, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+538768,int_stack+435448,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435448,int_stack+27247,int_stack+26932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218016, 0.0, zero_stack, 1.0, int_stack+235016,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+27667,int_stack+27247, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218331, 0.0, zero_stack, 1.0, int_stack+235331,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+436393,int_stack+300082,int_stack+435448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299137, 0.0, zero_stack, 1.0, int_stack+341620,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+28648,int_stack+28207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220566, 0.0, zero_stack, 1.0, int_stack+237566,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+29236,int_stack+28648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221007, 0.0, zero_stack, 1.0, int_stack+238007,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304555, 0.0, zero_stack, 1.0, int_stack+344455,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+24255,int_stack+10269,int_stack+436393,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+30580,int_stack+29992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95272, 0.0, zero_stack, 1.0, int_stack+108896,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+31364,int_stack+30580, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96448, 0.0, zero_stack, 1.0, int_stack+110072,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315958, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+546706,int_stack+505756,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+32687,int_stack+32372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226516, 1.0, int_stack+235016, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+33107,int_stack+32687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226831, 1.0, int_stack+235331, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+506701,int_stack+300082,int_stack+505756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317722, 1.0, int_stack+341620, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+34088,int_stack+33647, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229066, 1.0, int_stack+237566, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+34676,int_stack+34088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229507, 1.0, int_stack+238007, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+320557, 1.0, int_stack+344455, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+554644,int_stack+10269,int_stack+506701,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+36020,int_stack+35432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102084, 1.0, int_stack+108896, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+36804,int_stack+36020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103260, 1.0, int_stack+110072, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331540, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+560314,int_stack+435448,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435448,int_stack+38127,int_stack+37812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+235016, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+38547,int_stack+38127, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+235331, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+436393,int_stack+300082,int_stack+435448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+341620, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+39528,int_stack+39087, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+237566, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+40116,int_stack+39528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+238007, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+344455, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+29925,int_stack+10269,int_stack+436393,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+41460,int_stack+40872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+108896, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+42244,int_stack+41460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+110072, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+568252,int_stack+505756,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+43567,int_stack+43252, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243516,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+43987,int_stack+43567, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218331, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+243831,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+506701,int_stack+300082,int_stack+505756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+299137, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363754,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+44968,int_stack+44527, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+220566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246066,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+45556,int_stack+44968, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221007, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+246507,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+304555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+366589,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+35595,int_stack+10269,int_stack+506701,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+46900,int_stack+46312, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+95272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+115708,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+47684,int_stack+46900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+96448, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+116884,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+377572,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+576190,int_stack+435448,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435448,int_stack+49007,int_stack+48692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226516, 0.0, zero_stack, 1.0, int_stack+243516, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+49427,int_stack+49007, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226831, 0.0, zero_stack, 1.0, int_stack+243831, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+436393,int_stack+300082,int_stack+435448, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+317722, 0.0, zero_stack, 1.0, int_stack+363754, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+50408,int_stack+49967, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229066, 0.0, zero_stack, 1.0, int_stack+246066, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+50996,int_stack+50408, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229507, 0.0, zero_stack, 1.0, int_stack+246507, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+320557, 0.0, zero_stack, 1.0, int_stack+366589, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+41265,int_stack+10269,int_stack+436393,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+52340,int_stack+51752, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+102084, 0.0, zero_stack, 1.0, int_stack+115708, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+53124,int_stack+52340, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+103260, 0.0, zero_stack, 1.0, int_stack+116884, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331540, 0.0, zero_stack, 1.0, int_stack+377572, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+584128,int_stack+505756,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+54447,int_stack+54132, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235016, 1.0, int_stack+243516, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+54867,int_stack+54447, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235331, 1.0, int_stack+243831, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+506701,int_stack+300082,int_stack+505756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+341620, 1.0, int_stack+363754, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+55848,int_stack+55407, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+237566, 1.0, int_stack+246066, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+56436,int_stack+55848, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+238007, 1.0, int_stack+246507, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+344455, 1.0, int_stack+366589, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+46935,int_stack+10269,int_stack+506701,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+57780,int_stack+57192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+108896, 1.0, int_stack+115708, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+58564,int_stack+57780, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+110072, 1.0, int_stack+116884, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+377572, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+592066,int_stack+435448,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435448,int_stack+59887,int_stack+59572, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+243516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+60307,int_stack+59887, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+243831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+436393,int_stack+300082,int_stack+435448, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+363754, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+61288,int_stack+60847, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+246066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+61876,int_stack+61288, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+246507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+366589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+52605,int_stack+10269,int_stack+436393,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+63220,int_stack+62632, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+115708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+64004,int_stack+63220, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+116884, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+7182, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+377572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+600004,int_stack+505756,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+65327,int_stack+65012, 0.0, zero_stack, 1.0, int_stack+218016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252016,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+65747,int_stack+65327, 0.0, zero_stack, 1.0, int_stack+218331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252331,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+506701,int_stack+300082,int_stack+505756, 0.0, zero_stack, 1.0, int_stack+299137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387652,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+66728,int_stack+66287, 0.0, zero_stack, 1.0, int_stack+220566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254566,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+67316,int_stack+66728, 0.0, zero_stack, 1.0, int_stack+221007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255007,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+304555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390487,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+58275,int_stack+10269,int_stack+506701,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+68660,int_stack+68072, 0.0, zero_stack, 1.0, int_stack+95272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122520,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+69444,int_stack+68660, 0.0, zero_stack, 1.0, int_stack+96448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123696,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+315958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+607942,int_stack+435448,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435448,int_stack+70767,int_stack+70452, 0.0, zero_stack, 1.0, int_stack+226516, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252016, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+71187,int_stack+70767, 0.0, zero_stack, 1.0, int_stack+226831, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252331, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+436393,int_stack+300082,int_stack+435448, 0.0, zero_stack, 1.0, int_stack+317722, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387652, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+72168,int_stack+71727, 0.0, zero_stack, 1.0, int_stack+229066, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254566, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+72756,int_stack+72168, 0.0, zero_stack, 1.0, int_stack+229507, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255007, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+320557, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390487, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+63945,int_stack+10269,int_stack+436393,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+74100,int_stack+73512, 0.0, zero_stack, 1.0, int_stack+102084, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+122520, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+74884,int_stack+74100, 0.0, zero_stack, 1.0, int_stack+103260, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+123696, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+331540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+615880,int_stack+505756,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+76207,int_stack+75892, 0.0, zero_stack, 1.0, int_stack+235016, 0.0, zero_stack, 1.0, int_stack+252016, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+76627,int_stack+76207, 0.0, zero_stack, 1.0, int_stack+235331, 0.0, zero_stack, 1.0, int_stack+252331, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+506701,int_stack+300082,int_stack+505756, 0.0, zero_stack, 1.0, int_stack+341620, 0.0, zero_stack, 1.0, int_stack+387652, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+77608,int_stack+77167, 0.0, zero_stack, 1.0, int_stack+237566, 0.0, zero_stack, 1.0, int_stack+254566, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+78196,int_stack+77608, 0.0, zero_stack, 1.0, int_stack+238007, 0.0, zero_stack, 1.0, int_stack+255007, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+344455, 0.0, zero_stack, 1.0, int_stack+390487, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+69615,int_stack+10269,int_stack+506701,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+79540,int_stack+78952, 0.0, zero_stack, 1.0, int_stack+108896, 0.0, zero_stack, 1.0, int_stack+122520, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+80324,int_stack+79540, 0.0, zero_stack, 1.0, int_stack+110072, 0.0, zero_stack, 1.0, int_stack+123696, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+623818,int_stack+435448,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435448,int_stack+81647,int_stack+81332, 0.0, zero_stack, 1.0, int_stack+243516, 1.0, int_stack+252016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+82067,int_stack+81647, 0.0, zero_stack, 1.0, int_stack+243831, 1.0, int_stack+252331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+436393,int_stack+300082,int_stack+435448, 0.0, zero_stack, 1.0, int_stack+363754, 1.0, int_stack+387652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+83048,int_stack+82607, 0.0, zero_stack, 1.0, int_stack+246066, 1.0, int_stack+254566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+83636,int_stack+83048, 0.0, zero_stack, 1.0, int_stack+246507, 1.0, int_stack+255007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+366589, 1.0, int_stack+390487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+75285,int_stack+10269,int_stack+436393,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+84980,int_stack+84392, 0.0, zero_stack, 1.0, int_stack+115708, 1.0, int_stack+122520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+85764,int_stack+84980, 0.0, zero_stack, 1.0, int_stack+116884, 1.0, int_stack+123696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+7182, 0.0, zero_stack, 1.0, int_stack+377572, 1.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+631756,int_stack+505756,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+87087,int_stack+86772, 0.0, zero_stack, 2.0, int_stack+252016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+87507,int_stack+87087, 0.0, zero_stack, 2.0, int_stack+252331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+506701,int_stack+300082,int_stack+505756, 0.0, zero_stack, 2.0, int_stack+387652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+88488,int_stack+88047, 0.0, zero_stack, 2.0, int_stack+254566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8505,int_stack+89076,int_stack+88488, 0.0, zero_stack, 2.0, int_stack+255007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+10269,int_stack+8505,int_stack+7182, 0.0, zero_stack, 2.0, int_stack+390487, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+80955,int_stack+10269,int_stack+506701,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+90420,int_stack+89832, 0.0, zero_stack, 2.0, int_stack+122520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+91204,int_stack+90420, 0.0, zero_stack, 2.0, int_stack+123696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+7182, 0.0, zero_stack, 2.0, int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+639694,int_stack+435448,int_stack+10269,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435448,int_stack+92527,int_stack+92212, 1.0, int_stack+218016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260516,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+300082,int_stack+92947,int_stack+92527, 1.0, int_stack+218331, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260831,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+436393,int_stack+300082,int_stack+435448, 1.0, int_stack+299137, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409786,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+299137,int_stack+93928,int_stack+93487, 1.0, int_stack+220566, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263507,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+7182,int_stack+94516,int_stack+93928, 1.0, int_stack+221007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264536,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+8946,int_stack+7182,int_stack+299137, 1.0, int_stack+304555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412621,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+86625,int_stack+8946,int_stack+436393,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+97232,int_stack+95860, 1.0, int_stack+95272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129920,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+98016,int_stack+97232, 1.0, int_stack+96448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131096,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+7182, 1.0, int_stack+315958, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423604,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+647632,int_stack+505756,int_stack+8946,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+99339,int_stack+99024, 1.0, int_stack+226516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260516, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+506701,int_stack+99759,int_stack+99339, 1.0, int_stack+226831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260831, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+7182,int_stack+506701,int_stack+505756, 1.0, int_stack+317722, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409786, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+100740,int_stack+100299, 1.0, int_stack+229066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263507, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+101328,int_stack+100740, 1.0, int_stack+229507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264536, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+505756,int_stack+304555, 1.0, int_stack+320557, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412621, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+92295,int_stack+315958,int_stack+7182,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+7182,int_stack+104044,int_stack+102672, 1.0, int_stack+102084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129920, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+8946,int_stack+104828,int_stack+104044, 1.0, int_stack+103260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131096, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+8946,int_stack+7182, 1.0, int_stack+331540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423604, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+655570,int_stack+505756,int_stack+315958,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+315958,int_stack+106151,int_stack+105836, 1.0, int_stack+235016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260516, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+316903,int_stack+106571,int_stack+106151, 1.0, int_stack+235331, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260831, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+316903,int_stack+315958, 1.0, int_stack+341620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+409786, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+107552,int_stack+107111, 1.0, int_stack+237566, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263507, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+331540,int_stack+108140,int_stack+107552, 1.0, int_stack+238007, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264536, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+331540,int_stack+304555, 1.0, int_stack+344455, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412621, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+7182,int_stack+315958,int_stack+505756,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+331540,int_stack+110856,int_stack+109484, 1.0, int_stack+108896, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+129920, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+111640,int_stack+110856, 1.0, int_stack+110072, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+131096, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+331540, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+423604, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+97965,int_stack+435448,int_stack+315958,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+341620,int_stack+112963,int_stack+112648, 1.0, int_stack+243516, 0.0, zero_stack, 1.0, int_stack+260516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315958,int_stack+113383,int_stack+112963, 1.0, int_stack+243831, 0.0, zero_stack, 1.0, int_stack+260831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+315958,int_stack+341620, 1.0, int_stack+363754, 0.0, zero_stack, 1.0, int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+114364,int_stack+113923, 1.0, int_stack+246066, 0.0, zero_stack, 1.0, int_stack+263507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+114952,int_stack+114364, 1.0, int_stack+246507, 0.0, zero_stack, 1.0, int_stack+264536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+0,int_stack+304555, 1.0, int_stack+366589, 0.0, zero_stack, 1.0, int_stack+412621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+105903,int_stack+315958,int_stack+435448,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+117668,int_stack+116296, 1.0, int_stack+115708, 0.0, zero_stack, 1.0, int_stack+129920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+118452,int_stack+117668, 1.0, int_stack+116884, 0.0, zero_stack, 1.0, int_stack+131096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+0, 1.0, int_stack+377572, 0.0, zero_stack, 1.0, int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+663508,int_stack+505756,int_stack+315958,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+363754,int_stack+119775,int_stack+119460, 1.0, int_stack+252016, 1.0, int_stack+260516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315958,int_stack+120195,int_stack+119775, 1.0, int_stack+252331, 1.0, int_stack+260831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+315958,int_stack+363754, 1.0, int_stack+387652, 1.0, int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+121176,int_stack+120735, 1.0, int_stack+254566, 1.0, int_stack+263507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377572,int_stack+121764,int_stack+121176, 1.0, int_stack+255007, 1.0, int_stack+264536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+377572,int_stack+304555, 1.0, int_stack+390487, 1.0, int_stack+412621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+111573,int_stack+315958,int_stack+505756,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+377572,int_stack+124480,int_stack+123108, 1.0, int_stack+122520, 1.0, int_stack+129920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+125264,int_stack+124480, 1.0, int_stack+123696, 1.0, int_stack+131096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+505756,int_stack+377572, 1.0, int_stack+1764, 1.0, int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+117243,int_stack+435448,int_stack+315958,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+387652,int_stack+126587,int_stack+126272, 2.0, int_stack+260516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315958,int_stack+127007,int_stack+126587, 2.0, int_stack+260831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+315958,int_stack+387652, 2.0, int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+127988,int_stack+127547, 2.0, int_stack+263507, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377572,int_stack+128576,int_stack+127988, 2.0, int_stack+264536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+377572,int_stack+304555, 2.0, int_stack+412621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+671446,int_stack+315958,int_stack+435448,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+377572,int_stack+131880,int_stack+130508, 2.0, int_stack+129920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+132664,int_stack+131880, 2.0, int_stack+131096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+377572, 2.0, int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+125181,int_stack+505756,int_stack+315958,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+133987,int_stack+133672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271417,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315958,int_stack+134407,int_stack+133987, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271732,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+315958,int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298192,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+135388,int_stack+134947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273967,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+135976,int_stack+135388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274408,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+423604,int_stack+304555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303232,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+677116,int_stack+315958,int_stack+505756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+137320,int_stack+136732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163932,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+138104,int_stack+137320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165108,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+505756,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305878,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+682786,int_stack+0,int_stack+315958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+307642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+139427,int_stack+139112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271417, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315958,int_stack+139847,int_stack+139427, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271732, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+315958,int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298192, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+140828,int_stack+140387, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273967, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+141416,int_stack+140828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274408, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+423604,int_stack+304555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303232, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+133119,int_stack+315958,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+142760,int_stack+142172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163932, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+143544,int_stack+142760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165108, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+0,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305878, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+690724,int_stack+505756,int_stack+315958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+333304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+144867,int_stack+144552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271417, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315958,int_stack+145287,int_stack+144867, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271732, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+315958,int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298192, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+146268,int_stack+145827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273967, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+146856,int_stack+146268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274408, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+423604,int_stack+304555, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303232, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+138789,int_stack+315958,int_stack+505756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+148200,int_stack+147612, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163932, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+148984,int_stack+148200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165108, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+505756,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305878, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+698662,int_stack+0,int_stack+315958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+355438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+150307,int_stack+149992, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315958,int_stack+150727,int_stack+150307, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+271732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+315958,int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+151708,int_stack+151267, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+273967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+152296,int_stack+151708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+423604,int_stack+304555, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+303232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+144459,int_stack+315958,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+364699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+153640,int_stack+153052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+163932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+154424,int_stack+153640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+165108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+0,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+706600,int_stack+505756,int_stack+315958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+379336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+155747,int_stack+155432, 0.0, zero_stack, 1.0, int_stack+271417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315958,int_stack+156167,int_stack+155747, 0.0, zero_stack, 1.0, int_stack+271732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+315958,int_stack+409786, 0.0, zero_stack, 1.0, int_stack+298192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+157148,int_stack+156707, 0.0, zero_stack, 1.0, int_stack+273967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+157736,int_stack+157148, 0.0, zero_stack, 1.0, int_stack+274408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+315958,int_stack+423604,int_stack+304555, 0.0, zero_stack, 1.0, int_stack+303232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+150129,int_stack+315958,int_stack+505756, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+388597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+159080,int_stack+158492, 0.0, zero_stack, 1.0, int_stack+163932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+159864,int_stack+159080, 0.0, zero_stack, 1.0, int_stack+165108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+505756,int_stack+423604, 0.0, zero_stack, 1.0, int_stack+305878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+714538,int_stack+0,int_stack+315958, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+401470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+161187,int_stack+160872, 1.0, int_stack+271417, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+315958,int_stack+161607,int_stack+161187, 1.0, int_stack+271732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+315958,int_stack+409786, 1.0, int_stack+298192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+304555,int_stack+162588,int_stack+162147, 1.0, int_stack+273967, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+163176,int_stack+162588, 1.0, int_stack+274408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+298192,int_stack+423604,int_stack+304555, 1.0, int_stack+303232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+155799,int_stack+298192,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+410731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+165892,int_stack+164520, 1.0, int_stack+163932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+166676,int_stack+165892, 1.0, int_stack+165108, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+0,int_stack+423604, 1.0, int_stack+305878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+722476,int_stack+505756,int_stack+298192, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+425368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+167999,int_stack+167684,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+298192,int_stack+168419,int_stack+167999,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+299452,int_stack+298192,int_stack+409786,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+169400,int_stack+168959,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+169988,int_stack+169400,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+423604,int_stack+505756,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+161469,int_stack+0,int_stack+299452, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+3528, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+171332,int_stack+170744,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+172116,int_stack+171332,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+303232,int_stack+505756,int_stack+423604,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+730414,int_stack+303232,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+453172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+173439,int_stack+173124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279917,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+173859,int_stack+173439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280232,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1260,int_stack+0,int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461488,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+303232,int_stack+174840,int_stack+174399, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282467,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+175428,int_stack+174840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282908,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+304555,int_stack+423604,int_stack+303232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464323,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+167139,int_stack+304555,int_stack+1260, 0.0, zero_stack, 1.0, int_stack+301342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+176772,int_stack+176184, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203384,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+177556,int_stack+176772, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204560,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+0,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5418,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+738352,int_stack+505756,int_stack+304555, 0.0, zero_stack, 1.0, int_stack+307642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+178879,int_stack+178564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279917, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+179299,int_stack+178879, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280232, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+507016,int_stack+505756,int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461488, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+180280,int_stack+179839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282467, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377572,int_stack+180868,int_stack+180280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282908, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+377572,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464323, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+172809,int_stack+0,int_stack+507016, 0.0, zero_stack, 1.0, int_stack+318667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+182212,int_stack+181624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203384, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+182996,int_stack+182212, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204560, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+303232,int_stack+505756,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5418, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+746290,int_stack+303232,int_stack+0, 0.0, zero_stack, 1.0, int_stack+333304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+184319,int_stack+184004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279917, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+184739,int_stack+184319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280232, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1260,int_stack+0,int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461488, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+303232,int_stack+185720,int_stack+185279, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282467, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+186308,int_stack+185720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282908, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+304555,int_stack+423604,int_stack+303232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464323, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+178479,int_stack+304555,int_stack+1260, 0.0, zero_stack, 1.0, int_stack+342565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+187652,int_stack+187064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203384, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+188436,int_stack+187652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204560, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+0,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5418, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+754228,int_stack+505756,int_stack+304555, 0.0, zero_stack, 1.0, int_stack+355438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+189759,int_stack+189444, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+190179,int_stack+189759, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+280232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+507016,int_stack+505756,int_stack+409786, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+461488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+191160,int_stack+190719, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377572,int_stack+191748,int_stack+191160, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+377572,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+184149,int_stack+0,int_stack+507016, 0.0, zero_stack, 1.0, int_stack+364699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+193092,int_stack+192504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+193876,int_stack+193092, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+303232,int_stack+505756,int_stack+423604, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+5418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+762166,int_stack+303232,int_stack+0, 0.0, zero_stack, 1.0, int_stack+379336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+195199,int_stack+194884, 0.0, zero_stack, 1.0, int_stack+279917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+195619,int_stack+195199, 0.0, zero_stack, 1.0, int_stack+280232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1260,int_stack+0,int_stack+409786, 0.0, zero_stack, 1.0, int_stack+461488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+303232,int_stack+196600,int_stack+196159, 0.0, zero_stack, 1.0, int_stack+282467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+197188,int_stack+196600, 0.0, zero_stack, 1.0, int_stack+282908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+304555,int_stack+423604,int_stack+303232, 0.0, zero_stack, 1.0, int_stack+464323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+189819,int_stack+304555,int_stack+1260, 0.0, zero_stack, 1.0, int_stack+388597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+198532,int_stack+197944, 0.0, zero_stack, 1.0, int_stack+203384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+199316,int_stack+198532, 0.0, zero_stack, 1.0, int_stack+204560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+0,int_stack+423604, 0.0, zero_stack, 1.0, int_stack+5418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+770104,int_stack+505756,int_stack+304555, 0.0, zero_stack, 1.0, int_stack+401470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+409786,int_stack+200639,int_stack+200324, 1.0, int_stack+279917, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+201059,int_stack+200639, 1.0, int_stack+280232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+507016,int_stack+505756,int_stack+409786, 1.0, int_stack+461488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+202040,int_stack+201599, 1.0, int_stack+282467, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+377572,int_stack+202628,int_stack+202040, 1.0, int_stack+282908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+377572,int_stack+423604, 1.0, int_stack+464323, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+195489,int_stack+0,int_stack+507016, 0.0, zero_stack, 1.0, int_stack+410731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+423604,int_stack+205344,int_stack+203972, 1.0, int_stack+203384, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+464323,int_stack+206128,int_stack+205344, 1.0, int_stack+204560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+464323,int_stack+423604, 1.0, int_stack+5418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+778042,int_stack+505756,int_stack+0, 0.0, zero_stack, 1.0, int_stack+425368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+461488,int_stack+207451,int_stack+207136,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+207871,int_stack+207451,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1260,int_stack+0,int_stack+461488,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+505756,int_stack+208852,int_stack+208411,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5418,int_stack+209440,int_stack+208852,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+464323,int_stack+5418,int_stack+505756,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+201159,int_stack+464323,int_stack+1260, 0.0, zero_stack, 1.0, int_stack+3528, 1.0, int_stack+462433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+210784,int_stack+210196,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+211568,int_stack+210784,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+505756,int_stack+5418,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+785980,int_stack+0,int_stack+464323, 0.0, zero_stack, 1.0, int_stack+453172, 1.0, int_stack+475306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+461488,int_stack+212891,int_stack+212576,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+464323,int_stack+213311,int_stack+212891,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+464323,int_stack+461488,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+464323,int_stack+214292,int_stack+213851,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5418,int_stack+214880,int_stack+214292,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+5418,int_stack+464323,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+206829,int_stack+505756,int_stack+0, 0.0, zero_stack, 2.0, int_stack+462433, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+216224,int_stack+215636,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+217008,int_stack+216224,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+303232,int_stack+0,int_stack+5418,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+793918,int_stack+303232,int_stack+505756, 0.0, zero_stack, 2.0, int_stack+475306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+461488,int_stack+219606,int_stack+219291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289692,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+220026,int_stack+219606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290007,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+507016,int_stack+505756,int_stack+461488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483622,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+303232,int_stack+222792,int_stack+222351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292242,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5418,int_stack+223380,int_stack+222792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292683,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+304555,int_stack+5418,int_stack+303232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486457,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+212499,int_stack+304555,int_stack+507016, 1.0, int_stack+301342, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+224724,int_stack+224136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267665,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+225508,int_stack+224724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268841,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+505756,int_stack+5418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433684,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+218169,int_stack+0,int_stack+304555, 1.0, int_stack+307642, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+461488,int_stack+228106,int_stack+227791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289692, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+228526,int_stack+228106, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290007, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1260,int_stack+0,int_stack+461488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483622, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+231292,int_stack+230851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292242, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+423604,int_stack+231880,int_stack+231292, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292683, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+423604,int_stack+5418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486457, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+298192,int_stack+505756,int_stack+1260, 1.0, int_stack+318667, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+233224,int_stack+232636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267665, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+234008,int_stack+233224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268841, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+303862,int_stack+0,int_stack+5418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433684, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+226107,int_stack+303862,int_stack+505756, 1.0, int_stack+333304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+461488,int_stack+236606,int_stack+236291, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289692, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+237026,int_stack+236606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290007, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+507016,int_stack+505756,int_stack+461488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483622, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+303862,int_stack+239792,int_stack+239351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292242, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5418,int_stack+240380,int_stack+239792, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292683, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+305185,int_stack+5418,int_stack+303862, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486457, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+315958,int_stack+305185,int_stack+507016, 1.0, int_stack+342565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+241724,int_stack+241136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267665, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+242508,int_stack+241724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268841, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+505756,int_stack+5418, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433684, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+234045,int_stack+0,int_stack+305185, 1.0, int_stack+355438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+461488,int_stack+245106,int_stack+244791, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+289692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+355438,int_stack+245526,int_stack+245106, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+290007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+355438,int_stack+461488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+483622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+355438,int_stack+248292,int_stack+247851, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5418,int_stack+248880,int_stack+248292, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+292683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+5418,int_stack+355438, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+303862,int_stack+505756,int_stack+0, 1.0, int_stack+364699, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+250224,int_stack+249636, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+251008,int_stack+250224, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+268841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+435448,int_stack+0,int_stack+5418, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+433684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+241983,int_stack+435448,int_stack+505756, 1.0, int_stack+379336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+461488,int_stack+253606,int_stack+253291, 0.0, zero_stack, 1.0, int_stack+289692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+254026,int_stack+253606, 0.0, zero_stack, 1.0, int_stack+290007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+507016,int_stack+505756,int_stack+461488, 0.0, zero_stack, 1.0, int_stack+483622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+435448,int_stack+256792,int_stack+256351, 0.0, zero_stack, 1.0, int_stack+292242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5418,int_stack+257380,int_stack+256792, 0.0, zero_stack, 1.0, int_stack+292683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+355438,int_stack+5418,int_stack+435448, 0.0, zero_stack, 1.0, int_stack+486457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+363754,int_stack+355438,int_stack+507016, 1.0, int_stack+388597, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+258724,int_stack+258136, 0.0, zero_stack, 1.0, int_stack+267665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435448,int_stack+259508,int_stack+258724, 0.0, zero_stack, 1.0, int_stack+268841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+435448,int_stack+5418, 0.0, zero_stack, 1.0, int_stack+433684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+249921,int_stack+505756,int_stack+355438, 1.0, int_stack+401470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+461488,int_stack+262106,int_stack+261791, 1.0, int_stack+289692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+401470,int_stack+262526,int_stack+262106, 1.0, int_stack+290007, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+355438,int_stack+401470,int_stack+461488, 1.0, int_stack+483622, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+401470,int_stack+266321,int_stack+265880, 1.0, int_stack+292242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+5418,int_stack+266909,int_stack+266321, 1.0, int_stack+292683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+5418,int_stack+401470, 1.0, int_stack+486457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+387652,int_stack+505756,int_stack+355438, 1.0, int_stack+410731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+5418,int_stack+269625,int_stack+268253, 1.0, int_stack+267665, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+355438,int_stack+270409,int_stack+269625, 1.0, int_stack+268841, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+355438,int_stack+5418, 1.0, int_stack+433684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+257859,int_stack+0,int_stack+505756, 1.0, int_stack+425368, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+483622,int_stack+273007,int_stack+272692,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+273427,int_stack+273007,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+507016,int_stack+505756,int_stack+483622,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+276193,int_stack+275752,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+5418,int_stack+276781,int_stack+276193,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+355438,int_stack+5418,int_stack+0,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+433684,int_stack+355438,int_stack+507016, 1.0, int_stack+3528, 0.0, zero_stack, 1.0, int_stack+484567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+278125,int_stack+277537,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+278909,int_stack+278125,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+1764,int_stack+0,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+265797,int_stack+505756,int_stack+355438, 1.0, int_stack+453172, 0.0, zero_stack, 1.0, int_stack+497440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+483622,int_stack+281507,int_stack+281192,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+453172,int_stack+281927,int_stack+281507,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+355438,int_stack+453172,int_stack+483622,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+453172,int_stack+284693,int_stack+284252,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+285281,int_stack+284693,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+401470,int_stack+505756,int_stack+453172,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+0,int_stack+401470,int_stack+355438, 1.0, int_stack+462433, 1.0, int_stack+484567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+355438,int_stack+286625,int_stack+286037,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+453172,int_stack+287409,int_stack+286625,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+453172,int_stack+355438,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+273735,int_stack+505756,int_stack+401470, 1.0, int_stack+475306, 1.0, int_stack+497440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+483622,int_stack+291282,int_stack+290967,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+475306,int_stack+291702,int_stack+291282,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+401470,int_stack+475306,int_stack+483622,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+475306,int_stack+294468,int_stack+294027,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+505756,int_stack+295056,int_stack+294468,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+355438,int_stack+505756,int_stack+475306,21);
 /*--- compute (gp|hd) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+461488,int_stack+355438,int_stack+401470, 2.0, int_stack+484567, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+401470,int_stack+296400,int_stack+295812,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+475306,int_stack+297184,int_stack+296400,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+505756,int_stack+475306,int_stack+401470,28);
 /*--- compute (hp|hd) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+281673,int_stack+505756,int_stack+355438, 2.0, int_stack+497440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+801856,int_stack+323602,int_stack+310288,126);
     Libderiv->ABCD[11] = int_stack + 801856;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+321628,int_stack+347500,int_stack+335950,126);
     Libderiv->ABCD[10] = int_stack + 321628;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+341620,int_stack+369634,int_stack+358084,126);
     Libderiv->ABCD[9] = int_stack + 341620;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+369424,int_stack+393532,int_stack+381982,126);
     Libderiv->ABCD[8] = int_stack + 369424;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+813196,int_stack+415666,int_stack+404116,126);
     Libderiv->ABCD[7] = int_stack + 813196;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+409786,int_stack+439564,int_stack+428014,126);
     Libderiv->ABCD[6] = int_stack + 409786;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+824536,int_stack+467368,int_stack+455818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[2] = int_stack + 824536;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+835876,int_stack+489502,int_stack+477952, 0.0, zero_stack, 1.0, int_stack+447502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[1] = int_stack + 835876;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+483622,int_stack+509284,int_stack+500086, 1.0, int_stack+447502, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[0] = int_stack + 483622;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+505756,int_stack+522892,int_stack+517222,126);
     Libderiv->ABCD[155] = int_stack + 505756;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+517096,int_stack+530830,int_stack+12915,126);
     Libderiv->ABCD[143] = int_stack + 517096;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+439354,int_stack+538768,int_stack+18585,126);
     Libderiv->ABCD[142] = int_stack + 439354;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+528436,int_stack+546706,int_stack+24255,126);
     Libderiv->ABCD[131] = int_stack + 528436;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+539776,int_stack+560314,int_stack+554644,126);
     Libderiv->ABCD[130] = int_stack + 539776;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+551116,int_stack+568252,int_stack+29925,126);
     Libderiv->ABCD[129] = int_stack + 551116;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+562456,int_stack+576190,int_stack+35595,126);
     Libderiv->ABCD[119] = int_stack + 562456;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+12852,int_stack+584128,int_stack+41265,126);
     Libderiv->ABCD[118] = int_stack + 12852;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+573796,int_stack+592066,int_stack+46935,126);
     Libderiv->ABCD[117] = int_stack + 573796;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+585136,int_stack+600004,int_stack+52605,126);
     Libderiv->ABCD[116] = int_stack + 585136;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+596476,int_stack+607942,int_stack+58275,126);
     Libderiv->ABCD[107] = int_stack + 596476;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+24192,int_stack+615880,int_stack+63945,126);
     Libderiv->ABCD[106] = int_stack + 24192;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+607816,int_stack+623818,int_stack+69615,126);
     Libderiv->ABCD[105] = int_stack + 607816;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+619156,int_stack+631756,int_stack+75285,126);
     Libderiv->ABCD[104] = int_stack + 619156;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+35532,int_stack+639694,int_stack+80955,126);
     Libderiv->ABCD[103] = int_stack + 35532;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+630496,int_stack+647632,int_stack+86625,126);
     Libderiv->ABCD[95] = int_stack + 630496;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+641836,int_stack+655570,int_stack+92295,126);
     Libderiv->ABCD[94] = int_stack + 641836;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+46872,int_stack+97965,int_stack+7182,126);
     Libderiv->ABCD[93] = int_stack + 46872;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+58212,int_stack+663508,int_stack+105903,126);
     Libderiv->ABCD[92] = int_stack + 58212;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+653176,int_stack+117243,int_stack+111573,126);
     Libderiv->ABCD[91] = int_stack + 653176;
 /*--- compute (gd|hd) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+69552,int_stack+125181,int_stack+671446,126);
     Libderiv->ABCD[90] = int_stack + 69552;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+664516,int_stack+682786,int_stack+677116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[47] = int_stack + 664516;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+675856,int_stack+690724,int_stack+133119, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+335950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[46] = int_stack + 675856;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+687196,int_stack+698662,int_stack+138789, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+358084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[45] = int_stack + 687196;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+80892,int_stack+706600,int_stack+144459, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+381982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[44] = int_stack + 80892;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+698536,int_stack+714538,int_stack+150129, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+404116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[43] = int_stack + 698536;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+709876,int_stack+722476,int_stack+155799, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+428014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[42] = int_stack + 709876;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+92232,int_stack+730414,int_stack+161469, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+455818, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[38] = int_stack + 92232;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+721216,int_stack+738352,int_stack+167139, 0.0, zero_stack, 1.0, int_stack+310288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[35] = int_stack + 721216;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+732556,int_stack+746290,int_stack+172809, 0.0, zero_stack, 1.0, int_stack+335950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[34] = int_stack + 732556;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+103572,int_stack+754228,int_stack+178479, 0.0, zero_stack, 1.0, int_stack+358084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[33] = int_stack + 103572;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+743896,int_stack+762166,int_stack+184149, 0.0, zero_stack, 1.0, int_stack+381982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[32] = int_stack + 743896;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+755236,int_stack+770104,int_stack+189819, 0.0, zero_stack, 1.0, int_stack+404116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[31] = int_stack + 755236;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+766576,int_stack+778042,int_stack+195489, 0.0, zero_stack, 1.0, int_stack+428014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[30] = int_stack + 766576;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+114912,int_stack+785980,int_stack+201159, 0.0, zero_stack, 1.0, int_stack+455818, 1.0, int_stack+477952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[26] = int_stack + 114912;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+777916,int_stack+793918,int_stack+206829, 0.0, zero_stack, 2.0, int_stack+477952, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[25] = int_stack + 777916;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+789256,int_stack+218169,int_stack+212499, 1.0, int_stack+310288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[23] = int_stack + 789256;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+126252,int_stack+226107,int_stack+298192, 1.0, int_stack+335950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[22] = int_stack + 126252;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+137592,int_stack+234045,int_stack+315958, 1.0, int_stack+358084, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[21] = int_stack + 137592;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+309532,int_stack+241983,int_stack+303862, 1.0, int_stack+381982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[20] = int_stack + 309532;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+148932,int_stack+249921,int_stack+363754, 1.0, int_stack+404116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[19] = int_stack + 148932;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+393322,int_stack+257859,int_stack+387652, 1.0, int_stack+428014, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[18] = int_stack + 393322;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+421126,int_stack+265797,int_stack+433684, 1.0, int_stack+455818, 0.0, zero_stack, 1.0, int_stack+500086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[14] = int_stack + 421126;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+380764,int_stack+273735,int_stack+0, 1.0, int_stack+477952, 1.0, int_stack+500086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[13] = int_stack + 380764;
 /*--- compute (gd|hd) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+0,int_stack+281673,int_stack+461488, 2.0, int_stack+500086, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,126);
     Libderiv->ABCD[12] = int_stack + 0;

}
