/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d12vrr_order_hdhf(Libderiv_t *, prim_data *);

  /* Computes derivatives of (hd|hf) integrals */

void d12hrr_order_hdhf(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[7][8][11] = int_stack + 0;
 Libderiv->deriv_classes[7][8][10] = int_stack + 1620;
 Libderiv->deriv_classes[7][8][9] = int_stack + 3240;
 Libderiv->deriv_classes[7][8][8] = int_stack + 4860;
 Libderiv->deriv_classes[7][8][7] = int_stack + 6480;
 Libderiv->dvrr_classes[7][7] = int_stack + 8100;
 Libderiv->deriv_classes[7][8][6] = int_stack + 9396;
 Libderiv->deriv_classes[7][8][2] = int_stack + 11016;
 Libderiv->deriv_classes[7][8][1] = int_stack + 12636;
 Libderiv->dvrr_classes[6][8] = int_stack + 14256;
 Libderiv->deriv_classes[7][8][0] = int_stack + 15516;
 Libderiv->deriv2_classes[5][5][143] = int_stack + 17136;
 Libderiv->deriv2_classes[5][6][143] = int_stack + 17577;
 Libderiv->deriv2_classes[5][7][143] = int_stack + 18165;
 Libderiv->deriv2_classes[5][8][143] = int_stack + 18921;
 Libderiv->deriv2_classes[6][5][143] = int_stack + 19866;
 Libderiv->deriv2_classes[6][6][143] = int_stack + 20454;
 Libderiv->deriv2_classes[6][7][143] = int_stack + 21238;
 Libderiv->deriv2_classes[6][8][143] = int_stack + 22246;
 Libderiv->deriv2_classes[7][5][143] = int_stack + 23506;
 Libderiv->deriv2_classes[7][6][143] = int_stack + 24262;
 Libderiv->deriv2_classes[7][7][143] = int_stack + 25270;
 Libderiv->deriv2_classes[7][8][143] = int_stack + 26566;
 Libderiv->deriv2_classes[5][5][131] = int_stack + 28186;
 Libderiv->deriv2_classes[5][6][131] = int_stack + 28627;
 Libderiv->deriv2_classes[5][7][131] = int_stack + 29215;
 Libderiv->deriv2_classes[5][8][131] = int_stack + 29971;
 Libderiv->deriv2_classes[6][5][131] = int_stack + 30916;
 Libderiv->deriv2_classes[6][6][131] = int_stack + 31504;
 Libderiv->deriv2_classes[6][7][131] = int_stack + 32288;
 Libderiv->deriv2_classes[6][8][131] = int_stack + 33296;
 Libderiv->deriv2_classes[7][5][131] = int_stack + 34556;
 Libderiv->deriv2_classes[7][6][131] = int_stack + 35312;
 Libderiv->deriv2_classes[7][7][131] = int_stack + 36320;
 Libderiv->deriv2_classes[7][8][131] = int_stack + 37616;
 Libderiv->deriv2_classes[5][5][130] = int_stack + 39236;
 Libderiv->deriv2_classes[5][6][130] = int_stack + 39677;
 Libderiv->deriv2_classes[5][7][130] = int_stack + 40265;
 Libderiv->deriv2_classes[5][8][130] = int_stack + 41021;
 Libderiv->deriv2_classes[6][5][130] = int_stack + 41966;
 Libderiv->deriv2_classes[6][6][130] = int_stack + 42554;
 Libderiv->deriv2_classes[6][7][130] = int_stack + 43338;
 Libderiv->deriv2_classes[6][8][130] = int_stack + 44346;
 Libderiv->deriv2_classes[7][5][130] = int_stack + 45606;
 Libderiv->deriv2_classes[7][6][130] = int_stack + 46362;
 Libderiv->deriv2_classes[7][7][130] = int_stack + 47370;
 Libderiv->deriv2_classes[7][8][130] = int_stack + 48666;
 Libderiv->deriv2_classes[5][5][119] = int_stack + 50286;
 Libderiv->deriv2_classes[5][6][119] = int_stack + 50727;
 Libderiv->deriv2_classes[5][7][119] = int_stack + 51315;
 Libderiv->deriv2_classes[5][8][119] = int_stack + 52071;
 Libderiv->deriv2_classes[6][5][119] = int_stack + 53016;
 Libderiv->deriv2_classes[6][6][119] = int_stack + 53604;
 Libderiv->deriv2_classes[6][7][119] = int_stack + 54388;
 Libderiv->deriv2_classes[6][8][119] = int_stack + 55396;
 Libderiv->deriv2_classes[7][5][119] = int_stack + 56656;
 Libderiv->deriv2_classes[7][6][119] = int_stack + 57412;
 Libderiv->deriv2_classes[7][7][119] = int_stack + 58420;
 Libderiv->deriv2_classes[7][8][119] = int_stack + 59716;
 Libderiv->deriv2_classes[5][5][118] = int_stack + 61336;
 Libderiv->deriv2_classes[5][6][118] = int_stack + 61777;
 Libderiv->deriv2_classes[5][7][118] = int_stack + 62365;
 Libderiv->deriv2_classes[5][8][118] = int_stack + 63121;
 Libderiv->deriv2_classes[6][5][118] = int_stack + 64066;
 Libderiv->deriv2_classes[6][6][118] = int_stack + 64654;
 Libderiv->deriv2_classes[6][7][118] = int_stack + 65438;
 Libderiv->deriv2_classes[6][8][118] = int_stack + 66446;
 Libderiv->deriv2_classes[7][5][118] = int_stack + 67706;
 Libderiv->deriv2_classes[7][6][118] = int_stack + 68462;
 Libderiv->deriv2_classes[7][7][118] = int_stack + 69470;
 Libderiv->deriv2_classes[7][8][118] = int_stack + 70766;
 Libderiv->deriv2_classes[5][5][117] = int_stack + 72386;
 Libderiv->deriv2_classes[5][6][117] = int_stack + 72827;
 Libderiv->deriv2_classes[5][7][117] = int_stack + 73415;
 Libderiv->deriv2_classes[5][8][117] = int_stack + 74171;
 Libderiv->deriv2_classes[6][5][117] = int_stack + 75116;
 Libderiv->deriv2_classes[6][6][117] = int_stack + 75704;
 Libderiv->deriv2_classes[6][7][117] = int_stack + 76488;
 Libderiv->deriv2_classes[6][8][117] = int_stack + 77496;
 Libderiv->deriv2_classes[7][5][117] = int_stack + 78756;
 Libderiv->deriv2_classes[7][6][117] = int_stack + 79512;
 Libderiv->deriv2_classes[7][7][117] = int_stack + 80520;
 Libderiv->deriv2_classes[7][8][117] = int_stack + 81816;
 Libderiv->deriv2_classes[5][5][107] = int_stack + 83436;
 Libderiv->deriv2_classes[5][6][107] = int_stack + 83877;
 Libderiv->deriv2_classes[5][7][107] = int_stack + 84465;
 Libderiv->deriv2_classes[5][8][107] = int_stack + 85221;
 Libderiv->deriv2_classes[6][5][107] = int_stack + 86166;
 Libderiv->deriv2_classes[6][6][107] = int_stack + 86754;
 Libderiv->deriv2_classes[6][7][107] = int_stack + 87538;
 Libderiv->deriv2_classes[6][8][107] = int_stack + 88546;
 Libderiv->deriv2_classes[7][5][107] = int_stack + 89806;
 Libderiv->deriv2_classes[7][6][107] = int_stack + 90562;
 Libderiv->deriv2_classes[7][7][107] = int_stack + 91570;
 Libderiv->deriv2_classes[7][8][107] = int_stack + 92866;
 Libderiv->deriv2_classes[5][5][106] = int_stack + 94486;
 Libderiv->deriv2_classes[5][6][106] = int_stack + 94927;
 Libderiv->deriv2_classes[5][7][106] = int_stack + 95515;
 Libderiv->deriv2_classes[5][8][106] = int_stack + 96271;
 Libderiv->deriv2_classes[6][5][106] = int_stack + 97216;
 Libderiv->deriv2_classes[6][6][106] = int_stack + 97804;
 Libderiv->deriv2_classes[6][7][106] = int_stack + 98588;
 Libderiv->deriv2_classes[6][8][106] = int_stack + 99596;
 Libderiv->deriv2_classes[7][5][106] = int_stack + 100856;
 Libderiv->deriv2_classes[7][6][106] = int_stack + 101612;
 Libderiv->deriv2_classes[7][7][106] = int_stack + 102620;
 Libderiv->deriv2_classes[7][8][106] = int_stack + 103916;
 Libderiv->deriv2_classes[5][5][105] = int_stack + 105536;
 Libderiv->deriv2_classes[5][6][105] = int_stack + 105977;
 Libderiv->deriv2_classes[5][7][105] = int_stack + 106565;
 Libderiv->deriv2_classes[5][8][105] = int_stack + 107321;
 Libderiv->deriv2_classes[6][5][105] = int_stack + 108266;
 Libderiv->deriv2_classes[6][6][105] = int_stack + 108854;
 Libderiv->deriv2_classes[6][7][105] = int_stack + 109638;
 Libderiv->deriv2_classes[6][8][105] = int_stack + 110646;
 Libderiv->deriv2_classes[7][5][105] = int_stack + 111906;
 Libderiv->deriv2_classes[7][6][105] = int_stack + 112662;
 Libderiv->deriv2_classes[7][7][105] = int_stack + 113670;
 Libderiv->deriv2_classes[7][8][105] = int_stack + 114966;
 Libderiv->deriv2_classes[5][5][104] = int_stack + 116586;
 Libderiv->deriv2_classes[5][6][104] = int_stack + 117027;
 Libderiv->deriv2_classes[5][7][104] = int_stack + 117615;
 Libderiv->deriv2_classes[5][8][104] = int_stack + 118371;
 Libderiv->deriv2_classes[6][5][104] = int_stack + 119316;
 Libderiv->deriv2_classes[6][6][104] = int_stack + 119904;
 Libderiv->deriv2_classes[6][7][104] = int_stack + 120688;
 Libderiv->deriv2_classes[6][8][104] = int_stack + 121696;
 Libderiv->deriv2_classes[7][5][104] = int_stack + 122956;
 Libderiv->deriv2_classes[7][6][104] = int_stack + 123712;
 Libderiv->deriv2_classes[7][7][104] = int_stack + 124720;
 Libderiv->deriv2_classes[7][8][104] = int_stack + 126016;
 Libderiv->deriv2_classes[5][5][95] = int_stack + 127636;
 Libderiv->deriv2_classes[5][6][95] = int_stack + 128077;
 Libderiv->deriv2_classes[5][7][95] = int_stack + 128665;
 Libderiv->deriv2_classes[5][8][95] = int_stack + 129421;
 Libderiv->deriv2_classes[6][5][95] = int_stack + 130366;
 Libderiv->deriv2_classes[6][6][95] = int_stack + 130954;
 Libderiv->deriv2_classes[6][7][95] = int_stack + 131738;
 Libderiv->deriv2_classes[6][8][95] = int_stack + 132746;
 Libderiv->deriv2_classes[7][5][95] = int_stack + 134006;
 Libderiv->deriv2_classes[7][6][95] = int_stack + 134762;
 Libderiv->deriv2_classes[7][7][95] = int_stack + 135770;
 Libderiv->deriv2_classes[7][8][95] = int_stack + 137066;
 Libderiv->deriv2_classes[5][5][94] = int_stack + 138686;
 Libderiv->deriv2_classes[5][6][94] = int_stack + 139127;
 Libderiv->deriv2_classes[5][7][94] = int_stack + 139715;
 Libderiv->deriv2_classes[5][8][94] = int_stack + 140471;
 Libderiv->deriv2_classes[6][5][94] = int_stack + 141416;
 Libderiv->deriv2_classes[6][6][94] = int_stack + 142004;
 Libderiv->deriv2_classes[6][7][94] = int_stack + 142788;
 Libderiv->deriv2_classes[6][8][94] = int_stack + 143796;
 Libderiv->deriv2_classes[7][5][94] = int_stack + 145056;
 Libderiv->deriv2_classes[7][6][94] = int_stack + 145812;
 Libderiv->deriv2_classes[7][7][94] = int_stack + 146820;
 Libderiv->deriv2_classes[7][8][94] = int_stack + 148116;
 Libderiv->deriv2_classes[5][5][93] = int_stack + 149736;
 Libderiv->deriv2_classes[5][6][93] = int_stack + 150177;
 Libderiv->deriv2_classes[5][7][93] = int_stack + 150765;
 Libderiv->deriv2_classes[5][8][93] = int_stack + 151521;
 Libderiv->deriv2_classes[6][5][93] = int_stack + 152466;
 Libderiv->deriv2_classes[6][6][93] = int_stack + 153054;
 Libderiv->deriv2_classes[6][7][93] = int_stack + 153838;
 Libderiv->deriv2_classes[6][8][93] = int_stack + 154846;
 Libderiv->deriv2_classes[7][5][93] = int_stack + 156106;
 Libderiv->deriv2_classes[7][6][93] = int_stack + 156862;
 Libderiv->deriv2_classes[7][7][93] = int_stack + 157870;
 Libderiv->deriv2_classes[7][8][93] = int_stack + 159166;
 Libderiv->deriv2_classes[5][5][92] = int_stack + 160786;
 Libderiv->deriv2_classes[5][6][92] = int_stack + 161227;
 Libderiv->deriv2_classes[5][7][92] = int_stack + 161815;
 Libderiv->deriv2_classes[5][8][92] = int_stack + 162571;
 Libderiv->deriv2_classes[6][5][92] = int_stack + 163516;
 Libderiv->deriv2_classes[6][6][92] = int_stack + 164104;
 Libderiv->deriv2_classes[6][7][92] = int_stack + 164888;
 Libderiv->deriv2_classes[6][8][92] = int_stack + 165896;
 Libderiv->deriv2_classes[7][5][92] = int_stack + 167156;
 Libderiv->deriv2_classes[7][6][92] = int_stack + 167912;
 Libderiv->deriv2_classes[7][7][92] = int_stack + 168920;
 Libderiv->deriv2_classes[7][8][92] = int_stack + 170216;
 Libderiv->deriv2_classes[5][5][91] = int_stack + 171836;
 Libderiv->deriv2_classes[5][6][91] = int_stack + 172277;
 Libderiv->deriv2_classes[5][7][91] = int_stack + 172865;
 Libderiv->deriv2_classes[5][8][91] = int_stack + 173621;
 Libderiv->deriv2_classes[6][5][91] = int_stack + 174566;
 Libderiv->deriv2_classes[6][6][91] = int_stack + 175154;
 Libderiv->deriv2_classes[6][7][91] = int_stack + 175938;
 Libderiv->deriv2_classes[6][8][91] = int_stack + 176946;
 Libderiv->deriv2_classes[7][5][91] = int_stack + 178206;
 Libderiv->deriv2_classes[7][6][91] = int_stack + 178962;
 Libderiv->deriv2_classes[7][7][91] = int_stack + 179970;
 Libderiv->deriv2_classes[7][8][91] = int_stack + 181266;
 Libderiv->deriv2_classes[5][5][83] = int_stack + 182886;
 Libderiv->deriv2_classes[5][6][83] = int_stack + 183327;
 Libderiv->deriv2_classes[5][7][83] = int_stack + 183915;
 Libderiv->deriv2_classes[5][8][83] = int_stack + 184671;
 Libderiv->deriv2_classes[6][5][83] = int_stack + 185616;
 Libderiv->deriv2_classes[6][6][83] = int_stack + 186204;
 Libderiv->deriv2_classes[6][7][83] = int_stack + 186988;
 Libderiv->deriv2_classes[6][8][83] = int_stack + 187996;
 Libderiv->deriv_classes[7][5][11] = int_stack + 189256;
 Libderiv->deriv2_classes[7][5][83] = int_stack + 190012;
 Libderiv->deriv_classes[7][6][11] = int_stack + 190768;
 Libderiv->deriv2_classes[7][6][83] = int_stack + 191776;
 Libderiv->deriv_classes[7][7][11] = int_stack + 192784;
 Libderiv->deriv2_classes[7][7][83] = int_stack + 194080;
 Libderiv->deriv2_classes[7][8][83] = int_stack + 195376;
 Libderiv->deriv2_classes[5][5][82] = int_stack + 196996;
 Libderiv->deriv2_classes[5][6][82] = int_stack + 197437;
 Libderiv->deriv2_classes[5][7][82] = int_stack + 198025;
 Libderiv->deriv2_classes[5][8][82] = int_stack + 198781;
 Libderiv->deriv2_classes[6][5][82] = int_stack + 199726;
 Libderiv->deriv2_classes[6][6][82] = int_stack + 200314;
 Libderiv->deriv2_classes[6][7][82] = int_stack + 201098;
 Libderiv->deriv2_classes[6][8][82] = int_stack + 202106;
 Libderiv->deriv_classes[7][5][10] = int_stack + 203366;
 Libderiv->deriv2_classes[7][5][82] = int_stack + 204122;
 Libderiv->deriv_classes[7][6][10] = int_stack + 204878;
 Libderiv->deriv2_classes[7][6][82] = int_stack + 205886;
 Libderiv->deriv_classes[7][7][10] = int_stack + 206894;
 Libderiv->deriv2_classes[7][7][82] = int_stack + 208190;
 Libderiv->deriv2_classes[7][8][82] = int_stack + 209486;
 Libderiv->deriv2_classes[5][5][81] = int_stack + 211106;
 Libderiv->deriv2_classes[5][6][81] = int_stack + 211547;
 Libderiv->deriv2_classes[5][7][81] = int_stack + 212135;
 Libderiv->deriv2_classes[5][8][81] = int_stack + 212891;
 Libderiv->deriv2_classes[6][5][81] = int_stack + 213836;
 Libderiv->deriv2_classes[6][6][81] = int_stack + 214424;
 Libderiv->deriv2_classes[6][7][81] = int_stack + 215208;
 Libderiv->deriv2_classes[6][8][81] = int_stack + 216216;
 Libderiv->deriv_classes[7][5][9] = int_stack + 217476;
 Libderiv->deriv2_classes[7][5][81] = int_stack + 218232;
 Libderiv->deriv_classes[7][6][9] = int_stack + 218988;
 Libderiv->deriv2_classes[7][6][81] = int_stack + 219996;
 Libderiv->deriv_classes[7][7][9] = int_stack + 221004;
 Libderiv->deriv2_classes[7][7][81] = int_stack + 222300;
 Libderiv->deriv2_classes[7][8][81] = int_stack + 223596;
 Libderiv->deriv2_classes[5][5][80] = int_stack + 225216;
 Libderiv->deriv2_classes[5][6][80] = int_stack + 225657;
 Libderiv->deriv2_classes[5][7][80] = int_stack + 226245;
 Libderiv->deriv2_classes[5][8][80] = int_stack + 227001;
 Libderiv->deriv2_classes[6][5][80] = int_stack + 227946;
 Libderiv->deriv2_classes[6][6][80] = int_stack + 228534;
 Libderiv->deriv2_classes[6][7][80] = int_stack + 229318;
 Libderiv->deriv2_classes[6][8][80] = int_stack + 230326;
 Libderiv->deriv_classes[7][5][8] = int_stack + 231586;
 Libderiv->deriv2_classes[7][5][80] = int_stack + 232342;
 Libderiv->deriv_classes[7][6][8] = int_stack + 233098;
 Libderiv->deriv2_classes[7][6][80] = int_stack + 234106;
 Libderiv->deriv_classes[7][7][8] = int_stack + 235114;
 Libderiv->deriv2_classes[7][7][80] = int_stack + 236410;
 Libderiv->deriv2_classes[7][8][80] = int_stack + 237706;
 Libderiv->deriv2_classes[5][5][79] = int_stack + 239326;
 Libderiv->deriv2_classes[5][6][79] = int_stack + 239767;
 Libderiv->deriv2_classes[5][7][79] = int_stack + 240355;
 Libderiv->deriv2_classes[5][8][79] = int_stack + 241111;
 Libderiv->deriv2_classes[6][5][79] = int_stack + 242056;
 Libderiv->deriv2_classes[6][6][79] = int_stack + 242644;
 Libderiv->deriv2_classes[6][7][79] = int_stack + 243428;
 Libderiv->deriv2_classes[6][8][79] = int_stack + 244436;
 Libderiv->deriv_classes[7][5][7] = int_stack + 245696;
 Libderiv->deriv2_classes[7][5][79] = int_stack + 246452;
 Libderiv->deriv_classes[7][6][7] = int_stack + 247208;
 Libderiv->deriv2_classes[7][6][79] = int_stack + 248216;
 Libderiv->deriv_classes[7][7][7] = int_stack + 249224;
 Libderiv->deriv2_classes[7][7][79] = int_stack + 250520;
 Libderiv->deriv2_classes[7][8][79] = int_stack + 251816;
 Libderiv->deriv2_classes[5][5][78] = int_stack + 253436;
 Libderiv->deriv2_classes[5][6][78] = int_stack + 253877;
 Libderiv->deriv2_classes[5][7][78] = int_stack + 254465;
 Libderiv->deriv2_classes[5][8][78] = int_stack + 255221;
 Libderiv->deriv2_classes[6][5][78] = int_stack + 256166;
 Libderiv->deriv2_classes[6][6][78] = int_stack + 256754;
 Libderiv->deriv2_classes[6][7][78] = int_stack + 257538;
 Libderiv->deriv2_classes[6][8][78] = int_stack + 258546;
 Libderiv->dvrr_classes[7][5] = int_stack + 259806;
 Libderiv->deriv_classes[7][5][6] = int_stack + 260562;
 Libderiv->deriv2_classes[7][5][78] = int_stack + 261318;
 Libderiv->dvrr_classes[7][6] = int_stack + 262074;
 Libderiv->deriv_classes[7][6][6] = int_stack + 263082;
 Libderiv->deriv2_classes[7][6][78] = int_stack + 264090;
 Libderiv->deriv_classes[7][7][6] = int_stack + 265098;
 Libderiv->deriv2_classes[7][7][78] = int_stack + 266394;
 Libderiv->deriv2_classes[7][8][78] = int_stack + 267690;
 Libderiv->deriv2_classes[5][5][35] = int_stack + 269310;
 Libderiv->deriv2_classes[5][6][35] = int_stack + 269751;
 Libderiv->deriv2_classes[5][7][35] = int_stack + 270339;
 Libderiv->deriv2_classes[5][8][35] = int_stack + 271095;
 Libderiv->deriv2_classes[6][5][35] = int_stack + 272040;
 Libderiv->deriv2_classes[6][6][35] = int_stack + 272628;
 Libderiv->deriv2_classes[6][7][35] = int_stack + 273412;
 Libderiv->deriv2_classes[6][8][35] = int_stack + 274420;
 Libderiv->deriv2_classes[7][5][35] = int_stack + 275680;
 Libderiv->deriv2_classes[7][6][35] = int_stack + 276436;
 Libderiv->deriv2_classes[7][7][35] = int_stack + 277444;
 Libderiv->deriv2_classes[7][8][35] = int_stack + 278740;
 Libderiv->deriv2_classes[5][5][34] = int_stack + 280360;
 Libderiv->deriv2_classes[5][6][34] = int_stack + 280801;
 Libderiv->deriv2_classes[5][7][34] = int_stack + 281389;
 Libderiv->deriv2_classes[5][8][34] = int_stack + 282145;
 Libderiv->deriv2_classes[6][5][34] = int_stack + 283090;
 Libderiv->deriv2_classes[6][6][34] = int_stack + 283678;
 Libderiv->deriv2_classes[6][7][34] = int_stack + 284462;
 Libderiv->deriv2_classes[6][8][34] = int_stack + 285470;
 Libderiv->deriv2_classes[7][5][34] = int_stack + 286730;
 Libderiv->deriv2_classes[7][6][34] = int_stack + 287486;
 Libderiv->deriv2_classes[7][7][34] = int_stack + 288494;
 Libderiv->deriv2_classes[7][8][34] = int_stack + 289790;
 Libderiv->deriv2_classes[5][5][33] = int_stack + 291410;
 Libderiv->deriv2_classes[5][6][33] = int_stack + 291851;
 Libderiv->deriv2_classes[5][7][33] = int_stack + 292439;
 Libderiv->deriv2_classes[5][8][33] = int_stack + 293195;
 Libderiv->deriv2_classes[6][5][33] = int_stack + 294140;
 Libderiv->deriv2_classes[6][6][33] = int_stack + 294728;
 Libderiv->deriv2_classes[6][7][33] = int_stack + 295512;
 Libderiv->deriv2_classes[6][8][33] = int_stack + 296520;
 Libderiv->deriv2_classes[7][5][33] = int_stack + 297780;
 Libderiv->deriv2_classes[7][6][33] = int_stack + 298536;
 Libderiv->deriv2_classes[7][7][33] = int_stack + 299544;
 Libderiv->deriv2_classes[7][8][33] = int_stack + 300840;
 Libderiv->deriv2_classes[5][5][32] = int_stack + 302460;
 Libderiv->deriv2_classes[5][6][32] = int_stack + 302901;
 Libderiv->deriv2_classes[5][7][32] = int_stack + 303489;
 Libderiv->deriv2_classes[5][8][32] = int_stack + 304245;
 Libderiv->deriv2_classes[6][5][32] = int_stack + 305190;
 Libderiv->deriv2_classes[6][6][32] = int_stack + 305778;
 Libderiv->deriv2_classes[6][7][32] = int_stack + 306562;
 Libderiv->deriv2_classes[6][8][32] = int_stack + 307570;
 Libderiv->deriv2_classes[7][5][32] = int_stack + 308830;
 Libderiv->deriv2_classes[7][6][32] = int_stack + 309586;
 Libderiv->deriv2_classes[7][7][32] = int_stack + 310594;
 Libderiv->deriv2_classes[7][8][32] = int_stack + 311890;
 Libderiv->deriv2_classes[5][5][31] = int_stack + 313510;
 Libderiv->deriv2_classes[5][6][31] = int_stack + 313951;
 Libderiv->deriv2_classes[5][7][31] = int_stack + 314539;
 Libderiv->deriv2_classes[5][8][31] = int_stack + 315295;
 Libderiv->deriv2_classes[6][5][31] = int_stack + 316240;
 Libderiv->deriv2_classes[6][6][31] = int_stack + 316828;
 Libderiv->deriv2_classes[6][7][31] = int_stack + 317612;
 Libderiv->deriv2_classes[6][8][31] = int_stack + 318620;
 Libderiv->deriv2_classes[7][5][31] = int_stack + 319880;
 Libderiv->deriv2_classes[7][6][31] = int_stack + 320636;
 Libderiv->deriv2_classes[7][7][31] = int_stack + 321644;
 Libderiv->deriv2_classes[7][8][31] = int_stack + 322940;
 Libderiv->deriv2_classes[5][5][30] = int_stack + 324560;
 Libderiv->deriv2_classes[5][6][30] = int_stack + 325001;
 Libderiv->deriv2_classes[5][7][30] = int_stack + 325589;
 Libderiv->deriv2_classes[5][8][30] = int_stack + 326345;
 Libderiv->deriv2_classes[6][5][30] = int_stack + 327290;
 Libderiv->deriv2_classes[6][6][30] = int_stack + 327878;
 Libderiv->deriv2_classes[6][7][30] = int_stack + 328662;
 Libderiv->deriv2_classes[6][8][30] = int_stack + 329670;
 Libderiv->deriv_classes[7][5][2] = int_stack + 330930;
 Libderiv->deriv2_classes[7][5][30] = int_stack + 331686;
 Libderiv->deriv_classes[7][6][2] = int_stack + 332442;
 Libderiv->deriv2_classes[7][6][30] = int_stack + 333450;
 Libderiv->deriv_classes[7][7][2] = int_stack + 334458;
 Libderiv->deriv2_classes[7][7][30] = int_stack + 335754;
 Libderiv->deriv2_classes[7][8][30] = int_stack + 337050;
 Libderiv->deriv2_classes[5][5][26] = int_stack + 338670;
 Libderiv->deriv2_classes[5][6][26] = int_stack + 339111;
 Libderiv->deriv2_classes[5][7][26] = int_stack + 339699;
 Libderiv->deriv2_classes[5][8][26] = int_stack + 340455;
 Libderiv->deriv2_classes[6][5][26] = int_stack + 341400;
 Libderiv->deriv2_classes[6][6][26] = int_stack + 341988;
 Libderiv->deriv2_classes[6][7][26] = int_stack + 342772;
 Libderiv->deriv2_classes[6][8][26] = int_stack + 343780;
 Libderiv->deriv2_classes[7][5][26] = int_stack + 345040;
 Libderiv->deriv2_classes[7][6][26] = int_stack + 345796;
 Libderiv->deriv2_classes[7][7][26] = int_stack + 346804;
 Libderiv->deriv2_classes[7][8][26] = int_stack + 348100;
 Libderiv->deriv2_classes[5][5][23] = int_stack + 349720;
 Libderiv->deriv2_classes[5][6][23] = int_stack + 350161;
 Libderiv->deriv2_classes[5][7][23] = int_stack + 350749;
 Libderiv->deriv2_classes[5][8][23] = int_stack + 351505;
 Libderiv->deriv2_classes[6][5][23] = int_stack + 352450;
 Libderiv->deriv2_classes[6][6][23] = int_stack + 353038;
 Libderiv->deriv2_classes[6][7][23] = int_stack + 353822;
 Libderiv->deriv2_classes[6][8][23] = int_stack + 354830;
 Libderiv->deriv2_classes[7][5][23] = int_stack + 356090;
 Libderiv->deriv2_classes[7][6][23] = int_stack + 356846;
 Libderiv->deriv2_classes[7][7][23] = int_stack + 357854;
 Libderiv->deriv2_classes[7][8][23] = int_stack + 359150;
 Libderiv->deriv2_classes[5][5][22] = int_stack + 360770;
 Libderiv->deriv2_classes[5][6][22] = int_stack + 361211;
 Libderiv->deriv2_classes[5][7][22] = int_stack + 361799;
 Libderiv->deriv2_classes[5][8][22] = int_stack + 362555;
 Libderiv->deriv2_classes[6][5][22] = int_stack + 363500;
 Libderiv->deriv2_classes[6][6][22] = int_stack + 364088;
 Libderiv->deriv2_classes[6][7][22] = int_stack + 364872;
 Libderiv->deriv2_classes[6][8][22] = int_stack + 365880;
 Libderiv->deriv2_classes[7][5][22] = int_stack + 367140;
 Libderiv->deriv2_classes[7][6][22] = int_stack + 367896;
 Libderiv->deriv2_classes[7][7][22] = int_stack + 368904;
 Libderiv->deriv2_classes[7][8][22] = int_stack + 370200;
 Libderiv->deriv2_classes[5][5][21] = int_stack + 371820;
 Libderiv->deriv2_classes[5][6][21] = int_stack + 372261;
 Libderiv->deriv2_classes[5][7][21] = int_stack + 372849;
 Libderiv->deriv2_classes[5][8][21] = int_stack + 373605;
 Libderiv->deriv2_classes[6][5][21] = int_stack + 374550;
 Libderiv->deriv2_classes[6][6][21] = int_stack + 375138;
 Libderiv->deriv2_classes[6][7][21] = int_stack + 375922;
 Libderiv->deriv2_classes[6][8][21] = int_stack + 376930;
 Libderiv->deriv2_classes[7][5][21] = int_stack + 378190;
 Libderiv->deriv2_classes[7][6][21] = int_stack + 378946;
 Libderiv->deriv2_classes[7][7][21] = int_stack + 379954;
 Libderiv->deriv2_classes[7][8][21] = int_stack + 381250;
 Libderiv->deriv2_classes[5][5][20] = int_stack + 382870;
 Libderiv->deriv2_classes[5][6][20] = int_stack + 383311;
 Libderiv->deriv2_classes[5][7][20] = int_stack + 383899;
 Libderiv->deriv2_classes[5][8][20] = int_stack + 384655;
 Libderiv->deriv2_classes[6][5][20] = int_stack + 385600;
 Libderiv->deriv2_classes[6][6][20] = int_stack + 386188;
 Libderiv->deriv2_classes[6][7][20] = int_stack + 386972;
 Libderiv->deriv2_classes[6][8][20] = int_stack + 387980;
 Libderiv->deriv2_classes[7][5][20] = int_stack + 389240;
 Libderiv->deriv2_classes[7][6][20] = int_stack + 389996;
 Libderiv->deriv2_classes[7][7][20] = int_stack + 391004;
 Libderiv->deriv2_classes[7][8][20] = int_stack + 392300;
 Libderiv->deriv2_classes[5][5][19] = int_stack + 393920;
 Libderiv->deriv2_classes[5][6][19] = int_stack + 394361;
 Libderiv->deriv2_classes[5][7][19] = int_stack + 394949;
 Libderiv->deriv2_classes[5][8][19] = int_stack + 395705;
 Libderiv->deriv2_classes[6][5][19] = int_stack + 396650;
 Libderiv->deriv2_classes[6][6][19] = int_stack + 397238;
 Libderiv->deriv2_classes[6][7][19] = int_stack + 398022;
 Libderiv->deriv2_classes[6][8][19] = int_stack + 399030;
 Libderiv->deriv2_classes[7][5][19] = int_stack + 400290;
 Libderiv->deriv2_classes[7][6][19] = int_stack + 401046;
 Libderiv->deriv2_classes[7][7][19] = int_stack + 402054;
 Libderiv->deriv2_classes[7][8][19] = int_stack + 403350;
 Libderiv->deriv2_classes[5][5][18] = int_stack + 404970;
 Libderiv->deriv2_classes[5][6][18] = int_stack + 405411;
 Libderiv->deriv2_classes[5][7][18] = int_stack + 405999;
 Libderiv->deriv2_classes[5][8][18] = int_stack + 406755;
 Libderiv->deriv2_classes[6][5][18] = int_stack + 407700;
 Libderiv->deriv2_classes[6][6][18] = int_stack + 408288;
 Libderiv->deriv2_classes[6][7][18] = int_stack + 409072;
 Libderiv->deriv2_classes[6][8][18] = int_stack + 410080;
 Libderiv->deriv_classes[7][5][1] = int_stack + 411340;
 Libderiv->deriv2_classes[7][5][18] = int_stack + 412096;
 Libderiv->deriv_classes[7][6][1] = int_stack + 412852;
 Libderiv->deriv2_classes[7][6][18] = int_stack + 413860;
 Libderiv->deriv_classes[7][7][1] = int_stack + 414868;
 Libderiv->deriv2_classes[7][7][18] = int_stack + 416164;
 Libderiv->deriv2_classes[7][8][18] = int_stack + 417460;
 Libderiv->deriv2_classes[5][5][14] = int_stack + 419080;
 Libderiv->deriv2_classes[5][6][14] = int_stack + 419521;
 Libderiv->deriv2_classes[5][7][14] = int_stack + 420109;
 Libderiv->deriv2_classes[5][8][14] = int_stack + 420865;
 Libderiv->deriv2_classes[6][5][14] = int_stack + 421810;
 Libderiv->deriv2_classes[6][6][14] = int_stack + 422398;
 Libderiv->deriv2_classes[6][7][14] = int_stack + 423182;
 Libderiv->deriv2_classes[6][8][14] = int_stack + 424190;
 Libderiv->deriv2_classes[7][5][14] = int_stack + 425450;
 Libderiv->deriv2_classes[7][6][14] = int_stack + 426206;
 Libderiv->deriv2_classes[7][7][14] = int_stack + 427214;
 Libderiv->deriv2_classes[7][8][14] = int_stack + 428510;
 Libderiv->deriv2_classes[5][5][13] = int_stack + 430130;
 Libderiv->deriv2_classes[5][6][13] = int_stack + 430571;
 Libderiv->deriv2_classes[5][7][13] = int_stack + 431159;
 Libderiv->deriv2_classes[5][8][13] = int_stack + 431915;
 Libderiv->deriv2_classes[6][5][13] = int_stack + 432860;
 Libderiv->deriv2_classes[6][6][13] = int_stack + 433448;
 Libderiv->deriv2_classes[6][7][13] = int_stack + 434232;
 Libderiv->deriv2_classes[6][8][13] = int_stack + 435240;
 Libderiv->deriv2_classes[7][5][13] = int_stack + 436500;
 Libderiv->deriv2_classes[7][6][13] = int_stack + 437256;
 Libderiv->deriv2_classes[7][7][13] = int_stack + 438264;
 Libderiv->deriv2_classes[7][8][13] = int_stack + 439560;
 Libderiv->deriv_classes[5][5][11] = int_stack + 441180;
 Libderiv->deriv_classes[5][6][11] = int_stack + 441621;
 Libderiv->deriv_classes[5][7][11] = int_stack + 442209;
 Libderiv->deriv_classes[5][8][11] = int_stack + 442965;
 Libderiv->deriv2_classes[5][5][11] = int_stack + 443910;
 Libderiv->deriv2_classes[5][6][11] = int_stack + 444351;
 Libderiv->deriv2_classes[5][7][11] = int_stack + 444939;
 Libderiv->deriv2_classes[5][8][11] = int_stack + 445695;
 Libderiv->deriv_classes[6][5][11] = int_stack + 446640;
 Libderiv->deriv_classes[6][6][11] = int_stack + 447228;
 Libderiv->deriv_classes[6][7][11] = int_stack + 448012;
 Libderiv->deriv_classes[6][8][11] = int_stack + 449020;
 Libderiv->deriv2_classes[6][5][11] = int_stack + 450280;
 Libderiv->deriv2_classes[6][6][11] = int_stack + 450868;
 Libderiv->deriv2_classes[6][7][11] = int_stack + 451652;
 Libderiv->deriv2_classes[6][8][11] = int_stack + 452660;
 Libderiv->deriv2_classes[7][5][11] = int_stack + 453920;
 Libderiv->deriv2_classes[7][6][11] = int_stack + 454676;
 Libderiv->deriv2_classes[7][7][11] = int_stack + 455684;
 Libderiv->deriv2_classes[7][8][11] = int_stack + 456980;
 Libderiv->deriv_classes[5][5][10] = int_stack + 458600;
 Libderiv->deriv_classes[5][6][10] = int_stack + 459041;
 Libderiv->deriv_classes[5][7][10] = int_stack + 459629;
 Libderiv->deriv_classes[5][8][10] = int_stack + 460385;
 Libderiv->deriv2_classes[5][5][10] = int_stack + 461330;
 Libderiv->deriv2_classes[5][6][10] = int_stack + 461771;
 Libderiv->deriv2_classes[5][7][10] = int_stack + 462359;
 Libderiv->deriv2_classes[5][8][10] = int_stack + 463115;
 Libderiv->deriv_classes[6][5][10] = int_stack + 464060;
 Libderiv->deriv_classes[6][6][10] = int_stack + 464648;
 Libderiv->deriv_classes[6][7][10] = int_stack + 465432;
 Libderiv->deriv_classes[6][8][10] = int_stack + 466440;
 Libderiv->deriv2_classes[6][5][10] = int_stack + 467700;
 Libderiv->deriv2_classes[6][6][10] = int_stack + 468288;
 Libderiv->deriv2_classes[6][7][10] = int_stack + 469072;
 Libderiv->deriv2_classes[6][8][10] = int_stack + 470080;
 Libderiv->deriv2_classes[7][5][10] = int_stack + 471340;
 Libderiv->deriv2_classes[7][6][10] = int_stack + 472096;
 Libderiv->deriv2_classes[7][7][10] = int_stack + 473104;
 Libderiv->deriv2_classes[7][8][10] = int_stack + 474400;
 Libderiv->deriv_classes[5][5][9] = int_stack + 476020;
 Libderiv->deriv_classes[5][6][9] = int_stack + 476461;
 Libderiv->deriv_classes[5][7][9] = int_stack + 477049;
 Libderiv->deriv_classes[5][8][9] = int_stack + 477805;
 Libderiv->deriv2_classes[5][5][9] = int_stack + 478750;
 Libderiv->deriv2_classes[5][6][9] = int_stack + 479191;
 Libderiv->deriv2_classes[5][7][9] = int_stack + 479779;
 Libderiv->deriv2_classes[5][8][9] = int_stack + 480535;
 Libderiv->deriv_classes[6][5][9] = int_stack + 481480;
 Libderiv->deriv_classes[6][6][9] = int_stack + 482068;
 Libderiv->deriv_classes[6][7][9] = int_stack + 482852;
 Libderiv->deriv_classes[6][8][9] = int_stack + 483860;
 Libderiv->deriv2_classes[6][5][9] = int_stack + 485120;
 Libderiv->deriv2_classes[6][6][9] = int_stack + 485708;
 Libderiv->deriv2_classes[6][7][9] = int_stack + 486492;
 Libderiv->deriv2_classes[6][8][9] = int_stack + 487500;
 Libderiv->deriv2_classes[7][5][9] = int_stack + 488760;
 Libderiv->deriv2_classes[7][6][9] = int_stack + 489516;
 Libderiv->deriv2_classes[7][7][9] = int_stack + 490524;
 Libderiv->deriv2_classes[7][8][9] = int_stack + 491820;
 Libderiv->deriv_classes[5][5][8] = int_stack + 493440;
 Libderiv->deriv_classes[5][6][8] = int_stack + 493881;
 Libderiv->deriv_classes[5][7][8] = int_stack + 494469;
 Libderiv->deriv_classes[5][8][8] = int_stack + 495225;
 Libderiv->deriv2_classes[5][5][8] = int_stack + 496170;
 Libderiv->deriv2_classes[5][6][8] = int_stack + 496611;
 Libderiv->deriv2_classes[5][7][8] = int_stack + 497199;
 Libderiv->deriv2_classes[5][8][8] = int_stack + 497955;
 Libderiv->deriv_classes[6][5][8] = int_stack + 498900;
 Libderiv->deriv_classes[6][6][8] = int_stack + 499488;
 Libderiv->deriv_classes[6][7][8] = int_stack + 500272;
 Libderiv->deriv_classes[6][8][8] = int_stack + 501280;
 Libderiv->deriv2_classes[6][5][8] = int_stack + 502540;
 Libderiv->deriv2_classes[6][6][8] = int_stack + 503128;
 Libderiv->deriv2_classes[6][7][8] = int_stack + 503912;
 Libderiv->deriv2_classes[6][8][8] = int_stack + 504920;
 Libderiv->deriv2_classes[7][5][8] = int_stack + 506180;
 Libderiv->deriv2_classes[7][6][8] = int_stack + 506936;
 Libderiv->deriv2_classes[7][7][8] = int_stack + 507944;
 Libderiv->deriv2_classes[7][8][8] = int_stack + 509240;
 Libderiv->deriv_classes[5][5][7] = int_stack + 510860;
 Libderiv->deriv_classes[5][6][7] = int_stack + 511301;
 Libderiv->deriv_classes[5][7][7] = int_stack + 511889;
 Libderiv->deriv_classes[5][8][7] = int_stack + 512645;
 Libderiv->deriv2_classes[5][5][7] = int_stack + 513590;
 Libderiv->deriv2_classes[5][6][7] = int_stack + 514031;
 Libderiv->deriv2_classes[5][7][7] = int_stack + 514619;
 Libderiv->deriv2_classes[5][8][7] = int_stack + 515375;
 Libderiv->deriv_classes[6][5][7] = int_stack + 516320;
 Libderiv->deriv_classes[6][6][7] = int_stack + 516908;
 Libderiv->deriv_classes[6][7][7] = int_stack + 517692;
 Libderiv->deriv_classes[6][8][7] = int_stack + 518700;
 Libderiv->deriv2_classes[6][5][7] = int_stack + 519960;
 Libderiv->deriv2_classes[6][6][7] = int_stack + 520548;
 Libderiv->deriv2_classes[6][7][7] = int_stack + 521332;
 Libderiv->deriv2_classes[6][8][7] = int_stack + 522340;
 Libderiv->deriv2_classes[7][5][7] = int_stack + 523600;
 Libderiv->deriv2_classes[7][6][7] = int_stack + 524356;
 Libderiv->deriv2_classes[7][7][7] = int_stack + 525364;
 Libderiv->deriv2_classes[7][8][7] = int_stack + 526660;
 Libderiv->deriv_classes[5][5][6] = int_stack + 528280;
 Libderiv->deriv_classes[5][6][6] = int_stack + 528721;
 Libderiv->deriv_classes[5][7][6] = int_stack + 529309;
 Libderiv->deriv_classes[5][8][6] = int_stack + 530065;
 Libderiv->deriv2_classes[5][5][6] = int_stack + 531010;
 Libderiv->deriv2_classes[5][6][6] = int_stack + 531451;
 Libderiv->deriv2_classes[5][7][6] = int_stack + 532039;
 Libderiv->deriv2_classes[5][8][6] = int_stack + 532795;
 Libderiv->dvrr_classes[6][5] = int_stack + 533740;
 Libderiv->deriv_classes[6][5][6] = int_stack + 534328;
 Libderiv->dvrr_classes[6][6] = int_stack + 534916;
 Libderiv->deriv_classes[6][6][6] = int_stack + 535700;
 Libderiv->dvrr_classes[6][7] = int_stack + 536484;
 Libderiv->deriv_classes[6][7][6] = int_stack + 537492;
 Libderiv->deriv_classes[6][8][6] = int_stack + 538500;
 Libderiv->deriv2_classes[6][5][6] = int_stack + 539760;
 Libderiv->deriv2_classes[6][6][6] = int_stack + 540348;
 Libderiv->deriv2_classes[6][7][6] = int_stack + 541132;
 Libderiv->deriv2_classes[6][8][6] = int_stack + 542140;
 Libderiv->deriv_classes[7][5][0] = int_stack + 543400;
 Libderiv->deriv2_classes[7][5][6] = int_stack + 544156;
 Libderiv->deriv_classes[7][6][0] = int_stack + 544912;
 Libderiv->deriv2_classes[7][6][6] = int_stack + 545920;
 Libderiv->deriv_classes[7][7][0] = int_stack + 546928;
 Libderiv->deriv2_classes[7][7][6] = int_stack + 548224;
 Libderiv->deriv2_classes[7][8][6] = int_stack + 549520;
 Libderiv->deriv_classes[5][5][2] = int_stack + 551140;
 Libderiv->deriv_classes[5][6][2] = int_stack + 551581;
 Libderiv->deriv_classes[5][7][2] = int_stack + 552169;
 Libderiv->deriv_classes[5][8][2] = int_stack + 552925;
 Libderiv->deriv2_classes[5][5][2] = int_stack + 553870;
 Libderiv->deriv2_classes[5][6][2] = int_stack + 554311;
 Libderiv->deriv2_classes[5][7][2] = int_stack + 554899;
 Libderiv->deriv2_classes[5][8][2] = int_stack + 555655;
 Libderiv->deriv_classes[6][5][2] = int_stack + 556600;
 Libderiv->deriv_classes[6][6][2] = int_stack + 557188;
 Libderiv->deriv_classes[6][7][2] = int_stack + 557972;
 Libderiv->deriv_classes[6][8][2] = int_stack + 558980;
 Libderiv->deriv2_classes[6][5][2] = int_stack + 560240;
 Libderiv->deriv2_classes[6][6][2] = int_stack + 560828;
 Libderiv->deriv2_classes[6][7][2] = int_stack + 561612;
 Libderiv->deriv2_classes[6][8][2] = int_stack + 562620;
 Libderiv->deriv2_classes[7][5][2] = int_stack + 563880;
 Libderiv->deriv2_classes[7][6][2] = int_stack + 564636;
 Libderiv->deriv2_classes[7][7][2] = int_stack + 565644;
 Libderiv->deriv2_classes[7][8][2] = int_stack + 566940;
 Libderiv->deriv_classes[5][5][1] = int_stack + 568560;
 Libderiv->deriv_classes[5][6][1] = int_stack + 569001;
 Libderiv->deriv_classes[5][7][1] = int_stack + 569589;
 Libderiv->deriv_classes[5][8][1] = int_stack + 570345;
 Libderiv->deriv2_classes[5][5][1] = int_stack + 571290;
 Libderiv->deriv2_classes[5][6][1] = int_stack + 571731;
 Libderiv->deriv2_classes[5][7][1] = int_stack + 572319;
 Libderiv->deriv2_classes[5][8][1] = int_stack + 573075;
 Libderiv->deriv_classes[6][5][1] = int_stack + 574020;
 Libderiv->deriv_classes[6][6][1] = int_stack + 574608;
 Libderiv->deriv_classes[6][7][1] = int_stack + 575392;
 Libderiv->deriv_classes[6][8][1] = int_stack + 576400;
 Libderiv->deriv2_classes[6][5][1] = int_stack + 577660;
 Libderiv->deriv2_classes[6][6][1] = int_stack + 578248;
 Libderiv->deriv2_classes[6][7][1] = int_stack + 579032;
 Libderiv->deriv2_classes[6][8][1] = int_stack + 580040;
 Libderiv->deriv2_classes[7][5][1] = int_stack + 581300;
 Libderiv->deriv2_classes[7][6][1] = int_stack + 582056;
 Libderiv->deriv2_classes[7][7][1] = int_stack + 583064;
 Libderiv->deriv2_classes[7][8][1] = int_stack + 584360;
 Libderiv->dvrr_classes[5][5] = int_stack + 585980;
 Libderiv->dvrr_classes[5][6] = int_stack + 586421;
 Libderiv->dvrr_classes[5][7] = int_stack + 587009;
 Libderiv->dvrr_classes[5][8] = int_stack + 587765;
 Libderiv->deriv_classes[5][5][0] = int_stack + 588710;
 Libderiv->deriv_classes[5][6][0] = int_stack + 589151;
 Libderiv->deriv_classes[5][7][0] = int_stack + 589739;
 Libderiv->deriv_classes[5][8][0] = int_stack + 590495;
 Libderiv->deriv2_classes[5][5][0] = int_stack + 591440;
 Libderiv->deriv2_classes[5][6][0] = int_stack + 591881;
 Libderiv->deriv2_classes[5][7][0] = int_stack + 592469;
 Libderiv->deriv2_classes[5][8][0] = int_stack + 593225;
 Libderiv->deriv_classes[6][5][0] = int_stack + 594170;
 Libderiv->deriv_classes[6][6][0] = int_stack + 594758;
 Libderiv->deriv_classes[6][7][0] = int_stack + 595542;
 Libderiv->deriv_classes[6][8][0] = int_stack + 596550;
 Libderiv->deriv2_classes[6][5][0] = int_stack + 597810;
 Libderiv->deriv2_classes[6][6][0] = int_stack + 598398;
 Libderiv->deriv2_classes[6][7][0] = int_stack + 599182;
 Libderiv->deriv2_classes[6][8][0] = int_stack + 600190;
 Libderiv->deriv2_classes[7][5][0] = int_stack + 601450;
 Libderiv->deriv2_classes[7][6][0] = int_stack + 602206;
 Libderiv->deriv2_classes[7][7][0] = int_stack + 603214;
 Libderiv->deriv2_classes[7][8][0] = int_stack + 604510;
 memset(int_stack,0,4849040);

 Libderiv->dvrr_stack = int_stack + 2025904;
 for(i=0;i<num_prim_comb;i++) {
   d12vrr_order_hdhf(Libderiv, Data);
   Data++;
 }

 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+606130,int_stack+586421,int_stack+585980,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+607453,int_stack+587009,int_stack+586421,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+609217,int_stack+607453,int_stack+606130,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+611863,int_stack+441621,int_stack+441180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585980,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+613186,int_stack+442209,int_stack+441621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586421,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+614950,int_stack+613186,int_stack+611863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606130,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+617596,int_stack+442965,int_stack+442209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587009,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+619864,int_stack+617596,int_stack+613186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607453,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+623392,int_stack+619864,int_stack+614950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+609217,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+617596,int_stack+534916,int_stack+533740,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+619360,int_stack+536484,int_stack+534916,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+627802,int_stack+619360,int_stack+617596,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+631330,int_stack+447228,int_stack+446640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533740,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+633094,int_stack+448012,int_stack+447228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+534916,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+635446,int_stack+633094,int_stack+631330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617596,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+638974,int_stack+449020,int_stack+448012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536484,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+641998,int_stack+638974,int_stack+633094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619360,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+646702,int_stack+641998,int_stack+635446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+627802,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+652582,int_stack+646702,int_stack+623392,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+638974,int_stack+262074,int_stack+259806,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+641242,int_stack+8100,int_stack+262074,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+665812,int_stack+641242,int_stack+638974,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+644266,int_stack+190768,int_stack+189256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259806,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+670348,int_stack+192784,int_stack+190768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262074,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+673372,int_stack+670348,int_stack+644266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+638974,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+677908,int_stack+0,int_stack+192784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+681796,int_stack+677908,int_stack+670348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641242,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+687844,int_stack+681796,int_stack+673372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665812,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+695404,int_stack+687844,int_stack+646702,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+677908,int_stack+459041,int_stack+458600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585980, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+679231,int_stack+459629,int_stack+459041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586421, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+680995,int_stack+679231,int_stack+677908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606130, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+683641,int_stack+460385,int_stack+459629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587009, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+685909,int_stack+683641,int_stack+679231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607453, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+689437,int_stack+685909,int_stack+680995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+609217, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+683641,int_stack+464648,int_stack+464060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533740, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+685405,int_stack+465432,int_stack+464648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+534916, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+713044,int_stack+685405,int_stack+683641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617596, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+716572,int_stack+466440,int_stack+465432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536484, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+719596,int_stack+716572,int_stack+685405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619360, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+724300,int_stack+719596,int_stack+713044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+627802, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+730180,int_stack+724300,int_stack+689437,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+716572,int_stack+204878,int_stack+203366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259806, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+718840,int_stack+206894,int_stack+204878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262074, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+743410,int_stack+718840,int_stack+716572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+638974, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+747946,int_stack+1620,int_stack+206894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+751834,int_stack+747946,int_stack+718840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641242, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+757882,int_stack+751834,int_stack+743410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+765442,int_stack+757882,int_stack+724300,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+747946,int_stack+476461,int_stack+476020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585980, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+749269,int_stack+477049,int_stack+476461, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586421, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+751033,int_stack+749269,int_stack+747946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606130, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+753679,int_stack+477805,int_stack+477049, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587009, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+755947,int_stack+753679,int_stack+749269, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607453, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+759475,int_stack+755947,int_stack+751033, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+609217, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+753679,int_stack+482068,int_stack+481480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533740, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+755443,int_stack+482852,int_stack+482068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+534916, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+783082,int_stack+755443,int_stack+753679, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617596, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+483860,int_stack+482852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536484, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+786610,int_stack+0,int_stack+755443, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619360, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+791314,int_stack+786610,int_stack+783082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+627802, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+797194,int_stack+791314,int_stack+759475,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+786610,int_stack+218988,int_stack+217476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259806, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+221004,int_stack+218988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262074, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+810424,int_stack+0,int_stack+786610, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+638974, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+814960,int_stack+3240,int_stack+221004, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+818848,int_stack+814960,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641242, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+824896,int_stack+818848,int_stack+810424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+832456,int_stack+824896,int_stack+791314,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+814960,int_stack+493881,int_stack+493440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+585980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+816283,int_stack+494469,int_stack+493881, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+586421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+818047,int_stack+816283,int_stack+814960, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+820693,int_stack+495225,int_stack+494469, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+587009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+822961,int_stack+820693,int_stack+816283, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+607453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+826489,int_stack+822961,int_stack+818047, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+609217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+820693,int_stack+499488,int_stack+498900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+533740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+822457,int_stack+500272,int_stack+499488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+534916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+850096,int_stack+822457,int_stack+820693, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+853624,int_stack+501280,int_stack+500272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+536484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+856648,int_stack+853624,int_stack+822457, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+619360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+861352,int_stack+856648,int_stack+850096, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+867232,int_stack+861352,int_stack+826489,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+853624,int_stack+233098,int_stack+231586, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+259806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+855892,int_stack+235114,int_stack+233098, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+880462,int_stack+855892,int_stack+853624, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+638974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+884998,int_stack+4860,int_stack+235114, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+888886,int_stack+884998,int_stack+855892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+641242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+894934,int_stack+888886,int_stack+880462, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+902494,int_stack+894934,int_stack+861352,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+884998,int_stack+511301,int_stack+510860, 0.0, zero_stack, 1.0, int_stack+585980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+886321,int_stack+511889,int_stack+511301, 0.0, zero_stack, 1.0, int_stack+586421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+888085,int_stack+886321,int_stack+884998, 0.0, zero_stack, 1.0, int_stack+606130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+890731,int_stack+512645,int_stack+511889, 0.0, zero_stack, 1.0, int_stack+587009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+892999,int_stack+890731,int_stack+886321, 0.0, zero_stack, 1.0, int_stack+607453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+896527,int_stack+892999,int_stack+888085, 0.0, zero_stack, 1.0, int_stack+609217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+890731,int_stack+516908,int_stack+516320, 0.0, zero_stack, 1.0, int_stack+533740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+892495,int_stack+517692,int_stack+516908, 0.0, zero_stack, 1.0, int_stack+534916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+920134,int_stack+892495,int_stack+890731, 0.0, zero_stack, 1.0, int_stack+617596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+3024,int_stack+518700,int_stack+517692, 0.0, zero_stack, 1.0, int_stack+536484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+923662,int_stack+3024,int_stack+892495, 0.0, zero_stack, 1.0, int_stack+619360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+928366,int_stack+923662,int_stack+920134, 0.0, zero_stack, 1.0, int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+934246,int_stack+928366,int_stack+896527,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+923662,int_stack+247208,int_stack+245696, 0.0, zero_stack, 1.0, int_stack+259806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+3024,int_stack+249224,int_stack+247208, 0.0, zero_stack, 1.0, int_stack+262074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+947476,int_stack+3024,int_stack+923662, 0.0, zero_stack, 1.0, int_stack+638974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+952012,int_stack+6480,int_stack+249224, 0.0, zero_stack, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+955900,int_stack+952012,int_stack+3024, 0.0, zero_stack, 1.0, int_stack+641242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+961948,int_stack+955900,int_stack+947476, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+969508,int_stack+961948,int_stack+928366,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+952012,int_stack+528721,int_stack+528280, 1.0, int_stack+585980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+953335,int_stack+529309,int_stack+528721, 1.0, int_stack+586421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+955099,int_stack+953335,int_stack+952012, 1.0, int_stack+606130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+957745,int_stack+530065,int_stack+529309, 1.0, int_stack+587009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+960013,int_stack+957745,int_stack+953335, 1.0, int_stack+607453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+963541,int_stack+960013,int_stack+955099, 1.0, int_stack+609217, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+957745,int_stack+535700,int_stack+534328, 1.0, int_stack+533740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+959509,int_stack+537492,int_stack+535700, 1.0, int_stack+534916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+987148,int_stack+959509,int_stack+957745, 1.0, int_stack+617596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+990676,int_stack+538500,int_stack+537492, 1.0, int_stack+536484, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+993700,int_stack+990676,int_stack+959509, 1.0, int_stack+619360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+998404,int_stack+993700,int_stack+987148, 1.0, int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1004284,int_stack+998404,int_stack+963541,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+990676,int_stack+263082,int_stack+260562, 1.0, int_stack+259806, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+992944,int_stack+265098,int_stack+263082, 1.0, int_stack+262074, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1017514,int_stack+992944,int_stack+990676, 1.0, int_stack+638974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1022050,int_stack+9396,int_stack+265098, 1.0, int_stack+8100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1025938,int_stack+1022050,int_stack+992944, 1.0, int_stack+641242, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1031986,int_stack+1025938,int_stack+1017514, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1039546,int_stack+1031986,int_stack+998404,210);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+665812,int_stack+587765,int_stack+587009,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1022050,int_stack+665812,int_stack+607453,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+665812,int_stack+1022050,int_stack+609217,21);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1022050,int_stack+14256,int_stack+536484,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1025074,int_stack+1022050,int_stack+619360,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1029778,int_stack+1025074,int_stack+627802,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1057186,int_stack+1029778,int_stack+665812,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+551581,int_stack+551140,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+629125,int_stack+552169,int_stack+551581,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1022050,int_stack+629125,int_stack+627802,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1024696,int_stack+552925,int_stack+552169,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1035658,int_stack+1024696,int_stack+629125,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1024696,int_stack+1035658,int_stack+1022050,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1035658,int_stack+557188,int_stack+556600,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+638974,int_stack+557972,int_stack+557188,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+617596,int_stack+638974,int_stack+1035658,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+606130,int_stack+558980,int_stack+557972,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+6048,int_stack+606130,int_stack+638974,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1070416,int_stack+6048,int_stack+617596,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1076296,int_stack+1070416,int_stack+1024696, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+621124,int_stack+332442,int_stack+330930,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+6048,int_stack+334458,int_stack+332442,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+606130,int_stack+6048,int_stack+621124,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1089526,int_stack+11016,int_stack+334458,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1093414,int_stack+1089526,int_stack+6048,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1099462,int_stack+1093414,int_stack+606130,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1107022,int_stack+1099462,int_stack+1070416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1029778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1089526,int_stack+569001,int_stack+568560,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1090849,int_stack+569589,int_stack+569001,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1092613,int_stack+1090849,int_stack+1089526,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1095259,int_stack+570345,int_stack+569589,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1097527,int_stack+1095259,int_stack+1090849,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1101055,int_stack+1097527,int_stack+1092613,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1095259,int_stack+574608,int_stack+574020,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1097023,int_stack+575392,int_stack+574608,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+9072,int_stack+1097023,int_stack+1095259,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1124662,int_stack+576400,int_stack+575392,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1127686,int_stack+1124662,int_stack+1097023,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1132390,int_stack+1127686,int_stack+9072,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1138270,int_stack+1132390,int_stack+1101055, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1124662,int_stack+412852,int_stack+411340,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1126930,int_stack+414868,int_stack+412852,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1151500,int_stack+1126930,int_stack+1124662,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1156036,int_stack+12636,int_stack+414868,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1159924,int_stack+1156036,int_stack+1126930,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1165972,int_stack+1159924,int_stack+1151500,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1173532,int_stack+1165972,int_stack+1132390, 0.0, zero_stack, 1.0, int_stack+1029778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1156036,int_stack+589151,int_stack+588710,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1157359,int_stack+589739,int_stack+589151,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1159123,int_stack+1157359,int_stack+1156036,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1161769,int_stack+590495,int_stack+589739,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1164037,int_stack+1161769,int_stack+1157359,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1167565,int_stack+1164037,int_stack+1159123,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1161769,int_stack+594758,int_stack+594170,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1163533,int_stack+595542,int_stack+594758,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1191172,int_stack+1163533,int_stack+1161769,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1194700,int_stack+596550,int_stack+595542,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1197724,int_stack+1194700,int_stack+1163533,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1202428,int_stack+1197724,int_stack+1191172,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1208308,int_stack+1202428,int_stack+1167565, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+665812,int_stack+544912,int_stack+543400,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1194700,int_stack+546928,int_stack+544912,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1197724,int_stack+1194700,int_stack+665812,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1221538,int_stack+15516,int_stack+546928,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1225426,int_stack+1221538,int_stack+1194700,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1231474,int_stack+1225426,int_stack+1197724,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1239034,int_stack+1231474,int_stack+1202428, 1.0, int_stack+1029778, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1221538,int_stack+17577,int_stack+17136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+441180,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1222861,int_stack+18165,int_stack+17577, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+441621,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224625,int_stack+1222861,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+611863,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+18921,int_stack+18165, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+442209,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1227271,int_stack+668080,int_stack+1222861, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+613186,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1230799,int_stack+1227271,int_stack+1224625, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+614950,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+20454,int_stack+19866, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+446640,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+21238,int_stack+20454, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+447228,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1223890,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+631330,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1227418,int_stack+22246,int_stack+21238, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+448012,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12600,int_stack+1227418,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+633094,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+17304,int_stack+12600,int_stack+1223890, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+635446,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1256674,int_stack+17304,int_stack+1230799,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+24262,int_stack+23506, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+189256,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+25270,int_stack+24262, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+190768,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1221538,int_stack+12600,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+644266,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1226074,int_stack+26566,int_stack+25270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+192784,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1229962,int_stack+1226074,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+670348,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1229962,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+673372,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1277464,int_stack+1269904,int_stack+17304,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+28627,int_stack+28186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441180, 1.0, int_stack+458600,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+29215,int_stack+28627, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441621, 1.0, int_stack+459041,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611863, 1.0, int_stack+677908,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+29971,int_stack+29215, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442209, 1.0, int_stack+459629,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1221538,int_stack+668080,int_stack+1271227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613186, 1.0, int_stack+679231,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1225066,int_stack+1221538,int_stack+1272991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614950, 1.0, int_stack+680995,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1221538,int_stack+31504,int_stack+30916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+446640, 1.0, int_stack+464060,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+32288,int_stack+31504, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447228, 1.0, int_stack+464648,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272256,int_stack+1269904,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631330, 1.0, int_stack+683641,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1221538,int_stack+33296,int_stack+32288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448012, 1.0, int_stack+465432,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1229476,int_stack+1221538,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+633094, 1.0, int_stack+685405,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1229476,int_stack+1272256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635446, 1.0, int_stack+713044,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+18480,int_stack+12600,int_stack+1225066,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+35312,int_stack+34556, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189256, 1.0, int_stack+203366,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+36320,int_stack+35312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190768, 1.0, int_stack+204878,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272928,int_stack+1269904,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644266, 1.0, int_stack+716572,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1221538,int_stack+37616,int_stack+36320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192784, 1.0, int_stack+206894,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225426,int_stack+1221538,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+670348, 1.0, int_stack+718840,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1231474,int_stack+1225426,int_stack+1272928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+673372, 1.0, int_stack+743410,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1295104,int_stack+1231474,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+39677,int_stack+39236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+458600, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+40265,int_stack+39677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+459041, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+677908, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+41021,int_stack+40265, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+459629, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+668080,int_stack+13923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+679231, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1269904,int_stack+15687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+680995, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+42554,int_stack+41966, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+464060, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+43338,int_stack+42554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+464648, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+683641, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+44346,int_stack+43338, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+465432, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+685405, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1225948,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+713044, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+31710,int_stack+1269904,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+46362,int_stack+45606, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+203366, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+47370,int_stack+46362, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+204878, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+716572, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+48666,int_stack+47370, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+206894, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+718840, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+743410, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1320304,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+50727,int_stack+50286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441180, 0.0, zero_stack, 1.0, int_stack+476020,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+51315,int_stack+50727, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441621, 0.0, zero_stack, 1.0, int_stack+476461,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611863, 0.0, zero_stack, 1.0, int_stack+747946,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+52071,int_stack+51315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442209, 0.0, zero_stack, 1.0, int_stack+477049,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+668080,int_stack+1271227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613186, 0.0, zero_stack, 1.0, int_stack+749269,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1312744,int_stack+1272991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614950, 0.0, zero_stack, 1.0, int_stack+751033,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+53604,int_stack+53016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+446640, 0.0, zero_stack, 1.0, int_stack+481480,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+54388,int_stack+53604, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447228, 0.0, zero_stack, 1.0, int_stack+482068,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631330, 0.0, zero_stack, 1.0, int_stack+753679,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+55396,int_stack+54388, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448012, 0.0, zero_stack, 1.0, int_stack+482852,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+633094, 0.0, zero_stack, 1.0, int_stack+755443,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1225948,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635446, 0.0, zero_stack, 1.0, int_stack+783082,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1337944,int_stack+12600,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+57412,int_stack+56656, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189256, 0.0, zero_stack, 1.0, int_stack+217476,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+58420,int_stack+57412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190768, 0.0, zero_stack, 1.0, int_stack+218988,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644266, 0.0, zero_stack, 1.0, int_stack+786610,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+59716,int_stack+58420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192784, 0.0, zero_stack, 1.0, int_stack+221004,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+670348, 0.0, zero_stack, 1.0, int_stack+0,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+673372, 0.0, zero_stack, 1.0, int_stack+810424,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1351174,int_stack+1269904,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+61777,int_stack+61336, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458600, 1.0, int_stack+476020, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+62365,int_stack+61777, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459041, 1.0, int_stack+476461, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677908, 1.0, int_stack+747946, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+63121,int_stack+62365, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459629, 1.0, int_stack+477049, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+668080,int_stack+13923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+679231, 1.0, int_stack+749269, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1269904,int_stack+15687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680995, 1.0, int_stack+751033, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+64654,int_stack+64066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464060, 1.0, int_stack+481480, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+65438,int_stack+64654, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464648, 1.0, int_stack+482068, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+683641, 1.0, int_stack+753679, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+66446,int_stack+65438, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+465432, 1.0, int_stack+482852, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+685405, 1.0, int_stack+755443, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1225948,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713044, 1.0, int_stack+783082, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+44940,int_stack+1269904,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+68462,int_stack+67706, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203366, 1.0, int_stack+217476, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+69470,int_stack+68462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204878, 1.0, int_stack+218988, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716572, 1.0, int_stack+786610, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+70766,int_stack+69470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206894, 1.0, int_stack+221004, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+718840, 1.0, int_stack+0, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743410, 1.0, int_stack+810424, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1368814,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+72827,int_stack+72386, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+476020, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+73415,int_stack+72827, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+476461, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+747946, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+74171,int_stack+73415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+477049, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+668080,int_stack+1271227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+749269, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1312744,int_stack+1272991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+751033, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+75704,int_stack+75116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+481480, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+76488,int_stack+75704, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+482068, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+753679, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+77496,int_stack+76488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+482852, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+755443, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1225948,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+783082, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+58170,int_stack+12600,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+79512,int_stack+78756, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+217476, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+80520,int_stack+79512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+218988, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+786610, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+81816,int_stack+80520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+221004, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+810424, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1386454,int_stack+1269904,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+83877,int_stack+83436, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493440,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+84465,int_stack+83877, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+441621, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+493881,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+611863, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+814960,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+85221,int_stack+84465, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+442209, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+494469,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+668080,int_stack+13923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+613186, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+816283,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1269904,int_stack+15687, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+614950, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+818047,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+86754,int_stack+86166, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+446640, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498900,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+87538,int_stack+86754, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+447228, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+499488,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+631330, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+820693,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+88546,int_stack+87538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+448012, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+500272,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+633094, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+822457,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1225948,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+635446, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+850096,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+71400,int_stack+1269904,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+90562,int_stack+89806, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+189256, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+231586,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+91570,int_stack+90562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+190768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+233098,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+644266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+853624,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+92866,int_stack+91570, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+192784, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+235114,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+670348, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+855892,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+673372, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+880462,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1404094,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+94927,int_stack+94486, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+458600, 0.0, zero_stack, 1.0, int_stack+493440, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+95515,int_stack+94927, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459041, 0.0, zero_stack, 1.0, int_stack+493881, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+677908, 0.0, zero_stack, 1.0, int_stack+814960, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+96271,int_stack+95515, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+459629, 0.0, zero_stack, 1.0, int_stack+494469, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+668080,int_stack+1271227, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+679231, 0.0, zero_stack, 1.0, int_stack+816283, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1312744,int_stack+1272991, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+680995, 0.0, zero_stack, 1.0, int_stack+818047, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+97804,int_stack+97216, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464060, 0.0, zero_stack, 1.0, int_stack+498900, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+98588,int_stack+97804, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+464648, 0.0, zero_stack, 1.0, int_stack+499488, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+683641, 0.0, zero_stack, 1.0, int_stack+820693, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+99596,int_stack+98588, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+465432, 0.0, zero_stack, 1.0, int_stack+500272, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+685405, 0.0, zero_stack, 1.0, int_stack+822457, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1225948,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+713044, 0.0, zero_stack, 1.0, int_stack+850096, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+84630,int_stack+12600,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+101612,int_stack+100856, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+203366, 0.0, zero_stack, 1.0, int_stack+231586, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+102620,int_stack+101612, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+204878, 0.0, zero_stack, 1.0, int_stack+233098, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+716572, 0.0, zero_stack, 1.0, int_stack+853624, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+103916,int_stack+102620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+206894, 0.0, zero_stack, 1.0, int_stack+235114, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+718840, 0.0, zero_stack, 1.0, int_stack+855892, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+743410, 0.0, zero_stack, 1.0, int_stack+880462, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1421734,int_stack+1269904,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+105977,int_stack+105536, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476020, 1.0, int_stack+493440, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+106565,int_stack+105977, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+476461, 1.0, int_stack+493881, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+747946, 1.0, int_stack+814960, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+107321,int_stack+106565, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+477049, 1.0, int_stack+494469, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+668080,int_stack+13923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+749269, 1.0, int_stack+816283, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1269904,int_stack+15687, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+751033, 1.0, int_stack+818047, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+108854,int_stack+108266, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+481480, 1.0, int_stack+498900, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+109638,int_stack+108854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482068, 1.0, int_stack+499488, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+753679, 1.0, int_stack+820693, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+110646,int_stack+109638, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+482852, 1.0, int_stack+500272, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+755443, 1.0, int_stack+822457, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1225948,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+783082, 1.0, int_stack+850096, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+97860,int_stack+1269904,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+112662,int_stack+111906, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217476, 1.0, int_stack+231586, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+113670,int_stack+112662, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+218988, 1.0, int_stack+233098, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+786610, 1.0, int_stack+853624, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+114966,int_stack+113670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+221004, 1.0, int_stack+235114, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 1.0, int_stack+855892, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+810424, 1.0, int_stack+880462, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1439374,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+117027,int_stack+116586, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+493440, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+117615,int_stack+117027, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+493881, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+814960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+118371,int_stack+117615, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+494469, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+668080,int_stack+1271227, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+816283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1312744,int_stack+1272991, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+818047, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+119904,int_stack+119316, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+498900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+120688,int_stack+119904, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+499488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+820693, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+121696,int_stack+120688, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+500272, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+822457, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1225948,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+850096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1457014,int_stack+12600,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+123712,int_stack+122956, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+231586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+124720,int_stack+123712, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+233098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+853624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+126016,int_stack+124720, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+235114, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+855892, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+880462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1470244,int_stack+1269904,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+128077,int_stack+127636, 0.0, zero_stack, 1.0, int_stack+441180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510860,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+128665,int_stack+128077, 0.0, zero_stack, 1.0, int_stack+441621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511301,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 1.0, int_stack+611863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+884998,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+129421,int_stack+128665, 0.0, zero_stack, 1.0, int_stack+442209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511889,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+668080,int_stack+13923, 0.0, zero_stack, 1.0, int_stack+613186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+886321,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1269904,int_stack+15687, 0.0, zero_stack, 1.0, int_stack+614950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888085,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+130954,int_stack+130366, 0.0, zero_stack, 1.0, int_stack+446640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516320,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+131738,int_stack+130954, 0.0, zero_stack, 1.0, int_stack+447228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516908,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+631330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890731,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+132746,int_stack+131738, 0.0, zero_stack, 1.0, int_stack+448012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517692,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 1.0, int_stack+633094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892495,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1225948,int_stack+12600, 0.0, zero_stack, 1.0, int_stack+635446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+920134,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+111090,int_stack+1269904,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+134762,int_stack+134006, 0.0, zero_stack, 1.0, int_stack+189256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245696,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+135770,int_stack+134762, 0.0, zero_stack, 1.0, int_stack+190768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247208,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 1.0, int_stack+644266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+923662,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+137066,int_stack+135770, 0.0, zero_stack, 1.0, int_stack+192784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249224,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 1.0, int_stack+670348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 1.0, int_stack+673372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+947476,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1487884,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+139127,int_stack+138686, 0.0, zero_stack, 1.0, int_stack+458600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+510860, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+139715,int_stack+139127, 0.0, zero_stack, 1.0, int_stack+459041, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511301, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+677908, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+884998, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+140471,int_stack+139715, 0.0, zero_stack, 1.0, int_stack+459629, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+511889, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+668080,int_stack+1271227, 0.0, zero_stack, 1.0, int_stack+679231, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+886321, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1312744,int_stack+1272991, 0.0, zero_stack, 1.0, int_stack+680995, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+888085, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+142004,int_stack+141416, 0.0, zero_stack, 1.0, int_stack+464060, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516320, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+142788,int_stack+142004, 0.0, zero_stack, 1.0, int_stack+464648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+516908, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 1.0, int_stack+683641, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+890731, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+143796,int_stack+142788, 0.0, zero_stack, 1.0, int_stack+465432, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+517692, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 1.0, int_stack+685405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+892495, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1225948,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+713044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+920134, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+124320,int_stack+12600,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+145812,int_stack+145056, 0.0, zero_stack, 1.0, int_stack+203366, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+245696, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+146820,int_stack+145812, 0.0, zero_stack, 1.0, int_stack+204878, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+247208, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 1.0, int_stack+716572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+923662, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+148116,int_stack+146820, 0.0, zero_stack, 1.0, int_stack+206894, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249224, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 1.0, int_stack+718840, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 1.0, int_stack+743410, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+947476, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1505524,int_stack+1269904,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+150177,int_stack+149736, 0.0, zero_stack, 1.0, int_stack+476020, 0.0, zero_stack, 1.0, int_stack+510860, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+150765,int_stack+150177, 0.0, zero_stack, 1.0, int_stack+476461, 0.0, zero_stack, 1.0, int_stack+511301, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 1.0, int_stack+747946, 0.0, zero_stack, 1.0, int_stack+884998, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+151521,int_stack+150765, 0.0, zero_stack, 1.0, int_stack+477049, 0.0, zero_stack, 1.0, int_stack+511889, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+668080,int_stack+13923, 0.0, zero_stack, 1.0, int_stack+749269, 0.0, zero_stack, 1.0, int_stack+886321, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1269904,int_stack+15687, 0.0, zero_stack, 1.0, int_stack+751033, 0.0, zero_stack, 1.0, int_stack+888085, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+153054,int_stack+152466, 0.0, zero_stack, 1.0, int_stack+481480, 0.0, zero_stack, 1.0, int_stack+516320, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+153838,int_stack+153054, 0.0, zero_stack, 1.0, int_stack+482068, 0.0, zero_stack, 1.0, int_stack+516908, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+753679, 0.0, zero_stack, 1.0, int_stack+890731, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+154846,int_stack+153838, 0.0, zero_stack, 1.0, int_stack+482852, 0.0, zero_stack, 1.0, int_stack+517692, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 1.0, int_stack+755443, 0.0, zero_stack, 1.0, int_stack+892495, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1225948,int_stack+12600, 0.0, zero_stack, 1.0, int_stack+783082, 0.0, zero_stack, 1.0, int_stack+920134, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+137550,int_stack+1269904,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+156862,int_stack+156106, 0.0, zero_stack, 1.0, int_stack+217476, 0.0, zero_stack, 1.0, int_stack+245696, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+157870,int_stack+156862, 0.0, zero_stack, 1.0, int_stack+218988, 0.0, zero_stack, 1.0, int_stack+247208, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 1.0, int_stack+786610, 0.0, zero_stack, 1.0, int_stack+923662, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+159166,int_stack+157870, 0.0, zero_stack, 1.0, int_stack+221004, 0.0, zero_stack, 1.0, int_stack+249224, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 1.0, int_stack+810424, 0.0, zero_stack, 1.0, int_stack+947476, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1523164,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+161227,int_stack+160786, 0.0, zero_stack, 1.0, int_stack+493440, 1.0, int_stack+510860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+161815,int_stack+161227, 0.0, zero_stack, 1.0, int_stack+493881, 1.0, int_stack+511301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+814960, 1.0, int_stack+884998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+162571,int_stack+161815, 0.0, zero_stack, 1.0, int_stack+494469, 1.0, int_stack+511889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+668080,int_stack+1271227, 0.0, zero_stack, 1.0, int_stack+816283, 1.0, int_stack+886321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1312744,int_stack+1272991, 0.0, zero_stack, 1.0, int_stack+818047, 1.0, int_stack+888085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+164104,int_stack+163516, 0.0, zero_stack, 1.0, int_stack+498900, 1.0, int_stack+516320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+164888,int_stack+164104, 0.0, zero_stack, 1.0, int_stack+499488, 1.0, int_stack+516908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 1.0, int_stack+820693, 1.0, int_stack+890731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+165896,int_stack+164888, 0.0, zero_stack, 1.0, int_stack+500272, 1.0, int_stack+517692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 1.0, int_stack+822457, 1.0, int_stack+892495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1225948,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+850096, 1.0, int_stack+920134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+150780,int_stack+12600,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+167912,int_stack+167156, 0.0, zero_stack, 1.0, int_stack+231586, 1.0, int_stack+245696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+168920,int_stack+167912, 0.0, zero_stack, 1.0, int_stack+233098, 1.0, int_stack+247208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 1.0, int_stack+853624, 1.0, int_stack+923662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+170216,int_stack+168920, 0.0, zero_stack, 1.0, int_stack+235114, 1.0, int_stack+249224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 1.0, int_stack+855892, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 1.0, int_stack+880462, 1.0, int_stack+947476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1540804,int_stack+1269904,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+172277,int_stack+171836, 0.0, zero_stack, 2.0, int_stack+510860, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+172865,int_stack+172277, 0.0, zero_stack, 2.0, int_stack+511301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 2.0, int_stack+884998, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+173621,int_stack+172865, 0.0, zero_stack, 2.0, int_stack+511889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+668080,int_stack+13923, 0.0, zero_stack, 2.0, int_stack+886321, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1269904,int_stack+15687, 0.0, zero_stack, 2.0, int_stack+888085, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+175154,int_stack+174566, 0.0, zero_stack, 2.0, int_stack+516320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+175938,int_stack+175154, 0.0, zero_stack, 2.0, int_stack+516908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 2.0, int_stack+890731, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+176946,int_stack+175938, 0.0, zero_stack, 2.0, int_stack+517692, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 2.0, int_stack+892495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1225948,int_stack+12600, 0.0, zero_stack, 2.0, int_stack+920134, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+164010,int_stack+1269904,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+178962,int_stack+178206, 0.0, zero_stack, 2.0, int_stack+245696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+179970,int_stack+178962, 0.0, zero_stack, 2.0, int_stack+247208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 0.0, zero_stack, 2.0, int_stack+923662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+181266,int_stack+179970, 0.0, zero_stack, 2.0, int_stack+249224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 0.0, zero_stack, 2.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1232986,int_stack+1224562, 0.0, zero_stack, 2.0, int_stack+947476, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1558444,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+183327,int_stack+182886, 1.0, int_stack+441180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528280,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+183915,int_stack+183327, 1.0, int_stack+441621, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528721,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 1.0, int_stack+611863, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+952012,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+668080,int_stack+184671,int_stack+183915, 1.0, int_stack+442209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529309,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+668080,int_stack+1271227, 1.0, int_stack+613186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+953335,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1312744,int_stack+1272991, 1.0, int_stack+614950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+955099,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+186204,int_stack+185616, 1.0, int_stack+446640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+534328,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+186988,int_stack+186204, 1.0, int_stack+447228, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535700,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 1.0, int_stack+631330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957745,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+187996,int_stack+186988, 1.0, int_stack+448012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+537492,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1316860,int_stack+1314508, 1.0, int_stack+633094, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+959509,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1225948,int_stack+1269904, 1.0, int_stack+635446, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987148,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1576084,int_stack+12600,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+668080,int_stack+191776,int_stack+190012, 1.0, int_stack+189256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260562,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1221538,int_stack+194080,int_stack+191776, 1.0, int_stack+190768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263082,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1224562,int_stack+1221538,int_stack+668080, 1.0, int_stack+644266, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+990676,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1229098,int_stack+195376,int_stack+194080, 1.0, int_stack+192784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265098,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1232986,int_stack+1229098,int_stack+1221538, 1.0, int_stack+670348, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+992944,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1232986,int_stack+1224562, 1.0, int_stack+673372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1017514,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+177240,int_stack+1269904,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+197437,int_stack+196996, 1.0, int_stack+458600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528280, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+198025,int_stack+197437, 1.0, int_stack+459041, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528721, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 1.0, int_stack+677908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+952012, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+198781,int_stack+198025, 1.0, int_stack+459629, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529309, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1272172,int_stack+1269904,int_stack+13923, 1.0, int_stack+679231, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+953335, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1221538,int_stack+1272172,int_stack+15687, 1.0, int_stack+680995, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+955099, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+200314,int_stack+199726, 1.0, int_stack+464060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+534328, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+201098,int_stack+200314, 1.0, int_stack+464648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535700, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 1.0, int_stack+683641, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957745, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+202106,int_stack+201098, 1.0, int_stack+465432, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+537492, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1225948,int_stack+1274020,int_stack+1271668, 1.0, int_stack+685405, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+959509, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1225948,int_stack+12600, 1.0, int_stack+713044, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987148, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+668080,int_stack+1269904,int_stack+1221538,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1221538,int_stack+205886,int_stack+204122, 1.0, int_stack+203366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260562, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1223806,int_stack+208190,int_stack+205886, 1.0, int_stack+204878, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263082, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1226830,int_stack+1223806,int_stack+1221538, 1.0, int_stack+716572, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+990676, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1231366,int_stack+209486,int_stack+208190, 1.0, int_stack+206894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265098, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+681310,int_stack+1231366,int_stack+1223806, 1.0, int_stack+718840, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+992944, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+681310,int_stack+1226830, 1.0, int_stack+743410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1017514, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1589314,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+211547,int_stack+211106, 1.0, int_stack+476020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528280, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+212135,int_stack+211547, 1.0, int_stack+476461, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+528721, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 1.0, int_stack+747946, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+952012, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1312744,int_stack+212891,int_stack+212135, 1.0, int_stack+477049, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+529309, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1315012,int_stack+1312744,int_stack+1271227, 1.0, int_stack+749269, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+953335, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+743410,int_stack+1315012,int_stack+1272991, 1.0, int_stack+751033, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+955099, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+214424,int_stack+213836, 1.0, int_stack+481480, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+534328, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+215208,int_stack+214424, 1.0, int_stack+482068, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+535700, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 1.0, int_stack+753679, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+957745, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+216216,int_stack+215208, 1.0, int_stack+482852, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+537492, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+747820,int_stack+1316860,int_stack+1314508, 1.0, int_stack+755443, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+959509, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+747820,int_stack+1269904, 1.0, int_stack+783082, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+987148, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+1221538,int_stack+12600,int_stack+743410,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+743410,int_stack+219996,int_stack+218232, 1.0, int_stack+217476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260562, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+745678,int_stack+222300,int_stack+219996, 1.0, int_stack+218988, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263082, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+748702,int_stack+745678,int_stack+743410, 1.0, int_stack+786610, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+990676, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+753238,int_stack+223596,int_stack+222300, 1.0, int_stack+221004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265098, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+783082,int_stack+753238,int_stack+745678, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+992944, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+783082,int_stack+748702, 1.0, int_stack+810424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+194880,int_stack+1269904,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+225657,int_stack+225216, 1.0, int_stack+493440, 0.0, zero_stack, 1.0, int_stack+528280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+226245,int_stack+225657, 1.0, int_stack+493881, 0.0, zero_stack, 1.0, int_stack+528721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 1.0, int_stack+814960, 0.0, zero_stack, 1.0, int_stack+952012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+227001,int_stack+226245, 1.0, int_stack+494469, 0.0, zero_stack, 1.0, int_stack+529309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1272172,int_stack+1269904,int_stack+13923, 1.0, int_stack+816283, 0.0, zero_stack, 1.0, int_stack+953335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+810424,int_stack+1272172,int_stack+15687, 1.0, int_stack+818047, 0.0, zero_stack, 1.0, int_stack+955099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+228534,int_stack+227946, 1.0, int_stack+498900, 0.0, zero_stack, 1.0, int_stack+534328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+229318,int_stack+228534, 1.0, int_stack+499488, 0.0, zero_stack, 1.0, int_stack+535700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 1.0, int_stack+820693, 0.0, zero_stack, 1.0, int_stack+957745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+230326,int_stack+229318, 1.0, int_stack+500272, 0.0, zero_stack, 1.0, int_stack+537492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+814834,int_stack+0,int_stack+1271668, 1.0, int_stack+822457, 0.0, zero_stack, 1.0, int_stack+959509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+814834,int_stack+12600, 1.0, int_stack+850096, 0.0, zero_stack, 1.0, int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+743410,int_stack+1269904,int_stack+810424,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+810424,int_stack+234106,int_stack+232342, 1.0, int_stack+231586, 0.0, zero_stack, 1.0, int_stack+260562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+236410,int_stack+234106, 1.0, int_stack+233098, 0.0, zero_stack, 1.0, int_stack+263082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+812692,int_stack+0,int_stack+810424, 1.0, int_stack+853624, 0.0, zero_stack, 1.0, int_stack+990676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+817228,int_stack+237706,int_stack+236410, 1.0, int_stack+235114, 0.0, zero_stack, 1.0, int_stack+265098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+783082,int_stack+817228,int_stack+0, 1.0, int_stack+855892, 0.0, zero_stack, 1.0, int_stack+992944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+783082,int_stack+812692, 1.0, int_stack+880462, 0.0, zero_stack, 1.0, int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+212520,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+239767,int_stack+239326, 1.0, int_stack+510860, 1.0, int_stack+528280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+240355,int_stack+239767, 1.0, int_stack+511301, 1.0, int_stack+528721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 1.0, int_stack+884998, 1.0, int_stack+952012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1312744,int_stack+241111,int_stack+240355, 1.0, int_stack+511889, 1.0, int_stack+529309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1315012,int_stack+1312744,int_stack+1271227, 1.0, int_stack+886321, 1.0, int_stack+953335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+880462,int_stack+1315012,int_stack+1272991, 1.0, int_stack+888085, 1.0, int_stack+955099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+242644,int_stack+242056, 1.0, int_stack+516320, 1.0, int_stack+534328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+243428,int_stack+242644, 1.0, int_stack+516908, 1.0, int_stack+535700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 1.0, int_stack+890731, 1.0, int_stack+957745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+244436,int_stack+243428, 1.0, int_stack+517692, 1.0, int_stack+537492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+884872,int_stack+0,int_stack+1314508, 1.0, int_stack+892495, 1.0, int_stack+959509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+884872,int_stack+1269904, 1.0, int_stack+920134, 1.0, int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+810424,int_stack+12600,int_stack+880462,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+880462,int_stack+248216,int_stack+246452, 1.0, int_stack+245696, 1.0, int_stack+260562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+250520,int_stack+248216, 1.0, int_stack+247208, 1.0, int_stack+263082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+882730,int_stack+0,int_stack+880462, 1.0, int_stack+923662, 1.0, int_stack+990676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+887266,int_stack+251816,int_stack+250520, 1.0, int_stack+249224, 1.0, int_stack+265098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+920134,int_stack+887266,int_stack+0, 1.0, int_stack+3024, 1.0, int_stack+992944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+920134,int_stack+882730, 1.0, int_stack+947476, 1.0, int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+230160,int_stack+1269904,int_stack+12600,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+253877,int_stack+253436, 2.0, int_stack+528280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+254465,int_stack+253877, 2.0, int_stack+528721, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 2.0, int_stack+952012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+255221,int_stack+254465, 2.0, int_stack+529309, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1272172,int_stack+1269904,int_stack+13923, 2.0, int_stack+953335, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+947476,int_stack+1272172,int_stack+15687, 2.0, int_stack+955099, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+256754,int_stack+256166, 2.0, int_stack+534328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+257538,int_stack+256754, 2.0, int_stack+535700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 2.0, int_stack+957745, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+258546,int_stack+257538, 2.0, int_stack+537492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+951886,int_stack+1274020,int_stack+1271668, 2.0, int_stack+959509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+951886,int_stack+12600, 2.0, int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+880462,int_stack+1269904,int_stack+947476,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+947476,int_stack+264090,int_stack+261318, 2.0, int_stack+260562, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+949744,int_stack+266394,int_stack+264090, 2.0, int_stack+263082, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+952768,int_stack+949744,int_stack+947476, 2.0, int_stack+990676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+957304,int_stack+267690,int_stack+266394, 2.0, int_stack+265098, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+957304,int_stack+949744, 2.0, int_stack+992944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+0,int_stack+952768, 2.0, int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+247800,int_stack+1312744,int_stack+1269904,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+269751,int_stack+269310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551140,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+270339,int_stack+269751, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551581,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+627802,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1312744,int_stack+271095,int_stack+270339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552169,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1315012,int_stack+1312744,int_stack+1271227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629125,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1017514,int_stack+1315012,int_stack+1272991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1022050,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+272628,int_stack+272040, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556600,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+273412,int_stack+272628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557188,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035658,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+274420,int_stack+273412, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557972,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+638974,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+0,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617596,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+947476,int_stack+12600,int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+623392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1017514,int_stack+276436,int_stack+275680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330930,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+277444,int_stack+276436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332442,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272928,int_stack+1269904,int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621124,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1017514,int_stack+278740,int_stack+277444, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334458,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+1017514,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6048,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+0,int_stack+1272928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606130,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1606954,int_stack+1312744,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+646702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+280801,int_stack+280360, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551140, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+281389,int_stack+280801, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551581, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+627802, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1312744,int_stack+282145,int_stack+281389, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552169, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1315012,int_stack+1312744,int_stack+13923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629125, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+1315012,int_stack+15687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1022050, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+283678,int_stack+283090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556600, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+284462,int_stack+283678, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557188, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035658, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+285470,int_stack+284462, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557972, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+638974, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1269904,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617596, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+265440,int_stack+1312744,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+689437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+287486,int_stack+286730, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330930, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+2268,int_stack+288494,int_stack+287486, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332442, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1017514,int_stack+2268,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621124, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12600,int_stack+289790,int_stack+288494, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334458, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+12600,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6048, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+987148,int_stack+1269904,int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606130, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1624594,int_stack+987148,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+724300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+291851,int_stack+291410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551140, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314067,int_stack+292439,int_stack+291851, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551581, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1315831,int_stack+1314067,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+627802, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+987148,int_stack+293195,int_stack+292439, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552169, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+989416,int_stack+987148,int_stack+1314067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629125, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+992944,int_stack+989416,int_stack+1315831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1022050, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+987148,int_stack+294728,int_stack+294140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556600, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+988912,int_stack+295512,int_stack+294728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557188, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1312744,int_stack+988912,int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035658, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316272,int_stack+296520,int_stack+295512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557972, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+1316272,int_stack+988912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+638974, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1269904,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617596, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+278670,int_stack+12600,int_stack+992944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+759475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+298536,int_stack+297780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330930, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1315012,int_stack+299544,int_stack+298536, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332442, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1017514,int_stack+1315012,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621124, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+300840,int_stack+299544, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334458, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+1269904,int_stack+1315012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6048, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+0,int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606130, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1642234,int_stack+1269904,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+791314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+302901,int_stack+302460, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+303489,int_stack+302901, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+551581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+304245,int_stack+303489, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+552169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1272172,int_stack+1269904,int_stack+13923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+629125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1017514,int_stack+1272172,int_stack+15687, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1022050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+305778,int_stack+305190, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+556600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+306562,int_stack+305778, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1035658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+307570,int_stack+306562, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+557972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+638974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+0,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+291900,int_stack+1269904,int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+826489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1017514,int_stack+309586,int_stack+308830, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+310594,int_stack+309586, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+332442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+12600,int_stack+1017514, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+621124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1017514,int_stack+311890,int_stack+310594, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+334458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+1017514,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+6048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+987148,int_stack+1312744,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+606130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1659874,int_stack+987148,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+861352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+313951,int_stack+313510, 0.0, zero_stack, 1.0, int_stack+551140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+314539,int_stack+313951, 0.0, zero_stack, 1.0, int_stack+551581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+987148,int_stack+315295,int_stack+314539, 0.0, zero_stack, 1.0, int_stack+552169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+989416,int_stack+987148,int_stack+1271227, 0.0, zero_stack, 1.0, int_stack+629125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+992944,int_stack+989416,int_stack+1272991, 0.0, zero_stack, 1.0, int_stack+1022050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+987148,int_stack+316828,int_stack+316240, 0.0, zero_stack, 1.0, int_stack+556600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+988912,int_stack+317612,int_stack+316828, 0.0, zero_stack, 1.0, int_stack+557188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+988912,int_stack+987148, 0.0, zero_stack, 1.0, int_stack+1035658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1273432,int_stack+318620,int_stack+317612, 0.0, zero_stack, 1.0, int_stack+557972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+1273432,int_stack+988912, 0.0, zero_stack, 1.0, int_stack+638974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+0,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+617596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+305130,int_stack+12600,int_stack+992944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+896527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+320636,int_stack+319880, 0.0, zero_stack, 1.0, int_stack+330930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1272172,int_stack+321644,int_stack+320636, 0.0, zero_stack, 1.0, int_stack+332442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1017514,int_stack+1272172,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+621124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+322940,int_stack+321644, 0.0, zero_stack, 1.0, int_stack+334458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+0,int_stack+1272172, 0.0, zero_stack, 1.0, int_stack+6048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+987148,int_stack+1017514, 0.0, zero_stack, 1.0, int_stack+606130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1677514,int_stack+1269904,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+928366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+325001,int_stack+324560, 1.0, int_stack+551140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+325589,int_stack+325001, 1.0, int_stack+551581, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 1.0, int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+326345,int_stack+325589, 1.0, int_stack+552169, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1272172,int_stack+1269904,int_stack+13923, 1.0, int_stack+629125, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+1272172,int_stack+15687, 1.0, int_stack+1022050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+327878,int_stack+327290, 1.0, int_stack+556600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+328662,int_stack+327878, 1.0, int_stack+557188, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+632212,int_stack+1271668,int_stack+1269904, 1.0, int_stack+1035658, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+329670,int_stack+328662, 1.0, int_stack+557972, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12600,int_stack+1274020,int_stack+1271668, 1.0, int_stack+638974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+12600,int_stack+632212, 1.0, int_stack+617596, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+632212,int_stack+1269904,int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+963541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+333450,int_stack+331686, 1.0, int_stack+330930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+335754,int_stack+333450, 1.0, int_stack+332442, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1017514,int_stack+12600,int_stack+627802, 1.0, int_stack+621124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+337050,int_stack+335754, 1.0, int_stack+334458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+627802,int_stack+12600, 1.0, int_stack+6048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+0,int_stack+1017514, 1.0, int_stack+606130, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+318360,int_stack+1312744,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+998404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+339111,int_stack+338670,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+339699,int_stack+339111,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1312744,int_stack+340455,int_stack+339699,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1315012,int_stack+1312744,int_stack+1271227,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+1315012,int_stack+1272991,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+341988,int_stack+341400,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+342772,int_stack+341988,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+343780,int_stack+342772,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+606130,int_stack+1316860,int_stack+1314508,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+606130,int_stack+1269904,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+606130,int_stack+12600,int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1024696, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+345796,int_stack+345040,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+346804,int_stack+345796,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272928,int_stack+1269904,int_stack+627802,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+348100,int_stack+346804,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+627802,int_stack+1269904,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+0,int_stack+1312744,int_stack+1272928,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1695154,int_stack+0,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1070416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+350161,int_stack+349720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+568560,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+350749,int_stack+350161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569001,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089526,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+351505,int_stack+350749, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569589,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2268,int_stack+0,int_stack+13923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1090849,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+2268,int_stack+15687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1092613,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+0,int_stack+353038,int_stack+352450, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574020,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1764,int_stack+353822,int_stack+353038, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574608,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+4116,int_stack+1764,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1095259,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+12600,int_stack+354830,int_stack+353822, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575392,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+12600,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1097023,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1312744,int_stack+4116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9072,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+336000,int_stack+12600,int_stack+627802, 0.0, zero_stack, 1.0, int_stack+623392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+356846,int_stack+356090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411340,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1312744,int_stack+357854,int_stack+356846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412852,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1315768,int_stack+1312744,int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1124662,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+359150,int_stack+357854, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414868,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+627802,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1126930,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+0,int_stack+1315768, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1151500,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1712794,int_stack+1269904,int_stack+12600, 0.0, zero_stack, 1.0, int_stack+646702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+361211,int_stack+360770, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+568560, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+361799,int_stack+361211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569001, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089526, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+362555,int_stack+361799, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569589, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1272172,int_stack+1269904,int_stack+13923, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1090849, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+1272172,int_stack+15687, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1092613, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+364088,int_stack+363500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574020, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+364872,int_stack+364088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574608, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1095259, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+365880,int_stack+364872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575392, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+0,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1097023, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+0,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9072, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+349230,int_stack+1269904,int_stack+627802, 0.0, zero_stack, 1.0, int_stack+689437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+367896,int_stack+367140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411340, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+368904,int_stack+367896, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412852, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+0,int_stack+12600,int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1124662, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+370200,int_stack+368904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414868, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+627802,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1126930, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+987148,int_stack+1312744,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1151500, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1730434,int_stack+987148,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+724300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+372261,int_stack+371820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+568560, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+372849,int_stack+372261, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569001, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089526, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+987148,int_stack+373605,int_stack+372849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569589, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+989416,int_stack+987148,int_stack+1271227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1090849, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+989416,int_stack+1272991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1092613, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+987148,int_stack+375138,int_stack+374550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574020, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+988912,int_stack+375922,int_stack+375138, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574608, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+991264,int_stack+988912,int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1095259, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+994792,int_stack+376930,int_stack+375922, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575392, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+994792,int_stack+988912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1097023, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+1269904,int_stack+991264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9072, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+362460,int_stack+12600,int_stack+627802, 0.0, zero_stack, 1.0, int_stack+759475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+378946,int_stack+378190, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411340, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+379954,int_stack+378946, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412852, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272928,int_stack+1269904,int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1124662, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+381250,int_stack+379954, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414868, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+627802,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1126930, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+987148,int_stack+1272928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1151500, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1748074,int_stack+1312744,int_stack+12600, 0.0, zero_stack, 1.0, int_stack+791314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+383311,int_stack+382870, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+568560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+383899,int_stack+383311, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1089526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1312744,int_stack+384655,int_stack+383899, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+569589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1315012,int_stack+1312744,int_stack+13923, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1090849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+1315012,int_stack+15687, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1092613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+386188,int_stack+385600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+386972,int_stack+386188, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+574608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+12600,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1095259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+387980,int_stack+386972, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+575392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1097023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+987148,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+375690,int_stack+1312744,int_stack+627802, 0.0, zero_stack, 1.0, int_stack+826489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+389996,int_stack+389240, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+12600,int_stack+391004,int_stack+389996, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+412852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+987148,int_stack+12600,int_stack+627802, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1124662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+392300,int_stack+391004, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+414868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+991684,int_stack+627802,int_stack+12600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1126930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+991684,int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1151500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1765714,int_stack+1269904,int_stack+1312744, 0.0, zero_stack, 1.0, int_stack+861352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+394361,int_stack+393920, 0.0, zero_stack, 1.0, int_stack+568560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314067,int_stack+394949,int_stack+394361, 0.0, zero_stack, 1.0, int_stack+569001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1315831,int_stack+1314067,int_stack+1312744, 0.0, zero_stack, 1.0, int_stack+1089526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+395705,int_stack+394949, 0.0, zero_stack, 1.0, int_stack+569589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1272172,int_stack+1269904,int_stack+1314067, 0.0, zero_stack, 1.0, int_stack+1090849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+1272172,int_stack+1315831, 0.0, zero_stack, 1.0, int_stack+1092613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+397238,int_stack+396650, 0.0, zero_stack, 1.0, int_stack+574020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+398022,int_stack+397238, 0.0, zero_stack, 1.0, int_stack+574608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1312744,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+1095259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+399030,int_stack+398022, 0.0, zero_stack, 1.0, int_stack+575392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 1.0, int_stack+1097023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+12600,int_stack+987148,int_stack+1312744, 0.0, zero_stack, 1.0, int_stack+9072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1783354,int_stack+12600,int_stack+627802, 0.0, zero_stack, 1.0, int_stack+896527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+401046,int_stack+400290, 0.0, zero_stack, 1.0, int_stack+411340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1312744,int_stack+402054,int_stack+401046, 0.0, zero_stack, 1.0, int_stack+412852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1315768,int_stack+1312744,int_stack+627802, 0.0, zero_stack, 1.0, int_stack+1124662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+403350,int_stack+402054, 0.0, zero_stack, 1.0, int_stack+414868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+627802,int_stack+1312744, 0.0, zero_stack, 1.0, int_stack+1126930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+987148,int_stack+1315768, 0.0, zero_stack, 1.0, int_stack+1151500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1796584,int_stack+1269904,int_stack+12600, 0.0, zero_stack, 1.0, int_stack+928366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+12600,int_stack+405411,int_stack+404970, 1.0, int_stack+568560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13923,int_stack+405999,int_stack+405411, 1.0, int_stack+569001, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15687,int_stack+13923,int_stack+12600, 1.0, int_stack+1089526, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+406755,int_stack+405999, 1.0, int_stack+569589, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1272172,int_stack+1269904,int_stack+13923, 1.0, int_stack+1090849, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+1272172,int_stack+15687, 1.0, int_stack+1092613, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+408288,int_stack+407700, 1.0, int_stack+574020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+409072,int_stack+408288, 1.0, int_stack+574608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1089526,int_stack+1271668,int_stack+1269904, 1.0, int_stack+1095259, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+410080,int_stack+409072, 1.0, int_stack+575392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+12600,int_stack+1274020,int_stack+1271668, 1.0, int_stack+1097023, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+12600,int_stack+1089526, 1.0, int_stack+9072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+1269904,int_stack+627802, 0.0, zero_stack, 1.0, int_stack+963541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+413860,int_stack+412096, 1.0, int_stack+411340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1089526,int_stack+416164,int_stack+413860, 1.0, int_stack+412852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1092550,int_stack+1089526,int_stack+627802, 1.0, int_stack+1124662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+417460,int_stack+416164, 1.0, int_stack+414868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+627802,int_stack+1089526, 1.0, int_stack+1126930, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+987148,int_stack+1092550, 1.0, int_stack+1151500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+388920,int_stack+1312744,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+998404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+419521,int_stack+419080,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+420109,int_stack+419521,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1312744,int_stack+420865,int_stack+420109,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1315012,int_stack+1312744,int_stack+1271227,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+1315012,int_stack+1272991,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+422398,int_stack+421810,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+423182,int_stack+422398,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+424190,int_stack+423182,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+1316860,int_stack+1314508,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+987148,int_stack+1269904,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+406560,int_stack+1312744,int_stack+627802, 0.0, zero_stack, 1.0, int_stack+1024696, 1.0, int_stack+1101055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+426206,int_stack+425450,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+427214,int_stack+426206,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272928,int_stack+1269904,int_stack+627802,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+428510,int_stack+427214,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+627802,int_stack+1269904,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1089526,int_stack+987148,int_stack+1272928,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1814224,int_stack+1089526,int_stack+1312744, 0.0, zero_stack, 1.0, int_stack+1070416, 1.0, int_stack+1132390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+430571,int_stack+430130,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1314067,int_stack+431159,int_stack+430571,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1315831,int_stack+1314067,int_stack+1312744,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1089526,int_stack+431915,int_stack+431159,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1091794,int_stack+1089526,int_stack+1314067,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+1091794,int_stack+1315831,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1089526,int_stack+433448,int_stack+432860,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1091290,int_stack+434232,int_stack+433448,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1093642,int_stack+1091290,int_stack+1089526,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1097170,int_stack+435240,int_stack+434232,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+1097170,int_stack+1091290,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+987148,int_stack+1312744,int_stack+1093642,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+419790,int_stack+987148,int_stack+627802, 0.0, zero_stack, 2.0, int_stack+1101055, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+627802,int_stack+437256,int_stack+436500,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1312744,int_stack+438264,int_stack+437256,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1315768,int_stack+1312744,int_stack+627802,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+627802,int_stack+439560,int_stack+438264,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1089526,int_stack+627802,int_stack+1312744,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1089526,int_stack+1315768,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1831864,int_stack+1269904,int_stack+987148, 0.0, zero_stack, 2.0, int_stack+1132390, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+987148,int_stack+444351,int_stack+443910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588710,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+988471,int_stack+444939,int_stack+444351, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589151,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+990235,int_stack+988471,int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1156036,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+992881,int_stack+445695,int_stack+444939, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589739,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+992881,int_stack+988471, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1157359,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+627802,int_stack+1269904,int_stack+990235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1159123,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+450868,int_stack+450280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+594170,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271668,int_stack+451652,int_stack+450868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+594758,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+987148,int_stack+1271668,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1161769,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1274020,int_stack+452660,int_stack+451652, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595542,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+990676,int_stack+1274020,int_stack+1271668, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1163533,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+990676,int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191172,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+433020,int_stack+1269904,int_stack+627802, 1.0, int_stack+623392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+987148,int_stack+454676,int_stack+453920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543400,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+989416,int_stack+455684,int_stack+454676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544912,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1151500,int_stack+989416,int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665812,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+992440,int_stack+456980,int_stack+455684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546928,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1089526,int_stack+992440,int_stack+989416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1194700,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1089526,int_stack+1151500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1197724,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1849504,int_stack+1312744,int_stack+1269904, 1.0, int_stack+646702, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+461771,int_stack+461330, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588710, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+462359,int_stack+461771, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589151, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1156036, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1312744,int_stack+463115,int_stack+462359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589739, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1315012,int_stack+1312744,int_stack+1271227, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1157359, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1151500,int_stack+1315012,int_stack+1272991, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1159123, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+468288,int_stack+467700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+594170, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314508,int_stack+469072,int_stack+468288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+594758, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1269904,int_stack+1314508,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1161769, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316860,int_stack+470080,int_stack+469072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595542, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1089526,int_stack+1316860,int_stack+1314508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1163533, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1089526,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191172, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+446250,int_stack+1312744,int_stack+1151500, 1.0, int_stack+689437, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1151500,int_stack+472096,int_stack+471340, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543400, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+473104,int_stack+472096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544912, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272928,int_stack+1269904,int_stack+1151500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1151500,int_stack+474400,int_stack+473104, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546928, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1089526,int_stack+1151500,int_stack+1269904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1194700, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+987148,int_stack+1089526,int_stack+1272928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1197724, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+459480,int_stack+987148,int_stack+1312744, 1.0, int_stack+724300, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+479191,int_stack+478750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588710, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314067,int_stack+479779,int_stack+479191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589151, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1315831,int_stack+1314067,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1156036, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+987148,int_stack+480535,int_stack+479779, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589739, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+989416,int_stack+987148,int_stack+1314067, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1157359, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+992944,int_stack+989416,int_stack+1315831, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1159123, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+987148,int_stack+485708,int_stack+485120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+594170, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+988912,int_stack+486492,int_stack+485708, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+594758, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1312744,int_stack+988912,int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1161769, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1316272,int_stack+487500,int_stack+486492, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595542, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1089526,int_stack+1316272,int_stack+988912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1163533, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1094230,int_stack+1089526,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191172, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+681310,int_stack+1094230,int_stack+992944, 1.0, int_stack+759475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+489516,int_stack+488760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543400, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1315012,int_stack+490524,int_stack+489516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544912, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1151500,int_stack+1315012,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1089526,int_stack+491820,int_stack+490524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546928, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+1089526,int_stack+1315012, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1194700, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+987148,int_stack+1151500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1197724, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+477120,int_stack+1312744,int_stack+1094230, 1.0, int_stack+791314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1312744,int_stack+496611,int_stack+496170, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+588710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1314067,int_stack+497199,int_stack+496611, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1315831,int_stack+1314067,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1156036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1151500,int_stack+497955,int_stack+497199, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+589739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+1151500,int_stack+1314067, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1157359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1151500,int_stack+987148,int_stack+1315831, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1159123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+987148,int_stack+503128,int_stack+502540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+594170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+988912,int_stack+503912,int_stack+503128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+594758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+991264,int_stack+988912,int_stack+987148, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1161769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+994792,int_stack+504920,int_stack+503912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+595542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+994792,int_stack+988912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1163533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1089526,int_stack+1312744,int_stack+991264, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1191172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+783082,int_stack+1089526,int_stack+1151500, 1.0, int_stack+826489, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1151500,int_stack+506936,int_stack+506180, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+543400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1312744,int_stack+507944,int_stack+506936, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+544912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1315768,int_stack+1312744,int_stack+1151500, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1151500,int_stack+509240,int_stack+507944, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+546928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+1151500,int_stack+1312744, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1194700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+987148,int_stack+1315768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1197724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+494760,int_stack+1269904,int_stack+1089526, 1.0, int_stack+861352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1089526,int_stack+514031,int_stack+513590, 0.0, zero_stack, 1.0, int_stack+588710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1090849,int_stack+514619,int_stack+514031, 0.0, zero_stack, 1.0, int_stack+589151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1092613,int_stack+1090849,int_stack+1089526, 0.0, zero_stack, 1.0, int_stack+1156036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1095259,int_stack+515375,int_stack+514619, 0.0, zero_stack, 1.0, int_stack+589739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1097527,int_stack+1095259,int_stack+1090849, 0.0, zero_stack, 1.0, int_stack+1157359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1097527,int_stack+1092613, 0.0, zero_stack, 1.0, int_stack+1159123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1089526,int_stack+520548,int_stack+519960, 0.0, zero_stack, 1.0, int_stack+594170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1091290,int_stack+521332,int_stack+520548, 0.0, zero_stack, 1.0, int_stack+594758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1093642,int_stack+1091290,int_stack+1089526, 0.0, zero_stack, 1.0, int_stack+1161769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1097170,int_stack+522340,int_stack+521332, 0.0, zero_stack, 1.0, int_stack+595542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+987148,int_stack+1097170,int_stack+1091290, 0.0, zero_stack, 1.0, int_stack+1163533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+991852,int_stack+987148,int_stack+1093642, 0.0, zero_stack, 1.0, int_stack+1191172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+850096,int_stack+991852,int_stack+1269904, 1.0, int_stack+896527, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+524356,int_stack+523600, 0.0, zero_stack, 1.0, int_stack+543400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1272172,int_stack+525364,int_stack+524356, 0.0, zero_stack, 1.0, int_stack+544912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1151500,int_stack+1272172,int_stack+1269904, 0.0, zero_stack, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+987148,int_stack+526660,int_stack+525364, 0.0, zero_stack, 1.0, int_stack+546928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1089526,int_stack+987148,int_stack+1272172, 0.0, zero_stack, 1.0, int_stack+1194700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1089526,int_stack+1151500, 0.0, zero_stack, 1.0, int_stack+1197724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+512400,int_stack+1269904,int_stack+991852, 1.0, int_stack+928366, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+531451,int_stack+531010, 1.0, int_stack+588710, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+532039,int_stack+531451, 1.0, int_stack+589151, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904, 1.0, int_stack+1156036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1151500,int_stack+532795,int_stack+532039, 1.0, int_stack+589739, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1153768,int_stack+1151500,int_stack+1271227, 1.0, int_stack+1157359, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1089526,int_stack+1153768,int_stack+1272991, 1.0, int_stack+1159123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1151500,int_stack+540348,int_stack+539760, 1.0, int_stack+594170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1153264,int_stack+541132,int_stack+540348, 1.0, int_stack+594758, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1155616,int_stack+1153264,int_stack+1151500, 1.0, int_stack+1161769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1159144,int_stack+542140,int_stack+541132, 1.0, int_stack+595542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1269904,int_stack+1159144,int_stack+1153264, 1.0, int_stack+1163533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1159144,int_stack+1269904,int_stack+1155616, 1.0, int_stack+1191172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+920134,int_stack+1159144,int_stack+1089526, 1.0, int_stack+963541, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+1089526,int_stack+545920,int_stack+544156, 1.0, int_stack+543400, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1091794,int_stack+548224,int_stack+545920, 1.0, int_stack+544912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1094818,int_stack+1091794,int_stack+1089526, 1.0, int_stack+665812, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1269904,int_stack+549520,int_stack+548224, 1.0, int_stack+546928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1151500,int_stack+1269904,int_stack+1091794, 1.0, int_stack+1194700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1151500,int_stack+1094818, 1.0, int_stack+1197724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+530040,int_stack+1269904,int_stack+1159144, 1.0, int_stack+998404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+554311,int_stack+553870,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+554899,int_stack+554311,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+665812,int_stack+555655,int_stack+554899,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1151500,int_stack+665812,int_stack+1271227,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1155028,int_stack+1151500,int_stack+1272991,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1151500,int_stack+560828,int_stack+560240,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+561612,int_stack+560828,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272256,int_stack+1269904,int_stack+1151500,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1151500,int_stack+562620,int_stack+561612,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1159438,int_stack+1151500,int_stack+1269904,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1089526,int_stack+1159438,int_stack+1272256,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+987148,int_stack+1089526,int_stack+1155028, 1.0, int_stack+1024696, 0.0, zero_stack, 1.0, int_stack+1167565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+665812,int_stack+564636,int_stack+563880,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+565644,int_stack+564636,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272928,int_stack+1269904,int_stack+665812,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1151500,int_stack+566940,int_stack+565644,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1155388,int_stack+1151500,int_stack+1269904,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1312744,int_stack+1155388,int_stack+1272928,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1017514,int_stack+1312744,int_stack+1089526, 1.0, int_stack+1070416, 0.0, zero_stack, 1.0, int_stack+1202428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1070416,int_stack+571731,int_stack+571290,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1071739,int_stack+572319,int_stack+571731,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1073503,int_stack+1071739,int_stack+1070416,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+665812,int_stack+573075,int_stack+572319,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1089526,int_stack+665812,int_stack+1071739,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1093054,int_stack+1089526,int_stack+1073503,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1089526,int_stack+578248,int_stack+577660,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1070416,int_stack+579032,int_stack+578248,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1072768,int_stack+1070416,int_stack+1089526,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1089526,int_stack+580040,int_stack+579032,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1312744,int_stack+1089526,int_stack+1070416,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1269904,int_stack+1312744,int_stack+1072768,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1151500,int_stack+1269904,int_stack+1093054, 1.0, int_stack+1101055, 1.0, int_stack+1167565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+665812,int_stack+582056,int_stack+581300,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1312744,int_stack+583064,int_stack+582056,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1315768,int_stack+1312744,int_stack+665812,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1070416,int_stack+584360,int_stack+583064,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1089526,int_stack+1070416,int_stack+1312744,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1095574,int_stack+1089526,int_stack+1315768,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+547680,int_stack+1095574,int_stack+1269904, 1.0, int_stack+1132390, 1.0, int_stack+1202428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1269904,int_stack+591881,int_stack+591440,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1271227,int_stack+592469,int_stack+591881,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272991,int_stack+1271227,int_stack+1269904,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+665812,int_stack+593225,int_stack+592469,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1089526,int_stack+665812,int_stack+1271227,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1093054,int_stack+1089526,int_stack+1272991,21);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+1089526,int_stack+598398,int_stack+597810,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+599182,int_stack+598398,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272256,int_stack+1269904,int_stack+1089526,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1089526,int_stack+600190,int_stack+599182,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1097464,int_stack+1089526,int_stack+1269904,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1070416,int_stack+1097464,int_stack+1272256,28);
 /*--- compute (hp|hf) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+1124662,int_stack+1070416,int_stack+1093054, 2.0, int_stack+1167565, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+665812,int_stack+602206,int_stack+601450,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1269904,int_stack+603214,int_stack+602206,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+1272928,int_stack+1269904,int_stack+665812,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1089526,int_stack+604510,int_stack+603214,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+1093414,int_stack+1089526,int_stack+1269904,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+1099462,int_stack+1093414,int_stack+1272928,36);
 /*--- compute (ip|hf) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+565320,int_stack+1099462,int_stack+1070416, 2.0, int_stack+1202428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1867144,int_stack+695404,int_stack+652582,210);
     Libderiv->ABCD[11] = int_stack + 1867144;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+694540,int_stack+765442,int_stack+730180,210);
     Libderiv->ABCD[10] = int_stack + 694540;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1893604,int_stack+832456,int_stack+797194,210);
     Libderiv->ABCD[9] = int_stack + 1893604;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1920064,int_stack+902494,int_stack+867232,210);
     Libderiv->ABCD[8] = int_stack + 1920064;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1946524,int_stack+969508,int_stack+934246,210);
     Libderiv->ABCD[7] = int_stack + 1946524;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1972984,int_stack+1039546,int_stack+1004284,210);
     Libderiv->ABCD[6] = int_stack + 1972984;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1999444,int_stack+1107022,int_stack+1076296, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1057186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[2] = int_stack + 1999444;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1089526,int_stack+1173532,int_stack+1138270, 0.0, zero_stack, 1.0, int_stack+1057186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[1] = int_stack + 1089526;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1164730,int_stack+1239034,int_stack+1208308, 1.0, int_stack+1057186, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[0] = int_stack + 1164730;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1035154,int_stack+1277464,int_stack+1256674,210);
     Libderiv->ABCD[155] = int_stack + 1035154;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1234768,int_stack+1295104,int_stack+18480,210);
     Libderiv->ABCD[143] = int_stack + 1234768;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1261228,int_stack+1320304,int_stack+31710,210);
     Libderiv->ABCD[142] = int_stack + 1261228;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+13230,int_stack+1351174,int_stack+1337944,210);
     Libderiv->ABCD[131] = int_stack + 13230;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1287688,int_stack+1368814,int_stack+44940,210);
     Libderiv->ABCD[130] = int_stack + 1287688;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1314148,int_stack+1386454,int_stack+58170,210);
     Libderiv->ABCD[129] = int_stack + 1314148;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+39690,int_stack+1404094,int_stack+71400,210);
     Libderiv->ABCD[119] = int_stack + 39690;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1340608,int_stack+1421734,int_stack+84630,210);
     Libderiv->ABCD[118] = int_stack + 1340608;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+66150,int_stack+1439374,int_stack+97860,210);
     Libderiv->ABCD[117] = int_stack + 66150;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1367068,int_stack+1470244,int_stack+1457014,210);
     Libderiv->ABCD[116] = int_stack + 1367068;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1393528,int_stack+1487884,int_stack+111090,210);
     Libderiv->ABCD[107] = int_stack + 1393528;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+92610,int_stack+1505524,int_stack+124320,210);
     Libderiv->ABCD[106] = int_stack + 92610;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1419988,int_stack+1523164,int_stack+137550,210);
     Libderiv->ABCD[105] = int_stack + 1419988;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+119070,int_stack+1540804,int_stack+150780,210);
     Libderiv->ABCD[104] = int_stack + 119070;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1446448,int_stack+1558444,int_stack+164010,210);
     Libderiv->ABCD[103] = int_stack + 1446448;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+145530,int_stack+177240,int_stack+1576084,210);
     Libderiv->ABCD[95] = int_stack + 145530;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1472908,int_stack+1589314,int_stack+668080,210);
     Libderiv->ABCD[94] = int_stack + 1472908;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1499368,int_stack+194880,int_stack+1221538,210);
     Libderiv->ABCD[93] = int_stack + 1499368;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+171990,int_stack+212520,int_stack+743410,210);
     Libderiv->ABCD[92] = int_stack + 171990;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+743410,int_stack+230160,int_stack+810424,210);
     Libderiv->ABCD[91] = int_stack + 743410;
 /*--- compute (hd|hf) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+810424,int_stack+247800,int_stack+880462,210);
     Libderiv->ABCD[90] = int_stack + 810424;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+880462,int_stack+1606954,int_stack+947476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+652582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[47] = int_stack + 880462;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+947476,int_stack+1624594,int_stack+265440, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+730180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[46] = int_stack + 947476;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+198450,int_stack+1642234,int_stack+278670, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+797194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[45] = int_stack + 198450;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+224910,int_stack+1659874,int_stack+291900, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+867232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[44] = int_stack + 224910;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+251370,int_stack+1677514,int_stack+305130, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+934246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[43] = int_stack + 251370;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+277830,int_stack+318360,int_stack+632212, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1004284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[42] = int_stack + 277830;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+304290,int_stack+1695154,int_stack+606130, 0.0, zero_stack, 0.0, zero_stack, 2.0, int_stack+1076296, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[38] = int_stack + 304290;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1525828,int_stack+1712794,int_stack+336000, 0.0, zero_stack, 1.0, int_stack+652582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[35] = int_stack + 1525828;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1552288,int_stack+1730434,int_stack+349230, 0.0, zero_stack, 1.0, int_stack+730180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[34] = int_stack + 1552288;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+330750,int_stack+1748074,int_stack+362460, 0.0, zero_stack, 1.0, int_stack+797194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[33] = int_stack + 330750;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1578748,int_stack+1765714,int_stack+375690, 0.0, zero_stack, 1.0, int_stack+867232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[32] = int_stack + 1578748;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+357210,int_stack+1796584,int_stack+1783354, 0.0, zero_stack, 1.0, int_stack+934246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[31] = int_stack + 357210;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1605208,int_stack+388920,int_stack+0, 0.0, zero_stack, 1.0, int_stack+1004284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[30] = int_stack + 1605208;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1631668,int_stack+1814224,int_stack+406560, 0.0, zero_stack, 1.0, int_stack+1076296, 1.0, int_stack+1138270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[26] = int_stack + 1631668;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+383670,int_stack+1831864,int_stack+419790, 0.0, zero_stack, 2.0, int_stack+1138270, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[25] = int_stack + 383670;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1658128,int_stack+1849504,int_stack+433020, 1.0, int_stack+652582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[23] = int_stack + 1658128;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+410130,int_stack+459480,int_stack+446250, 1.0, int_stack+730180, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[22] = int_stack + 410130;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+436590,int_stack+477120,int_stack+681310, 1.0, int_stack+797194, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[21] = int_stack + 436590;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+463050,int_stack+494760,int_stack+783082, 1.0, int_stack+867232, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[20] = int_stack + 463050;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+769870,int_stack+512400,int_stack+850096, 1.0, int_stack+934246, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[19] = int_stack + 769870;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+836884,int_stack+530040,int_stack+920134, 1.0, int_stack+1004284, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[18] = int_stack + 836884;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+906922,int_stack+1017514,int_stack+987148, 1.0, int_stack+1076296, 0.0, zero_stack, 1.0, int_stack+1208308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[14] = int_stack + 906922;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+973936,int_stack+547680,int_stack+1151500, 1.0, int_stack+1138270, 1.0, int_stack+1208308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[13] = int_stack + 973936;
 /*--- compute (hd|hf) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1000396,int_stack+565320,int_stack+1124662, 2.0, int_stack+1208308, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,210);
     Libderiv->ABCD[12] = int_stack + 1000396;

}
