/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gfhh(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gf|hh) integrals */

void d1hrr_order_gfhh(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][5][11] = int_stack + 0;
 Libderiv->deriv_classes[4][6][11] = int_stack + 315;
 Libderiv->deriv_classes[4][7][11] = int_stack + 735;
 Libderiv->deriv_classes[4][8][11] = int_stack + 1275;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1950;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2775;
 Libderiv->deriv_classes[5][5][11] = int_stack + 3765;
 Libderiv->deriv_classes[5][6][11] = int_stack + 4206;
 Libderiv->deriv_classes[5][7][11] = int_stack + 4794;
 Libderiv->deriv_classes[5][8][11] = int_stack + 5550;
 Libderiv->deriv_classes[5][9][11] = int_stack + 6495;
 Libderiv->deriv_classes[5][10][11] = int_stack + 7650;
 Libderiv->deriv_classes[6][5][11] = int_stack + 9036;
 Libderiv->deriv_classes[6][6][11] = int_stack + 9624;
 Libderiv->deriv_classes[6][7][11] = int_stack + 10408;
 Libderiv->deriv_classes[6][8][11] = int_stack + 11416;
 Libderiv->deriv_classes[6][9][11] = int_stack + 12676;
 Libderiv->deriv_classes[6][10][11] = int_stack + 14216;
 Libderiv->deriv_classes[7][5][11] = int_stack + 16064;
 Libderiv->deriv_classes[7][6][11] = int_stack + 16820;
 Libderiv->deriv_classes[7][7][11] = int_stack + 17828;
 Libderiv->deriv_classes[7][8][11] = int_stack + 19124;
 Libderiv->deriv_classes[7][9][11] = int_stack + 20744;
 Libderiv->deriv_classes[7][10][11] = int_stack + 22724;
 Libderiv->deriv_classes[4][5][10] = int_stack + 25100;
 Libderiv->deriv_classes[4][6][10] = int_stack + 25415;
 Libderiv->deriv_classes[4][7][10] = int_stack + 25835;
 Libderiv->deriv_classes[4][8][10] = int_stack + 26375;
 Libderiv->deriv_classes[4][9][10] = int_stack + 27050;
 Libderiv->deriv_classes[4][10][10] = int_stack + 27875;
 Libderiv->deriv_classes[5][5][10] = int_stack + 28865;
 Libderiv->deriv_classes[5][6][10] = int_stack + 29306;
 Libderiv->deriv_classes[5][7][10] = int_stack + 29894;
 Libderiv->deriv_classes[5][8][10] = int_stack + 30650;
 Libderiv->deriv_classes[5][9][10] = int_stack + 31595;
 Libderiv->deriv_classes[5][10][10] = int_stack + 32750;
 Libderiv->deriv_classes[6][5][10] = int_stack + 34136;
 Libderiv->deriv_classes[6][6][10] = int_stack + 34724;
 Libderiv->deriv_classes[6][7][10] = int_stack + 35508;
 Libderiv->deriv_classes[6][8][10] = int_stack + 36516;
 Libderiv->deriv_classes[6][9][10] = int_stack + 37776;
 Libderiv->deriv_classes[6][10][10] = int_stack + 39316;
 Libderiv->deriv_classes[7][5][10] = int_stack + 41164;
 Libderiv->deriv_classes[7][6][10] = int_stack + 41920;
 Libderiv->deriv_classes[7][7][10] = int_stack + 42928;
 Libderiv->deriv_classes[7][8][10] = int_stack + 44224;
 Libderiv->deriv_classes[7][9][10] = int_stack + 45844;
 Libderiv->deriv_classes[7][10][10] = int_stack + 47824;
 Libderiv->deriv_classes[4][5][9] = int_stack + 50200;
 Libderiv->deriv_classes[4][6][9] = int_stack + 50515;
 Libderiv->deriv_classes[4][7][9] = int_stack + 50935;
 Libderiv->deriv_classes[4][8][9] = int_stack + 51475;
 Libderiv->deriv_classes[4][9][9] = int_stack + 52150;
 Libderiv->deriv_classes[4][10][9] = int_stack + 52975;
 Libderiv->deriv_classes[5][5][9] = int_stack + 53965;
 Libderiv->deriv_classes[5][6][9] = int_stack + 54406;
 Libderiv->deriv_classes[5][7][9] = int_stack + 54994;
 Libderiv->deriv_classes[5][8][9] = int_stack + 55750;
 Libderiv->deriv_classes[5][9][9] = int_stack + 56695;
 Libderiv->deriv_classes[5][10][9] = int_stack + 57850;
 Libderiv->deriv_classes[6][5][9] = int_stack + 59236;
 Libderiv->deriv_classes[6][6][9] = int_stack + 59824;
 Libderiv->deriv_classes[6][7][9] = int_stack + 60608;
 Libderiv->deriv_classes[6][8][9] = int_stack + 61616;
 Libderiv->deriv_classes[6][9][9] = int_stack + 62876;
 Libderiv->deriv_classes[6][10][9] = int_stack + 64416;
 Libderiv->deriv_classes[7][5][9] = int_stack + 66264;
 Libderiv->deriv_classes[7][6][9] = int_stack + 67020;
 Libderiv->deriv_classes[7][7][9] = int_stack + 68028;
 Libderiv->deriv_classes[7][8][9] = int_stack + 69324;
 Libderiv->deriv_classes[7][9][9] = int_stack + 70944;
 Libderiv->deriv_classes[7][10][9] = int_stack + 72924;
 Libderiv->deriv_classes[4][5][8] = int_stack + 75300;
 Libderiv->deriv_classes[4][6][8] = int_stack + 75615;
 Libderiv->deriv_classes[4][7][8] = int_stack + 76035;
 Libderiv->deriv_classes[4][8][8] = int_stack + 76575;
 Libderiv->deriv_classes[4][9][8] = int_stack + 77250;
 Libderiv->deriv_classes[4][10][8] = int_stack + 78075;
 Libderiv->deriv_classes[5][5][8] = int_stack + 79065;
 Libderiv->deriv_classes[5][6][8] = int_stack + 79506;
 Libderiv->deriv_classes[5][7][8] = int_stack + 80094;
 Libderiv->deriv_classes[5][8][8] = int_stack + 80850;
 Libderiv->deriv_classes[5][9][8] = int_stack + 81795;
 Libderiv->deriv_classes[5][10][8] = int_stack + 82950;
 Libderiv->deriv_classes[6][5][8] = int_stack + 84336;
 Libderiv->deriv_classes[6][6][8] = int_stack + 84924;
 Libderiv->deriv_classes[6][7][8] = int_stack + 85708;
 Libderiv->deriv_classes[6][8][8] = int_stack + 86716;
 Libderiv->deriv_classes[6][9][8] = int_stack + 87976;
 Libderiv->deriv_classes[6][10][8] = int_stack + 89516;
 Libderiv->deriv_classes[7][5][8] = int_stack + 91364;
 Libderiv->deriv_classes[7][6][8] = int_stack + 92120;
 Libderiv->deriv_classes[7][7][8] = int_stack + 93128;
 Libderiv->deriv_classes[7][8][8] = int_stack + 94424;
 Libderiv->deriv_classes[7][9][8] = int_stack + 96044;
 Libderiv->deriv_classes[7][10][8] = int_stack + 98024;
 Libderiv->deriv_classes[4][5][7] = int_stack + 100400;
 Libderiv->deriv_classes[4][6][7] = int_stack + 100715;
 Libderiv->deriv_classes[4][7][7] = int_stack + 101135;
 Libderiv->deriv_classes[4][8][7] = int_stack + 101675;
 Libderiv->deriv_classes[4][9][7] = int_stack + 102350;
 Libderiv->deriv_classes[4][10][7] = int_stack + 103175;
 Libderiv->deriv_classes[5][5][7] = int_stack + 104165;
 Libderiv->deriv_classes[5][6][7] = int_stack + 104606;
 Libderiv->deriv_classes[5][7][7] = int_stack + 105194;
 Libderiv->deriv_classes[5][8][7] = int_stack + 105950;
 Libderiv->deriv_classes[5][9][7] = int_stack + 106895;
 Libderiv->deriv_classes[5][10][7] = int_stack + 108050;
 Libderiv->deriv_classes[6][5][7] = int_stack + 109436;
 Libderiv->deriv_classes[6][6][7] = int_stack + 110024;
 Libderiv->deriv_classes[6][7][7] = int_stack + 110808;
 Libderiv->deriv_classes[6][8][7] = int_stack + 111816;
 Libderiv->deriv_classes[6][9][7] = int_stack + 113076;
 Libderiv->deriv_classes[6][10][7] = int_stack + 114616;
 Libderiv->deriv_classes[7][5][7] = int_stack + 116464;
 Libderiv->deriv_classes[7][6][7] = int_stack + 117220;
 Libderiv->deriv_classes[7][7][7] = int_stack + 118228;
 Libderiv->deriv_classes[7][8][7] = int_stack + 119524;
 Libderiv->deriv_classes[7][9][7] = int_stack + 121144;
 Libderiv->deriv_classes[7][10][7] = int_stack + 123124;
 Libderiv->deriv_classes[4][5][6] = int_stack + 125500;
 Libderiv->deriv_classes[4][6][6] = int_stack + 125815;
 Libderiv->deriv_classes[4][7][6] = int_stack + 126235;
 Libderiv->deriv_classes[4][8][6] = int_stack + 126775;
 Libderiv->deriv_classes[4][9][6] = int_stack + 127450;
 Libderiv->deriv_classes[4][10][6] = int_stack + 128275;
 Libderiv->deriv_classes[5][5][6] = int_stack + 129265;
 Libderiv->deriv_classes[5][6][6] = int_stack + 129706;
 Libderiv->deriv_classes[5][7][6] = int_stack + 130294;
 Libderiv->deriv_classes[5][8][6] = int_stack + 131050;
 Libderiv->deriv_classes[5][9][6] = int_stack + 131995;
 Libderiv->deriv_classes[5][10][6] = int_stack + 133150;
 Libderiv->deriv_classes[6][5][6] = int_stack + 134536;
 Libderiv->deriv_classes[6][6][6] = int_stack + 135124;
 Libderiv->deriv_classes[6][7][6] = int_stack + 135908;
 Libderiv->deriv_classes[6][8][6] = int_stack + 136916;
 Libderiv->deriv_classes[6][9][6] = int_stack + 138176;
 Libderiv->deriv_classes[6][10][6] = int_stack + 139716;
 Libderiv->dvrr_classes[7][5] = int_stack + 141564;
 Libderiv->deriv_classes[7][5][6] = int_stack + 142320;
 Libderiv->dvrr_classes[7][6] = int_stack + 143076;
 Libderiv->deriv_classes[7][6][6] = int_stack + 144084;
 Libderiv->dvrr_classes[7][7] = int_stack + 145092;
 Libderiv->deriv_classes[7][7][6] = int_stack + 146388;
 Libderiv->dvrr_classes[7][8] = int_stack + 147684;
 Libderiv->deriv_classes[7][8][6] = int_stack + 149304;
 Libderiv->dvrr_classes[7][9] = int_stack + 150924;
 Libderiv->deriv_classes[7][9][6] = int_stack + 152904;
 Libderiv->deriv_classes[7][10][6] = int_stack + 154884;
 Libderiv->deriv_classes[4][5][2] = int_stack + 157260;
 Libderiv->deriv_classes[4][6][2] = int_stack + 157575;
 Libderiv->deriv_classes[4][7][2] = int_stack + 157995;
 Libderiv->deriv_classes[4][8][2] = int_stack + 158535;
 Libderiv->deriv_classes[4][9][2] = int_stack + 159210;
 Libderiv->deriv_classes[4][10][2] = int_stack + 160035;
 Libderiv->deriv_classes[5][5][2] = int_stack + 161025;
 Libderiv->deriv_classes[5][6][2] = int_stack + 161466;
 Libderiv->deriv_classes[5][7][2] = int_stack + 162054;
 Libderiv->deriv_classes[5][8][2] = int_stack + 162810;
 Libderiv->deriv_classes[5][9][2] = int_stack + 163755;
 Libderiv->deriv_classes[5][10][2] = int_stack + 164910;
 Libderiv->deriv_classes[6][5][2] = int_stack + 166296;
 Libderiv->deriv_classes[6][6][2] = int_stack + 166884;
 Libderiv->deriv_classes[6][7][2] = int_stack + 167668;
 Libderiv->deriv_classes[6][8][2] = int_stack + 168676;
 Libderiv->deriv_classes[6][9][2] = int_stack + 169936;
 Libderiv->deriv_classes[6][10][2] = int_stack + 171476;
 Libderiv->deriv_classes[7][5][2] = int_stack + 173324;
 Libderiv->deriv_classes[7][6][2] = int_stack + 174080;
 Libderiv->deriv_classes[7][7][2] = int_stack + 175088;
 Libderiv->deriv_classes[7][8][2] = int_stack + 176384;
 Libderiv->deriv_classes[7][9][2] = int_stack + 178004;
 Libderiv->deriv_classes[7][10][2] = int_stack + 179984;
 Libderiv->deriv_classes[4][5][1] = int_stack + 182360;
 Libderiv->deriv_classes[4][6][1] = int_stack + 182675;
 Libderiv->deriv_classes[4][7][1] = int_stack + 183095;
 Libderiv->deriv_classes[4][8][1] = int_stack + 183635;
 Libderiv->deriv_classes[4][9][1] = int_stack + 184310;
 Libderiv->deriv_classes[4][10][1] = int_stack + 185135;
 Libderiv->deriv_classes[5][5][1] = int_stack + 186125;
 Libderiv->deriv_classes[5][6][1] = int_stack + 186566;
 Libderiv->deriv_classes[5][7][1] = int_stack + 187154;
 Libderiv->deriv_classes[5][8][1] = int_stack + 187910;
 Libderiv->deriv_classes[5][9][1] = int_stack + 188855;
 Libderiv->deriv_classes[5][10][1] = int_stack + 190010;
 Libderiv->deriv_classes[6][5][1] = int_stack + 191396;
 Libderiv->deriv_classes[6][6][1] = int_stack + 191984;
 Libderiv->deriv_classes[6][7][1] = int_stack + 192768;
 Libderiv->deriv_classes[6][8][1] = int_stack + 193776;
 Libderiv->deriv_classes[6][9][1] = int_stack + 195036;
 Libderiv->deriv_classes[6][10][1] = int_stack + 196576;
 Libderiv->deriv_classes[7][5][1] = int_stack + 198424;
 Libderiv->deriv_classes[7][6][1] = int_stack + 199180;
 Libderiv->deriv_classes[7][7][1] = int_stack + 200188;
 Libderiv->deriv_classes[7][8][1] = int_stack + 201484;
 Libderiv->deriv_classes[7][9][1] = int_stack + 203104;
 Libderiv->deriv_classes[7][10][1] = int_stack + 205084;
 Libderiv->dvrr_classes[4][5] = int_stack + 207460;
 Libderiv->dvrr_classes[4][6] = int_stack + 207775;
 Libderiv->dvrr_classes[4][7] = int_stack + 208195;
 Libderiv->dvrr_classes[4][8] = int_stack + 208735;
 Libderiv->dvrr_classes[4][9] = int_stack + 209410;
 Libderiv->dvrr_classes[4][10] = int_stack + 210235;
 Libderiv->deriv_classes[4][5][0] = int_stack + 211225;
 Libderiv->deriv_classes[4][6][0] = int_stack + 211540;
 Libderiv->deriv_classes[4][7][0] = int_stack + 211960;
 Libderiv->deriv_classes[4][8][0] = int_stack + 212500;
 Libderiv->deriv_classes[4][9][0] = int_stack + 213175;
 Libderiv->deriv_classes[4][10][0] = int_stack + 214000;
 Libderiv->dvrr_classes[5][5] = int_stack + 214990;
 Libderiv->dvrr_classes[5][6] = int_stack + 215431;
 Libderiv->dvrr_classes[5][7] = int_stack + 216019;
 Libderiv->dvrr_classes[5][8] = int_stack + 216775;
 Libderiv->dvrr_classes[5][9] = int_stack + 217720;
 Libderiv->dvrr_classes[5][10] = int_stack + 218875;
 Libderiv->deriv_classes[5][5][0] = int_stack + 220261;
 Libderiv->deriv_classes[5][6][0] = int_stack + 220702;
 Libderiv->deriv_classes[5][7][0] = int_stack + 221290;
 Libderiv->deriv_classes[5][8][0] = int_stack + 222046;
 Libderiv->deriv_classes[5][9][0] = int_stack + 222991;
 Libderiv->deriv_classes[5][10][0] = int_stack + 224146;
 Libderiv->dvrr_classes[6][5] = int_stack + 225532;
 Libderiv->dvrr_classes[6][6] = int_stack + 226120;
 Libderiv->dvrr_classes[6][7] = int_stack + 226904;
 Libderiv->dvrr_classes[6][8] = int_stack + 227912;
 Libderiv->dvrr_classes[6][9] = int_stack + 229172;
 Libderiv->dvrr_classes[6][10] = int_stack + 230712;
 Libderiv->deriv_classes[6][5][0] = int_stack + 232560;
 Libderiv->deriv_classes[6][6][0] = int_stack + 233148;
 Libderiv->deriv_classes[6][7][0] = int_stack + 233932;
 Libderiv->deriv_classes[6][8][0] = int_stack + 234940;
 Libderiv->deriv_classes[6][9][0] = int_stack + 236200;
 Libderiv->deriv_classes[6][10][0] = int_stack + 237740;
 Libderiv->deriv_classes[7][5][0] = int_stack + 239588;
 Libderiv->deriv_classes[7][6][0] = int_stack + 240344;
 Libderiv->deriv_classes[7][7][0] = int_stack + 241352;
 Libderiv->deriv_classes[7][8][0] = int_stack + 242648;
 Libderiv->deriv_classes[7][9][0] = int_stack + 244268;
 Libderiv->deriv_classes[7][10][0] = int_stack + 246248;
 memset(int_stack,0,1988992);

 Libderiv->dvrr_stack = int_stack + 1236309;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gfhh(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+248624,int_stack+207775,int_stack+207460,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+249569,int_stack+208195,int_stack+207775,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+250829,int_stack+249569,int_stack+248624,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+252719,int_stack+208735,int_stack+208195,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+254339,int_stack+252719,int_stack+249569,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+256859,int_stack+254339,int_stack+250829,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+260009,int_stack+209410,int_stack+208735,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+262034,int_stack+260009,int_stack+252719,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+265274,int_stack+262034,int_stack+254339,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+269474,int_stack+265274,int_stack+256859,15);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+274199,int_stack+315,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207460,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+275144,int_stack+735,int_stack+315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207775,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+276404,int_stack+275144,int_stack+274199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248624,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+278294,int_stack+1275,int_stack+735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208195,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+279914,int_stack+278294,int_stack+275144, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249569,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+282434,int_stack+279914,int_stack+276404, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250829,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+274199,int_stack+1950,int_stack+1275, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208735,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+285584,int_stack+274199,int_stack+278294, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252719,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+288824,int_stack+285584,int_stack+279914, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254339,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+276224,int_stack+288824,int_stack+282434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256859,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+280949,int_stack+2775,int_stack+1950, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209410,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+293024,int_stack+280949,int_stack+274199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260009,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+297074,int_stack+293024,int_stack+285584, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262034,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+280949,int_stack+297074,int_stack+288824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265274,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+287249,int_stack+280949,int_stack+276224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269474,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+274199,int_stack+215431,int_stack+214990,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+275522,int_stack+216019,int_stack+215431,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+277286,int_stack+275522,int_stack+274199,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+279932,int_stack+216775,int_stack+216019,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+282200,int_stack+279932,int_stack+275522,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+293864,int_stack+282200,int_stack+277286,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+298274,int_stack+217720,int_stack+216775,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+301109,int_stack+298274,int_stack+279932,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+305645,int_stack+301109,int_stack+282200,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+311525,int_stack+305645,int_stack+293864,21);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+285728,int_stack+4206,int_stack+3765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214990,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+0,int_stack+4794,int_stack+4206, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215431,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+1764,int_stack+0,int_stack+285728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274199,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+318140,int_stack+5550,int_stack+4794, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216019,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+320408,int_stack+318140,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275522,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+323936,int_stack+320408,int_stack+1764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277286,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+6495,int_stack+5550, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216775,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+328346,int_stack+0,int_stack+318140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279932,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+332882,int_stack+328346,int_stack+320408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282200,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+338762,int_stack+332882,int_stack+323936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293864,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+318140,int_stack+7650,int_stack+6495, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217720,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+321605,int_stack+318140,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298274,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+0,int_stack+321605,int_stack+328346, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301109,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+318140,int_stack+0,int_stack+332882, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305645,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+326960,int_stack+318140,int_stack+338762, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311525,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+336221,int_stack+326960,int_stack+287249,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+318140,int_stack+226120,int_stack+225532,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+319904,int_stack+226904,int_stack+226120,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+322256,int_stack+319904,int_stack+318140,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+227912,int_stack+226904,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+3024,int_stack+0,int_stack+319904,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+285728,int_stack+3024,int_stack+322256,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+356066,int_stack+229172,int_stack+227912,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+359846,int_stack+356066,int_stack+0,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+365894,int_stack+359846,int_stack+3024,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+373734,int_stack+365894,int_stack+285728,28);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+291608,int_stack+9624,int_stack+9036, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225532,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+382554,int_stack+10408,int_stack+9624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226120,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+384906,int_stack+382554,int_stack+291608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318140,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+388434,int_stack+11416,int_stack+10408, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226904,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+391458,int_stack+388434,int_stack+382554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319904,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+396162,int_stack+391458,int_stack+384906, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322256,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+382554,int_stack+12676,int_stack+11416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227912,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+402042,int_stack+382554,int_stack+388434, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+408090,int_stack+402042,int_stack+391458, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+386334,int_stack+408090,int_stack+396162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285728,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+395154,int_stack+14216,int_stack+12676, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229172,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+7728,int_stack+395154,int_stack+382554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356066,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+415930,int_stack+7728,int_stack+402042, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359846,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+395154,int_stack+415930,int_stack+408090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365894,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+406914,int_stack+395154,int_stack+386334, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373734,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+419262,int_stack+406914,int_stack+326960,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+447045,int_stack+419262,int_stack+336221,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+7728,int_stack+143076,int_stack+141564,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9996,int_stack+145092,int_stack+143076,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+382554,int_stack+9996,int_stack+7728,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+387090,int_stack+147684,int_stack+145092,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+390978,int_stack+387090,int_stack+9996,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+397026,int_stack+390978,int_stack+382554,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+325784,int_stack+150924,int_stack+147684,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+330644,int_stack+325784,int_stack+387090,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+338420,int_stack+330644,int_stack+390978,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+486735,int_stack+338420,int_stack+397026,36);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13020,int_stack+16820,int_stack+16064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141564,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+348500,int_stack+17828,int_stack+16820, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143076,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+351524,int_stack+348500,int_stack+13020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7728,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+13020,int_stack+19124,int_stack+17828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145092,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+498075,int_stack+13020,int_stack+348500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9996,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+504123,int_stack+498075,int_stack+351524, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382554,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+348500,int_stack+20744,int_stack+19124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147684,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+511683,int_stack+348500,int_stack+13020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387090,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+519459,int_stack+511683,int_stack+498075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390978,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+529539,int_stack+519459,int_stack+504123, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397026,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+498075,int_stack+22724,int_stack+20744, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150924,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+13020,int_stack+498075,int_stack+348500, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325784,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+498075,int_stack+13020,int_stack+511683, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330644,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+540879,int_stack+498075,int_stack+519459, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338420,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+498075,int_stack+540879,int_stack+529539, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486735,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+513951,int_stack+498075,int_stack+406914,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+550995,int_stack+513951,int_stack+419262,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+498075,int_stack+25415,int_stack+25100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207460, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+499020,int_stack+25835,int_stack+25415, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207775, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+500280,int_stack+499020,int_stack+498075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248624, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+502170,int_stack+26375,int_stack+25835, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208195, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+503790,int_stack+502170,int_stack+499020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249569, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+506310,int_stack+503790,int_stack+500280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250829, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+498075,int_stack+27050,int_stack+26375, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208735, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+509460,int_stack+498075,int_stack+502170, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252719, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+512700,int_stack+509460,int_stack+503790, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254339, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+500100,int_stack+512700,int_stack+506310, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256859, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+504825,int_stack+27875,int_stack+27050, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209410, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+516900,int_stack+504825,int_stack+498075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260009, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+520950,int_stack+516900,int_stack+509460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262034, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+504825,int_stack+520950,int_stack+512700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265274, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+511125,int_stack+504825,int_stack+500100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269474, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+498075,int_stack+29306,int_stack+28865, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214990, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+499398,int_stack+29894,int_stack+29306, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215431, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+501162,int_stack+499398,int_stack+498075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274199, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+503808,int_stack+30650,int_stack+29894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216019, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+506076,int_stack+503808,int_stack+499398, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275522, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+517740,int_stack+506076,int_stack+501162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277286, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+498075,int_stack+31595,int_stack+30650, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216775, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+522150,int_stack+498075,int_stack+503808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279932, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+526686,int_stack+522150,int_stack+506076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282200, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+500910,int_stack+526686,int_stack+517740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293864, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+517740,int_stack+32750,int_stack+31595, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217720, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+532566,int_stack+517740,int_stack+498075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298274, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+538236,int_stack+532566,int_stack+522150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301109, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+517740,int_stack+538236,int_stack+526686, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305645, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+526560,int_stack+517740,int_stack+500910, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311525, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+13020,int_stack+526560,int_stack+511125,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+498075,int_stack+34724,int_stack+34136, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225532, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+499839,int_stack+35508,int_stack+34724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226120, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+502191,int_stack+499839,int_stack+498075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318140, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+505719,int_stack+36516,int_stack+35508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226904, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+508743,int_stack+505719,int_stack+499839, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319904, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+513447,int_stack+508743,int_stack+502191, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322256, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+498075,int_stack+37776,int_stack+36516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227912, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+519327,int_stack+498075,int_stack+505719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+535821,int_stack+519327,int_stack+508743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+501855,int_stack+535821,int_stack+513447, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285728, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+510675,int_stack+39316,int_stack+37776, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229172, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+32865,int_stack+510675,int_stack+498075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356066, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+404586,int_stack+32865,int_stack+519327, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359846, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+510675,int_stack+404586,int_stack+535821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365894, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+535821,int_stack+510675,int_stack+501855, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373734, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+404586,int_stack+535821,int_stack+526560,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+606561,int_stack+404586,int_stack+13020,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13020,int_stack+41920,int_stack+41164, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141564, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15288,int_stack+42928,int_stack+41920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143076, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18312,int_stack+15288,int_stack+13020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7728, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+22848,int_stack+44224,int_stack+42928, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145092, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26736,int_stack+22848,int_stack+15288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9996, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+32784,int_stack+26736,int_stack+18312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382554, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13020,int_stack+45844,int_stack+44224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147684, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+432369,int_stack+13020,int_stack+22848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387090, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+498075,int_stack+432369,int_stack+26736, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390978, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+17880,int_stack+498075,int_stack+32784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397026, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+29220,int_stack+47824,int_stack+45844, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150924, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+35160,int_stack+29220,int_stack+13020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325784, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+508155,int_stack+35160,int_stack+432369, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330644, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+29220,int_stack+508155,int_stack+498075, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338420, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+498075,int_stack+29220,int_stack+17880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486735, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+13020,int_stack+498075,int_stack+535821,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+646251,int_stack+13020,int_stack+404586,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+404586,int_stack+50515,int_stack+50200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207460, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+405531,int_stack+50935,int_stack+50515, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207775, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+406791,int_stack+405531,int_stack+404586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248624, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+408681,int_stack+51475,int_stack+50935, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208195, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+410301,int_stack+408681,int_stack+405531, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249569, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+412821,int_stack+410301,int_stack+406791, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250829, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+404586,int_stack+52150,int_stack+51475, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208735, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+415971,int_stack+404586,int_stack+408681, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252719, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+419211,int_stack+415971,int_stack+410301, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254339, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+406611,int_stack+419211,int_stack+412821, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256859, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+411336,int_stack+52975,int_stack+52150, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209410, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+423411,int_stack+411336,int_stack+404586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260009, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+427461,int_stack+423411,int_stack+415971, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262034, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+411336,int_stack+427461,int_stack+419211, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265274, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+417636,int_stack+411336,int_stack+406611, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269474, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+404586,int_stack+54406,int_stack+53965, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214990, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+405909,int_stack+54994,int_stack+54406, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215431, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+407673,int_stack+405909,int_stack+404586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274199, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+410319,int_stack+55750,int_stack+54994, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216019, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+412587,int_stack+410319,int_stack+405909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275522, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+424251,int_stack+412587,int_stack+407673, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277286, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+404586,int_stack+56695,int_stack+55750, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216775, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+428661,int_stack+404586,int_stack+410319, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279932, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+433197,int_stack+428661,int_stack+412587, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282200, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+407421,int_stack+433197,int_stack+424251, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293864, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+424251,int_stack+57850,int_stack+56695, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217720, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+439077,int_stack+424251,int_stack+404586, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298274, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13020,int_stack+439077,int_stack+428661, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301109, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+424251,int_stack+13020,int_stack+433197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305645, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13020,int_stack+424251,int_stack+407421, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311525, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+424251,int_stack+13020,int_stack+417636,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+444096,int_stack+59824,int_stack+59236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225532, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+22281,int_stack+60608,int_stack+59824, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226120, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+24633,int_stack+22281,int_stack+444096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318140, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+28161,int_stack+61616,int_stack+60608, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226904, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+31185,int_stack+28161,int_stack+22281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319904, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+35889,int_stack+31185,int_stack+24633, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322256, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+22281,int_stack+62876,int_stack+61616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227912, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+41769,int_stack+22281,int_stack+28161, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+47817,int_stack+41769,int_stack+31185, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+26061,int_stack+47817,int_stack+35889, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285728, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+34881,int_stack+64416,int_stack+62876, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229172, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+55657,int_stack+34881,int_stack+22281, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356066, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+404586,int_stack+55657,int_stack+41769, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359846, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+34881,int_stack+404586,int_stack+47817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365894, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+404586,int_stack+34881,int_stack+26061, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373734, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+22281,int_stack+404586,int_stack+13020,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+498075,int_stack+22281,int_stack+424251,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13020,int_stack+67020,int_stack+66264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141564, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15288,int_stack+68028,int_stack+67020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143076, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+416934,int_stack+15288,int_stack+13020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7728, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18312,int_stack+69324,int_stack+68028, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145092, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+421470,int_stack+18312,int_stack+15288, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9996, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+427518,int_stack+421470,int_stack+416934, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382554, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13020,int_stack+70944,int_stack+69324, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147684, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+435078,int_stack+13020,int_stack+18312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387090, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+50064,int_stack+435078,int_stack+421470, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390978, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+537765,int_stack+50064,int_stack+427518, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397026, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+416934,int_stack+72924,int_stack+70944, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150924, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+422874,int_stack+416934,int_stack+13020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325784, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+60144,int_stack+422874,int_stack+435078, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330644, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+416934,int_stack+60144,int_stack+50064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338420, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+50064,int_stack+416934,int_stack+537765, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486735, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+701817,int_stack+50064,int_stack+404586,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+738861,int_stack+701817,int_stack+22281,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+701817,int_stack+75615,int_stack+75300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+702762,int_stack+76035,int_stack+75615, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+207775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704022,int_stack+702762,int_stack+701817, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+705912,int_stack+76575,int_stack+76035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+707532,int_stack+705912,int_stack+702762, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+249569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+710052,int_stack+707532,int_stack+704022, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+250829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+701817,int_stack+77250,int_stack+76575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+208735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+713202,int_stack+701817,int_stack+705912, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+252719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+716442,int_stack+713202,int_stack+707532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+703842,int_stack+716442,int_stack+710052, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+708567,int_stack+78075,int_stack+77250, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+209410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+720642,int_stack+708567,int_stack+701817, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+260009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+724692,int_stack+720642,int_stack+713202, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+262034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+708567,int_stack+724692,int_stack+716442, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+714867,int_stack+708567,int_stack+703842, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+269474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+701817,int_stack+79506,int_stack+79065, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+214990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+703140,int_stack+80094,int_stack+79506, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+215431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704904,int_stack+703140,int_stack+701817, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+274199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+707550,int_stack+80850,int_stack+80094, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+709818,int_stack+707550,int_stack+703140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+275522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+721482,int_stack+709818,int_stack+704904, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+701817,int_stack+81795,int_stack+80850, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+216775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+725892,int_stack+701817,int_stack+707550, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+730428,int_stack+725892,int_stack+709818, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+282200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+704652,int_stack+730428,int_stack+721482, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+293864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+721482,int_stack+82950,int_stack+81795, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+217720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+404586,int_stack+721482,int_stack+701817, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+298274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+410256,int_stack+404586,int_stack+725892, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+301109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+721482,int_stack+410256,int_stack+730428, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+404586,int_stack+721482,int_stack+704652, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+311525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+413847,int_stack+404586,int_stack+714867,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+433692,int_stack+84924,int_stack+84336, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+225532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+435456,int_stack+85708,int_stack+84924, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+437808,int_stack+435456,int_stack+433692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+318140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+441336,int_stack+86716,int_stack+85708, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+226904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+701817,int_stack+441336,int_stack+435456, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+319904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+706521,int_stack+701817,int_stack+437808, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+433692,int_stack+87976,int_stack+86716, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+227912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+712401,int_stack+433692,int_stack+441336, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+437472,int_stack+712401,int_stack+701817, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+718449,int_stack+437472,int_stack+706521, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+285728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+701817,int_stack+89516,int_stack+87976, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+229172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+727269,int_stack+701817,int_stack+433692, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+356066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+701817,int_stack+727269,int_stack+712401, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+359846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+537765,int_stack+701817,int_stack+437472, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+365894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+701817,int_stack+537765,int_stack+718449, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+13020,int_stack+701817,int_stack+404586,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+40803,int_stack+13020,int_stack+413847,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+404586,int_stack+92120,int_stack+91364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+141564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+406854,int_stack+93128,int_stack+92120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+143076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+409878,int_stack+406854,int_stack+404586, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+7728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+414414,int_stack+94424,int_stack+93128, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+145092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+418302,int_stack+414414,int_stack+406854, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+424350,int_stack+418302,int_stack+409878, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+382554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+404586,int_stack+96044,int_stack+94424, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+147684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+431910,int_stack+404586,int_stack+414414, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+387090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+537765,int_stack+431910,int_stack+418302, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+390978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+409446,int_stack+537765,int_stack+424350, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+420786,int_stack+98024,int_stack+96044, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+150924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+714165,int_stack+420786,int_stack+404586, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+325784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+723885,int_stack+714165,int_stack+431910, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+330644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+420786,int_stack+723885,int_stack+537765, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+714165,int_stack+420786,int_stack+409446, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+486735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+404586,int_stack+714165,int_stack+701817,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+794427,int_stack+404586,int_stack+13020,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13020,int_stack+100715,int_stack+100400, 0.0, zero_stack, 1.0, int_stack+207460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+13965,int_stack+101135,int_stack+100715, 0.0, zero_stack, 1.0, int_stack+207775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+15225,int_stack+13965,int_stack+13020, 0.0, zero_stack, 1.0, int_stack+248624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+17115,int_stack+101675,int_stack+101135, 0.0, zero_stack, 1.0, int_stack+208195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+18735,int_stack+17115,int_stack+13965, 0.0, zero_stack, 1.0, int_stack+249569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+21255,int_stack+18735,int_stack+15225, 0.0, zero_stack, 1.0, int_stack+250829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13020,int_stack+102350,int_stack+101675, 0.0, zero_stack, 1.0, int_stack+208735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+24405,int_stack+13020,int_stack+17115, 0.0, zero_stack, 1.0, int_stack+252719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+27645,int_stack+24405,int_stack+18735, 0.0, zero_stack, 1.0, int_stack+254339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+15045,int_stack+27645,int_stack+21255, 0.0, zero_stack, 1.0, int_stack+256859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+19770,int_stack+103175,int_stack+102350, 0.0, zero_stack, 1.0, int_stack+209410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+31845,int_stack+19770,int_stack+13020, 0.0, zero_stack, 1.0, int_stack+260009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+404586,int_stack+31845,int_stack+24405, 0.0, zero_stack, 1.0, int_stack+262034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+31845,int_stack+404586,int_stack+27645, 0.0, zero_stack, 1.0, int_stack+265274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+404586,int_stack+31845,int_stack+15045, 0.0, zero_stack, 1.0, int_stack+269474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+411201,int_stack+104606,int_stack+104165, 0.0, zero_stack, 1.0, int_stack+214990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+412524,int_stack+105194,int_stack+104606, 0.0, zero_stack, 1.0, int_stack+215431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+414288,int_stack+412524,int_stack+411201, 0.0, zero_stack, 1.0, int_stack+274199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+416934,int_stack+105950,int_stack+105194, 0.0, zero_stack, 1.0, int_stack+216019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+419202,int_stack+416934,int_stack+412524, 0.0, zero_stack, 1.0, int_stack+275522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+422730,int_stack+419202,int_stack+414288, 0.0, zero_stack, 1.0, int_stack+277286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+411201,int_stack+106895,int_stack+105950, 0.0, zero_stack, 1.0, int_stack+216775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+427140,int_stack+411201,int_stack+416934, 0.0, zero_stack, 1.0, int_stack+279932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+431676,int_stack+427140,int_stack+419202, 0.0, zero_stack, 1.0, int_stack+282200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+414036,int_stack+431676,int_stack+422730, 0.0, zero_stack, 1.0, int_stack+293864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+420651,int_stack+108050,int_stack+106895, 0.0, zero_stack, 1.0, int_stack+217720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+437556,int_stack+420651,int_stack+411201, 0.0, zero_stack, 1.0, int_stack+298274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+13020,int_stack+437556,int_stack+427140, 0.0, zero_stack, 1.0, int_stack+301109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+437556,int_stack+13020,int_stack+431676, 0.0, zero_stack, 1.0, int_stack+305645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+13020,int_stack+437556,int_stack+414036, 0.0, zero_stack, 1.0, int_stack+311525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+411201,int_stack+13020,int_stack+404586,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+404586,int_stack+110024,int_stack+109436, 0.0, zero_stack, 1.0, int_stack+225532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+406350,int_stack+110808,int_stack+110024, 0.0, zero_stack, 1.0, int_stack+226120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+22281,int_stack+406350,int_stack+404586, 0.0, zero_stack, 1.0, int_stack+318140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+25809,int_stack+111816,int_stack+110808, 0.0, zero_stack, 1.0, int_stack+226904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+28833,int_stack+25809,int_stack+406350, 0.0, zero_stack, 1.0, int_stack+319904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+404586,int_stack+28833,int_stack+22281, 0.0, zero_stack, 1.0, int_stack+322256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+33537,int_stack+113076,int_stack+111816, 0.0, zero_stack, 1.0, int_stack+227912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+431046,int_stack+33537,int_stack+25809, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+437094,int_stack+431046,int_stack+28833, 0.0, zero_stack, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+22281,int_stack+437094,int_stack+404586, 0.0, zero_stack, 1.0, int_stack+285728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+404586,int_stack+114616,int_stack+113076, 0.0, zero_stack, 1.0, int_stack+229172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+701817,int_stack+404586,int_stack+33537, 0.0, zero_stack, 1.0, int_stack+356066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+709377,int_stack+701817,int_stack+431046, 0.0, zero_stack, 1.0, int_stack+359846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+719457,int_stack+709377,int_stack+437094, 0.0, zero_stack, 1.0, int_stack+365894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+431046,int_stack+719457,int_stack+22281, 0.0, zero_stack, 1.0, int_stack+373734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+701817,int_stack+431046,int_stack+13020,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+849993,int_stack+701817,int_stack+411201,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+13020,int_stack+117220,int_stack+116464, 0.0, zero_stack, 1.0, int_stack+141564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+15288,int_stack+118228,int_stack+117220, 0.0, zero_stack, 1.0, int_stack+143076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+18312,int_stack+15288,int_stack+13020, 0.0, zero_stack, 1.0, int_stack+7728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+22848,int_stack+119524,int_stack+118228, 0.0, zero_stack, 1.0, int_stack+145092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+26736,int_stack+22848,int_stack+15288, 0.0, zero_stack, 1.0, int_stack+9996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+32784,int_stack+26736,int_stack+18312, 0.0, zero_stack, 1.0, int_stack+382554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+13020,int_stack+121144,int_stack+119524, 0.0, zero_stack, 1.0, int_stack+147684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+729600,int_stack+13020,int_stack+22848, 0.0, zero_stack, 1.0, int_stack+387090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+404586,int_stack+729600,int_stack+26736, 0.0, zero_stack, 1.0, int_stack+390978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+17880,int_stack+404586,int_stack+32784, 0.0, zero_stack, 1.0, int_stack+397026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+29220,int_stack+123124,int_stack+121144, 0.0, zero_stack, 1.0, int_stack+150924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+414666,int_stack+29220,int_stack+13020, 0.0, zero_stack, 1.0, int_stack+325784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+537765,int_stack+414666,int_stack+729600, 0.0, zero_stack, 1.0, int_stack+330644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+414666,int_stack+537765,int_stack+404586, 0.0, zero_stack, 1.0, int_stack+338420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+80493,int_stack+414666,int_stack+17880, 0.0, zero_stack, 1.0, int_stack+486735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+889683,int_stack+80493,int_stack+431046,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+926727,int_stack+889683,int_stack+701817,441);
 /*--- compute (g0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+701817,int_stack+125815,int_stack+125500, 1.0, int_stack+207460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+702762,int_stack+126235,int_stack+125815, 1.0, int_stack+207775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704022,int_stack+702762,int_stack+701817, 1.0, int_stack+248624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+705912,int_stack+126775,int_stack+126235, 1.0, int_stack+208195, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+707532,int_stack+705912,int_stack+702762, 1.0, int_stack+249569, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+710052,int_stack+707532,int_stack+704022, 1.0, int_stack+250829, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+248624,int_stack+127450,int_stack+126775, 1.0, int_stack+208735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+701817,int_stack+248624,int_stack+705912, 1.0, int_stack+252719, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+713202,int_stack+701817,int_stack+707532, 1.0, int_stack+254339, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+250649,int_stack+713202,int_stack+710052, 1.0, int_stack+256859, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+255374,int_stack+128275,int_stack+127450, 1.0, int_stack+209410, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+705057,int_stack+255374,int_stack+248624, 1.0, int_stack+260009, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+717402,int_stack+705057,int_stack+701817, 1.0, int_stack+262034, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+701817,int_stack+717402,int_stack+713202, 1.0, int_stack+265274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+708117,int_stack+701817,int_stack+250649, 1.0, int_stack+269474, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+701817,int_stack+129706,int_stack+129265, 1.0, int_stack+214990, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+703140,int_stack+130294,int_stack+129706, 1.0, int_stack+215431, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+704904,int_stack+703140,int_stack+701817, 1.0, int_stack+274199, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+714732,int_stack+131050,int_stack+130294, 1.0, int_stack+216019, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+717000,int_stack+714732,int_stack+703140, 1.0, int_stack+275522, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+720528,int_stack+717000,int_stack+704904, 1.0, int_stack+277286, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+274199,int_stack+131995,int_stack+131050, 1.0, int_stack+216775, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+701817,int_stack+274199,int_stack+714732, 1.0, int_stack+279932, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+724938,int_stack+701817,int_stack+717000, 1.0, int_stack+282200, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+277034,int_stack+724938,int_stack+720528, 1.0, int_stack+293864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+714732,int_stack+133150,int_stack+131995, 1.0, int_stack+217720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+718197,int_stack+714732,int_stack+274199, 1.0, int_stack+298274, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+730818,int_stack+718197,int_stack+701817, 1.0, int_stack+301109, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+714732,int_stack+730818,int_stack+724938, 1.0, int_stack+305645, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+723552,int_stack+714732,int_stack+277034, 1.0, int_stack+311525, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+889683,int_stack+723552,int_stack+708117,441);
 /*--- compute (i0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+701817,int_stack+135124,int_stack+134536, 1.0, int_stack+225532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+703581,int_stack+135908,int_stack+135124, 1.0, int_stack+226120, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+705933,int_stack+703581,int_stack+701817, 1.0, int_stack+318140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+709461,int_stack+136916,int_stack+135908, 1.0, int_stack+226904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+712485,int_stack+709461,int_stack+703581, 1.0, int_stack+319904, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+717189,int_stack+712485,int_stack+705933, 1.0, int_stack+322256, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+318140,int_stack+138176,int_stack+136916, 1.0, int_stack+227912, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+732813,int_stack+318140,int_stack+709461, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+701817,int_stack+732813,int_stack+712485, 1.0, int_stack+3024, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+274199,int_stack+701817,int_stack+717189, 1.0, int_stack+285728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+139716,int_stack+138176, 1.0, int_stack+229172, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+709657,int_stack+0,int_stack+318140, 1.0, int_stack+356066, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+283019,int_stack+709657,int_stack+732813, 1.0, int_stack+359846, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+709657,int_stack+283019,int_stack+701817, 1.0, int_stack+365894, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+283019,int_stack+709657,int_stack+274199, 1.0, int_stack+373734, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+13020,int_stack+283019,int_stack+723552,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+80493,int_stack+13020,int_stack+889683,441);
 /*--- compute (k0|hp) ---*/
   d1hrr3_build_hp(Libderiv->CD,int_stack+889683,int_stack+144084,int_stack+142320, 1.0, int_stack+141564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+891951,int_stack+146388,int_stack+144084, 1.0, int_stack+143076, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hd) ---*/
   d1hrr3_build_hd(Libderiv->CD,int_stack+894975,int_stack+891951,int_stack+889683, 1.0, int_stack+7728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+899511,int_stack+149304,int_stack+146388, 1.0, int_stack+145092, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+903399,int_stack+899511,int_stack+891951, 1.0, int_stack+9996, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hf) ---*/
   d1hrr3_build_hf(Libderiv->CD,int_stack+909447,int_stack+903399,int_stack+894975, 1.0, int_stack+382554, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+889683,int_stack+152904,int_stack+149304, 1.0, int_stack+147684, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+917007,int_stack+889683,int_stack+899511, 1.0, int_stack+387090, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+701817,int_stack+917007,int_stack+903399, 1.0, int_stack+390978, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hg) ---*/
   d1hrr3_build_hg(Libderiv->CD,int_stack+382554,int_stack+701817,int_stack+909447, 1.0, int_stack+397026, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+393894,int_stack+154884,int_stack+152904, 1.0, int_stack+150924, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+399834,int_stack+393894,int_stack+889683, 1.0, int_stack+325784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+889683,int_stack+399834,int_stack+917007, 1.0, int_stack+330644, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+902643,int_stack+889683,int_stack+701817, 1.0, int_stack+338420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|hh) ---*/
   d1hrr3_build_hh(Libderiv->CD,int_stack+701817,int_stack+902643,int_stack+382554, 1.0, int_stack+486735, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|hh) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+889683,int_stack+701817,int_stack+283019,441);
 /*--- compute (hd|hh) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+382554,int_stack+889683,int_stack+13020,441);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+889683,int_stack+210235,int_stack+209410,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+892158,int_stack+889683,int_stack+260009,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+896208,int_stack+892158,int_stack+262034,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+889683,int_stack+896208,int_stack+265274,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+895983,int_stack+889683,int_stack+269474,15);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+889683,int_stack+218875,int_stack+217720,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+902598,int_stack+889683,int_stack+298274,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+908268,int_stack+902598,int_stack+301109,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+915828,int_stack+908268,int_stack+305645,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+902598,int_stack+915828,int_stack+311525,21);
 /*--- compute (gp|hh) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+701817,int_stack+902598,int_stack+895983,441);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+911859,int_stack+230712,int_stack+229172,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+916479,int_stack+911859,int_stack+356066,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+721662,int_stack+916479,int_stack+359846,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+911859,int_stack+721662,int_stack+365894,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+721662,int_stack+911859,int_stack+373734,28);
 /*--- compute (hp|hh) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+0,int_stack+721662,int_stack+902598,441);
 /*--- compute (gd|hh) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+248624,int_stack+0,int_stack+701817,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+911859,int_stack+157575,int_stack+157260,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+912804,int_stack+157995,int_stack+157575,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+914064,int_stack+912804,int_stack+911859,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+915954,int_stack+158535,int_stack+157995,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+917574,int_stack+915954,int_stack+912804,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+920094,int_stack+917574,int_stack+914064,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+911859,int_stack+159210,int_stack+158535,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+923244,int_stack+911859,int_stack+915954,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+734010,int_stack+923244,int_stack+917574,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+913884,int_stack+734010,int_stack+920094,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+918609,int_stack+160035,int_stack+159210,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+889683,int_stack+918609,int_stack+911859,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+486735,int_stack+889683,int_stack+923244,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+889683,int_stack+486735,int_stack+734010,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+486735,int_stack+889683,int_stack+913884,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+889683,int_stack+161466,int_stack+161025,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+891006,int_stack+162054,int_stack+161466,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+892770,int_stack+891006,int_stack+889683,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+734010,int_stack+162810,int_stack+162054,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+493350,int_stack+734010,int_stack+891006,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+911859,int_stack+493350,int_stack+892770,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+889683,int_stack+163755,int_stack+162810,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+916269,int_stack+889683,int_stack+734010,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+920805,int_stack+916269,int_stack+493350,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+438120,int_stack+920805,int_stack+911859,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+892518,int_stack+164910,int_stack+163755,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+27783,int_stack+892518,int_stack+889683,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+288314,int_stack+27783,int_stack+916269,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+27783,int_stack+288314,int_stack+920805,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+288314,int_stack+27783,int_stack+438120,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+297575,int_stack+288314,int_stack+486735, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+895983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+486735,int_stack+166884,int_stack+166296,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+488499,int_stack+167668,int_stack+166884,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+490851,int_stack+488499,int_stack+486735,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+494379,int_stack+168676,int_stack+167668,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+438120,int_stack+494379,int_stack+488499,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+27783,int_stack+438120,int_stack+490851,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+486735,int_stack+169936,int_stack+168676,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+33663,int_stack+486735,int_stack+494379,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+317420,int_stack+33663,int_stack+438120,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+438120,int_stack+317420,int_stack+27783,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+27783,int_stack+171476,int_stack+169936,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+490515,int_stack+27783,int_stack+486735,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+325260,int_stack+490515,int_stack+33663,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+27783,int_stack+325260,int_stack+317420,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+317420,int_stack+27783,int_stack+438120,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+329768,int_stack+317420,int_stack+288314, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+902598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+120183,int_stack+329768,int_stack+297575, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+701817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+288314,int_stack+174080,int_stack+173324,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+290582,int_stack+175088,int_stack+174080,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+293606,int_stack+290582,int_stack+288314,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+298142,int_stack+176384,int_stack+175088,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+302030,int_stack+298142,int_stack+290582,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+308078,int_stack+302030,int_stack+293606,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+288314,int_stack+178004,int_stack+176384,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+438120,int_stack+288314,int_stack+298142,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+27783,int_stack+438120,int_stack+302030,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+486735,int_stack+27783,int_stack+308078,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+293174,int_stack+179984,int_stack+178004,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+299114,int_stack+293174,int_stack+288314,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+357551,int_stack+299114,int_stack+438120,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+288314,int_stack+357551,int_stack+27783,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+357551,int_stack+288314,int_stack+486735,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+982293,int_stack+357551,int_stack+317420, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+721662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1019337,int_stack+982293,int_stack+329768, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+982293,int_stack+182675,int_stack+182360,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+983238,int_stack+183095,int_stack+182675,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+984498,int_stack+983238,int_stack+982293,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+986388,int_stack+183635,int_stack+183095,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+988008,int_stack+986388,int_stack+983238,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+990528,int_stack+988008,int_stack+984498,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+982293,int_stack+184310,int_stack+183635,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+993678,int_stack+982293,int_stack+986388,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+996918,int_stack+993678,int_stack+988008,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+984318,int_stack+996918,int_stack+990528,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+989043,int_stack+185135,int_stack+184310,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1001118,int_stack+989043,int_stack+982293,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+1005168,int_stack+1001118,int_stack+993678,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+889683,int_stack+1005168,int_stack+996918,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+989043,int_stack+889683,int_stack+984318,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+889683,int_stack+186566,int_stack+186125,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+891006,int_stack+187154,int_stack+186566,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+892770,int_stack+891006,int_stack+889683,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+982293,int_stack+187910,int_stack+187154,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+984561,int_stack+982293,int_stack+891006,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+995658,int_stack+984561,int_stack+892770,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+889683,int_stack+188855,int_stack+187910,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+1000068,int_stack+889683,int_stack+982293,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1004604,int_stack+1000068,int_stack+984561,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+982293,int_stack+1004604,int_stack+995658,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+892518,int_stack+190010,int_stack+188855,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+1010484,int_stack+892518,int_stack+889683,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+486735,int_stack+1010484,int_stack+1000068,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+1010484,int_stack+486735,int_stack+1004604,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+486735,int_stack+1010484,int_stack+982293,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+995658,int_stack+486735,int_stack+989043, 0.0, zero_stack, 1.0, int_stack+895983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+982293,int_stack+191984,int_stack+191396,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+984057,int_stack+192768,int_stack+191984,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+986409,int_stack+984057,int_stack+982293,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+989937,int_stack+193776,int_stack+192768,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+889683,int_stack+989937,int_stack+984057,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+288314,int_stack+889683,int_stack+986409,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+982293,int_stack+195036,int_stack+193776,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+294194,int_stack+982293,int_stack+989937,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+986073,int_stack+294194,int_stack+889683,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+300242,int_stack+986073,int_stack+288314,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+288314,int_stack+196576,int_stack+195036,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+309062,int_stack+288314,int_stack+982293,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+316622,int_stack+309062,int_stack+294194,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+288314,int_stack+316622,int_stack+986073,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+309062,int_stack+288314,int_stack+300242,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+321410,int_stack+309062,int_stack+486735, 0.0, zero_stack, 1.0, int_stack+902598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1074903,int_stack+321410,int_stack+995658, 0.0, zero_stack, 1.0, int_stack+701817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+486735,int_stack+199180,int_stack+198424,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+489003,int_stack+200188,int_stack+199180,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+492027,int_stack+489003,int_stack+486735,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+288314,int_stack+201484,int_stack+200188,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+292202,int_stack+288314,int_stack+489003,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+298250,int_stack+292202,int_stack+492027,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+486735,int_stack+203104,int_stack+201484,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+349193,int_stack+486735,int_stack+288314,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+356969,int_stack+349193,int_stack+292202,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+367049,int_stack+356969,int_stack+298250,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+288314,int_stack+205084,int_stack+203104,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+294254,int_stack+288314,int_stack+486735,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+982293,int_stack+294254,int_stack+349193,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+288314,int_stack+982293,int_stack+356969,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+982293,int_stack+288314,int_stack+367049,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+159873,int_stack+982293,int_stack+309062, 0.0, zero_stack, 1.0, int_stack+721662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1114593,int_stack+159873,int_stack+321410, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (g0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+159873,int_stack+211540,int_stack+211225,15);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+160818,int_stack+211960,int_stack+211540,15);
 /*--- compute (g0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+162078,int_stack+160818,int_stack+159873,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+163968,int_stack+212500,int_stack+211960,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+165588,int_stack+163968,int_stack+160818,15);
 /*--- compute (g0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+168108,int_stack+165588,int_stack+162078,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+159873,int_stack+213175,int_stack+212500,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+171258,int_stack+159873,int_stack+163968,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+174498,int_stack+171258,int_stack+165588,15);
 /*--- compute (g0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+161898,int_stack+174498,int_stack+168108,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+166623,int_stack+214000,int_stack+213175,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+178698,int_stack+166623,int_stack+159873,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+182748,int_stack+178698,int_stack+171258,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+889683,int_stack+182748,int_stack+174498,15);
 /*--- compute (g0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+166623,int_stack+889683,int_stack+161898,15);
 /*--- compute (h0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+889683,int_stack+220702,int_stack+220261,21);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+891006,int_stack+221290,int_stack+220702,21);
 /*--- compute (h0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+892770,int_stack+891006,int_stack+889683,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+159873,int_stack+222046,int_stack+221290,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+162141,int_stack+159873,int_stack+891006,21);
 /*--- compute (h0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+173238,int_stack+162141,int_stack+892770,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+889683,int_stack+222991,int_stack+222046,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+177648,int_stack+889683,int_stack+159873,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+182184,int_stack+177648,int_stack+162141,21);
 /*--- compute (h0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+159873,int_stack+182184,int_stack+173238,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+892518,int_stack+224146,int_stack+222991,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+188064,int_stack+892518,int_stack+889683,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+193734,int_stack+188064,int_stack+177648,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+173238,int_stack+193734,int_stack+182184,21);
 /*--- compute (h0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+182058,int_stack+173238,int_stack+159873,21);
 /*--- compute (gp|hh) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+191319,int_stack+182058,int_stack+166623, 1.0, int_stack+895983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (i0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+159873,int_stack+233148,int_stack+232560,28);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+161637,int_stack+233932,int_stack+233148,28);
 /*--- compute (i0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+163989,int_stack+161637,int_stack+159873,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+167517,int_stack+234940,int_stack+233932,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+170541,int_stack+167517,int_stack+161637,28);
 /*--- compute (i0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+175245,int_stack+170541,int_stack+163989,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+159873,int_stack+236200,int_stack+234940,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+889683,int_stack+159873,int_stack+167517,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+211164,int_stack+889683,int_stack+170541,28);
 /*--- compute (i0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+163653,int_stack+211164,int_stack+175245,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+172473,int_stack+237740,int_stack+236200,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+219004,int_stack+172473,int_stack+159873,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+226564,int_stack+219004,int_stack+889683,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+889683,int_stack+226564,int_stack+211164,28);
 /*--- compute (i0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+211164,int_stack+889683,int_stack+163653,28);
 /*--- compute (hp|hh) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+982293,int_stack+211164,int_stack+182058, 1.0, int_stack+902598, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gd|hh) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+288314,int_stack+982293,int_stack+191319, 1.0, int_stack+701817, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (k0|hp) ---*/
   hrr3_build_hp(Libderiv->CD,int_stack+701817,int_stack+240344,int_stack+239588,36);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+704085,int_stack+241352,int_stack+240344,36);
 /*--- compute (k0|hd) ---*/
   hrr3_build_hd(Libderiv->CD,int_stack+707109,int_stack+704085,int_stack+701817,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+711645,int_stack+242648,int_stack+241352,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+715533,int_stack+711645,int_stack+704085,36);
 /*--- compute (k0|hf) ---*/
   hrr3_build_hf(Libderiv->CD,int_stack+889683,int_stack+715533,int_stack+707109,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+701817,int_stack+244268,int_stack+242648,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+897243,int_stack+701817,int_stack+711645,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+905019,int_stack+897243,int_stack+715533,36);
 /*--- compute (k0|hg) ---*/
   hrr3_build_hg(Libderiv->CD,int_stack+486735,int_stack+905019,int_stack+889683,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+889683,int_stack+246248,int_stack+244268,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+706677,int_stack+889683,int_stack+701817,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+223512,int_stack+706677,int_stack+897243,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+701817,int_stack+223512,int_stack+905019,36);
 /*--- compute (k0|hh) ---*/
   hrr3_build_hh(Libderiv->CD,int_stack+223512,int_stack+701817,int_stack+486735,36);
 /*--- compute (ip|hh) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+889683,int_stack+223512,int_stack+211164, 1.0, int_stack+721662, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (hd|hh) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+159873,int_stack+889683,int_stack+982293, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1170159,int_stack+550995,int_stack+447045,441);
     Libderiv->ABCD[11] = int_stack + 1170159;
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+537765,int_stack+646251,int_stack+606561,441);
     Libderiv->ABCD[10] = int_stack + 537765;
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+603915,int_stack+738861,int_stack+498075,441);
     Libderiv->ABCD[9] = int_stack + 603915;
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+438120,int_stack+794427,int_stack+40803,441);
     Libderiv->ABCD[8] = int_stack + 438120;
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+0,int_stack+926727,int_stack+849993,441);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (gf|hh) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+670065,int_stack+382554,int_stack+80493,441);
     Libderiv->ABCD[6] = int_stack + 670065;
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+328004,int_stack+1019337,int_stack+120183, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+248624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[2] = int_stack + 328004;
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+66150,int_stack+1114593,int_stack+1074903, 0.0, zero_stack, 1.0, int_stack+248624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[1] = int_stack + 66150;
 /*--- compute (gf|hh) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+736215,int_stack+159873,int_stack+288314, 1.0, int_stack+248624, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,441);
     Libderiv->ABCD[0] = int_stack + 736215;

}
