/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <string.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/hrr_header.h>

#include "d1hrr_header.h"

extern void d1vrr_order_gfih(Libderiv_t *, prim_data *);

  /* Computes derivatives of (gf|ih) integrals */

void d1hrr_order_gfih(Libderiv_t *Libderiv, int num_prim_comb)
{
 prim_data *Data = Libderiv->PrimQuartet;
 double *int_stack = Libderiv->int_stack;
 double *zero_stack = Libderiv->zero_stack;
 int i,j;
 double tmp, *target;

 Libderiv->deriv_classes[4][6][11] = int_stack + 0;
 Libderiv->deriv_classes[4][7][11] = int_stack + 420;
 Libderiv->deriv_classes[4][8][11] = int_stack + 960;
 Libderiv->deriv_classes[4][9][11] = int_stack + 1635;
 Libderiv->deriv_classes[4][10][11] = int_stack + 2460;
 Libderiv->deriv_classes[4][11][11] = int_stack + 3450;
 Libderiv->deriv_classes[5][6][11] = int_stack + 4620;
 Libderiv->deriv_classes[5][7][11] = int_stack + 5208;
 Libderiv->deriv_classes[5][8][11] = int_stack + 5964;
 Libderiv->deriv_classes[5][9][11] = int_stack + 6909;
 Libderiv->deriv_classes[5][10][11] = int_stack + 8064;
 Libderiv->deriv_classes[5][11][11] = int_stack + 9450;
 Libderiv->deriv_classes[6][6][11] = int_stack + 11088;
 Libderiv->deriv_classes[6][7][11] = int_stack + 11872;
 Libderiv->deriv_classes[6][8][11] = int_stack + 12880;
 Libderiv->deriv_classes[6][9][11] = int_stack + 14140;
 Libderiv->deriv_classes[6][10][11] = int_stack + 15680;
 Libderiv->deriv_classes[6][11][11] = int_stack + 17528;
 Libderiv->deriv_classes[7][6][11] = int_stack + 19712;
 Libderiv->deriv_classes[7][7][11] = int_stack + 20720;
 Libderiv->deriv_classes[7][8][11] = int_stack + 22016;
 Libderiv->deriv_classes[7][9][11] = int_stack + 23636;
 Libderiv->deriv_classes[7][10][11] = int_stack + 25616;
 Libderiv->deriv_classes[7][11][11] = int_stack + 27992;
 Libderiv->deriv_classes[4][6][10] = int_stack + 30800;
 Libderiv->deriv_classes[4][7][10] = int_stack + 31220;
 Libderiv->deriv_classes[4][8][10] = int_stack + 31760;
 Libderiv->deriv_classes[4][9][10] = int_stack + 32435;
 Libderiv->deriv_classes[4][10][10] = int_stack + 33260;
 Libderiv->deriv_classes[4][11][10] = int_stack + 34250;
 Libderiv->deriv_classes[5][6][10] = int_stack + 35420;
 Libderiv->deriv_classes[5][7][10] = int_stack + 36008;
 Libderiv->deriv_classes[5][8][10] = int_stack + 36764;
 Libderiv->deriv_classes[5][9][10] = int_stack + 37709;
 Libderiv->deriv_classes[5][10][10] = int_stack + 38864;
 Libderiv->deriv_classes[5][11][10] = int_stack + 40250;
 Libderiv->deriv_classes[6][6][10] = int_stack + 41888;
 Libderiv->deriv_classes[6][7][10] = int_stack + 42672;
 Libderiv->deriv_classes[6][8][10] = int_stack + 43680;
 Libderiv->deriv_classes[6][9][10] = int_stack + 44940;
 Libderiv->deriv_classes[6][10][10] = int_stack + 46480;
 Libderiv->deriv_classes[6][11][10] = int_stack + 48328;
 Libderiv->deriv_classes[7][6][10] = int_stack + 50512;
 Libderiv->deriv_classes[7][7][10] = int_stack + 51520;
 Libderiv->deriv_classes[7][8][10] = int_stack + 52816;
 Libderiv->deriv_classes[7][9][10] = int_stack + 54436;
 Libderiv->deriv_classes[7][10][10] = int_stack + 56416;
 Libderiv->deriv_classes[7][11][10] = int_stack + 58792;
 Libderiv->deriv_classes[4][6][9] = int_stack + 61600;
 Libderiv->deriv_classes[4][7][9] = int_stack + 62020;
 Libderiv->deriv_classes[4][8][9] = int_stack + 62560;
 Libderiv->deriv_classes[4][9][9] = int_stack + 63235;
 Libderiv->deriv_classes[4][10][9] = int_stack + 64060;
 Libderiv->deriv_classes[4][11][9] = int_stack + 65050;
 Libderiv->deriv_classes[5][6][9] = int_stack + 66220;
 Libderiv->deriv_classes[5][7][9] = int_stack + 66808;
 Libderiv->deriv_classes[5][8][9] = int_stack + 67564;
 Libderiv->deriv_classes[5][9][9] = int_stack + 68509;
 Libderiv->deriv_classes[5][10][9] = int_stack + 69664;
 Libderiv->deriv_classes[5][11][9] = int_stack + 71050;
 Libderiv->deriv_classes[6][6][9] = int_stack + 72688;
 Libderiv->deriv_classes[6][7][9] = int_stack + 73472;
 Libderiv->deriv_classes[6][8][9] = int_stack + 74480;
 Libderiv->deriv_classes[6][9][9] = int_stack + 75740;
 Libderiv->deriv_classes[6][10][9] = int_stack + 77280;
 Libderiv->deriv_classes[6][11][9] = int_stack + 79128;
 Libderiv->deriv_classes[7][6][9] = int_stack + 81312;
 Libderiv->deriv_classes[7][7][9] = int_stack + 82320;
 Libderiv->deriv_classes[7][8][9] = int_stack + 83616;
 Libderiv->deriv_classes[7][9][9] = int_stack + 85236;
 Libderiv->deriv_classes[7][10][9] = int_stack + 87216;
 Libderiv->deriv_classes[7][11][9] = int_stack + 89592;
 Libderiv->deriv_classes[4][6][8] = int_stack + 92400;
 Libderiv->deriv_classes[4][7][8] = int_stack + 92820;
 Libderiv->deriv_classes[4][8][8] = int_stack + 93360;
 Libderiv->deriv_classes[4][9][8] = int_stack + 94035;
 Libderiv->deriv_classes[4][10][8] = int_stack + 94860;
 Libderiv->deriv_classes[4][11][8] = int_stack + 95850;
 Libderiv->deriv_classes[5][6][8] = int_stack + 97020;
 Libderiv->deriv_classes[5][7][8] = int_stack + 97608;
 Libderiv->deriv_classes[5][8][8] = int_stack + 98364;
 Libderiv->deriv_classes[5][9][8] = int_stack + 99309;
 Libderiv->deriv_classes[5][10][8] = int_stack + 100464;
 Libderiv->deriv_classes[5][11][8] = int_stack + 101850;
 Libderiv->deriv_classes[6][6][8] = int_stack + 103488;
 Libderiv->deriv_classes[6][7][8] = int_stack + 104272;
 Libderiv->deriv_classes[6][8][8] = int_stack + 105280;
 Libderiv->deriv_classes[6][9][8] = int_stack + 106540;
 Libderiv->deriv_classes[6][10][8] = int_stack + 108080;
 Libderiv->deriv_classes[6][11][8] = int_stack + 109928;
 Libderiv->deriv_classes[7][6][8] = int_stack + 112112;
 Libderiv->deriv_classes[7][7][8] = int_stack + 113120;
 Libderiv->deriv_classes[7][8][8] = int_stack + 114416;
 Libderiv->deriv_classes[7][9][8] = int_stack + 116036;
 Libderiv->deriv_classes[7][10][8] = int_stack + 118016;
 Libderiv->deriv_classes[7][11][8] = int_stack + 120392;
 Libderiv->deriv_classes[4][6][7] = int_stack + 123200;
 Libderiv->deriv_classes[4][7][7] = int_stack + 123620;
 Libderiv->deriv_classes[4][8][7] = int_stack + 124160;
 Libderiv->deriv_classes[4][9][7] = int_stack + 124835;
 Libderiv->deriv_classes[4][10][7] = int_stack + 125660;
 Libderiv->deriv_classes[4][11][7] = int_stack + 126650;
 Libderiv->deriv_classes[5][6][7] = int_stack + 127820;
 Libderiv->deriv_classes[5][7][7] = int_stack + 128408;
 Libderiv->deriv_classes[5][8][7] = int_stack + 129164;
 Libderiv->deriv_classes[5][9][7] = int_stack + 130109;
 Libderiv->deriv_classes[5][10][7] = int_stack + 131264;
 Libderiv->deriv_classes[5][11][7] = int_stack + 132650;
 Libderiv->deriv_classes[6][6][7] = int_stack + 134288;
 Libderiv->deriv_classes[6][7][7] = int_stack + 135072;
 Libderiv->deriv_classes[6][8][7] = int_stack + 136080;
 Libderiv->deriv_classes[6][9][7] = int_stack + 137340;
 Libderiv->deriv_classes[6][10][7] = int_stack + 138880;
 Libderiv->deriv_classes[6][11][7] = int_stack + 140728;
 Libderiv->deriv_classes[7][6][7] = int_stack + 142912;
 Libderiv->deriv_classes[7][7][7] = int_stack + 143920;
 Libderiv->deriv_classes[7][8][7] = int_stack + 145216;
 Libderiv->deriv_classes[7][9][7] = int_stack + 146836;
 Libderiv->deriv_classes[7][10][7] = int_stack + 148816;
 Libderiv->deriv_classes[7][11][7] = int_stack + 151192;
 Libderiv->deriv_classes[4][6][6] = int_stack + 154000;
 Libderiv->deriv_classes[4][7][6] = int_stack + 154420;
 Libderiv->deriv_classes[4][8][6] = int_stack + 154960;
 Libderiv->deriv_classes[4][9][6] = int_stack + 155635;
 Libderiv->deriv_classes[4][10][6] = int_stack + 156460;
 Libderiv->deriv_classes[4][11][6] = int_stack + 157450;
 Libderiv->deriv_classes[5][6][6] = int_stack + 158620;
 Libderiv->deriv_classes[5][7][6] = int_stack + 159208;
 Libderiv->deriv_classes[5][8][6] = int_stack + 159964;
 Libderiv->deriv_classes[5][9][6] = int_stack + 160909;
 Libderiv->deriv_classes[5][10][6] = int_stack + 162064;
 Libderiv->deriv_classes[5][11][6] = int_stack + 163450;
 Libderiv->deriv_classes[6][6][6] = int_stack + 165088;
 Libderiv->deriv_classes[6][7][6] = int_stack + 165872;
 Libderiv->deriv_classes[6][8][6] = int_stack + 166880;
 Libderiv->deriv_classes[6][9][6] = int_stack + 168140;
 Libderiv->deriv_classes[6][10][6] = int_stack + 169680;
 Libderiv->deriv_classes[6][11][6] = int_stack + 171528;
 Libderiv->dvrr_classes[7][6] = int_stack + 173712;
 Libderiv->deriv_classes[7][6][6] = int_stack + 174720;
 Libderiv->dvrr_classes[7][7] = int_stack + 175728;
 Libderiv->deriv_classes[7][7][6] = int_stack + 177024;
 Libderiv->dvrr_classes[7][8] = int_stack + 178320;
 Libderiv->deriv_classes[7][8][6] = int_stack + 179940;
 Libderiv->dvrr_classes[7][9] = int_stack + 181560;
 Libderiv->deriv_classes[7][9][6] = int_stack + 183540;
 Libderiv->dvrr_classes[7][10] = int_stack + 185520;
 Libderiv->deriv_classes[7][10][6] = int_stack + 187896;
 Libderiv->deriv_classes[7][11][6] = int_stack + 190272;
 Libderiv->deriv_classes[4][6][2] = int_stack + 193080;
 Libderiv->deriv_classes[4][7][2] = int_stack + 193500;
 Libderiv->deriv_classes[4][8][2] = int_stack + 194040;
 Libderiv->deriv_classes[4][9][2] = int_stack + 194715;
 Libderiv->deriv_classes[4][10][2] = int_stack + 195540;
 Libderiv->deriv_classes[4][11][2] = int_stack + 196530;
 Libderiv->deriv_classes[5][6][2] = int_stack + 197700;
 Libderiv->deriv_classes[5][7][2] = int_stack + 198288;
 Libderiv->deriv_classes[5][8][2] = int_stack + 199044;
 Libderiv->deriv_classes[5][9][2] = int_stack + 199989;
 Libderiv->deriv_classes[5][10][2] = int_stack + 201144;
 Libderiv->deriv_classes[5][11][2] = int_stack + 202530;
 Libderiv->deriv_classes[6][6][2] = int_stack + 204168;
 Libderiv->deriv_classes[6][7][2] = int_stack + 204952;
 Libderiv->deriv_classes[6][8][2] = int_stack + 205960;
 Libderiv->deriv_classes[6][9][2] = int_stack + 207220;
 Libderiv->deriv_classes[6][10][2] = int_stack + 208760;
 Libderiv->deriv_classes[6][11][2] = int_stack + 210608;
 Libderiv->deriv_classes[7][6][2] = int_stack + 212792;
 Libderiv->deriv_classes[7][7][2] = int_stack + 213800;
 Libderiv->deriv_classes[7][8][2] = int_stack + 215096;
 Libderiv->deriv_classes[7][9][2] = int_stack + 216716;
 Libderiv->deriv_classes[7][10][2] = int_stack + 218696;
 Libderiv->deriv_classes[7][11][2] = int_stack + 221072;
 Libderiv->deriv_classes[4][6][1] = int_stack + 223880;
 Libderiv->deriv_classes[4][7][1] = int_stack + 224300;
 Libderiv->deriv_classes[4][8][1] = int_stack + 224840;
 Libderiv->deriv_classes[4][9][1] = int_stack + 225515;
 Libderiv->deriv_classes[4][10][1] = int_stack + 226340;
 Libderiv->deriv_classes[4][11][1] = int_stack + 227330;
 Libderiv->deriv_classes[5][6][1] = int_stack + 228500;
 Libderiv->deriv_classes[5][7][1] = int_stack + 229088;
 Libderiv->deriv_classes[5][8][1] = int_stack + 229844;
 Libderiv->deriv_classes[5][9][1] = int_stack + 230789;
 Libderiv->deriv_classes[5][10][1] = int_stack + 231944;
 Libderiv->deriv_classes[5][11][1] = int_stack + 233330;
 Libderiv->deriv_classes[6][6][1] = int_stack + 234968;
 Libderiv->deriv_classes[6][7][1] = int_stack + 235752;
 Libderiv->deriv_classes[6][8][1] = int_stack + 236760;
 Libderiv->deriv_classes[6][9][1] = int_stack + 238020;
 Libderiv->deriv_classes[6][10][1] = int_stack + 239560;
 Libderiv->deriv_classes[6][11][1] = int_stack + 241408;
 Libderiv->deriv_classes[7][6][1] = int_stack + 243592;
 Libderiv->deriv_classes[7][7][1] = int_stack + 244600;
 Libderiv->deriv_classes[7][8][1] = int_stack + 245896;
 Libderiv->deriv_classes[7][9][1] = int_stack + 247516;
 Libderiv->deriv_classes[7][10][1] = int_stack + 249496;
 Libderiv->deriv_classes[7][11][1] = int_stack + 251872;
 Libderiv->dvrr_classes[4][6] = int_stack + 254680;
 Libderiv->dvrr_classes[4][7] = int_stack + 255100;
 Libderiv->dvrr_classes[4][8] = int_stack + 255640;
 Libderiv->dvrr_classes[4][9] = int_stack + 256315;
 Libderiv->dvrr_classes[4][10] = int_stack + 257140;
 Libderiv->dvrr_classes[4][11] = int_stack + 258130;
 Libderiv->deriv_classes[4][6][0] = int_stack + 259300;
 Libderiv->deriv_classes[4][7][0] = int_stack + 259720;
 Libderiv->deriv_classes[4][8][0] = int_stack + 260260;
 Libderiv->deriv_classes[4][9][0] = int_stack + 260935;
 Libderiv->deriv_classes[4][10][0] = int_stack + 261760;
 Libderiv->deriv_classes[4][11][0] = int_stack + 262750;
 Libderiv->dvrr_classes[5][6] = int_stack + 263920;
 Libderiv->dvrr_classes[5][7] = int_stack + 264508;
 Libderiv->dvrr_classes[5][8] = int_stack + 265264;
 Libderiv->dvrr_classes[5][9] = int_stack + 266209;
 Libderiv->dvrr_classes[5][10] = int_stack + 267364;
 Libderiv->dvrr_classes[5][11] = int_stack + 268750;
 Libderiv->deriv_classes[5][6][0] = int_stack + 270388;
 Libderiv->deriv_classes[5][7][0] = int_stack + 270976;
 Libderiv->deriv_classes[5][8][0] = int_stack + 271732;
 Libderiv->deriv_classes[5][9][0] = int_stack + 272677;
 Libderiv->deriv_classes[5][10][0] = int_stack + 273832;
 Libderiv->deriv_classes[5][11][0] = int_stack + 275218;
 Libderiv->dvrr_classes[6][6] = int_stack + 276856;
 Libderiv->dvrr_classes[6][7] = int_stack + 277640;
 Libderiv->dvrr_classes[6][8] = int_stack + 278648;
 Libderiv->dvrr_classes[6][9] = int_stack + 279908;
 Libderiv->dvrr_classes[6][10] = int_stack + 281448;
 Libderiv->dvrr_classes[6][11] = int_stack + 283296;
 Libderiv->deriv_classes[6][6][0] = int_stack + 285480;
 Libderiv->deriv_classes[6][7][0] = int_stack + 286264;
 Libderiv->deriv_classes[6][8][0] = int_stack + 287272;
 Libderiv->deriv_classes[6][9][0] = int_stack + 288532;
 Libderiv->deriv_classes[6][10][0] = int_stack + 290072;
 Libderiv->deriv_classes[6][11][0] = int_stack + 291920;
 Libderiv->deriv_classes[7][6][0] = int_stack + 294104;
 Libderiv->deriv_classes[7][7][0] = int_stack + 295112;
 Libderiv->deriv_classes[7][8][0] = int_stack + 296408;
 Libderiv->deriv_classes[7][9][0] = int_stack + 298028;
 Libderiv->deriv_classes[7][10][0] = int_stack + 300008;
 Libderiv->deriv_classes[7][11][0] = int_stack + 302384;
 memset(int_stack,0,2441536);

 Libderiv->dvrr_stack = int_stack + 1586912;
 for(i=0;i<num_prim_comb;i++) {
   d1vrr_order_gfih(Libderiv, Data);
   Data++;
 }

 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+305192,int_stack+255100,int_stack+254680,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+306452,int_stack+255640,int_stack+255100,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+308072,int_stack+306452,int_stack+305192,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+310592,int_stack+256315,int_stack+255640,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+312617,int_stack+310592,int_stack+306452,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+315857,int_stack+312617,int_stack+308072,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+320057,int_stack+257140,int_stack+256315,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+322532,int_stack+320057,int_stack+310592,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+326582,int_stack+322532,int_stack+312617,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+331982,int_stack+326582,int_stack+315857,15);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+338282,int_stack+420,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254680,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+339542,int_stack+960,int_stack+420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255100,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+341162,int_stack+339542,int_stack+338282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305192,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+343682,int_stack+1635,int_stack+960, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255640,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+345707,int_stack+343682,int_stack+339542, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+306452,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+348947,int_stack+345707,int_stack+341162, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308072,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+338282,int_stack+2460,int_stack+1635, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256315,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+353147,int_stack+338282,int_stack+343682, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310592,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+357197,int_stack+353147,int_stack+345707, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+312617,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+340757,int_stack+357197,int_stack+348947, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315857,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+347057,int_stack+3450,int_stack+2460, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257140,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+362597,int_stack+347057,int_stack+338282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+320057,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+367547,int_stack+362597,int_stack+353147, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322532,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+347057,int_stack+367547,int_stack+357197, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+326582,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+355157,int_stack+347057,int_stack+340757, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331982,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+338282,int_stack+264508,int_stack+263920,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+340046,int_stack+265264,int_stack+264508,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+342314,int_stack+340046,int_stack+338282,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+345842,int_stack+266209,int_stack+265264,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+348677,int_stack+345842,int_stack+340046,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+363977,int_stack+348677,int_stack+342314,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+369857,int_stack+267364,int_stack+266209,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+373322,int_stack+369857,int_stack+345842,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+378992,int_stack+373322,int_stack+348677,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+386552,int_stack+378992,int_stack+363977,21);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+353213,int_stack+5208,int_stack+4620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263920,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+0,int_stack+5964,int_stack+5208, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264508,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+2268,int_stack+0,int_stack+353213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338282,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+395372,int_stack+6909,int_stack+5964, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265264,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+398207,int_stack+395372,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340046,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+402743,int_stack+398207,int_stack+2268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342314,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+0,int_stack+8064,int_stack+6909, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+266209,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+408623,int_stack+0,int_stack+395372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345842,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+414293,int_stack+408623,int_stack+398207, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348677,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+421853,int_stack+414293,int_stack+402743, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363977,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+395372,int_stack+9450,int_stack+8064, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267364,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+399530,int_stack+395372,int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369857,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+399530,int_stack+408623, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373322,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+395372,int_stack+0,int_stack+414293, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378992,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+406712,int_stack+395372,int_stack+421853, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386552,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+419060,int_stack+406712,int_stack+355157,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+395372,int_stack+277640,int_stack+276856,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+397724,int_stack+278648,int_stack+277640,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+400748,int_stack+397724,int_stack+395372,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+0,int_stack+279908,int_stack+278648,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+3780,int_stack+0,int_stack+397724,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+353213,int_stack+3780,int_stack+400748,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+445520,int_stack+281448,int_stack+279908,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+450140,int_stack+445520,int_stack+0,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+457700,int_stack+450140,int_stack+3780,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+467780,int_stack+457700,int_stack+353213,28);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+361053,int_stack+11872,int_stack+11088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276856,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+479540,int_stack+12880,int_stack+11872, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277640,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+482564,int_stack+479540,int_stack+361053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395372,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+487268,int_stack+14140,int_stack+12880, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278648,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+491048,int_stack+487268,int_stack+479540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397724,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+497096,int_stack+491048,int_stack+482564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400748,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+479540,int_stack+15680,int_stack+14140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279908,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+504936,int_stack+479540,int_stack+487268, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+512496,int_stack+504936,int_stack+491048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+484160,int_stack+512496,int_stack+497096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353213,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+495920,int_stack+17528,int_stack+15680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281448,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+9828,int_stack+495920,int_stack+479540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445520,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+522576,int_stack+9828,int_stack+504936, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450140,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+495920,int_stack+522576,int_stack+512496, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457700,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+511040,int_stack+495920,int_stack+484160, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467780,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+527504,int_stack+511040,int_stack+406712,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+564548,int_stack+527504,int_stack+419060,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+9828,int_stack+175728,int_stack+173712,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+12852,int_stack+178320,int_stack+175728,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+479540,int_stack+12852,int_stack+9828,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+485588,int_stack+181560,int_stack+178320,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+490448,int_stack+485588,int_stack+12852,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+498224,int_stack+490448,int_stack+479540,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+405452,int_stack+185520,int_stack+181560,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+411392,int_stack+405452,int_stack+485588,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+421112,int_stack+411392,int_stack+490448,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+617468,int_stack+421112,int_stack+498224,36);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+434072,int_stack+20720,int_stack+19712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173712,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+16740,int_stack+22016,int_stack+20720, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175728,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+437096,int_stack+16740,int_stack+434072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+632588,int_stack+23636,int_stack+22016, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178320,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+637448,int_stack+632588,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12852,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+645224,int_stack+637448,int_stack+437096, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479540,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+16740,int_stack+25616,int_stack+23636, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181560,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+434072,int_stack+16740,int_stack+632588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485588,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+655304,int_stack+434072,int_stack+637448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490448,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+668264,int_stack+655304,int_stack+645224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498224,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+632588,int_stack+27992,int_stack+25616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185520,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+639716,int_stack+632588,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405452,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+683384,int_stack+639716,int_stack+434072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411392,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+632588,int_stack+683384,int_stack+655304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421112,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+683384,int_stack+632588,int_stack+668264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617468,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+632588,int_stack+683384,int_stack+511040,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+681980,int_stack+632588,int_stack+527504,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+632588,int_stack+31220,int_stack+30800, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254680, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+633848,int_stack+31760,int_stack+31220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255100, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+635468,int_stack+633848,int_stack+632588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305192, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+637988,int_stack+32435,int_stack+31760, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255640, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+640013,int_stack+637988,int_stack+633848, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+306452, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+643253,int_stack+640013,int_stack+635468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308072, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+632588,int_stack+33260,int_stack+32435, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256315, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+647453,int_stack+632588,int_stack+637988, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310592, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+651503,int_stack+647453,int_stack+640013, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+312617, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+635063,int_stack+651503,int_stack+643253, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315857, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+641363,int_stack+34250,int_stack+33260, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257140, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+656903,int_stack+641363,int_stack+632588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+320057, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+661853,int_stack+656903,int_stack+647453, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322532, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+641363,int_stack+661853,int_stack+651503, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+326582, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+649463,int_stack+641363,int_stack+635063, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331982, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+632588,int_stack+36008,int_stack+35420, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263920, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+634352,int_stack+36764,int_stack+36008, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264508, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+636620,int_stack+634352,int_stack+632588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338282, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+640148,int_stack+37709,int_stack+36764, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265264, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+642983,int_stack+640148,int_stack+634352, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340046, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+658283,int_stack+642983,int_stack+636620, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342314, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+632588,int_stack+38864,int_stack+37709, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+266209, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+664163,int_stack+632588,int_stack+640148, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345842, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+669833,int_stack+664163,int_stack+642983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348677, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+636053,int_stack+669833,int_stack+658283, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363977, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+658283,int_stack+40250,int_stack+38864, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267364, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+434072,int_stack+658283,int_stack+632588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369857, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+16740,int_stack+434072,int_stack+664163, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373322, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+434072,int_stack+16740,int_stack+669833, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378992, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+16740,int_stack+434072,int_stack+636053, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386552, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+508304,int_stack+16740,int_stack+649463,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+434072,int_stack+42672,int_stack+41888, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276856, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+436424,int_stack+43680,int_stack+42672, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277640, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+439448,int_stack+436424,int_stack+434072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395372, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+29088,int_stack+44940,int_stack+43680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278648, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+32868,int_stack+29088,int_stack+436424, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397724, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+632588,int_stack+32868,int_stack+439448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400748, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+434072,int_stack+46480,int_stack+44940, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279908, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+38916,int_stack+434072,int_stack+29088, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+640428,int_stack+38916,int_stack+32868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+650508,int_stack+640428,int_stack+632588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353213, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+632588,int_stack+48328,int_stack+46480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281448, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+29088,int_stack+632588,int_stack+434072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445520, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+662268,int_stack+29088,int_stack+38916, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450140, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+29088,int_stack+662268,int_stack+640428, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457700, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+662268,int_stack+29088,int_stack+650508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467780, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+756068,int_stack+662268,int_stack+16740,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+793112,int_stack+756068,int_stack+508304,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+508304,int_stack+51520,int_stack+50512, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173712, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+511328,int_stack+52816,int_stack+51520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175728, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+515216,int_stack+511328,int_stack+508304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+521264,int_stack+54436,int_stack+52816, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178320, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+526124,int_stack+521264,int_stack+511328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12852, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+533900,int_stack+526124,int_stack+515216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479540, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+508304,int_stack+56416,int_stack+54436, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181560, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+543980,int_stack+508304,int_stack+521264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485588, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+16740,int_stack+543980,int_stack+526124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490448, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+514244,int_stack+16740,int_stack+533900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498224, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+529364,int_stack+58792,int_stack+56416, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185520, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+29700,int_stack+529364,int_stack+508304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405452, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+41580,int_stack+29700,int_stack+543980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411392, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+529364,int_stack+41580,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421112, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+16740,int_stack+529364,int_stack+514244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617468, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+508304,int_stack+16740,int_stack+662268,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+846032,int_stack+508304,int_stack+756068,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+756068,int_stack+62020,int_stack+61600, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254680, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+757328,int_stack+62560,int_stack+62020, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255100, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+758948,int_stack+757328,int_stack+756068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305192, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+761468,int_stack+63235,int_stack+62560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255640, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+763493,int_stack+761468,int_stack+757328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+306452, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+766733,int_stack+763493,int_stack+758948, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308072, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+756068,int_stack+64060,int_stack+63235, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256315, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+770933,int_stack+756068,int_stack+761468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310592, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+774983,int_stack+770933,int_stack+763493, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+312617, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+758543,int_stack+774983,int_stack+766733, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315857, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+764843,int_stack+65050,int_stack+64060, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257140, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+780383,int_stack+764843,int_stack+756068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+320057, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+785333,int_stack+780383,int_stack+770933, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322532, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+764843,int_stack+785333,int_stack+774983, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+326582, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+772943,int_stack+764843,int_stack+758543, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331982, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+756068,int_stack+66808,int_stack+66220, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263920, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+757832,int_stack+67564,int_stack+66808, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264508, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+760100,int_stack+757832,int_stack+756068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338282, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+763628,int_stack+68509,int_stack+67564, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265264, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+766463,int_stack+763628,int_stack+757832, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340046, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+781763,int_stack+766463,int_stack+760100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342314, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+756068,int_stack+69664,int_stack+68509, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+266209, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+508304,int_stack+756068,int_stack+763628, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345842, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+513974,int_stack+508304,int_stack+766463, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348677, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+759533,int_stack+513974,int_stack+781763, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363977, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+781763,int_stack+71050,int_stack+69664, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267364, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+785921,int_stack+781763,int_stack+756068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369857, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+521534,int_stack+785921,int_stack+508304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373322, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+781763,int_stack+521534,int_stack+513974, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378992, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+508304,int_stack+781763,int_stack+759533, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386552, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+520652,int_stack+508304,int_stack+772943,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+547112,int_stack+73472,int_stack+72688, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276856, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+549464,int_stack+74480,int_stack+73472, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277640, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+552488,int_stack+549464,int_stack+547112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395372, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+557192,int_stack+75740,int_stack+74480, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278648, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+756068,int_stack+557192,int_stack+549464, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397724, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+762116,int_stack+756068,int_stack+552488, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400748, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+547112,int_stack+77280,int_stack+75740, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279908, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+769956,int_stack+547112,int_stack+557192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+551732,int_stack+769956,int_stack+756068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+777516,int_stack+551732,int_stack+762116, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353213, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+756068,int_stack+79128,int_stack+77280, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281448, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+16740,int_stack+756068,int_stack+547112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445520, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+756068,int_stack+16740,int_stack+769956, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450140, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+16740,int_stack+756068,int_stack+551732, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457700, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+756068,int_stack+16740,int_stack+777516, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467780, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+16740,int_stack+756068,int_stack+508304,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+920120,int_stack+16740,int_stack+520652,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+508304,int_stack+82320,int_stack+81312, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173712, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+511328,int_stack+83616,int_stack+82320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175728, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+515216,int_stack+511328,int_stack+508304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+521264,int_stack+85236,int_stack+83616, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178320, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+526124,int_stack+521264,int_stack+511328, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12852, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+533900,int_stack+526124,int_stack+515216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479540, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+508304,int_stack+87216,int_stack+85236, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181560, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+543980,int_stack+508304,int_stack+521264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485588, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+53784,int_stack+543980,int_stack+526124, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490448, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+514244,int_stack+53784,int_stack+533900, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498224, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+529364,int_stack+89592,int_stack+87216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185520, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+66744,int_stack+529364,int_stack+508304, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405452, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+772532,int_stack+66744,int_stack+543980, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411392, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+66744,int_stack+772532,int_stack+53784, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421112, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+529364,int_stack+66744,int_stack+514244, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617468, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+632588,int_stack+529364,int_stack+756068,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+973040,int_stack+632588,int_stack+16740,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16740,int_stack+92820,int_stack+92400, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+254680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18000,int_stack+93360,int_stack+92820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+19620,int_stack+18000,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+22140,int_stack+94035,int_stack+93360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+255640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+24165,int_stack+22140,int_stack+18000, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+306452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+27405,int_stack+24165,int_stack+19620, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+308072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+16740,int_stack+94860,int_stack+94035, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+256315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+31605,int_stack+16740,int_stack+22140, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+310592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+35655,int_stack+31605,int_stack+24165, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+312617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+19215,int_stack+35655,int_stack+27405, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+315857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+25515,int_stack+95850,int_stack+94860, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+257140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+41055,int_stack+25515,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+320057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+46005,int_stack+41055,int_stack+31605, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+322532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+25515,int_stack+46005,int_stack+35655, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+326582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+33615,int_stack+25515,int_stack+19215, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+331982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16740,int_stack+97608,int_stack+97020, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+263920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+18504,int_stack+98364,int_stack+97608, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+264508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+20772,int_stack+18504,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+338282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+24300,int_stack+99309,int_stack+98364, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+265264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+27135,int_stack+24300,int_stack+18504, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+340046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+42435,int_stack+27135,int_stack+20772, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+342314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+16740,int_stack+100464,int_stack+99309, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+266209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+48315,int_stack+16740,int_stack+24300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+345842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+53985,int_stack+48315,int_stack+27135, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+348677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+20205,int_stack+53985,int_stack+42435, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+363977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+42435,int_stack+101850,int_stack+100464, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+267364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+61545,int_stack+42435,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+369857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+68475,int_stack+61545,int_stack+48315, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+373322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+42435,int_stack+68475,int_stack+53985, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+378992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+53775,int_stack+42435,int_stack+20205, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+386552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+66123,int_stack+53775,int_stack+33615,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+16740,int_stack+104272,int_stack+103488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+276856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+19092,int_stack+105280,int_stack+104272, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+277640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+22116,int_stack+19092,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+395372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+26820,int_stack+106540,int_stack+105280, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+278648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+30600,int_stack+26820,int_stack+19092, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+397724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+36648,int_stack+30600,int_stack+22116, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+400748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+16740,int_stack+108080,int_stack+106540, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+279908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+44488,int_stack+16740,int_stack+26820, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+92583,int_stack+44488,int_stack+30600, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+21360,int_stack+92583,int_stack+36648, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+353213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+33120,int_stack+109928,int_stack+108080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+281448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+102663,int_stack+33120,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+445520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+632588,int_stack+102663,int_stack+44488, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+450140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+33120,int_stack+632588,int_stack+92583, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+457700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+92583,int_stack+33120,int_stack+21360, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+467780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+756068,int_stack+92583,int_stack+53775,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+508304,int_stack+756068,int_stack+66123,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+109047,int_stack+113120,int_stack+112112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+173712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+632588,int_stack+114416,int_stack+113120, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+175728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+636476,int_stack+632588,int_stack+109047, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+109047,int_stack+116036,int_stack+114416, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+178320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+642524,int_stack+109047,int_stack+632588, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+12852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+650300,int_stack+642524,int_stack+636476, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+479540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+632588,int_stack+118016,int_stack+116036, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+181560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+660380,int_stack+632588,int_stack+109047, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+485588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+16740,int_stack+660380,int_stack+642524, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+490448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+29700,int_stack+16740,int_stack+650300, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+498224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+109047,int_stack+120392,int_stack+118016, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+185520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+670100,int_stack+109047,int_stack+632588, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+405452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+632588,int_stack+670100,int_stack+660380, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+411392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+648788,int_stack+632588,int_stack+16740, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+421112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+44820,int_stack+648788,int_stack+29700, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+632588,int_stack+44820,int_stack+92583,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+16740,int_stack+632588,int_stack+756068,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+756068,int_stack+123620,int_stack+123200, 0.0, zero_stack, 1.0, int_stack+254680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+757328,int_stack+124160,int_stack+123620, 0.0, zero_stack, 1.0, int_stack+255100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+758948,int_stack+757328,int_stack+756068, 0.0, zero_stack, 1.0, int_stack+305192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+761468,int_stack+124835,int_stack+124160, 0.0, zero_stack, 1.0, int_stack+255640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+763493,int_stack+761468,int_stack+757328, 0.0, zero_stack, 1.0, int_stack+306452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+766733,int_stack+763493,int_stack+758948, 0.0, zero_stack, 1.0, int_stack+308072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+756068,int_stack+125660,int_stack+124835, 0.0, zero_stack, 1.0, int_stack+256315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+770933,int_stack+756068,int_stack+761468, 0.0, zero_stack, 1.0, int_stack+310592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+774983,int_stack+770933,int_stack+763493, 0.0, zero_stack, 1.0, int_stack+312617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+758543,int_stack+774983,int_stack+766733, 0.0, zero_stack, 1.0, int_stack+315857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+764843,int_stack+126650,int_stack+125660, 0.0, zero_stack, 1.0, int_stack+257140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+780383,int_stack+764843,int_stack+756068, 0.0, zero_stack, 1.0, int_stack+320057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+785333,int_stack+780383,int_stack+770933, 0.0, zero_stack, 1.0, int_stack+322532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+764843,int_stack+785333,int_stack+774983, 0.0, zero_stack, 1.0, int_stack+326582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+772943,int_stack+764843,int_stack+758543, 0.0, zero_stack, 1.0, int_stack+331982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+756068,int_stack+128408,int_stack+127820, 0.0, zero_stack, 1.0, int_stack+263920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+757832,int_stack+129164,int_stack+128408, 0.0, zero_stack, 1.0, int_stack+264508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+760100,int_stack+757832,int_stack+756068, 0.0, zero_stack, 1.0, int_stack+338282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+763628,int_stack+130109,int_stack+129164, 0.0, zero_stack, 1.0, int_stack+265264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+766463,int_stack+763628,int_stack+757832, 0.0, zero_stack, 1.0, int_stack+340046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+781763,int_stack+766463,int_stack+760100, 0.0, zero_stack, 1.0, int_stack+342314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+756068,int_stack+131264,int_stack+130109, 0.0, zero_stack, 1.0, int_stack+266209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+632588,int_stack+756068,int_stack+763628, 0.0, zero_stack, 1.0, int_stack+345842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+638258,int_stack+632588,int_stack+766463, 0.0, zero_stack, 1.0, int_stack+348677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+759533,int_stack+638258,int_stack+781763, 0.0, zero_stack, 1.0, int_stack+363977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+781763,int_stack+132650,int_stack+131264, 0.0, zero_stack, 1.0, int_stack+267364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+785921,int_stack+781763,int_stack+756068, 0.0, zero_stack, 1.0, int_stack+369857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+645818,int_stack+785921,int_stack+632588, 0.0, zero_stack, 1.0, int_stack+373322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+781763,int_stack+645818,int_stack+638258, 0.0, zero_stack, 1.0, int_stack+378992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+632588,int_stack+781763,int_stack+759533, 0.0, zero_stack, 1.0, int_stack+386552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+644936,int_stack+632588,int_stack+772943,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+671396,int_stack+135072,int_stack+134288, 0.0, zero_stack, 1.0, int_stack+276856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+673748,int_stack+136080,int_stack+135072, 0.0, zero_stack, 1.0, int_stack+277640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+676772,int_stack+673748,int_stack+671396, 0.0, zero_stack, 1.0, int_stack+395372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+756068,int_stack+137340,int_stack+136080, 0.0, zero_stack, 1.0, int_stack+278648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+759848,int_stack+756068,int_stack+673748, 0.0, zero_stack, 1.0, int_stack+397724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+765896,int_stack+759848,int_stack+676772, 0.0, zero_stack, 1.0, int_stack+400748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+671396,int_stack+138880,int_stack+137340, 0.0, zero_stack, 1.0, int_stack+279908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+773736,int_stack+671396,int_stack+756068, 0.0, zero_stack, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+781296,int_stack+773736,int_stack+759848, 0.0, zero_stack, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+90828,int_stack+781296,int_stack+765896, 0.0, zero_stack, 1.0, int_stack+353213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+756068,int_stack+140728,int_stack+138880, 0.0, zero_stack, 1.0, int_stack+281448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+761612,int_stack+756068,int_stack+671396, 0.0, zero_stack, 1.0, int_stack+445520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+102588,int_stack+761612,int_stack+773736, 0.0, zero_stack, 1.0, int_stack+450140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+756068,int_stack+102588,int_stack+781296, 0.0, zero_stack, 1.0, int_stack+457700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+102588,int_stack+756068,int_stack+90828, 0.0, zero_stack, 1.0, int_stack+467780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+756068,int_stack+102588,int_stack+632588,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+1047128,int_stack+756068,int_stack+644936,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+632588,int_stack+143920,int_stack+142912, 0.0, zero_stack, 1.0, int_stack+173712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+635612,int_stack+145216,int_stack+143920, 0.0, zero_stack, 1.0, int_stack+175728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+639500,int_stack+635612,int_stack+632588, 0.0, zero_stack, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+645548,int_stack+146836,int_stack+145216, 0.0, zero_stack, 1.0, int_stack+178320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+650408,int_stack+645548,int_stack+635612, 0.0, zero_stack, 1.0, int_stack+12852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+658184,int_stack+650408,int_stack+639500, 0.0, zero_stack, 1.0, int_stack+479540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+632588,int_stack+148816,int_stack+146836, 0.0, zero_stack, 1.0, int_stack+181560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+668264,int_stack+632588,int_stack+645548, 0.0, zero_stack, 1.0, int_stack+485588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+119052,int_stack+668264,int_stack+650408, 0.0, zero_stack, 1.0, int_stack+490448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+638528,int_stack+119052,int_stack+658184, 0.0, zero_stack, 1.0, int_stack+498224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+653648,int_stack+151192,int_stack+148816, 0.0, zero_stack, 1.0, int_stack+185520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+132012,int_stack+653648,int_stack+632588, 0.0, zero_stack, 1.0, int_stack+405452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1100048,int_stack+132012,int_stack+668264, 0.0, zero_stack, 1.0, int_stack+411392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+132012,int_stack+1100048,int_stack+119052, 0.0, zero_stack, 1.0, int_stack+421112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+653648,int_stack+132012,int_stack+638528, 0.0, zero_stack, 1.0, int_stack+617468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1100048,int_stack+653648,int_stack+102588,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1149440,int_stack+1100048,int_stack+756068,588);
 /*--- compute (g0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+756068,int_stack+154420,int_stack+154000, 1.0, int_stack+254680, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+757328,int_stack+154960,int_stack+154420, 1.0, int_stack+255100, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+758948,int_stack+757328,int_stack+756068, 1.0, int_stack+305192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+761468,int_stack+155635,int_stack+154960, 1.0, int_stack+255640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+763493,int_stack+761468,int_stack+757328, 1.0, int_stack+306452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+766733,int_stack+763493,int_stack+758948, 1.0, int_stack+308072, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+305192,int_stack+156460,int_stack+155635, 1.0, int_stack+256315, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+756068,int_stack+305192,int_stack+761468, 1.0, int_stack+310592, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+770933,int_stack+756068,int_stack+763493, 1.0, int_stack+312617, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+307667,int_stack+770933,int_stack+766733, 1.0, int_stack+315857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+313967,int_stack+157450,int_stack+156460, 1.0, int_stack+257140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+760118,int_stack+313967,int_stack+305192, 1.0, int_stack+320057, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+776333,int_stack+760118,int_stack+756068, 1.0, int_stack+322532, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+756068,int_stack+776333,int_stack+770933, 1.0, int_stack+326582, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (g0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+764168,int_stack+756068,int_stack+307667, 1.0, int_stack+331982, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,15);
 /*--- compute (h0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+756068,int_stack+159208,int_stack+158620, 1.0, int_stack+263920, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+757832,int_stack+159964,int_stack+159208, 1.0, int_stack+264508, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+760100,int_stack+757832,int_stack+756068, 1.0, int_stack+338282, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+772988,int_stack+160909,int_stack+159964, 1.0, int_stack+265264, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+775823,int_stack+772988,int_stack+757832, 1.0, int_stack+340046, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+780359,int_stack+775823,int_stack+760100, 1.0, int_stack+342314, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+338282,int_stack+162064,int_stack+160909, 1.0, int_stack+266209, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+756068,int_stack+338282,int_stack+772988, 1.0, int_stack+345842, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+305192,int_stack+756068,int_stack+775823, 1.0, int_stack+348677, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+341747,int_stack+305192,int_stack+780359, 1.0, int_stack+363977, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+772988,int_stack+163450,int_stack+162064, 1.0, int_stack+267364, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+777146,int_stack+772988,int_stack+338282, 1.0, int_stack+369857, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+1100048,int_stack+777146,int_stack+756068, 1.0, int_stack+373322, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+772988,int_stack+1100048,int_stack+305192, 1.0, int_stack+378992, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (h0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+305192,int_stack+772988,int_stack+341747, 1.0, int_stack+386552, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1100048,int_stack+305192,int_stack+764168,588);
 /*--- compute (i0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+317540,int_stack+165872,int_stack+165088, 1.0, int_stack+276856, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1126508,int_stack+166880,int_stack+165872, 1.0, int_stack+277640, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1129532,int_stack+1126508,int_stack+317540, 1.0, int_stack+395372, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1134236,int_stack+168140,int_stack+166880, 1.0, int_stack+278648, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1138016,int_stack+1134236,int_stack+1126508, 1.0, int_stack+397724, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+756068,int_stack+1138016,int_stack+1129532, 1.0, int_stack+400748, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+1126508,int_stack+169680,int_stack+168140, 1.0, int_stack+279908, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+395372,int_stack+1126508,int_stack+1134236, 1.0, int_stack+0, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+763908,int_stack+395372,int_stack+1138016, 1.0, int_stack+3780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1131128,int_stack+763908,int_stack+756068, 1.0, int_stack+353213, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+756068,int_stack+171528,int_stack+169680, 1.0, int_stack+281448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+0,int_stack+756068,int_stack+1126508, 1.0, int_stack+445520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+773988,int_stack+0,int_stack+395372, 1.0, int_stack+450140, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+338282,int_stack+773988,int_stack+763908, 1.0, int_stack+457700, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (i0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+756068,int_stack+338282,int_stack+1131128, 1.0, int_stack+467780, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+632588,int_stack+756068,int_stack+305192,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+90828,int_stack+632588,int_stack+1100048,588);
 /*--- compute (k0|ip) ---*/
   d1hrr3_build_ip(Libderiv->CD,int_stack+1100048,int_stack+177024,int_stack+174720, 1.0, int_stack+173712, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kp) ---*/
   d1hrr3_build_kp(Libderiv->CD,int_stack+1103072,int_stack+179940,int_stack+177024, 1.0, int_stack+175728, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|id) ---*/
   d1hrr3_build_id(Libderiv->CD,int_stack+1106960,int_stack+1103072,int_stack+1100048, 1.0, int_stack+9828, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lp) ---*/
   d1hrr3_build_lp(Libderiv->CD,int_stack+1113008,int_stack+183540,int_stack+179940, 1.0, int_stack+178320, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kd) ---*/
   d1hrr3_build_kd(Libderiv->CD,int_stack+1117868,int_stack+1113008,int_stack+1103072, 1.0, int_stack+12852, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|if) ---*/
   d1hrr3_build_if(Libderiv->CD,int_stack+395372,int_stack+1117868,int_stack+1106960, 1.0, int_stack+479540, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|mp) ---*/
   d1hrr3_build_mp(Libderiv->CD,int_stack+479540,int_stack+187896,int_stack+183540, 1.0, int_stack+181560, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ld) ---*/
   d1hrr3_build_ld(Libderiv->CD,int_stack+1100048,int_stack+479540,int_stack+1113008, 1.0, int_stack+485588, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kf) ---*/
   d1hrr3_build_kf(Libderiv->CD,int_stack+1125644,int_stack+1100048,int_stack+1117868, 1.0, int_stack+490448, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ig) ---*/
   d1hrr3_build_ig(Libderiv->CD,int_stack+1109768,int_stack+1125644,int_stack+395372, 1.0, int_stack+498224, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|np) ---*/
   d1hrr3_build_np(Libderiv->CD,int_stack+395372,int_stack+190272,int_stack+187896, 1.0, int_stack+185520, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|md) ---*/
   d1hrr3_build_md(Libderiv->CD,int_stack+485480,int_stack+395372,int_stack+479540, 1.0, int_stack+405452, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|lf) ---*/
   d1hrr3_build_lf(Libderiv->CD,int_stack+338282,int_stack+485480,int_stack+1100048, 1.0, int_stack+411392, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|kg) ---*/
   d1hrr3_build_kg(Libderiv->CD,int_stack+479540,int_stack+338282,int_stack+1125644, 1.0, int_stack+421112, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (k0|ih) ---*/
   d1hrr3_build_ih(Libderiv->CD,int_stack+338282,int_stack+479540,int_stack+1109768, 1.0, int_stack+617468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,36);
 /*--- compute (ip|ih) ---*/
   hrr1_build_ip(Libderiv->AB,int_stack+1100048,int_stack+338282,int_stack+756068,588);
 /*--- compute (hd|ih) ---*/
   hrr1_build_hd(Libderiv->AB,int_stack+1223528,int_stack+1100048,int_stack+632588,588);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1100048,int_stack+258130,int_stack+257140,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1103018,int_stack+1100048,int_stack+320057,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1107968,int_stack+1103018,int_stack+322532,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1114718,int_stack+1107968,int_stack+326582,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1100048,int_stack+1114718,int_stack+331982,15);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1108868,int_stack+268750,int_stack+267364,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+1113026,int_stack+1108868,int_stack+369857,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+1119956,int_stack+1113026,int_stack+373322,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+1129406,int_stack+1119956,int_stack+378992,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+1108868,int_stack+1129406,int_stack+386552,21);
 /*--- compute (gp|ih) ---*/
   hrr1_build_gp(Libderiv->AB,int_stack+1121216,int_stack+1108868,int_stack+1100048,588);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+756068,int_stack+283296,int_stack+281448,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+761612,int_stack+756068,int_stack+445520,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+770852,int_stack+761612,int_stack+450140,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+617468,int_stack+770852,int_stack+457700,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+756068,int_stack+617468,int_stack+467780,28);
 /*--- compute (hp|ih) ---*/
   hrr1_build_hp(Libderiv->AB,int_stack+617468,int_stack+756068,int_stack+1108868,588);
 /*--- compute (gd|ih) ---*/
   hrr1_build_gd(Libderiv->AB,int_stack+305192,int_stack+617468,int_stack+1121216,588);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+654512,int_stack+193500,int_stack+193080,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+655772,int_stack+194040,int_stack+193500,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+657392,int_stack+655772,int_stack+654512,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+659912,int_stack+194715,int_stack+194040,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+661937,int_stack+659912,int_stack+655772,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+665177,int_stack+661937,int_stack+657392,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+654512,int_stack+195540,int_stack+194715,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+669377,int_stack+654512,int_stack+659912,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+673427,int_stack+669377,int_stack+661937,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+656987,int_stack+673427,int_stack+665177,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+663287,int_stack+196530,int_stack+195540,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+772532,int_stack+663287,int_stack+654512,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+777482,int_stack+772532,int_stack+669377,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+663287,int_stack+777482,int_stack+673427,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+772532,int_stack+663287,int_stack+656987,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1147676,int_stack+198288,int_stack+197700,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+781352,int_stack+199044,int_stack+198288,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+783620,int_stack+781352,int_stack+1147676,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+787148,int_stack+199989,int_stack+199044,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+654512,int_stack+787148,int_stack+781352,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+659048,int_stack+654512,int_stack+783620,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+781352,int_stack+201144,int_stack+199989,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+664928,int_stack+781352,int_stack+787148,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+784817,int_stack+664928,int_stack+654512,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+670598,int_stack+784817,int_stack+659048,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+654512,int_stack+202530,int_stack+201144,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+358112,int_stack+654512,int_stack+781352,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+654512,int_stack+358112,int_stack+664928,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+358112,int_stack+654512,int_stack+784817,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+654512,int_stack+358112,int_stack+670598,21);
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+358112,int_stack+654512,int_stack+772532, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1100048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+772532,int_stack+204952,int_stack+204168,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+774884,int_stack+205960,int_stack+204952,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+777908,int_stack+774884,int_stack+772532,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+782612,int_stack+207220,int_stack+205960,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+786392,int_stack+782612,int_stack+774884,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+384572,int_stack+786392,int_stack+777908,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+254680,int_stack+208760,int_stack+207220,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+772532,int_stack+254680,int_stack+782612,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+392412,int_stack+772532,int_stack+786392,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+780092,int_stack+392412,int_stack+384572,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+384572,int_stack+210608,int_stack+208760,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+402492,int_stack+384572,int_stack+254680,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+411732,int_stack+402492,int_stack+772532,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+666860,int_stack+411732,int_stack+392412,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+384572,int_stack+666860,int_stack+780092,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+401036,int_stack+384572,int_stack+654512, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1108868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gd|ih) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+438080,int_stack+401036,int_stack+358112, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+1121216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+358112,int_stack+213800,int_stack+212792,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+361136,int_stack+215096,int_stack+213800,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+365024,int_stack+361136,int_stack+358112,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+371072,int_stack+216716,int_stack+215096,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+375932,int_stack+371072,int_stack+361136,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+654512,int_stack+375932,int_stack+365024,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+358112,int_stack+218696,int_stack+216716,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+664592,int_stack+358112,int_stack+371072,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+772532,int_stack+664592,int_stack+375932,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+364052,int_stack+772532,int_stack+654512,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+654512,int_stack+221072,int_stack+218696,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+491000,int_stack+654512,int_stack+358112,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+0,int_stack+491000,int_stack+664592,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+654512,int_stack+0,int_stack+772532,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+143748,int_stack+654512,int_stack+364052,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+164916,int_stack+143748,int_stack+384572, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+756068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1297616,int_stack+164916,int_stack+401036, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+617468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+143748,int_stack+224300,int_stack+223880,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+145008,int_stack+224840,int_stack+224300,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+146628,int_stack+145008,int_stack+143748,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+149148,int_stack+225515,int_stack+224840,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+151173,int_stack+149148,int_stack+145008,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+154413,int_stack+151173,int_stack+146628,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+143748,int_stack+226340,int_stack+225515,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+158613,int_stack+143748,int_stack+149148,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+162663,int_stack+158613,int_stack+151173,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+146223,int_stack+162663,int_stack+154413,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+152523,int_stack+227330,int_stack+226340,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+168063,int_stack+152523,int_stack+143748,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+173013,int_stack+168063,int_stack+158613,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+152523,int_stack+173013,int_stack+162663,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+160623,int_stack+152523,int_stack+146223,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1147676,int_stack+229088,int_stack+228500,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+143748,int_stack+229844,int_stack+229088,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+146016,int_stack+143748,int_stack+1147676,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+149544,int_stack+230789,int_stack+229844,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+152379,int_stack+149544,int_stack+143748,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+169443,int_stack+152379,int_stack+146016,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+143748,int_stack+231944,int_stack+230789,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+175323,int_stack+143748,int_stack+149544,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+180993,int_stack+175323,int_stack+152379,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+147213,int_stack+180993,int_stack+169443,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+169443,int_stack+233330,int_stack+231944,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+188553,int_stack+169443,int_stack+143748,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+195483,int_stack+188553,int_stack+175323,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+169443,int_stack+195483,int_stack+180993,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+180783,int_stack+169443,int_stack+147213,21);
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+193131,int_stack+180783,int_stack+160623, 0.0, zero_stack, 1.0, int_stack+1100048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+143748,int_stack+235752,int_stack+234968,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+146100,int_stack+236760,int_stack+235752,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+149124,int_stack+146100,int_stack+143748,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+153828,int_stack+238020,int_stack+236760,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+157608,int_stack+153828,int_stack+146100,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+163656,int_stack+157608,int_stack+149124,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+254680,int_stack+239560,int_stack+238020,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+143748,int_stack+254680,int_stack+153828,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+219591,int_stack+143748,int_stack+157608,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+151308,int_stack+219591,int_stack+163656,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+163068,int_stack+241408,int_stack+239560,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+168612,int_stack+163068,int_stack+254680,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+229671,int_stack+168612,int_stack+143748,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+163068,int_stack+229671,int_stack+219591,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+219591,int_stack+163068,int_stack+151308,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+358112,int_stack+219591,int_stack+180783, 0.0, zero_stack, 1.0, int_stack+1108868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gd|ih) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+1371704,int_stack+358112,int_stack+193131, 0.0, zero_stack, 1.0, int_stack+1121216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+236055,int_stack+244600,int_stack+243592,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+239079,int_stack+245896,int_stack+244600,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+143748,int_stack+239079,int_stack+236055,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+149796,int_stack+247516,int_stack+245896,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+154656,int_stack+149796,int_stack+239079,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+236055,int_stack+154656,int_stack+143748,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+143748,int_stack+249496,int_stack+247516,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+162432,int_stack+143748,int_stack+149796,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+172152,int_stack+162432,int_stack+154656,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+185112,int_stack+172152,int_stack+236055,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+236055,int_stack+251872,int_stack+249496,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+243183,int_stack+236055,int_stack+143748,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+143748,int_stack+243183,int_stack+162432,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+236055,int_stack+143748,int_stack+172152,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+143748,int_stack+236055,int_stack+185112,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+164916,int_stack+143748,int_stack+219591, 0.0, zero_stack, 1.0, int_stack+756068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+1424624,int_stack+164916,int_stack+358112, 0.0, zero_stack, 1.0, int_stack+617468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (g0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+358112,int_stack+259720,int_stack+259300,15);
 /*--- compute (g0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+359372,int_stack+260260,int_stack+259720,15);
 /*--- compute (g0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+360992,int_stack+359372,int_stack+358112,15);
 /*--- compute (g0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+363512,int_stack+260935,int_stack+260260,15);
 /*--- compute (g0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+365537,int_stack+363512,int_stack+359372,15);
 /*--- compute (g0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+368777,int_stack+365537,int_stack+360992,15);
 /*--- compute (g0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+358112,int_stack+261760,int_stack+260935,15);
 /*--- compute (g0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+372977,int_stack+358112,int_stack+363512,15);
 /*--- compute (g0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+377027,int_stack+372977,int_stack+365537,15);
 /*--- compute (g0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+360587,int_stack+377027,int_stack+368777,15);
 /*--- compute (g0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+366887,int_stack+262750,int_stack+261760,15);
 /*--- compute (g0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+382427,int_stack+366887,int_stack+358112,15);
 /*--- compute (g0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+387377,int_stack+382427,int_stack+372977,15);
 /*--- compute (g0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+366887,int_stack+387377,int_stack+377027,15);
 /*--- compute (g0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+374987,int_stack+366887,int_stack+360587,15);
 /*--- compute (h0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1147676,int_stack+270976,int_stack+270388,21);
 /*--- compute (h0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+358112,int_stack+271732,int_stack+270976,21);
 /*--- compute (h0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+360380,int_stack+358112,int_stack+1147676,21);
 /*--- compute (h0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+363908,int_stack+272677,int_stack+271732,21);
 /*--- compute (h0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+366743,int_stack+363908,int_stack+358112,21);
 /*--- compute (h0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+383807,int_stack+366743,int_stack+360380,21);
 /*--- compute (h0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+358112,int_stack+273832,int_stack+272677,21);
 /*--- compute (h0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+389687,int_stack+358112,int_stack+363908,21);
 /*--- compute (h0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+395357,int_stack+389687,int_stack+366743,21);
 /*--- compute (h0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+361577,int_stack+395357,int_stack+383807,21);
 /*--- compute (h0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+383807,int_stack+275218,int_stack+273832,21);
 /*--- compute (h0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+402917,int_stack+383807,int_stack+358112,21);
 /*--- compute (h0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+409847,int_stack+402917,int_stack+389687,21);
 /*--- compute (h0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+383807,int_stack+409847,int_stack+395357,21);
 /*--- compute (h0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+395147,int_stack+383807,int_stack+361577,21);
 /*--- compute (gp|ih) ---*/
   d1hrr1_build_gp(Libderiv->AB,int_stack+407495,int_stack+395147,int_stack+374987, 1.0, int_stack+1100048, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (i0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+1100048,int_stack+286264,int_stack+285480,28);
 /*--- compute (i0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+1102400,int_stack+287272,int_stack+286264,28);
 /*--- compute (i0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+358112,int_stack+1102400,int_stack+1100048,28);
 /*--- compute (i0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+362816,int_stack+288532,int_stack+287272,28);
 /*--- compute (i0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+366596,int_stack+362816,int_stack+1102400,28);
 /*--- compute (i0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+1100048,int_stack+366596,int_stack+358112,28);
 /*--- compute (i0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+358112,int_stack+290072,int_stack+288532,28);
 /*--- compute (i0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+372644,int_stack+358112,int_stack+362816,28);
 /*--- compute (i0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+380204,int_stack+372644,int_stack+366596,28);
 /*--- compute (i0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+143748,int_stack+380204,int_stack+1100048,28);
 /*--- compute (i0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+1100048,int_stack+291920,int_stack+290072,28);
 /*--- compute (i0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+362732,int_stack+1100048,int_stack+358112,28);
 /*--- compute (i0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+155508,int_stack+362732,int_stack+372644,28);
 /*--- compute (i0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+358112,int_stack+155508,int_stack+380204,28);
 /*--- compute (i0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+155508,int_stack+358112,int_stack+143748,28);
 /*--- compute (hp|ih) ---*/
   d1hrr1_build_hp(Libderiv->AB,int_stack+171972,int_stack+155508,int_stack+395147, 1.0, int_stack+1108868, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gd|ih) ---*/
   d1hrr1_build_gd(Libderiv->AB,int_stack+209016,int_stack+171972,int_stack+407495, 1.0, int_stack+1121216, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (k0|ip) ---*/
   hrr3_build_ip(Libderiv->CD,int_stack+143748,int_stack+295112,int_stack+294104,36);
 /*--- compute (k0|kp) ---*/
   hrr3_build_kp(Libderiv->CD,int_stack+146772,int_stack+296408,int_stack+295112,36);
 /*--- compute (k0|id) ---*/
   hrr3_build_id(Libderiv->CD,int_stack+358112,int_stack+146772,int_stack+143748,36);
 /*--- compute (k0|lp) ---*/
   hrr3_build_lp(Libderiv->CD,int_stack+364160,int_stack+298028,int_stack+296408,36);
 /*--- compute (k0|kd) ---*/
   hrr3_build_kd(Libderiv->CD,int_stack+369020,int_stack+364160,int_stack+146772,36);
 /*--- compute (k0|if) ---*/
   hrr3_build_if(Libderiv->CD,int_stack+143748,int_stack+369020,int_stack+358112,36);
 /*--- compute (k0|mp) ---*/
   hrr3_build_mp(Libderiv->CD,int_stack+358112,int_stack+300008,int_stack+298028,36);
 /*--- compute (k0|ld) ---*/
   hrr3_build_ld(Libderiv->CD,int_stack+376796,int_stack+358112,int_stack+364160,36);
 /*--- compute (k0|kf) ---*/
   hrr3_build_kf(Libderiv->CD,int_stack+386516,int_stack+376796,int_stack+369020,36);
 /*--- compute (k0|ig) ---*/
   hrr3_build_ig(Libderiv->CD,int_stack+399476,int_stack+386516,int_stack+143748,36);
 /*--- compute (k0|np) ---*/
   hrr3_build_np(Libderiv->CD,int_stack+143748,int_stack+302384,int_stack+300008,36);
 /*--- compute (k0|md) ---*/
   hrr3_build_md(Libderiv->CD,int_stack+364052,int_stack+143748,int_stack+358112,36);
 /*--- compute (k0|lf) ---*/
   hrr3_build_lf(Libderiv->CD,int_stack+414596,int_stack+364052,int_stack+376796,36);
 /*--- compute (k0|kg) ---*/
   hrr3_build_kg(Libderiv->CD,int_stack+358112,int_stack+414596,int_stack+386516,36);
 /*--- compute (k0|ih) ---*/
   hrr3_build_ih(Libderiv->CD,int_stack+414596,int_stack+358112,int_stack+399476,36);
 /*--- compute (ip|ih) ---*/
   d1hrr1_build_ip(Libderiv->AB,int_stack+1100048,int_stack+414596,int_stack+155508, 1.0, int_stack+756068, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (hd|ih) ---*/
   d1hrr1_build_hd(Libderiv->AB,int_stack+358112,int_stack+1100048,int_stack+171972, 1.0, int_stack+617468, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+1498712,int_stack+681980,int_stack+564548,588);
     Libderiv->ABCD[11] = int_stack + 1498712;
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+561224,int_stack+846032,int_stack+793112,588);
     Libderiv->ABCD[10] = int_stack + 561224;
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+649424,int_stack+973040,int_stack+920120,588);
     Libderiv->ABCD[9] = int_stack + 649424;
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+737624,int_stack+16740,int_stack+508304,588);
     Libderiv->ABCD[8] = int_stack + 737624;
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+0,int_stack+1149440,int_stack+1047128,588);
     Libderiv->ABCD[7] = int_stack + 0;
 /*--- compute (gf|ih) ---*/
   hrr1_build_gf(Libderiv->AB,int_stack+825824,int_stack+1223528,int_stack+90828,588);
     Libderiv->ABCD[6] = int_stack + 825824;
 /*--- compute (gf|ih) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+88200,int_stack+1297616,int_stack+438080, 0.0, zero_stack, 0.0, zero_stack, 1.0, int_stack+305192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[2] = int_stack + 88200;
 /*--- compute (gf|ih) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+432200,int_stack+1424624,int_stack+1371704, 0.0, zero_stack, 1.0, int_stack+305192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[1] = int_stack + 432200;
 /*--- compute (gf|ih) ---*/
   d1hrr1_build_gf(Libderiv->AB,int_stack+914024,int_stack+358112,int_stack+209016, 1.0, int_stack+305192, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack, 0.0, zero_stack,588);
     Libderiv->ABCD[0] = int_stack + 914024;

}
