/*
 *  Copyright (C) 1996-2017 Edward F. Valeev and Justin T. Fermann
 *
 *  This file is part of Libint.
 *
 *  Libint is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Libint is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with Libint.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdio.h>
#include <libint/libint.h>
#include "libderiv.h"
#include <libint/vrr_header.h>
#include <libint/hrr_header.h>
#include "deriv_header.h"

  /* Computes quartets necessary to compute derivatives of (hg|ih) integrals */

void d1vrr_order_hgih(Libderiv_t *Libderiv, prim_data *Data)
{
 double *dvrr_stack = Libderiv->dvrr_stack;
 double *tmp, *target_ptr;
 int i, am[2];
 /* compute (0 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+0, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (0 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+0, dvrr_stack+3, Data->F+5, Data->F+6, NULL);

 /* compute (0 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12, Data->F+4, Data->F+5, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+15, dvrr_stack+12, dvrr_stack+0, Data->F+4, Data->F+5, NULL);

 /* compute (1 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+21, dvrr_stack+15, dvrr_stack+6, NULL, NULL, dvrr_stack+0);

 /* compute (0 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+15, dvrr_stack+6, dvrr_stack+12, dvrr_stack+0, NULL);

 /* compute (0 0 | 1 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+3, Data->F+4, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+52, dvrr_stack+49, dvrr_stack+12, Data->F+3, Data->F+4, NULL);

 /* compute (0 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+58, dvrr_stack+52, dvrr_stack+15, dvrr_stack+49, dvrr_stack+12, NULL);

 /* compute (0 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+68, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+71, dvrr_stack+3, dvrr_stack+68, Data->F+6, Data->F+7, NULL);

 /* compute (0 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+77, dvrr_stack+6, dvrr_stack+71, dvrr_stack+0, dvrr_stack+3, NULL);

 /* compute (1 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+87, dvrr_stack+39, dvrr_stack+77, NULL, NULL, dvrr_stack+6);

 /* compute (1 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+117, dvrr_stack+58, dvrr_stack+39, NULL, NULL, dvrr_stack+15);

 /* compute (2 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+147, dvrr_stack+117, dvrr_stack+87, dvrr_stack+58, dvrr_stack+39, dvrr_stack+21);

 /* compute (0 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+39, dvrr_stack+77, dvrr_stack+15, dvrr_stack+6, NULL);

 /* compute (0 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+58, dvrr_stack+39, dvrr_stack+52, dvrr_stack+15, NULL);

 /* compute (1 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+237, dvrr_stack+222, dvrr_stack+207, NULL, NULL, dvrr_stack+39);

 /* compute (0 0 | 1 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+2, Data->F+3, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+282, dvrr_stack+49, Data->F+2, Data->F+3, NULL);

 /* compute (0 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+291, dvrr_stack+285, dvrr_stack+52, dvrr_stack+282, dvrr_stack+49, NULL);

 /* compute (0 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+301, dvrr_stack+291, dvrr_stack+58, dvrr_stack+285, dvrr_stack+52, NULL);

 /* compute (1 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+316, dvrr_stack+301, dvrr_stack+222, NULL, NULL, dvrr_stack+58);

 /* compute (0 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+49, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+361, dvrr_stack+68, dvrr_stack+49, Data->F+7, Data->F+8, NULL);

 /* compute (0 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+367, dvrr_stack+71, dvrr_stack+361, dvrr_stack+3, dvrr_stack+68, NULL);

 /* compute (0 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+377, dvrr_stack+77, dvrr_stack+367, dvrr_stack+6, dvrr_stack+71, NULL);

 /* compute (1 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+392, dvrr_stack+207, dvrr_stack+377, NULL, NULL, dvrr_stack+77);

 /* compute (2 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+437, dvrr_stack+237, dvrr_stack+392, dvrr_stack+222, dvrr_stack+207, dvrr_stack+87);

 /* compute (2 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+527, dvrr_stack+316, dvrr_stack+237, dvrr_stack+301, dvrr_stack+222, dvrr_stack+117);

 /* compute (3 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+617, dvrr_stack+527, dvrr_stack+437, dvrr_stack+316, dvrr_stack+237, dvrr_stack+147);

 /* compute (0 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+767, dvrr_stack+222, dvrr_stack+207, dvrr_stack+58, dvrr_stack+39, NULL);

 /* compute (0 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+788, dvrr_stack+301, dvrr_stack+222, dvrr_stack+291, dvrr_stack+58, NULL);

 /* compute (0 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+809, dvrr_stack+207, dvrr_stack+377, dvrr_stack+39, dvrr_stack+77, NULL);

 /* compute (1 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+830, dvrr_stack+767, dvrr_stack+809, NULL, NULL, dvrr_stack+207);

 /* compute (1 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+893, dvrr_stack+788, dvrr_stack+767, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+956, dvrr_stack+893, dvrr_stack+830, dvrr_stack+788, dvrr_stack+767, dvrr_stack+237);

 /* compute (0 0 | 1 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+1082, Data->F+1, Data->F+2, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+1085, dvrr_stack+1082, dvrr_stack+282, Data->F+1, Data->F+2, NULL);

 /* compute (0 0 | 3 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1091, dvrr_stack+1085, dvrr_stack+285, dvrr_stack+1082, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1101, dvrr_stack+1091, dvrr_stack+291, dvrr_stack+1085, dvrr_stack+285, NULL);

 /* compute (0 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1116, dvrr_stack+1101, dvrr_stack+301, dvrr_stack+1091, dvrr_stack+291, NULL);

 /* compute (1 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1137, dvrr_stack+1116, dvrr_stack+788, NULL, NULL, dvrr_stack+301);

 /* compute (2 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1200, dvrr_stack+1137, dvrr_stack+893, dvrr_stack+1116, dvrr_stack+788, dvrr_stack+316);

 /* compute (0 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+282, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+285, dvrr_stack+49, dvrr_stack+282, Data->F+8, Data->F+9, NULL);

 /* compute (0 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1326, dvrr_stack+361, dvrr_stack+285, dvrr_stack+68, dvrr_stack+49, NULL);

 /* compute (0 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1336, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+71, dvrr_stack+361, NULL);

 /* compute (0 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+1351, dvrr_stack+377, dvrr_stack+1336, dvrr_stack+77, dvrr_stack+367, NULL);

 /* compute (1 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+1372, dvrr_stack+809, dvrr_stack+1351, NULL, NULL, dvrr_stack+377);

 /* compute (2 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+1435, dvrr_stack+830, dvrr_stack+1372, dvrr_stack+767, dvrr_stack+809, dvrr_stack+392);

 /* compute (3 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1561, dvrr_stack+956, dvrr_stack+1435, dvrr_stack+893, dvrr_stack+830, dvrr_stack+437);

 /* compute (3 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+1771, dvrr_stack+1200, dvrr_stack+956, dvrr_stack+1137, dvrr_stack+893, dvrr_stack+527);

 /* compute (4 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+1981, dvrr_stack+1771, dvrr_stack+1561, dvrr_stack+1200, dvrr_stack+956, dvrr_stack+617);

 /* compute (0 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2296, dvrr_stack+767, dvrr_stack+809, dvrr_stack+222, dvrr_stack+207, NULL);

 /* compute (0 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2324, dvrr_stack+788, dvrr_stack+767, dvrr_stack+301, dvrr_stack+222, NULL);

 /* compute (1 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2352, dvrr_stack+2324, dvrr_stack+2296, NULL, NULL, dvrr_stack+767);

 /* compute (0 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2436, dvrr_stack+1116, dvrr_stack+788, dvrr_stack+1101, dvrr_stack+301, NULL);

 /* compute (1 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2464, dvrr_stack+2436, dvrr_stack+2324, NULL, NULL, dvrr_stack+788);

 /* compute (0 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2548, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+207, dvrr_stack+377, NULL);

 /* compute (1 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+2576, dvrr_stack+2296, dvrr_stack+2548, NULL, NULL, dvrr_stack+809);

 /* compute (2 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2660, dvrr_stack+2352, dvrr_stack+2576, dvrr_stack+2324, dvrr_stack+2296, dvrr_stack+830);

 /* compute (2 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+2828, dvrr_stack+2464, dvrr_stack+2352, dvrr_stack+2436, dvrr_stack+2324, dvrr_stack+893);

 /* compute (3 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+2996, dvrr_stack+2828, dvrr_stack+2660, dvrr_stack+2464, dvrr_stack+2352, dvrr_stack+956);

 /* compute (0 0 | 1 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+893, Data->F+0, Data->F+1, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+896, dvrr_stack+893, dvrr_stack+1082, Data->F+0, Data->F+1, NULL);

 /* compute (0 0 | 3 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+902, dvrr_stack+896, dvrr_stack+1085, dvrr_stack+893, dvrr_stack+1082, NULL);

 /* compute (0 0 | 4 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+902, dvrr_stack+1091, dvrr_stack+896, dvrr_stack+1085, NULL);

 /* compute (0 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+912, dvrr_stack+222, dvrr_stack+1101, dvrr_stack+902, dvrr_stack+1091, NULL);

 /* compute (0 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+912, dvrr_stack+1116, dvrr_stack+222, dvrr_stack+1101, NULL);

 /* compute (1 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3304, dvrr_stack+3276, dvrr_stack+2436, NULL, NULL, dvrr_stack+1116);

 /* compute (2 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+3388, dvrr_stack+3304, dvrr_stack+2464, dvrr_stack+3276, dvrr_stack+2436, dvrr_stack+1137);

 /* compute (3 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+3556, dvrr_stack+3388, dvrr_stack+2828, dvrr_stack+3304, dvrr_stack+2464, dvrr_stack+1200);

 /* compute (0 0 | 1 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3304, Data->F+10, Data->F+11, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+3307, dvrr_stack+282, dvrr_stack+3304, Data->F+9, Data->F+10, NULL);

 /* compute (0 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+3313, dvrr_stack+285, dvrr_stack+3307, dvrr_stack+49, dvrr_stack+282, NULL);

 /* compute (0 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+222, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+361, dvrr_stack+285, NULL);

 /* compute (0 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3323, dvrr_stack+1336, dvrr_stack+222, dvrr_stack+367, dvrr_stack+1326, NULL);

 /* compute (0 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3344, dvrr_stack+1351, dvrr_stack+3323, dvrr_stack+377, dvrr_stack+1336, NULL);

 /* compute (1 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+3836, dvrr_stack+2548, dvrr_stack+3344, NULL, NULL, dvrr_stack+1351);

 /* compute (2 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+3920, dvrr_stack+2576, dvrr_stack+3836, dvrr_stack+2296, dvrr_stack+2548, dvrr_stack+1372);

 /* compute (3 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+4088, dvrr_stack+2660, dvrr_stack+3920, dvrr_stack+2352, dvrr_stack+2576, dvrr_stack+1435);

 /* compute (4 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+4368, dvrr_stack+2996, dvrr_stack+4088, dvrr_stack+2828, dvrr_stack+2660, dvrr_stack+1561);

 /* compute (4 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+4788, dvrr_stack+3556, dvrr_stack+2996, dvrr_stack+3388, dvrr_stack+2828, dvrr_stack+1771);

 /* compute (5 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+5208, dvrr_stack+4788, dvrr_stack+4368, dvrr_stack+3556, dvrr_stack+2996, dvrr_stack+1981);
 tmp = dvrr_stack + 5208;
 target_ptr = Libderiv->dvrr_classes[5][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (0 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3372, dvrr_stack+2296, dvrr_stack+2548, dvrr_stack+767, dvrr_stack+809, NULL);

 /* compute (0 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3408, dvrr_stack+2324, dvrr_stack+2296, dvrr_stack+788, dvrr_stack+767, NULL);

 /* compute (1 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3444, dvrr_stack+3408, dvrr_stack+3372, NULL, NULL, dvrr_stack+2296);

 /* compute (0 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3552, dvrr_stack+2436, dvrr_stack+2324, dvrr_stack+1116, dvrr_stack+788, NULL);

 /* compute (1 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3588, dvrr_stack+3552, dvrr_stack+3408, NULL, NULL, dvrr_stack+2324);

 /* compute (0 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+767, dvrr_stack+2548, dvrr_stack+3344, dvrr_stack+809, dvrr_stack+1351, NULL);

 /* compute (1 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3696, dvrr_stack+3372, dvrr_stack+767, NULL, NULL, dvrr_stack+2548);

 /* compute (2 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+3444, dvrr_stack+3696, dvrr_stack+3408, dvrr_stack+3372, dvrr_stack+2576);

 /* compute (2 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6012, dvrr_stack+3588, dvrr_stack+3444, dvrr_stack+3552, dvrr_stack+3408, dvrr_stack+2352);

 /* compute (3 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6228, dvrr_stack+6012, dvrr_stack+5796, dvrr_stack+3588, dvrr_stack+3444, dvrr_stack+2660);

 /* compute (0 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2352, dvrr_stack+3276, dvrr_stack+2436, dvrr_stack+912, dvrr_stack+1116, NULL);

 /* compute (1 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6588, dvrr_stack+2352, dvrr_stack+3552, NULL, NULL, dvrr_stack+2436);

 /* compute (2 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+6588, dvrr_stack+3588, dvrr_stack+2352, dvrr_stack+3552, dvrr_stack+2464);

 /* compute (3 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6912, dvrr_stack+6696, dvrr_stack+6012, dvrr_stack+6588, dvrr_stack+3588, dvrr_stack+2828);

 /* compute (0 0 | 1 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2828, Data->F+11, Data->F+12, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+803, dvrr_stack+3304, dvrr_stack+2828, Data->F+10, Data->F+11, NULL);

 /* compute (0 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+2831, dvrr_stack+3307, dvrr_stack+803, dvrr_stack+282, dvrr_stack+3304, NULL);

 /* compute (0 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+2841, dvrr_stack+3313, dvrr_stack+2831, dvrr_stack+285, dvrr_stack+3307, NULL);

 /* compute (0 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2856, dvrr_stack+222, dvrr_stack+2841, dvrr_stack+1326, dvrr_stack+3313, NULL);

 /* compute (0 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2877, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+1336, dvrr_stack+222, NULL);

 /* compute (0 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2905, dvrr_stack+3344, dvrr_stack+2877, dvrr_stack+1351, dvrr_stack+3323, NULL);

 /* compute (1 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+6588, dvrr_stack+767, dvrr_stack+2905, NULL, NULL, dvrr_stack+3344);

 /* compute (2 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7272, dvrr_stack+3696, dvrr_stack+6588, dvrr_stack+3372, dvrr_stack+767, dvrr_stack+3836);

 /* compute (3 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7488, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+3444, dvrr_stack+3696, dvrr_stack+3920);

 /* compute (4 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7848, dvrr_stack+6228, dvrr_stack+7488, dvrr_stack+6012, dvrr_stack+5796, dvrr_stack+4088);

 /* compute (4 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8388, dvrr_stack+6912, dvrr_stack+6228, dvrr_stack+6696, dvrr_stack+6012, dvrr_stack+2996);

 /* compute (5 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+8928, dvrr_stack+8388, dvrr_stack+7848, dvrr_stack+6912, dvrr_stack+6228, dvrr_stack+4368);
 tmp = dvrr_stack + 8928;
 target_ptr = Libderiv->dvrr_classes[5][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+9684,dvrr_stack+8928,dvrr_stack+5208,21);


 /* compute (0 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+3372, dvrr_stack+767, dvrr_stack+2296, dvrr_stack+2548, NULL);

 /* compute (0 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6741, dvrr_stack+3408, dvrr_stack+3372, dvrr_stack+2324, dvrr_stack+2296, NULL);

 /* compute (1 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6786, dvrr_stack+6741, dvrr_stack+6696, NULL, NULL, dvrr_stack+3372);

 /* compute (0 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6921, dvrr_stack+3552, dvrr_stack+3408, dvrr_stack+2436, dvrr_stack+2324, NULL);

 /* compute (1 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6966, dvrr_stack+6921, dvrr_stack+6741, NULL, NULL, dvrr_stack+3408);

 /* compute (0 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2296, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+2548, dvrr_stack+3344, NULL);

 /* compute (1 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7101, dvrr_stack+6696, dvrr_stack+2296, NULL, NULL, dvrr_stack+767);

 /* compute (2 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+6786, dvrr_stack+7101, dvrr_stack+6741, dvrr_stack+6696, dvrr_stack+3696);

 /* compute (2 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11718, dvrr_stack+6966, dvrr_stack+6786, dvrr_stack+6921, dvrr_stack+6741, dvrr_stack+3444);

 /* compute (3 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11988, dvrr_stack+11718, dvrr_stack+11448, dvrr_stack+6966, dvrr_stack+6786, dvrr_stack+5796);

 /* compute (0 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3444, dvrr_stack+2352, dvrr_stack+3552, dvrr_stack+3276, dvrr_stack+2436, NULL);

 /* compute (1 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2388, dvrr_stack+3444, dvrr_stack+6921, NULL, NULL, dvrr_stack+3552);

 /* compute (2 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+2388, dvrr_stack+6966, dvrr_stack+3444, dvrr_stack+6921, dvrr_stack+3588);

 /* compute (3 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12708, dvrr_stack+12438, dvrr_stack+11718, dvrr_stack+2388, dvrr_stack+6966, dvrr_stack+6012);

 /* compute (0 0 | 1 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+6012, Data->F+12, Data->F+13, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6015, dvrr_stack+2828, dvrr_stack+6012, Data->F+11, Data->F+12, NULL);

 /* compute (0 0 | 3 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+6021, dvrr_stack+803, dvrr_stack+6015, dvrr_stack+3304, dvrr_stack+2828, NULL);

 /* compute (0 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+6031, dvrr_stack+2831, dvrr_stack+6021, dvrr_stack+3307, dvrr_stack+803, NULL);

 /* compute (0 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+6046, dvrr_stack+2841, dvrr_stack+6031, dvrr_stack+3313, dvrr_stack+2831, NULL);

 /* compute (0 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+3276, dvrr_stack+2856, dvrr_stack+6046, dvrr_stack+222, dvrr_stack+2841, NULL);

 /* compute (0 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+7236, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+3323, dvrr_stack+2856, NULL);

 /* compute (0 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6067, dvrr_stack+2905, dvrr_stack+7236, dvrr_stack+3344, dvrr_stack+2877, NULL);

 /* compute (1 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2388, dvrr_stack+2296, dvrr_stack+6067, NULL, NULL, dvrr_stack+2905);

 /* compute (2 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13158, dvrr_stack+7101, dvrr_stack+2388, dvrr_stack+6696, dvrr_stack+2296, dvrr_stack+6588);

 /* compute (3 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13428, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+6786, dvrr_stack+7101, dvrr_stack+7272);

 /* compute (4 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+13878, dvrr_stack+11988, dvrr_stack+13428, dvrr_stack+11718, dvrr_stack+11448, dvrr_stack+7488);

 /* compute (4 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+14553, dvrr_stack+12708, dvrr_stack+11988, dvrr_stack+12438, dvrr_stack+11718, dvrr_stack+6228);

 /* compute (5 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+15228, dvrr_stack+14553, dvrr_stack+13878, dvrr_stack+12708, dvrr_stack+11988, dvrr_stack+7848);
 tmp = dvrr_stack + 15228;
 target_ptr = Libderiv->dvrr_classes[5][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+16173,dvrr_stack+15228,dvrr_stack+8928,21);


 /* compute (0 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+6696, dvrr_stack+2296, dvrr_stack+3372, dvrr_stack+767, NULL);

 /* compute (0 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+6741, dvrr_stack+6696, dvrr_stack+3408, dvrr_stack+3372, NULL);

 /* compute (1 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+12438, dvrr_stack+2941, NULL, NULL, dvrr_stack+6696);

 /* compute (0 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12658, dvrr_stack+6921, dvrr_stack+6741, dvrr_stack+3552, dvrr_stack+3408, NULL);

 /* compute (1 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12713, dvrr_stack+12658, dvrr_stack+12438, NULL, NULL, dvrr_stack+6741);

 /* compute (0 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3372, dvrr_stack+2296, dvrr_stack+6067, dvrr_stack+767, dvrr_stack+2905, NULL);

 /* compute (1 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12878, dvrr_stack+2941, dvrr_stack+3372, NULL, NULL, dvrr_stack+2296);

 /* compute (2 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18441, dvrr_stack+12493, dvrr_stack+12878, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+7101);

 /* compute (2 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18771, dvrr_stack+12713, dvrr_stack+12493, dvrr_stack+12658, dvrr_stack+12438, dvrr_stack+6786);

 /* compute (3 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19101, dvrr_stack+18771, dvrr_stack+18441, dvrr_stack+12713, dvrr_stack+12493, dvrr_stack+11448);

 /* compute (0 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6786, dvrr_stack+3444, dvrr_stack+6921, dvrr_stack+2352, dvrr_stack+3552, NULL);

 /* compute (1 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3489, dvrr_stack+6786, dvrr_stack+12658, NULL, NULL, dvrr_stack+6921);

 /* compute (2 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+3489, dvrr_stack+12713, dvrr_stack+6786, dvrr_stack+12658, dvrr_stack+6966);

 /* compute (3 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+19981, dvrr_stack+19651, dvrr_stack+18771, dvrr_stack+3489, dvrr_stack+12713, dvrr_stack+11718);

 /* compute (0 0 | 1 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+11718, Data->F+13, Data->F+14, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+11721, dvrr_stack+6012, dvrr_stack+11718, Data->F+12, Data->F+13, NULL);

 /* compute (0 0 | 3 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+11727, dvrr_stack+6015, dvrr_stack+11721, dvrr_stack+2828, dvrr_stack+6012, NULL);

 /* compute (0 0 | 4 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+11737, dvrr_stack+6021, dvrr_stack+11727, dvrr_stack+803, dvrr_stack+6015, NULL);

 /* compute (0 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+11752, dvrr_stack+6031, dvrr_stack+11737, dvrr_stack+2831, dvrr_stack+6021, NULL);

 /* compute (0 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+11773, dvrr_stack+6046, dvrr_stack+11752, dvrr_stack+2841, dvrr_stack+6031, NULL);

 /* compute (0 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11801, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+2856, dvrr_stack+6046, NULL);

 /* compute (0 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+11837, dvrr_stack+7236, dvrr_stack+11801, dvrr_stack+2877, dvrr_stack+3276, NULL);

 /* compute (0 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11882, dvrr_stack+6067, dvrr_stack+11837, dvrr_stack+2905, dvrr_stack+7236, NULL);

 /* compute (1 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3489, dvrr_stack+3372, dvrr_stack+11882, NULL, NULL, dvrr_stack+6067);

 /* compute (2 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20531, dvrr_stack+12878, dvrr_stack+3489, dvrr_stack+2941, dvrr_stack+3372, dvrr_stack+2388);

 /* compute (3 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+20861, dvrr_stack+18441, dvrr_stack+20531, dvrr_stack+12493, dvrr_stack+12878, dvrr_stack+13158);

 /* compute (4 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+21411, dvrr_stack+19101, dvrr_stack+20861, dvrr_stack+18771, dvrr_stack+18441, dvrr_stack+13428);

 /* compute (4 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+22236, dvrr_stack+19981, dvrr_stack+19101, dvrr_stack+19651, dvrr_stack+18771, dvrr_stack+11988);

 /* compute (5 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+23061, dvrr_stack+22236, dvrr_stack+21411, dvrr_stack+19981, dvrr_stack+19101, dvrr_stack+13878);
 tmp = dvrr_stack + 23061;
 target_ptr = Libderiv->dvrr_classes[5][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+24216,dvrr_stack+23061,dvrr_stack+15228,21);


 /* compute (0 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+2941, dvrr_stack+3372, dvrr_stack+6696, dvrr_stack+2296, NULL);

 /* compute (0 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19717, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+6741, dvrr_stack+6696, NULL);

 /* compute (1 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19783, dvrr_stack+19717, dvrr_stack+19651, NULL, NULL, dvrr_stack+2941);

 /* compute (0 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19981, dvrr_stack+12658, dvrr_stack+12438, dvrr_stack+6921, dvrr_stack+6741, NULL);

 /* compute (1 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20047, dvrr_stack+19981, dvrr_stack+19717, NULL, NULL, dvrr_stack+12438);

 /* compute (0 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6696, dvrr_stack+3372, dvrr_stack+11882, dvrr_stack+2296, dvrr_stack+6067, NULL);

 /* compute (1 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20245, dvrr_stack+19651, dvrr_stack+6696, NULL, NULL, dvrr_stack+3372);

 /* compute (2 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27051, dvrr_stack+19783, dvrr_stack+20245, dvrr_stack+19717, dvrr_stack+19651, dvrr_stack+12878);

 /* compute (2 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27447, dvrr_stack+20047, dvrr_stack+19783, dvrr_stack+19981, dvrr_stack+19717, dvrr_stack+12493);

 /* compute (3 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27843, dvrr_stack+27447, dvrr_stack+27051, dvrr_stack+20047, dvrr_stack+19783, dvrr_stack+18441);

 /* compute (0 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+6786, dvrr_stack+12658, dvrr_stack+3444, dvrr_stack+6921, NULL);

 /* compute (1 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6841, dvrr_stack+12493, dvrr_stack+19981, NULL, NULL, dvrr_stack+12658);

 /* compute (2 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+6841, dvrr_stack+20047, dvrr_stack+12493, dvrr_stack+19981, dvrr_stack+12713);

 /* compute (3 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+28899, dvrr_stack+28503, dvrr_stack+27447, dvrr_stack+6841, dvrr_stack+20047, dvrr_stack+18771);

 /* compute (0 0 | 1 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+2828, Data->F+14, Data->F+15, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+18771, dvrr_stack+11718, dvrr_stack+2828, Data->F+13, Data->F+14, NULL);

 /* compute (0 0 | 3 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+18777, dvrr_stack+11721, dvrr_stack+18771, dvrr_stack+6012, dvrr_stack+11718, NULL);

 /* compute (0 0 | 4 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+18787, dvrr_stack+11727, dvrr_stack+18777, dvrr_stack+6015, dvrr_stack+11721, NULL);

 /* compute (0 0 | 5 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+18802, dvrr_stack+11737, dvrr_stack+18787, dvrr_stack+6021, dvrr_stack+11727, NULL);

 /* compute (0 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+18823, dvrr_stack+11752, dvrr_stack+18802, dvrr_stack+6031, dvrr_stack+11737, NULL);

 /* compute (0 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+18851, dvrr_stack+11773, dvrr_stack+18823, dvrr_stack+6046, dvrr_stack+11752, NULL);

 /* compute (0 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+18887, dvrr_stack+11801, dvrr_stack+18851, dvrr_stack+3276, dvrr_stack+11773, NULL);

 /* compute (0 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+18932, dvrr_stack+11837, dvrr_stack+18887, dvrr_stack+7236, dvrr_stack+11801, NULL);

 /* compute (0 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18987, dvrr_stack+11882, dvrr_stack+18932, dvrr_stack+6067, dvrr_stack+11837, NULL);

 /* compute (1 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+6841, dvrr_stack+6696, dvrr_stack+18987, NULL, NULL, dvrr_stack+11882);

 /* compute (2 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29559, dvrr_stack+20245, dvrr_stack+6841, dvrr_stack+19651, dvrr_stack+6696, dvrr_stack+3489);

 /* compute (3 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+29955, dvrr_stack+27051, dvrr_stack+29559, dvrr_stack+19783, dvrr_stack+20245, dvrr_stack+20531);

 /* compute (4 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+30615, dvrr_stack+27843, dvrr_stack+29955, dvrr_stack+27447, dvrr_stack+27051, dvrr_stack+20861);

 /* compute (4 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+31605, dvrr_stack+28899, dvrr_stack+27843, dvrr_stack+28503, dvrr_stack+27447, dvrr_stack+19101);

 /* compute (5 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+32595, dvrr_stack+31605, dvrr_stack+30615, dvrr_stack+28899, dvrr_stack+27843, dvrr_stack+21411);
 tmp = dvrr_stack + 32595;
 target_ptr = Libderiv->dvrr_classes[5][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+33981,dvrr_stack+32595,dvrr_stack+23061,21);


 /* compute (0 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+19651, dvrr_stack+6696, dvrr_stack+2941, dvrr_stack+3372, NULL);

 /* compute (0 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28581, dvrr_stack+19717, dvrr_stack+19651, dvrr_stack+12438, dvrr_stack+2941, NULL);

 /* compute (1 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28659, dvrr_stack+28581, dvrr_stack+28503, NULL, NULL, dvrr_stack+19651);

 /* compute (0 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28893, dvrr_stack+19981, dvrr_stack+19717, dvrr_stack+12658, dvrr_stack+12438, NULL);

 /* compute (1 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+28971, dvrr_stack+28893, dvrr_stack+28581, NULL, NULL, dvrr_stack+19717);

 /* compute (0 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29205, dvrr_stack+6696, dvrr_stack+18987, dvrr_stack+3372, dvrr_stack+11882, NULL);

 /* compute (1 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29283, dvrr_stack+28503, dvrr_stack+29205, NULL, NULL, dvrr_stack+6696);

 /* compute (2 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37446, dvrr_stack+28659, dvrr_stack+29283, dvrr_stack+28581, dvrr_stack+28503, dvrr_stack+20245);

 /* compute (2 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37914, dvrr_stack+28971, dvrr_stack+28659, dvrr_stack+28893, dvrr_stack+28581, dvrr_stack+19783);

 /* compute (3 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+38382, dvrr_stack+37914, dvrr_stack+37446, dvrr_stack+28971, dvrr_stack+28659, dvrr_stack+27051);

 /* compute (0 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19783, dvrr_stack+12493, dvrr_stack+19981, dvrr_stack+6786, dvrr_stack+12658, NULL);

 /* compute (1 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12559, dvrr_stack+19783, dvrr_stack+28893, NULL, NULL, dvrr_stack+19981);

 /* compute (2 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39162, dvrr_stack+12559, dvrr_stack+28971, dvrr_stack+19783, dvrr_stack+28893, dvrr_stack+20047);

 /* compute (3 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+39630, dvrr_stack+39162, dvrr_stack+37914, dvrr_stack+12559, dvrr_stack+28971, dvrr_stack+27447);

 /* compute (0 0 | 1 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+27447, Data->F+15, Data->F+16, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+27450, dvrr_stack+2828, dvrr_stack+27447, Data->F+14, Data->F+15, NULL);

 /* compute (0 0 | 3 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+27456, dvrr_stack+18771, dvrr_stack+27450, dvrr_stack+11718, dvrr_stack+2828, NULL);

 /* compute (0 0 | 4 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+27466, dvrr_stack+18777, dvrr_stack+27456, dvrr_stack+11721, dvrr_stack+18771, NULL);

 /* compute (0 0 | 5 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+27481, dvrr_stack+18787, dvrr_stack+27466, dvrr_stack+11727, dvrr_stack+18777, NULL);

 /* compute (0 0 | 6 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+27502, dvrr_stack+18802, dvrr_stack+27481, dvrr_stack+11737, dvrr_stack+18787, NULL);

 /* compute (0 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+27530, dvrr_stack+18823, dvrr_stack+27502, dvrr_stack+11752, dvrr_stack+18802, NULL);

 /* compute (0 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+27566, dvrr_stack+18851, dvrr_stack+27530, dvrr_stack+11773, dvrr_stack+18823, NULL);

 /* compute (0 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+12438, dvrr_stack+18887, dvrr_stack+27566, dvrr_stack+11801, dvrr_stack+18851, NULL);

 /* compute (0 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27611, dvrr_stack+18932, dvrr_stack+12438, dvrr_stack+11837, dvrr_stack+18887, NULL);

 /* compute (0 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27677, dvrr_stack+18987, dvrr_stack+27611, dvrr_stack+11882, dvrr_stack+18932, NULL);

 /* compute (1 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+12559, dvrr_stack+29205, dvrr_stack+27677, NULL, NULL, dvrr_stack+18987);

 /* compute (2 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40410, dvrr_stack+29283, dvrr_stack+12559, dvrr_stack+28503, dvrr_stack+29205, dvrr_stack+6841);

 /* compute (3 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+40878, dvrr_stack+37446, dvrr_stack+40410, dvrr_stack+28659, dvrr_stack+29283, dvrr_stack+29559);

 /* compute (4 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+41658, dvrr_stack+38382, dvrr_stack+40878, dvrr_stack+37914, dvrr_stack+37446, dvrr_stack+29955);

 /* compute (4 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+42828, dvrr_stack+39630, dvrr_stack+38382, dvrr_stack+39162, dvrr_stack+37914, dvrr_stack+27843);

 /* compute (5 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+43998, dvrr_stack+42828, dvrr_stack+41658, dvrr_stack+39630, dvrr_stack+38382, dvrr_stack+30615);
 tmp = dvrr_stack + 43998;
 target_ptr = Libderiv->dvrr_classes[5][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+45636,dvrr_stack+43998,dvrr_stack+32595,21);


 /* compute (0 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39162, dvrr_stack+28503, dvrr_stack+29205, dvrr_stack+19651, dvrr_stack+6696, NULL);

 /* compute (0 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39253, dvrr_stack+28581, dvrr_stack+28503, dvrr_stack+19717, dvrr_stack+19651, NULL);

 /* compute (1 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39344, dvrr_stack+39253, dvrr_stack+39162, NULL, NULL, dvrr_stack+28503);

 /* compute (0 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39617, dvrr_stack+28893, dvrr_stack+28581, dvrr_stack+19981, dvrr_stack+19717, NULL);

 /* compute (1 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39708, dvrr_stack+39617, dvrr_stack+39253, NULL, NULL, dvrr_stack+28581);

 /* compute (0 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+28503, dvrr_stack+29205, dvrr_stack+27677, dvrr_stack+6696, dvrr_stack+18987, NULL);

 /* compute (1 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39981, dvrr_stack+39162, dvrr_stack+28503, NULL, NULL, dvrr_stack+29205);

 /* compute (2 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+49794, dvrr_stack+39344, dvrr_stack+39981, dvrr_stack+39253, dvrr_stack+39162, dvrr_stack+29283);

 /* compute (2 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50340, dvrr_stack+39708, dvrr_stack+39344, dvrr_stack+39617, dvrr_stack+39253, dvrr_stack+28659);

 /* compute (3 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+50886, dvrr_stack+50340, dvrr_stack+49794, dvrr_stack+39708, dvrr_stack+39344, dvrr_stack+37446);

 /* compute (0 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39253, dvrr_stack+19783, dvrr_stack+28893, dvrr_stack+12493, dvrr_stack+19981, NULL);

 /* compute (1 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+28594, dvrr_stack+39253, dvrr_stack+39617, NULL, NULL, dvrr_stack+28893);

 /* compute (2 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+19651, dvrr_stack+28594, dvrr_stack+39708, dvrr_stack+39253, dvrr_stack+39617, dvrr_stack+28971);

 /* compute (3 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+51796, dvrr_stack+19651, dvrr_stack+50340, dvrr_stack+28594, dvrr_stack+39708, dvrr_stack+37914);

 /* compute (0 0 | 1 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+37914, Data->F+16, Data->F+17, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+37917, dvrr_stack+27447, dvrr_stack+37914, Data->F+15, Data->F+16, NULL);

 /* compute (0 0 | 3 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+37923, dvrr_stack+27450, dvrr_stack+37917, dvrr_stack+2828, dvrr_stack+27447, NULL);

 /* compute (0 0 | 4 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+37933, dvrr_stack+27456, dvrr_stack+37923, dvrr_stack+18771, dvrr_stack+27450, NULL);

 /* compute (0 0 | 5 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+37948, dvrr_stack+27466, dvrr_stack+37933, dvrr_stack+18777, dvrr_stack+27456, NULL);

 /* compute (0 0 | 6 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+37969, dvrr_stack+27481, dvrr_stack+37948, dvrr_stack+18787, dvrr_stack+27466, NULL);

 /* compute (0 0 | 7 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+37997, dvrr_stack+27502, dvrr_stack+37969, dvrr_stack+18802, dvrr_stack+27481, NULL);

 /* compute (0 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+38033, dvrr_stack+27530, dvrr_stack+37997, dvrr_stack+18823, dvrr_stack+27502, NULL);

 /* compute (0 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2941, dvrr_stack+27566, dvrr_stack+38033, dvrr_stack+18851, dvrr_stack+27530, NULL);

 /* compute (0 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+12493, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+18887, dvrr_stack+27566, NULL);

 /* compute (0 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+38078, dvrr_stack+27611, dvrr_stack+12493, dvrr_stack+18932, dvrr_stack+12438, NULL);

 /* compute (0 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+39253, dvrr_stack+27677, dvrr_stack+38078, dvrr_stack+18987, dvrr_stack+27611, NULL);

 /* compute (1 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+28594, dvrr_stack+28503, dvrr_stack+39253, NULL, NULL, dvrr_stack+27677);

 /* compute (2 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+52706, dvrr_stack+39981, dvrr_stack+28594, dvrr_stack+39162, dvrr_stack+28503, dvrr_stack+12559);

 /* compute (3 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+53252, dvrr_stack+49794, dvrr_stack+52706, dvrr_stack+39344, dvrr_stack+39981, dvrr_stack+40410);

 /* compute (4 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+54162, dvrr_stack+50886, dvrr_stack+53252, dvrr_stack+50340, dvrr_stack+49794, dvrr_stack+40878);

 /* compute (4 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+55527, dvrr_stack+51796, dvrr_stack+50886, dvrr_stack+19651, dvrr_stack+50340, dvrr_stack+38382);

 /* compute (5 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+56892, dvrr_stack+55527, dvrr_stack+54162, dvrr_stack+51796, dvrr_stack+50886, dvrr_stack+41658);

 /* compute (5 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+58803,dvrr_stack+56892,dvrr_stack+43998,21);


 /* compute (1 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+6012, dvrr_stack+0, dvrr_stack+3, NULL, NULL, Data->F+6);

 /* compute (1 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+51796, dvrr_stack+6, dvrr_stack+71, NULL, NULL, dvrr_stack+3);

 /* compute (2 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+51814, dvrr_stack+21, dvrr_stack+51796, dvrr_stack+15, dvrr_stack+6, dvrr_stack+6012);

 /* compute (1 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+51850, dvrr_stack+77, dvrr_stack+367, NULL, NULL, dvrr_stack+71);

 /* compute (2 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+51880, dvrr_stack+87, dvrr_stack+51850, dvrr_stack+39, dvrr_stack+77, dvrr_stack+51796);

 /* compute (3 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+51940, dvrr_stack+147, dvrr_stack+51880, dvrr_stack+117, dvrr_stack+87, dvrr_stack+51814);

 /* compute (1 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+52040, dvrr_stack+377, dvrr_stack+1336, NULL, NULL, dvrr_stack+367);

 /* compute (2 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+52085, dvrr_stack+392, dvrr_stack+52040, dvrr_stack+207, dvrr_stack+377, dvrr_stack+51850);

 /* compute (3 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+52175, dvrr_stack+437, dvrr_stack+52085, dvrr_stack+237, dvrr_stack+392, dvrr_stack+51880);

 /* compute (4 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+52325, dvrr_stack+617, dvrr_stack+52175, dvrr_stack+527, dvrr_stack+437, dvrr_stack+51940);

 /* compute (1 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+52550, dvrr_stack+1351, dvrr_stack+3323, NULL, NULL, dvrr_stack+1336);

 /* compute (2 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+50340, dvrr_stack+1372, dvrr_stack+52550, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+52040);

 /* compute (3 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+50466, dvrr_stack+1435, dvrr_stack+50340, dvrr_stack+830, dvrr_stack+1372, dvrr_stack+52085);

 /* compute (4 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+19651, dvrr_stack+1561, dvrr_stack+50466, dvrr_stack+956, dvrr_stack+1435, dvrr_stack+52175);

 /* compute (5 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+39344, dvrr_stack+1981, dvrr_stack+19651, dvrr_stack+1771, dvrr_stack+1561, dvrr_stack+52325);

 /* compute (1 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+809, dvrr_stack+3344, dvrr_stack+2877, NULL, NULL, dvrr_stack+3323);

 /* compute (2 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+933, dvrr_stack+3836, dvrr_stack+809, dvrr_stack+2548, dvrr_stack+3344, dvrr_stack+52550);

 /* compute (3 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+28867, dvrr_stack+3920, dvrr_stack+933, dvrr_stack+2576, dvrr_stack+3836, dvrr_stack+50340);

 /* compute (4 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+63717, dvrr_stack+4088, dvrr_stack+28867, dvrr_stack+2660, dvrr_stack+3920, dvrr_stack+50466);

 /* compute (5 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+64137, dvrr_stack+4368, dvrr_stack+63717, dvrr_stack+2996, dvrr_stack+4088, dvrr_stack+19651);

 /* compute (6 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+64725, dvrr_stack+5208, dvrr_stack+64137, dvrr_stack+4788, dvrr_stack+4368, dvrr_stack+39344);
 tmp = dvrr_stack + 64725;
 target_ptr = Libderiv->dvrr_classes[6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2996, dvrr_stack+2905, dvrr_stack+7236, NULL, NULL, dvrr_stack+2877);

 /* compute (2 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+19966, dvrr_stack+6588, dvrr_stack+2996, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+809);

 /* compute (3 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+65509, dvrr_stack+7272, dvrr_stack+19966, dvrr_stack+3696, dvrr_stack+6588, dvrr_stack+933);

 /* compute (4 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+65869, dvrr_stack+7488, dvrr_stack+65509, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+28867);

 /* compute (5 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+66409, dvrr_stack+7848, dvrr_stack+65869, dvrr_stack+6228, dvrr_stack+7488, dvrr_stack+63717);

 /* compute (6 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+67165, dvrr_stack+8928, dvrr_stack+66409, dvrr_stack+8388, dvrr_stack+7848, dvrr_stack+64137);
 tmp = dvrr_stack + 67165;
 target_ptr = Libderiv->dvrr_classes[6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+68173,dvrr_stack+67165,dvrr_stack+64725,28);


 /* compute (1 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+6067, dvrr_stack+11837, NULL, NULL, dvrr_stack+7236);

 /* compute (2 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6112, dvrr_stack+2388, dvrr_stack+5796, dvrr_stack+2296, dvrr_stack+6067, dvrr_stack+2996);

 /* compute (3 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70525, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+7101, dvrr_stack+2388, dvrr_stack+19966);

 /* compute (4 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70975, dvrr_stack+13428, dvrr_stack+70525, dvrr_stack+11448, dvrr_stack+13158, dvrr_stack+65509);

 /* compute (5 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+71650, dvrr_stack+13878, dvrr_stack+70975, dvrr_stack+11988, dvrr_stack+13428, dvrr_stack+65869);

 /* compute (6 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+72595, dvrr_stack+15228, dvrr_stack+71650, dvrr_stack+14553, dvrr_stack+13878, dvrr_stack+66409);
 tmp = dvrr_stack + 72595;
 target_ptr = Libderiv->dvrr_classes[6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+73855,dvrr_stack+72595,dvrr_stack+67165,28);


 /* compute (1 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11448, dvrr_stack+11882, dvrr_stack+18932, NULL, NULL, dvrr_stack+11837);

 /* compute (2 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11937, dvrr_stack+3489, dvrr_stack+11448, dvrr_stack+3372, dvrr_stack+11882, dvrr_stack+5796);

 /* compute (3 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+76879, dvrr_stack+20531, dvrr_stack+11937, dvrr_stack+12878, dvrr_stack+3489, dvrr_stack+6112);

 /* compute (4 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+77429, dvrr_stack+20861, dvrr_stack+76879, dvrr_stack+18441, dvrr_stack+20531, dvrr_stack+70525);

 /* compute (5 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+78254, dvrr_stack+21411, dvrr_stack+77429, dvrr_stack+19101, dvrr_stack+20861, dvrr_stack+70975);

 /* compute (6 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+79409, dvrr_stack+23061, dvrr_stack+78254, dvrr_stack+22236, dvrr_stack+21411, dvrr_stack+71650);
 tmp = dvrr_stack + 79409;
 target_ptr = Libderiv->dvrr_classes[6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+80949,dvrr_stack+79409,dvrr_stack+72595,28);


 /* compute (1 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18441, dvrr_stack+18987, dvrr_stack+27611, NULL, NULL, dvrr_stack+18932);

 /* compute (2 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+19053, dvrr_stack+6841, dvrr_stack+18441, dvrr_stack+6696, dvrr_stack+18987, dvrr_stack+11448);

 /* compute (3 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+84729, dvrr_stack+29559, dvrr_stack+19053, dvrr_stack+20245, dvrr_stack+6841, dvrr_stack+11937);

 /* compute (4 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+85389, dvrr_stack+29955, dvrr_stack+84729, dvrr_stack+27051, dvrr_stack+29559, dvrr_stack+76879);

 /* compute (5 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+86379, dvrr_stack+30615, dvrr_stack+85389, dvrr_stack+27843, dvrr_stack+29955, dvrr_stack+77429);

 /* compute (6 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+87765, dvrr_stack+32595, dvrr_stack+86379, dvrr_stack+31605, dvrr_stack+30615, dvrr_stack+78254);
 tmp = dvrr_stack + 87765;
 target_ptr = Libderiv->dvrr_classes[6][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+89613,dvrr_stack+87765,dvrr_stack+79409,28);


 /* compute (1 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27051, dvrr_stack+27677, dvrr_stack+38078, NULL, NULL, dvrr_stack+27611);

 /* compute (2 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27755, dvrr_stack+12559, dvrr_stack+27051, dvrr_stack+29205, dvrr_stack+27677, dvrr_stack+18441);

 /* compute (3 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+94233, dvrr_stack+40410, dvrr_stack+27755, dvrr_stack+29283, dvrr_stack+12559, dvrr_stack+19053);

 /* compute (4 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+95013, dvrr_stack+40878, dvrr_stack+94233, dvrr_stack+37446, dvrr_stack+40410, dvrr_stack+84729);

 /* compute (5 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+96183, dvrr_stack+41658, dvrr_stack+95013, dvrr_stack+38382, dvrr_stack+40878, dvrr_stack+85389);

 /* compute (6 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+97821, dvrr_stack+43998, dvrr_stack+96183, dvrr_stack+42828, dvrr_stack+41658, dvrr_stack+86379);
 tmp = dvrr_stack + 97821;
 target_ptr = Libderiv->dvrr_classes[6][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+100005,dvrr_stack+97821,dvrr_stack+87765,28);


 /* compute (0 0 | 1 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+37446, Data->F+17, Data->F+18, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+37449, dvrr_stack+37914, dvrr_stack+37446, Data->F+16, Data->F+17, NULL);

 /* compute (0 0 | 3 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+39, dvrr_stack+37917, dvrr_stack+37449, dvrr_stack+27447, dvrr_stack+37914, NULL);

 /* compute (0 0 | 4 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+207, dvrr_stack+37923, dvrr_stack+39, dvrr_stack+27450, dvrr_stack+37917, NULL);

 /* compute (0 0 | 5 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+37455, dvrr_stack+37933, dvrr_stack+207, dvrr_stack+27456, dvrr_stack+37923, NULL);

 /* compute (0 0 | 6 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+37476, dvrr_stack+37948, dvrr_stack+37455, dvrr_stack+27466, dvrr_stack+37933, NULL);

 /* compute (0 0 | 7 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+767, dvrr_stack+37969, dvrr_stack+37476, dvrr_stack+27481, dvrr_stack+37948, NULL);

 /* compute (0 0 | 8 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+237, dvrr_stack+37997, dvrr_stack+767, dvrr_stack+27502, dvrr_stack+37969, NULL);

 /* compute (0 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+37504, dvrr_stack+38033, dvrr_stack+237, dvrr_stack+27530, dvrr_stack+37997, NULL);

 /* compute (0 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+37559, dvrr_stack+2941, dvrr_stack+37504, dvrr_stack+27566, dvrr_stack+38033, NULL);

 /* compute (0 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37625, dvrr_stack+12493, dvrr_stack+37559, dvrr_stack+12438, dvrr_stack+2941, NULL);

 /* compute (0 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+37703, dvrr_stack+38078, dvrr_stack+37625, dvrr_stack+27611, dvrr_stack+12493, NULL);

 /* compute (1 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+20182, dvrr_stack+39253, dvrr_stack+37703, NULL, NULL, dvrr_stack+38078);

 /* compute (2 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+38156, dvrr_stack+28594, dvrr_stack+20182, dvrr_stack+28503, dvrr_stack+39253, dvrr_stack+27051);

 /* compute (3 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+105549, dvrr_stack+52706, dvrr_stack+38156, dvrr_stack+39981, dvrr_stack+28594, dvrr_stack+27755);

 /* compute (4 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+106459, dvrr_stack+53252, dvrr_stack+105549, dvrr_stack+49794, dvrr_stack+52706, dvrr_stack+94233);

 /* compute (5 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+107824, dvrr_stack+54162, dvrr_stack+106459, dvrr_stack+50886, dvrr_stack+53252, dvrr_stack+95013);

 /* compute (6 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+109735, dvrr_stack+56892, dvrr_stack+107824, dvrr_stack+55527, dvrr_stack+54162, dvrr_stack+96183);

 /* compute (6 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+112283,dvrr_stack+109735,dvrr_stack+97821,28);


 /* compute (1 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+55527, Data->F+6, Data->F+7, NULL, NULL, NULL);

 /* compute (1 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+55530, dvrr_stack+3, dvrr_stack+68, NULL, NULL, Data->F+7);

 /* compute (2 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+55539, dvrr_stack+6012, dvrr_stack+55530, dvrr_stack+0, dvrr_stack+3, dvrr_stack+55527);

 /* compute (1 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+55557, dvrr_stack+71, dvrr_stack+361, NULL, NULL, dvrr_stack+68);

 /* compute (2 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+55575, dvrr_stack+51796, dvrr_stack+55557, dvrr_stack+6, dvrr_stack+71, dvrr_stack+55530);

 /* compute (3 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+55611, dvrr_stack+51814, dvrr_stack+55575, dvrr_stack+21, dvrr_stack+51796, dvrr_stack+55539);

 /* compute (1 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+55671, dvrr_stack+367, dvrr_stack+1326, NULL, NULL, dvrr_stack+361);

 /* compute (2 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+55701, dvrr_stack+51850, dvrr_stack+55671, dvrr_stack+77, dvrr_stack+367, dvrr_stack+55557);

 /* compute (3 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+55761, dvrr_stack+51880, dvrr_stack+55701, dvrr_stack+87, dvrr_stack+51850, dvrr_stack+55575);

 /* compute (4 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+55861, dvrr_stack+51940, dvrr_stack+55761, dvrr_stack+147, dvrr_stack+51880, dvrr_stack+55611);

 /* compute (1 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+56011, dvrr_stack+1336, dvrr_stack+222, NULL, NULL, dvrr_stack+1326);

 /* compute (2 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+56056, dvrr_stack+52040, dvrr_stack+56011, dvrr_stack+377, dvrr_stack+1336, dvrr_stack+55671);

 /* compute (3 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+56146, dvrr_stack+52085, dvrr_stack+56056, dvrr_stack+392, dvrr_stack+52040, dvrr_stack+55701);

 /* compute (4 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+56296, dvrr_stack+52175, dvrr_stack+56146, dvrr_stack+437, dvrr_stack+52085, dvrr_stack+55761);

 /* compute (5 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+56521, dvrr_stack+52325, dvrr_stack+56296, dvrr_stack+617, dvrr_stack+52175, dvrr_stack+55861);

 /* compute (1 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+377, dvrr_stack+3323, dvrr_stack+2856, NULL, NULL, dvrr_stack+222);

 /* compute (2 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+49794, dvrr_stack+52550, dvrr_stack+377, dvrr_stack+1351, dvrr_stack+3323, dvrr_stack+56011);

 /* compute (3 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+49920, dvrr_stack+50340, dvrr_stack+49794, dvrr_stack+1372, dvrr_stack+52550, dvrr_stack+56056);

 /* compute (4 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+50676, dvrr_stack+50466, dvrr_stack+49920, dvrr_stack+1435, dvrr_stack+50340, dvrr_stack+56146);

 /* compute (5 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+50991, dvrr_stack+19651, dvrr_stack+50676, dvrr_stack+1561, dvrr_stack+50466, dvrr_stack+56296);

 /* compute (6 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+39785, dvrr_stack+39344, dvrr_stack+50991, dvrr_stack+1981, dvrr_stack+19651, dvrr_stack+56521);

 /* compute (1 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+1351, dvrr_stack+2877, dvrr_stack+3276, NULL, NULL, dvrr_stack+2856);

 /* compute (2 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+1435, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+3344, dvrr_stack+2877, dvrr_stack+377);

 /* compute (3 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+51432, dvrr_stack+933, dvrr_stack+1435, dvrr_stack+3836, dvrr_stack+809, dvrr_stack+49794);

 /* compute (4 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+38702, dvrr_stack+28867, dvrr_stack+51432, dvrr_stack+3920, dvrr_stack+933, dvrr_stack+49920);

 /* compute (5 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+118835, dvrr_stack+63717, dvrr_stack+38702, dvrr_stack+4088, dvrr_stack+28867, dvrr_stack+50676);

 /* compute (6 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+119423, dvrr_stack+64137, dvrr_stack+118835, dvrr_stack+4368, dvrr_stack+63717, dvrr_stack+50991);

 /* compute (7 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+3654, dvrr_stack+64725, dvrr_stack+119423, dvrr_stack+5208, dvrr_stack+64137, dvrr_stack+39785);
 tmp = dvrr_stack + 3654;
 target_ptr = Libderiv->dvrr_classes[7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+3344, dvrr_stack+7236, dvrr_stack+11801, NULL, NULL, dvrr_stack+3276);

 /* compute (2 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+27285, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+2905, dvrr_stack+7236, dvrr_stack+1351);

 /* compute (3 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+29147, dvrr_stack+19966, dvrr_stack+27285, dvrr_stack+6588, dvrr_stack+2996, dvrr_stack+1435);

 /* compute (4 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+120207, dvrr_stack+65509, dvrr_stack+29147, dvrr_stack+7272, dvrr_stack+19966, dvrr_stack+51432);

 /* compute (5 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+120747, dvrr_stack+65869, dvrr_stack+120207, dvrr_stack+7488, dvrr_stack+65509, dvrr_stack+38702);

 /* compute (6 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+121503, dvrr_stack+66409, dvrr_stack+120747, dvrr_stack+7848, dvrr_stack+65869, dvrr_stack+118835);

 /* compute (7 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+122511, dvrr_stack+67165, dvrr_stack+121503, dvrr_stack+8928, dvrr_stack+66409, dvrr_stack+119423);
 tmp = dvrr_stack + 122511;
 target_ptr = Libderiv->dvrr_classes[7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+123807,dvrr_stack+122511,dvrr_stack+3654,36);


 /* compute (1 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7272, dvrr_stack+11837, dvrr_stack+18887, NULL, NULL, dvrr_stack+11801);

 /* compute (2 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7407, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+6067, dvrr_stack+11837, dvrr_stack+3344);

 /* compute (3 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+7677, dvrr_stack+6112, dvrr_stack+7407, dvrr_stack+2388, dvrr_stack+5796, dvrr_stack+27285);

 /* compute (4 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+126831, dvrr_stack+70525, dvrr_stack+7677, dvrr_stack+13158, dvrr_stack+6112, dvrr_stack+29147);

 /* compute (5 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+127506, dvrr_stack+70975, dvrr_stack+126831, dvrr_stack+13428, dvrr_stack+70525, dvrr_stack+120207);

 /* compute (6 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+128451, dvrr_stack+71650, dvrr_stack+127506, dvrr_stack+13878, dvrr_stack+70975, dvrr_stack+120747);

 /* compute (7 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+12793, dvrr_stack+72595, dvrr_stack+128451, dvrr_stack+15228, dvrr_stack+71650, dvrr_stack+121503);
 tmp = dvrr_stack + 12793;
 target_ptr = Libderiv->dvrr_classes[7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+129711,dvrr_stack+12793,dvrr_stack+122511,36);


 /* compute (1 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+8127, dvrr_stack+18932, dvrr_stack+12438, NULL, NULL, dvrr_stack+18887);

 /* compute (2 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+2296, dvrr_stack+11448, dvrr_stack+8127, dvrr_stack+11882, dvrr_stack+18932, dvrr_stack+7272);

 /* compute (3 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+133599, dvrr_stack+11937, dvrr_stack+2296, dvrr_stack+3489, dvrr_stack+11448, dvrr_stack+7407);

 /* compute (4 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+134149, dvrr_stack+76879, dvrr_stack+133599, dvrr_stack+20531, dvrr_stack+11937, dvrr_stack+7677);

 /* compute (5 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+134974, dvrr_stack+77429, dvrr_stack+134149, dvrr_stack+20861, dvrr_stack+76879, dvrr_stack+126831);

 /* compute (6 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+136129, dvrr_stack+78254, dvrr_stack+134974, dvrr_stack+21411, dvrr_stack+77429, dvrr_stack+127506);

 /* compute (7 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+137669, dvrr_stack+79409, dvrr_stack+136129, dvrr_stack+23061, dvrr_stack+78254, dvrr_stack+128451);
 tmp = dvrr_stack + 137669;
 target_ptr = Libderiv->dvrr_classes[7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+139649,dvrr_stack+137669,dvrr_stack+12793,36);


 /* compute (1 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+3452, dvrr_stack+27611, dvrr_stack+12493, NULL, NULL, dvrr_stack+12438);

 /* compute (2 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20455, dvrr_stack+18441, dvrr_stack+3452, dvrr_stack+18987, dvrr_stack+27611, dvrr_stack+8127);

 /* compute (3 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+20851, dvrr_stack+19053, dvrr_stack+20455, dvrr_stack+6841, dvrr_stack+18441, dvrr_stack+2296);

 /* compute (4 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+144509, dvrr_stack+84729, dvrr_stack+20851, dvrr_stack+29559, dvrr_stack+19053, dvrr_stack+133599);

 /* compute (5 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+145499, dvrr_stack+85389, dvrr_stack+144509, dvrr_stack+29955, dvrr_stack+84729, dvrr_stack+134149);

 /* compute (6 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+146885, dvrr_stack+86379, dvrr_stack+145499, dvrr_stack+30615, dvrr_stack+85389, dvrr_stack+134974);

 /* compute (7 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+148733, dvrr_stack+87765, dvrr_stack+146885, dvrr_stack+32595, dvrr_stack+86379, dvrr_stack+136129);
 tmp = dvrr_stack + 148733;
 target_ptr = Libderiv->dvrr_classes[7][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+151109,dvrr_stack+148733,dvrr_stack+137669,36);


 /* compute (1 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+21511, dvrr_stack+38078, dvrr_stack+37625, NULL, NULL, dvrr_stack+12493);

 /* compute (2 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+21745, dvrr_stack+27051, dvrr_stack+21511, dvrr_stack+27677, dvrr_stack+38078, dvrr_stack+3452);

 /* compute (3 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+29507, dvrr_stack+27755, dvrr_stack+21745, dvrr_stack+12559, dvrr_stack+27051, dvrr_stack+20455);

 /* compute (4 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+30287, dvrr_stack+94233, dvrr_stack+29507, dvrr_stack+40410, dvrr_stack+27755, dvrr_stack+20851);

 /* compute (5 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+157049, dvrr_stack+95013, dvrr_stack+30287, dvrr_stack+40878, dvrr_stack+94233, dvrr_stack+144509);

 /* compute (6 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+158687, dvrr_stack+96183, dvrr_stack+157049, dvrr_stack+41658, dvrr_stack+95013, dvrr_stack+145499);

 /* compute (7 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+160871, dvrr_stack+97821, dvrr_stack+158687, dvrr_stack+43998, dvrr_stack+96183, dvrr_stack+146885);
 tmp = dvrr_stack + 160871;
 target_ptr = Libderiv->dvrr_classes[7][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+163679,dvrr_stack+160871,dvrr_stack+148733,36);


 /* compute (0 0 | 1 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+12559, Data->F+18, Data->F+19, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+6, dvrr_stack+37446, dvrr_stack+12559, Data->F+17, Data->F+18, NULL);

 /* compute (0 0 | 3 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+12562, dvrr_stack+37449, dvrr_stack+6, dvrr_stack+37914, dvrr_stack+37446, NULL);

 /* compute (0 0 | 4 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+12572, dvrr_stack+39, dvrr_stack+12562, dvrr_stack+37917, dvrr_stack+37449, NULL);

 /* compute (0 0 | 5 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+12587, dvrr_stack+207, dvrr_stack+12572, dvrr_stack+37923, dvrr_stack+39, NULL);

 /* compute (0 0 | 6 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+12608, dvrr_stack+37455, dvrr_stack+12587, dvrr_stack+37933, dvrr_stack+207, NULL);

 /* compute (0 0 | 7 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+2905, dvrr_stack+37476, dvrr_stack+12608, dvrr_stack+37948, dvrr_stack+37455, NULL);

 /* compute (0 0 | 8 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+6067, dvrr_stack+767, dvrr_stack+2905, dvrr_stack+37969, dvrr_stack+37476, NULL);

 /* compute (0 0 | 9 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+11882, dvrr_stack+237, dvrr_stack+6067, dvrr_stack+37997, dvrr_stack+767, NULL);

 /* compute (0 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18987, dvrr_stack+37504, dvrr_stack+11882, dvrr_stack+38033, dvrr_stack+237, NULL);

 /* compute (0 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+27677, dvrr_stack+37559, dvrr_stack+18987, dvrr_stack+2941, dvrr_stack+37504, NULL);

 /* compute (0 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+12636, dvrr_stack+37625, dvrr_stack+27677, dvrr_stack+12493, dvrr_stack+37559, NULL);

 /* compute (1 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+40373, dvrr_stack+37703, dvrr_stack+12636, NULL, NULL, dvrr_stack+37625);

 /* compute (2 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+40646, dvrr_stack+20182, dvrr_stack+40373, dvrr_stack+39253, dvrr_stack+37703, dvrr_stack+21511);

 /* compute (3 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+41192, dvrr_stack+38156, dvrr_stack+40646, dvrr_stack+28594, dvrr_stack+20182, dvrr_stack+21745);

 /* compute (4 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+170807, dvrr_stack+105549, dvrr_stack+41192, dvrr_stack+52706, dvrr_stack+38156, dvrr_stack+29507);

 /* compute (5 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+172172, dvrr_stack+106459, dvrr_stack+170807, dvrr_stack+53252, dvrr_stack+105549, dvrr_stack+30287);

 /* compute (6 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+174083, dvrr_stack+107824, dvrr_stack+172172, dvrr_stack+54162, dvrr_stack+106459, dvrr_stack+157049);

 /* compute (7 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+176631, dvrr_stack+109735, dvrr_stack+174083, dvrr_stack+56892, dvrr_stack+107824, dvrr_stack+158687);

 /* compute (7 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+179907,dvrr_stack+176631,dvrr_stack+160871,36);


 /* compute (1 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+12727, Data->F+7, Data->F+8, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+12730, dvrr_stack+55527, dvrr_stack+12727, Data->F+6, Data->F+7, NULL);

 /* compute (1 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+12736, dvrr_stack+68, dvrr_stack+49, NULL, NULL, Data->F+8);

 /* compute (2 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+12745, dvrr_stack+55530, dvrr_stack+12736, dvrr_stack+3, dvrr_stack+68, dvrr_stack+12727);

 /* compute (3 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+12763, dvrr_stack+55539, dvrr_stack+12745, dvrr_stack+6012, dvrr_stack+55530, dvrr_stack+12730);

 /* compute (1 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+8292, dvrr_stack+361, dvrr_stack+285, NULL, NULL, dvrr_stack+49);

 /* compute (2 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+8310, dvrr_stack+55557, dvrr_stack+8292, dvrr_stack+71, dvrr_stack+361, dvrr_stack+12736);

 /* compute (3 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+1603, dvrr_stack+55575, dvrr_stack+8310, dvrr_stack+51796, dvrr_stack+55557, dvrr_stack+12745);

 /* compute (4 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+1663, dvrr_stack+55611, dvrr_stack+1603, dvrr_stack+51814, dvrr_stack+55575, dvrr_stack+12763);

 /* compute (1 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+71, dvrr_stack+1326, dvrr_stack+3313, NULL, NULL, dvrr_stack+285);

 /* compute (2 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+440, dvrr_stack+55671, dvrr_stack+71, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+8292);

 /* compute (3 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+50130, dvrr_stack+55701, dvrr_stack+440, dvrr_stack+51850, dvrr_stack+55671, dvrr_stack+8310);

 /* compute (4 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+37794, dvrr_stack+55761, dvrr_stack+50130, dvrr_stack+51880, dvrr_stack+55701, dvrr_stack+1603);

 /* compute (5 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+52613, dvrr_stack+55861, dvrr_stack+37794, dvrr_stack+51940, dvrr_stack+55761, dvrr_stack+1663);

 /* compute (1 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+51850, dvrr_stack+222, dvrr_stack+2841, NULL, NULL, dvrr_stack+3313);

 /* compute (2 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+50230, dvrr_stack+56011, dvrr_stack+51850, dvrr_stack+1336, dvrr_stack+222, dvrr_stack+71);

 /* compute (3 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+18639, dvrr_stack+56056, dvrr_stack+50230, dvrr_stack+52040, dvrr_stack+56011, dvrr_stack+440);

 /* compute (4 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+52823, dvrr_stack+56146, dvrr_stack+18639, dvrr_stack+52085, dvrr_stack+56056, dvrr_stack+50130);

 /* compute (5 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+53048, dvrr_stack+56296, dvrr_stack+52823, dvrr_stack+52175, dvrr_stack+56146, dvrr_stack+37794);

 /* compute (6 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+53363, dvrr_stack+56521, dvrr_stack+53048, dvrr_stack+52325, dvrr_stack+56296, dvrr_stack+52613);

 /* compute (1 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+52040, dvrr_stack+2856, dvrr_stack+6046, NULL, NULL, dvrr_stack+2841);

 /* compute (2 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+4662, dvrr_stack+377, dvrr_stack+52040, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+51850);

 /* compute (3 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+52103, dvrr_stack+49794, dvrr_stack+4662, dvrr_stack+52550, dvrr_stack+377, dvrr_stack+50230);

 /* compute (4 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+53783, dvrr_stack+49920, dvrr_stack+52103, dvrr_stack+50340, dvrr_stack+49794, dvrr_stack+18639);

 /* compute (5 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+54098, dvrr_stack+50676, dvrr_stack+53783, dvrr_stack+50466, dvrr_stack+49920, dvrr_stack+52823);

 /* compute (6 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+54539, dvrr_stack+50991, dvrr_stack+54098, dvrr_stack+19651, dvrr_stack+50676, dvrr_stack+53048);

 /* compute (7 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+6382, dvrr_stack+39785, dvrr_stack+54539, dvrr_stack+39344, dvrr_stack+50991, dvrr_stack+53363);

 /* compute (1 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+50320, dvrr_stack+3276, dvrr_stack+11773, NULL, NULL, dvrr_stack+6046);

 /* compute (2 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+50404, dvrr_stack+1351, dvrr_stack+50320, dvrr_stack+2877, dvrr_stack+3276, dvrr_stack+52040);

 /* compute (3 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+55127, dvrr_stack+1435, dvrr_stack+50404, dvrr_stack+809, dvrr_stack+1351, dvrr_stack+4662);

 /* compute (4 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+42102, dvrr_stack+51432, dvrr_stack+55127, dvrr_stack+933, dvrr_stack+1435, dvrr_stack+52103);

 /* compute (5 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+28223, dvrr_stack+38702, dvrr_stack+42102, dvrr_stack+28867, dvrr_stack+51432, dvrr_stack+53783);

 /* compute (6 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+188331, dvrr_stack+118835, dvrr_stack+28223, dvrr_stack+63717, dvrr_stack+38702, dvrr_stack+54098);

 /* compute (7 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+189115, dvrr_stack+119423, dvrr_stack+188331, dvrr_stack+64137, dvrr_stack+118835, dvrr_stack+54539);

 /* compute (8 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+190123, dvrr_stack+3654, dvrr_stack+189115, dvrr_stack+64725, dvrr_stack+119423, dvrr_stack+6382);
 tmp = dvrr_stack + 190123;
 target_ptr = Libderiv->dvrr_classes[8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+63717, dvrr_stack+11801, dvrr_stack+18851, NULL, NULL, dvrr_stack+11773);

 /* compute (2 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+63825, dvrr_stack+3344, dvrr_stack+63717, dvrr_stack+7236, dvrr_stack+11801, dvrr_stack+50320);

 /* compute (3 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+64041, dvrr_stack+27285, dvrr_stack+63825, dvrr_stack+2996, dvrr_stack+3344, dvrr_stack+50404);

 /* compute (4 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+191383, dvrr_stack+29147, dvrr_stack+64041, dvrr_stack+19966, dvrr_stack+27285, dvrr_stack+55127);

 /* compute (5 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+191923, dvrr_stack+120207, dvrr_stack+191383, dvrr_stack+65509, dvrr_stack+29147, dvrr_stack+42102);

 /* compute (6 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+192679, dvrr_stack+120747, dvrr_stack+191923, dvrr_stack+65869, dvrr_stack+120207, dvrr_stack+28223);

 /* compute (7 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+193687, dvrr_stack+121503, dvrr_stack+192679, dvrr_stack+66409, dvrr_stack+120747, dvrr_stack+188331);

 /* compute (8 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+65509, dvrr_stack+122511, dvrr_stack+193687, dvrr_stack+67165, dvrr_stack+121503, dvrr_stack+189115);
 tmp = dvrr_stack + 65509;
 target_ptr = Libderiv->dvrr_classes[8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+194983,dvrr_stack+65509,dvrr_stack+190123,45);


 /* compute (1 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+2996, dvrr_stack+18887, dvrr_stack+27566, NULL, NULL, dvrr_stack+18851);

 /* compute (2 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+64401, dvrr_stack+7272, dvrr_stack+2996, dvrr_stack+11837, dvrr_stack+18887, dvrr_stack+63717);

 /* compute (3 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+19449, dvrr_stack+7407, dvrr_stack+64401, dvrr_stack+5796, dvrr_stack+7272, dvrr_stack+63825);

 /* compute (4 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+198763, dvrr_stack+7677, dvrr_stack+19449, dvrr_stack+6112, dvrr_stack+7407, dvrr_stack+64041);

 /* compute (5 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+199438, dvrr_stack+126831, dvrr_stack+198763, dvrr_stack+70525, dvrr_stack+7677, dvrr_stack+191383);

 /* compute (6 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+200383, dvrr_stack+127506, dvrr_stack+199438, dvrr_stack+70975, dvrr_stack+126831, dvrr_stack+191923);

 /* compute (7 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+201643, dvrr_stack+128451, dvrr_stack+200383, dvrr_stack+71650, dvrr_stack+127506, dvrr_stack+192679);

 /* compute (8 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+70525, dvrr_stack+12793, dvrr_stack+201643, dvrr_stack+72595, dvrr_stack+128451, dvrr_stack+193687);
 tmp = dvrr_stack + 70525;
 target_ptr = Libderiv->dvrr_classes[8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+203263,dvrr_stack+70525,dvrr_stack+65509,45);


 /* compute (1 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+6112, dvrr_stack+12438, dvrr_stack+2941, NULL, NULL, dvrr_stack+27566);

 /* compute (2 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+28811, dvrr_stack+8127, dvrr_stack+6112, dvrr_stack+18932, dvrr_stack+12438, dvrr_stack+2996);

 /* compute (3 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+208123, dvrr_stack+2296, dvrr_stack+28811, dvrr_stack+11448, dvrr_stack+8127, dvrr_stack+64401);

 /* compute (4 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+208673, dvrr_stack+133599, dvrr_stack+208123, dvrr_stack+11937, dvrr_stack+2296, dvrr_stack+19449);

 /* compute (5 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+209498, dvrr_stack+134149, dvrr_stack+208673, dvrr_stack+76879, dvrr_stack+133599, dvrr_stack+198763);

 /* compute (6 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+210653, dvrr_stack+134974, dvrr_stack+209498, dvrr_stack+77429, dvrr_stack+134149, dvrr_stack+199438);

 /* compute (7 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+212193, dvrr_stack+136129, dvrr_stack+210653, dvrr_stack+78254, dvrr_stack+134974, dvrr_stack+200383);

 /* compute (8 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+76879, dvrr_stack+137669, dvrr_stack+212193, dvrr_stack+79409, dvrr_stack+136129, dvrr_stack+201643);
 tmp = dvrr_stack + 76879;
 target_ptr = Libderiv->dvrr_classes[8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+214173,dvrr_stack+76879,dvrr_stack+70525,45);


 /* compute (1 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+11937, dvrr_stack+12493, dvrr_stack+37559, NULL, NULL, dvrr_stack+2941);

 /* compute (2 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+220248, dvrr_stack+3452, dvrr_stack+11937, dvrr_stack+27611, dvrr_stack+12493, dvrr_stack+6112);

 /* compute (3 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+220644, dvrr_stack+20455, dvrr_stack+220248, dvrr_stack+18441, dvrr_stack+3452, dvrr_stack+28811);

 /* compute (4 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+221304, dvrr_stack+20851, dvrr_stack+220644, dvrr_stack+19053, dvrr_stack+20455, dvrr_stack+208123);

 /* compute (5 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+222294, dvrr_stack+144509, dvrr_stack+221304, dvrr_stack+84729, dvrr_stack+20851, dvrr_stack+208673);

 /* compute (6 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+223680, dvrr_stack+145499, dvrr_stack+222294, dvrr_stack+85389, dvrr_stack+144509, dvrr_stack+209498);

 /* compute (7 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+225528, dvrr_stack+146885, dvrr_stack+223680, dvrr_stack+86379, dvrr_stack+145499, dvrr_stack+210653);

 /* compute (8 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+84729, dvrr_stack+148733, dvrr_stack+225528, dvrr_stack+87765, dvrr_stack+146885, dvrr_stack+212193);
 tmp = dvrr_stack + 84729;
 target_ptr = Libderiv->dvrr_classes[8][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+227904,dvrr_stack+84729,dvrr_stack+76879,45);


 /* compute (1 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+19053, dvrr_stack+37625, dvrr_stack+27677, NULL, NULL, dvrr_stack+37559);

 /* compute (2 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+235329, dvrr_stack+21511, dvrr_stack+19053, dvrr_stack+38078, dvrr_stack+37625, dvrr_stack+11937);

 /* compute (3 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+235797, dvrr_stack+21745, dvrr_stack+235329, dvrr_stack+27051, dvrr_stack+21511, dvrr_stack+220248);

 /* compute (4 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+236577, dvrr_stack+29507, dvrr_stack+235797, dvrr_stack+27755, dvrr_stack+21745, dvrr_stack+220644);

 /* compute (5 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+237747, dvrr_stack+30287, dvrr_stack+236577, dvrr_stack+94233, dvrr_stack+29507, dvrr_stack+221304);

 /* compute (6 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+239385, dvrr_stack+157049, dvrr_stack+237747, dvrr_stack+95013, dvrr_stack+30287, dvrr_stack+222294);

 /* compute (7 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+241569, dvrr_stack+158687, dvrr_stack+239385, dvrr_stack+96183, dvrr_stack+157049, dvrr_stack+223680);

 /* compute (8 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+94233, dvrr_stack+160871, dvrr_stack+241569, dvrr_stack+97821, dvrr_stack+158687, dvrr_stack+225528);
 tmp = dvrr_stack + 94233;
 target_ptr = Libderiv->dvrr_classes[8][11];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+244377,dvrr_stack+94233,dvrr_stack+84729,45);


 /* compute (0 0 | 1 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+3, Data->F+19, Data->F+20, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+29141, dvrr_stack+12559, dvrr_stack+3, Data->F+18, Data->F+19, NULL);

 /* compute (0 0 | 3 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+367, dvrr_stack+6, dvrr_stack+29141, dvrr_stack+37446, dvrr_stack+12559, NULL);

 /* compute (0 0 | 4 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+1336, dvrr_stack+12562, dvrr_stack+367, dvrr_stack+37449, dvrr_stack+6, NULL);

 /* compute (0 0 | 5 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+3323, dvrr_stack+12572, dvrr_stack+1336, dvrr_stack+39, dvrr_stack+12562, NULL);

 /* compute (0 0 | 6 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+2877, dvrr_stack+12587, dvrr_stack+3323, dvrr_stack+207, dvrr_stack+12572, NULL);

 /* compute (0 0 | 7 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+67129, dvrr_stack+12608, dvrr_stack+2877, dvrr_stack+37455, dvrr_stack+12587, NULL);

 /* compute (0 0 | 8 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+72550, dvrr_stack+2905, dvrr_stack+67129, dvrr_stack+37476, dvrr_stack+12608, NULL);

 /* compute (0 0 | 9 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+79354, dvrr_stack+6067, dvrr_stack+72550, dvrr_stack+767, dvrr_stack+2905, NULL);

 /* compute (0 0 | 10 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+87699, dvrr_stack+11882, dvrr_stack+79354, dvrr_stack+237, dvrr_stack+6067, NULL);

 /* compute (0 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+97743, dvrr_stack+18987, dvrr_stack+87699, dvrr_stack+37504, dvrr_stack+11882, NULL);

 /* compute (0 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+27755, dvrr_stack+27677, dvrr_stack+97743, dvrr_stack+37559, dvrr_stack+18987, NULL);

 /* compute (1 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+27846, dvrr_stack+12636, dvrr_stack+27755, NULL, NULL, dvrr_stack+27677);

 /* compute (2 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+253287, dvrr_stack+40373, dvrr_stack+27846, dvrr_stack+37703, dvrr_stack+12636, dvrr_stack+19053);

 /* compute (3 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+253833, dvrr_stack+40646, dvrr_stack+253287, dvrr_stack+20182, dvrr_stack+40373, dvrr_stack+235329);

 /* compute (4 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+254743, dvrr_stack+41192, dvrr_stack+253833, dvrr_stack+38156, dvrr_stack+40646, dvrr_stack+235797);

 /* compute (5 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+256108, dvrr_stack+170807, dvrr_stack+254743, dvrr_stack+105549, dvrr_stack+41192, dvrr_stack+236577);

 /* compute (6 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+258019, dvrr_stack+172172, dvrr_stack+256108, dvrr_stack+106459, dvrr_stack+170807, dvrr_stack+237747);

 /* compute (7 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+260567, dvrr_stack+174083, dvrr_stack+258019, dvrr_stack+107824, dvrr_stack+172172, dvrr_stack+239385);

 /* compute (8 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+105549, dvrr_stack+176631, dvrr_stack+260567, dvrr_stack+109735, dvrr_stack+174083, dvrr_stack+241569);

 /* compute (8 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+263843,dvrr_stack+105549,dvrr_stack+94233,45);


 /* compute (1 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+109644, Data->F+8, Data->F+9, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+109647, dvrr_stack+12727, dvrr_stack+109644, Data->F+7, Data->F+8, NULL);

 /* compute (3 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+39, dvrr_stack+12730, dvrr_stack+109647, dvrr_stack+55527, dvrr_stack+12727, NULL);

 /* compute (1 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+109653, dvrr_stack+49, dvrr_stack+282, NULL, NULL, Data->F+9);

 /* compute (2 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1753, dvrr_stack+12736, dvrr_stack+109653, dvrr_stack+68, dvrr_stack+49, dvrr_stack+109644);

 /* compute (3 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+109662, dvrr_stack+12745, dvrr_stack+1753, dvrr_stack+55530, dvrr_stack+12736, dvrr_stack+109647);

 /* compute (4 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+11837, dvrr_stack+12763, dvrr_stack+109662, dvrr_stack+55539, dvrr_stack+12745, dvrr_stack+39);

 /* compute (1 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+109692, dvrr_stack+285, dvrr_stack+3307, NULL, NULL, dvrr_stack+282);

 /* compute (2 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+767, dvrr_stack+8292, dvrr_stack+109692, dvrr_stack+361, dvrr_stack+285, dvrr_stack+109653);

 /* compute (3 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+37703, dvrr_stack+8310, dvrr_stack+767, dvrr_stack+55557, dvrr_stack+8292, dvrr_stack+1753);

 /* compute (4 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+28119, dvrr_stack+1603, dvrr_stack+37703, dvrr_stack+55575, dvrr_stack+8310, dvrr_stack+109662);

 /* compute (5 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+27051, dvrr_stack+1663, dvrr_stack+28119, dvrr_stack+55611, dvrr_stack+1603, dvrr_stack+11837);

 /* compute (1 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+55557, dvrr_stack+3313, dvrr_stack+2831, NULL, NULL, dvrr_stack+3307);

 /* compute (2 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+27177, dvrr_stack+71, dvrr_stack+55557, dvrr_stack+1326, dvrr_stack+3313, dvrr_stack+109692);

 /* compute (3 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+38078, dvrr_stack+440, dvrr_stack+27177, dvrr_stack+55671, dvrr_stack+71, dvrr_stack+767);

 /* compute (4 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+38178, dvrr_stack+50130, dvrr_stack+38078, dvrr_stack+55701, dvrr_stack+440, dvrr_stack+37703);

 /* compute (5 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+38328, dvrr_stack+37794, dvrr_stack+38178, dvrr_stack+55761, dvrr_stack+50130, dvrr_stack+28119);

 /* compute (6 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+12135, dvrr_stack+52613, dvrr_stack+38328, dvrr_stack+55861, dvrr_stack+37794, dvrr_stack+27051);

 /* compute (1 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+51895, dvrr_stack+2841, dvrr_stack+6031, NULL, NULL, dvrr_stack+2831);

 /* compute (2 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+55671, dvrr_stack+51850, dvrr_stack+51895, dvrr_stack+222, dvrr_stack+2841, dvrr_stack+55557);

 /* compute (3 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+38538, dvrr_stack+50230, dvrr_stack+55671, dvrr_stack+56011, dvrr_stack+51850, dvrr_stack+27177);

 /* compute (4 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+11448, dvrr_stack+18639, dvrr_stack+38538, dvrr_stack+56056, dvrr_stack+50230, dvrr_stack+38078);

 /* compute (5 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+19899, dvrr_stack+52823, dvrr_stack+11448, dvrr_stack+56146, dvrr_stack+18639, dvrr_stack+38178);

 /* compute (6 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+274373, dvrr_stack+53048, dvrr_stack+19899, dvrr_stack+56296, dvrr_stack+52823, dvrr_stack+38328);

 /* compute (7 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+274793, dvrr_stack+53363, dvrr_stack+274373, dvrr_stack+56521, dvrr_stack+53048, dvrr_stack+12135);

 /* compute (1 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+52550, dvrr_stack+6046, dvrr_stack+11752, NULL, NULL, dvrr_stack+6031);

 /* compute (2 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+56011, dvrr_stack+52040, dvrr_stack+52550, dvrr_stack+2856, dvrr_stack+6046, dvrr_stack+51895);

 /* compute (3 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+56137, dvrr_stack+4662, dvrr_stack+56011, dvrr_stack+377, dvrr_stack+52040, dvrr_stack+55671);

 /* compute (4 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+275333, dvrr_stack+52103, dvrr_stack+56137, dvrr_stack+49794, dvrr_stack+4662, dvrr_stack+38538);

 /* compute (5 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+275648, dvrr_stack+53783, dvrr_stack+275333, dvrr_stack+49920, dvrr_stack+52103, dvrr_stack+11448);

 /* compute (6 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+276089, dvrr_stack+54098, dvrr_stack+275648, dvrr_stack+50676, dvrr_stack+53783, dvrr_stack+19899);

 /* compute (7 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+276677, dvrr_stack+54539, dvrr_stack+276089, dvrr_stack+50991, dvrr_stack+54098, dvrr_stack+274373);

 /* compute (8 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+277433, dvrr_stack+6382, dvrr_stack+276677, dvrr_stack+39785, dvrr_stack+54539, dvrr_stack+274793);

 /* compute (1 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+49794, dvrr_stack+11773, dvrr_stack+18823, NULL, NULL, dvrr_stack+11752);

 /* compute (2 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+933, dvrr_stack+50320, dvrr_stack+49794, dvrr_stack+3276, dvrr_stack+11773, dvrr_stack+52550);

 /* compute (3 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+50572, dvrr_stack+50404, dvrr_stack+933, dvrr_stack+1351, dvrr_stack+50320, dvrr_stack+56011);

 /* compute (4 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+50852, dvrr_stack+55127, dvrr_stack+50572, dvrr_stack+1435, dvrr_stack+50404, dvrr_stack+56137);

 /* compute (5 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+278378, dvrr_stack+42102, dvrr_stack+50852, dvrr_stack+51432, dvrr_stack+55127, dvrr_stack+275333);

 /* compute (6 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+278966, dvrr_stack+28223, dvrr_stack+278378, dvrr_stack+38702, dvrr_stack+42102, dvrr_stack+275648);

 /* compute (7 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+279750, dvrr_stack+188331, dvrr_stack+278966, dvrr_stack+118835, dvrr_stack+28223, dvrr_stack+276089);

 /* compute (8 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+280758, dvrr_stack+189115, dvrr_stack+279750, dvrr_stack+119423, dvrr_stack+188331, dvrr_stack+276677);

 /* compute (9 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+282018, dvrr_stack+190123, dvrr_stack+280758, dvrr_stack+3654, dvrr_stack+189115, dvrr_stack+277433);
 tmp = dvrr_stack + 282018;
 target_ptr = Libderiv->dvrr_classes[9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (1 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+118835, dvrr_stack+18851, dvrr_stack+27530, NULL, NULL, dvrr_stack+18823);

 /* compute (2 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+5796, dvrr_stack+63717, dvrr_stack+118835, dvrr_stack+11801, dvrr_stack+18851, dvrr_stack+49794);

 /* compute (3 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+118943, dvrr_stack+63825, dvrr_stack+5796, dvrr_stack+3344, dvrr_stack+63717, dvrr_stack+933);

 /* compute (4 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+119303, dvrr_stack+64041, dvrr_stack+118943, dvrr_stack+27285, dvrr_stack+63825, dvrr_stack+50572);

 /* compute (5 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+283558, dvrr_stack+191383, dvrr_stack+119303, dvrr_stack+29147, dvrr_stack+64041, dvrr_stack+50852);

 /* compute (6 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+284314, dvrr_stack+191923, dvrr_stack+283558, dvrr_stack+120207, dvrr_stack+191383, dvrr_stack+278378);

 /* compute (7 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+285322, dvrr_stack+192679, dvrr_stack+284314, dvrr_stack+120747, dvrr_stack+191923, dvrr_stack+278966);

 /* compute (8 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+119843, dvrr_stack+193687, dvrr_stack+285322, dvrr_stack+121503, dvrr_stack+192679, dvrr_stack+279750);

 /* compute (9 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+286618, dvrr_stack+65509, dvrr_stack+119843, dvrr_stack+122511, dvrr_stack+193687, dvrr_stack+280758);
 tmp = dvrr_stack + 286618;
 target_ptr = Libderiv->dvrr_classes[9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_ip(Libderiv->CD,dvrr_stack+288598,dvrr_stack+286618,dvrr_stack+282018,55);


 /* compute (1 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+29147, dvrr_stack+27566, dvrr_stack+38033, NULL, NULL, dvrr_stack+27530);

 /* compute (2 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+121463, dvrr_stack+2996, dvrr_stack+29147, dvrr_stack+18887, dvrr_stack+27566, dvrr_stack+118835);

 /* compute (3 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+121733, dvrr_stack+64401, dvrr_stack+121463, dvrr_stack+7272, dvrr_stack+2996, dvrr_stack+5796);

 /* compute (4 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+293218, dvrr_stack+19449, dvrr_stack+121733, dvrr_stack+7407, dvrr_stack+64401, dvrr_stack+118943);

 /* compute (5 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+293893, dvrr_stack+198763, dvrr_stack+293218, dvrr_stack+7677, dvrr_stack+19449, dvrr_stack+119303);

 /* compute (6 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+294838, dvrr_stack+199438, dvrr_stack+293893, dvrr_stack+126831, dvrr_stack+198763, dvrr_stack+283558);

 /* compute (7 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+296098, dvrr_stack+200383, dvrr_stack+294838, dvrr_stack+127506, dvrr_stack+199438, dvrr_stack+284314);

 /* compute (8 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+297718, dvrr_stack+201643, dvrr_stack+296098, dvrr_stack+128451, dvrr_stack+200383, dvrr_stack+285322);

 /* compute (9 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+126831, dvrr_stack+70525, dvrr_stack+297718, dvrr_stack+12793, dvrr_stack+201643, dvrr_stack+119843);
 tmp = dvrr_stack + 126831;
 target_ptr = Libderiv->dvrr_classes[9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_kp(Libderiv->CD,dvrr_stack+299743,dvrr_stack+126831,dvrr_stack+286618,55);


 /* compute (1 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+129306, dvrr_stack+2941, dvrr_stack+37504, NULL, NULL, dvrr_stack+38033);

 /* compute (2 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+38688, dvrr_stack+6112, dvrr_stack+129306, dvrr_stack+12438, dvrr_stack+2941, dvrr_stack+29147);

 /* compute (3 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+7138, dvrr_stack+28811, dvrr_stack+38688, dvrr_stack+8127, dvrr_stack+6112, dvrr_stack+121463);

 /* compute (4 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+305683, dvrr_stack+208123, dvrr_stack+7138, dvrr_stack+2296, dvrr_stack+28811, dvrr_stack+121733);

 /* compute (5 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+306508, dvrr_stack+208673, dvrr_stack+305683, dvrr_stack+133599, dvrr_stack+208123, dvrr_stack+293218);

 /* compute (6 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+307663, dvrr_stack+209498, dvrr_stack+306508, dvrr_stack+134149, dvrr_stack+208673, dvrr_stack+293893);

 /* compute (7 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+309203, dvrr_stack+210653, dvrr_stack+307663, dvrr_stack+134974, dvrr_stack+209498, dvrr_stack+294838);

 /* compute (8 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+133599, dvrr_stack+212193, dvrr_stack+309203, dvrr_stack+136129, dvrr_stack+210653, dvrr_stack+296098);

 /* compute (9 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+311183, dvrr_stack+76879, dvrr_stack+133599, dvrr_stack+137669, dvrr_stack+212193, dvrr_stack+297718);
 tmp = dvrr_stack + 311183;
 target_ptr = Libderiv->dvrr_classes[9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_lp(Libderiv->CD,dvrr_stack+314208,dvrr_stack+311183,dvrr_stack+126831,55);


 /* compute (1 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+18441, dvrr_stack+37559, dvrr_stack+18987, NULL, NULL, dvrr_stack+37504);

 /* compute (2 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+136074, dvrr_stack+11937, dvrr_stack+18441, dvrr_stack+12493, dvrr_stack+37559, dvrr_stack+129306);

 /* compute (3 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+136470, dvrr_stack+220248, dvrr_stack+136074, dvrr_stack+3452, dvrr_stack+11937, dvrr_stack+38688);

 /* compute (4 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+321633, dvrr_stack+220644, dvrr_stack+136470, dvrr_stack+20455, dvrr_stack+220248, dvrr_stack+7138);

 /* compute (5 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+322623, dvrr_stack+221304, dvrr_stack+321633, dvrr_stack+20851, dvrr_stack+220644, dvrr_stack+305683);

 /* compute (6 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+324009, dvrr_stack+222294, dvrr_stack+322623, dvrr_stack+144509, dvrr_stack+221304, dvrr_stack+306508);

 /* compute (7 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+325857, dvrr_stack+223680, dvrr_stack+324009, dvrr_stack+145499, dvrr_stack+222294, dvrr_stack+307663);

 /* compute (8 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+328233, dvrr_stack+225528, dvrr_stack+325857, dvrr_stack+146885, dvrr_stack+223680, dvrr_stack+309203);

 /* compute (9 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+144509, dvrr_stack+84729, dvrr_stack+328233, dvrr_stack+148733, dvrr_stack+225528, dvrr_stack+133599);
 tmp = dvrr_stack + 144509;
 target_ptr = Libderiv->dvrr_classes[9][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_mp(Libderiv->CD,dvrr_stack+331203,dvrr_stack+144509,dvrr_stack+311183,55);


 /* compute (1 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+148139, dvrr_stack+27677, dvrr_stack+97743, NULL, NULL, dvrr_stack+18987);

 /* compute (2 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+137130, dvrr_stack+19053, dvrr_stack+148139, dvrr_stack+37625, dvrr_stack+27677, dvrr_stack+18441);

 /* compute (3 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+20214, dvrr_stack+235329, dvrr_stack+137130, dvrr_stack+21511, dvrr_stack+19053, dvrr_stack+136074);

 /* compute (4 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+340278, dvrr_stack+235797, dvrr_stack+20214, dvrr_stack+21745, dvrr_stack+235329, dvrr_stack+136470);

 /* compute (5 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+341448, dvrr_stack+236577, dvrr_stack+340278, dvrr_stack+29507, dvrr_stack+235797, dvrr_stack+321633);

 /* compute (6 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+343086, dvrr_stack+237747, dvrr_stack+341448, dvrr_stack+30287, dvrr_stack+236577, dvrr_stack+322623);

 /* compute (7 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+345270, dvrr_stack+239385, dvrr_stack+343086, dvrr_stack+157049, dvrr_stack+237747, dvrr_stack+324009);

 /* compute (8 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+348078, dvrr_stack+241569, dvrr_stack+345270, dvrr_stack+158687, dvrr_stack+239385, dvrr_stack+325857);

 /* compute (9 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+351588, dvrr_stack+94233, dvrr_stack+348078, dvrr_stack+160871, dvrr_stack+241569, dvrr_stack+328233);

 /* compute (9 0 | 10 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_np(Libderiv->CD,dvrr_stack+355878,dvrr_stack+351588,dvrr_stack+144509,55);


 /* compute (0 0 | 1 0) m=20 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00p0(Data,dvrr_stack+68, Data->F+20, Data->F+21, NULL, NULL, NULL);

 /* compute (0 0 | 2 0) m=19 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00d0(Data,dvrr_stack+361, dvrr_stack+3, dvrr_stack+68, Data->F+19, Data->F+20, NULL);

 /* compute (0 0 | 3 0) m=18 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00f0(Data,dvrr_stack+1326, dvrr_stack+29141, dvrr_stack+361, dvrr_stack+12559, dvrr_stack+3, NULL);

 /* compute (0 0 | 4 0) m=17 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00g0(Data,dvrr_stack+157049, dvrr_stack+367, dvrr_stack+1326, dvrr_stack+6, dvrr_stack+29141, NULL);

 /* compute (0 0 | 5 0) m=16 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00h0(Data,dvrr_stack+2856, dvrr_stack+1336, dvrr_stack+157049, dvrr_stack+12562, dvrr_stack+367, NULL);

 /* compute (0 0 | 6 0) m=15 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_00i0(Data,dvrr_stack+157049, dvrr_stack+3323, dvrr_stack+2856, dvrr_stack+12572, dvrr_stack+1336, NULL);

 /* compute (0 0 | 7 0) m=14 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+11801, dvrr_stack+2877, dvrr_stack+157049, dvrr_stack+12587, dvrr_stack+3323, NULL);

 /* compute (0 0 | 8 0) m=13 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+3323, dvrr_stack+67129, dvrr_stack+11801, dvrr_stack+12608, dvrr_stack+2877, NULL);

 /* compute (0 0 | 9 0) m=12 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+3368, dvrr_stack+72550, dvrr_stack+3323, dvrr_stack+2905, dvrr_stack+67129, NULL);

 /* compute (0 0 | 10 0) m=11 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+27611, dvrr_stack+79354, dvrr_stack+3368, dvrr_stack+6067, dvrr_stack+72550, NULL);

 /* compute (0 0 | 11 0) m=10 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+37625, dvrr_stack+87699, dvrr_stack+27611, dvrr_stack+11882, dvrr_stack+79354, NULL);

 /* compute (0 0 | 12 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 0;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+3323, dvrr_stack+97743, dvrr_stack+37625, dvrr_stack+18987, dvrr_stack+87699, NULL);

 /* compute (1 0 | 12 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+157049, dvrr_stack+27755, dvrr_stack+3323, NULL, NULL, dvrr_stack+97743);

 /* compute (2 0 | 12 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+157322, dvrr_stack+27846, dvrr_stack+157049, dvrr_stack+12636, dvrr_stack+27755, dvrr_stack+148139);

 /* compute (3 0 | 12 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+157868, dvrr_stack+253287, dvrr_stack+157322, dvrr_stack+40373, dvrr_stack+27846, dvrr_stack+137130);

 /* compute (4 0 | 12 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+158778, dvrr_stack+253833, dvrr_stack+157868, dvrr_stack+40646, dvrr_stack+253287, dvrr_stack+20214);

 /* compute (5 0 | 12 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+29282, dvrr_stack+254743, dvrr_stack+158778, dvrr_stack+41192, dvrr_stack+253833, dvrr_stack+340278);

 /* compute (6 0 | 12 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+157049, dvrr_stack+256108, dvrr_stack+29282, dvrr_stack+170807, dvrr_stack+254743, dvrr_stack+341448);

 /* compute (7 0 | 12 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+366768, dvrr_stack+258019, dvrr_stack+157049, dvrr_stack+172172, dvrr_stack+256108, dvrr_stack+343086);

 /* compute (8 0 | 12 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+253287, dvrr_stack+260567, dvrr_stack+366768, dvrr_stack+174083, dvrr_stack+258019, dvrr_stack+345270);

 /* compute (9 0 | 12 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 12;
 vrr_build_xxxx(am,Data,dvrr_stack+170807, dvrr_stack+105549, dvrr_stack+253287, dvrr_stack+176631, dvrr_stack+260567, dvrr_stack+348078);

 /* compute (9 0 | 11 1) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 hrr3_build_op(Libderiv->CD,dvrr_stack+366768,dvrr_stack+170807,dvrr_stack+351588,55);


 /* compute (1 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+3, dvrr_stack+12, dvrr_stack+0, NULL, NULL, Data->F+5);

 /* compute (1 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+253287, dvrr_stack+52, dvrr_stack+15, NULL, NULL, dvrr_stack+12);

 /* compute (2 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+67129, dvrr_stack+253287, dvrr_stack+21, dvrr_stack+52, dvrr_stack+15, dvrr_stack+3);

 /* compute (1 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+207, dvrr_stack+291, dvrr_stack+58, NULL, NULL, dvrr_stack+52);

 /* compute (2 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+253305, dvrr_stack+207, dvrr_stack+117, dvrr_stack+291, dvrr_stack+58, dvrr_stack+253287);

 /* compute (3 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+18887, dvrr_stack+253305, dvrr_stack+147, dvrr_stack+207, dvrr_stack+117, dvrr_stack+67129);

 /* compute (1 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+72550, dvrr_stack+1101, dvrr_stack+301, NULL, NULL, dvrr_stack+291);

 /* compute (2 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+253365, dvrr_stack+72550, dvrr_stack+316, dvrr_stack+1101, dvrr_stack+301, dvrr_stack+207);

 /* compute (3 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+253455, dvrr_stack+253365, dvrr_stack+527, dvrr_stack+72550, dvrr_stack+316, dvrr_stack+253305);

 /* compute (4 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+253605, dvrr_stack+253455, dvrr_stack+617, dvrr_stack+253365, dvrr_stack+527, dvrr_stack+18887);

 /* compute (1 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+291, dvrr_stack+912, dvrr_stack+1116, NULL, NULL, dvrr_stack+1101);

 /* compute (2 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+253830, dvrr_stack+291, dvrr_stack+1137, dvrr_stack+912, dvrr_stack+1116, dvrr_stack+72550);

 /* compute (3 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+253956, dvrr_stack+253830, dvrr_stack+1200, dvrr_stack+291, dvrr_stack+1137, dvrr_stack+253365);

 /* compute (4 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+254166, dvrr_stack+253956, dvrr_stack+1771, dvrr_stack+253830, dvrr_stack+1200, dvrr_stack+253455);

 /* compute (5 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+1101, dvrr_stack+254166, dvrr_stack+1981, dvrr_stack+253956, dvrr_stack+1771, dvrr_stack+253605);

 /* compute (1 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+1771, Data->F+5, Data->F+6, NULL, NULL, NULL);

 /* compute (2 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+1774, dvrr_stack+3, dvrr_stack+6012, dvrr_stack+12, dvrr_stack+0, dvrr_stack+1771);

 /* compute (3 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+1792, dvrr_stack+67129, dvrr_stack+51814, dvrr_stack+253287, dvrr_stack+21, dvrr_stack+1774);

 /* compute (4 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+253830, dvrr_stack+18887, dvrr_stack+51940, dvrr_stack+253305, dvrr_stack+147, dvrr_stack+1792);

 /* compute (5 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+254481, dvrr_stack+253605, dvrr_stack+52325, dvrr_stack+253455, dvrr_stack+617, dvrr_stack+253830);

 /* compute (6 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+254796, dvrr_stack+1101, dvrr_stack+39344, dvrr_stack+254166, dvrr_stack+1981, dvrr_stack+254481);

 /* compute (2 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+29141, dvrr_stack+1771, dvrr_stack+55527, Data->F+5, Data->F+6, NULL);

 /* compute (3 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+253287, dvrr_stack+1774, dvrr_stack+55539, dvrr_stack+3, dvrr_stack+6012, dvrr_stack+29141);

 /* compute (4 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+253317, dvrr_stack+1792, dvrr_stack+55611, dvrr_stack+67129, dvrr_stack+51814, dvrr_stack+253287);

 /* compute (5 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+1852, dvrr_stack+253830, dvrr_stack+55861, dvrr_stack+18887, dvrr_stack+51940, dvrr_stack+253317);

 /* compute (6 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+2062, dvrr_stack+254481, dvrr_stack+56521, dvrr_stack+253605, dvrr_stack+52325, dvrr_stack+1852);

 /* compute (7 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+255384, dvrr_stack+254796, dvrr_stack+39785, dvrr_stack+1101, dvrr_stack+39344, dvrr_stack+2062);

 /* compute (3 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+51940, dvrr_stack+29141, dvrr_stack+12730, dvrr_stack+1771, dvrr_stack+55527, NULL);

 /* compute (4 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+72550, dvrr_stack+253287, dvrr_stack+12763, dvrr_stack+1774, dvrr_stack+55539, dvrr_stack+51940);

 /* compute (5 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+253407, dvrr_stack+253317, dvrr_stack+1663, dvrr_stack+1792, dvrr_stack+55611, dvrr_stack+72550);

 /* compute (6 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+253533, dvrr_stack+1852, dvrr_stack+52613, dvrr_stack+253830, dvrr_stack+55861, dvrr_stack+253407);

 /* compute (7 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+253813, dvrr_stack+2062, dvrr_stack+53363, dvrr_stack+254481, dvrr_stack+56521, dvrr_stack+253533);

 /* compute (8 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+256140, dvrr_stack+255384, dvrr_stack+6382, dvrr_stack+254796, dvrr_stack+39785, dvrr_stack+253813);

 /* compute (4 0 | 0 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+1771, dvrr_stack+51940, dvrr_stack+39, dvrr_stack+29141, dvrr_stack+12730, NULL);

 /* compute (5 0 | 1 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+51940, dvrr_stack+72550, dvrr_stack+11837, dvrr_stack+253287, dvrr_stack+12763, dvrr_stack+1771);

 /* compute (6 0 | 2 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+254353, dvrr_stack+253407, dvrr_stack+27051, dvrr_stack+253317, dvrr_stack+1663, dvrr_stack+51940);

 /* compute (7 0 | 3 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+148373, dvrr_stack+253533, dvrr_stack+12135, dvrr_stack+1852, dvrr_stack+52613, dvrr_stack+254353);

 /* compute (8 0 | 4 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+257085, dvrr_stack+253813, dvrr_stack+274793, dvrr_stack+2062, dvrr_stack+53363, dvrr_stack+148373);

 /* compute (9 0 | 5 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+253287, dvrr_stack+256140, dvrr_stack+277433, dvrr_stack+255384, dvrr_stack+6382, dvrr_stack+257085);

 /* compute (1 0 | 0 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p000(Data,dvrr_stack+257085, Data->F+9, Data->F+10, NULL, NULL, NULL);

 /* compute (2 0 | 0 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d000(Data,dvrr_stack+29141, dvrr_stack+109644, dvrr_stack+257085, Data->F+8, Data->F+9, NULL);

 /* compute (3 0 | 0 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f000(Data,dvrr_stack+257088, dvrr_stack+109647, dvrr_stack+29141, dvrr_stack+12727, dvrr_stack+109644, NULL);

 /* compute (4 0 | 0 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g000(Data,dvrr_stack+257098, dvrr_stack+39, dvrr_stack+257088, dvrr_stack+12730, dvrr_stack+109647, NULL);

 /* compute (1 0 | 1 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0p0(Data,dvrr_stack+109644, dvrr_stack+282, dvrr_stack+3304, NULL, NULL, Data->F+10);

 /* compute (2 0 | 1 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0p0(Data,dvrr_stack+257113, dvrr_stack+109653, dvrr_stack+109644, dvrr_stack+49, dvrr_stack+282, dvrr_stack+257085);

 /* compute (3 0 | 1 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0p0(Data,dvrr_stack+257131, dvrr_stack+1753, dvrr_stack+257113, dvrr_stack+12736, dvrr_stack+109653, dvrr_stack+29141);

 /* compute (4 0 | 1 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0p0(Data,dvrr_stack+72550, dvrr_stack+109662, dvrr_stack+257131, dvrr_stack+12745, dvrr_stack+1753, dvrr_stack+257088);

 /* compute (5 0 | 1 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0p0(Data,dvrr_stack+1753, dvrr_stack+11837, dvrr_stack+72550, dvrr_stack+12763, dvrr_stack+109662, dvrr_stack+257098);

 /* compute (1 0 | 2 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0d0(Data,dvrr_stack+1816, dvrr_stack+3307, dvrr_stack+803, NULL, NULL, dvrr_stack+3304);

 /* compute (2 0 | 2 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0d0(Data,dvrr_stack+67129, dvrr_stack+109692, dvrr_stack+1816, dvrr_stack+285, dvrr_stack+3307, dvrr_stack+109644);

 /* compute (3 0 | 2 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0d0(Data,dvrr_stack+1834, dvrr_stack+767, dvrr_stack+67129, dvrr_stack+8292, dvrr_stack+109692, dvrr_stack+257113);

 /* compute (4 0 | 2 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0d0(Data,dvrr_stack+109644, dvrr_stack+37703, dvrr_stack+1834, dvrr_stack+8310, dvrr_stack+767, dvrr_stack+257131);

 /* compute (5 0 | 2 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0d0(Data,dvrr_stack+1894, dvrr_stack+28119, dvrr_stack+109644, dvrr_stack+1603, dvrr_stack+37703, dvrr_stack+72550);

 /* compute (6 0 | 2 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0d0(Data,dvrr_stack+2020, dvrr_stack+27051, dvrr_stack+1894, dvrr_stack+1663, dvrr_stack+28119, dvrr_stack+1753);

 /* compute (1 0 | 3 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0f0(Data,dvrr_stack+27051, dvrr_stack+2831, dvrr_stack+6021, NULL, NULL, dvrr_stack+803);

 /* compute (2 0 | 3 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0f0(Data,dvrr_stack+27081, dvrr_stack+55557, dvrr_stack+27051, dvrr_stack+3313, dvrr_stack+2831, dvrr_stack+1816);

 /* compute (3 0 | 3 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0f0(Data,dvrr_stack+51940, dvrr_stack+27177, dvrr_stack+27081, dvrr_stack+71, dvrr_stack+55557, dvrr_stack+67129);

 /* compute (4 0 | 3 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0f0(Data,dvrr_stack+2188, dvrr_stack+38078, dvrr_stack+51940, dvrr_stack+440, dvrr_stack+27177, dvrr_stack+1834);

 /* compute (5 0 | 3 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0f0(Data,dvrr_stack+27141, dvrr_stack+38178, dvrr_stack+2188, dvrr_stack+50130, dvrr_stack+38078, dvrr_stack+109644);

 /* compute (6 0 | 3 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0f0(Data,dvrr_stack+2338, dvrr_stack+38328, dvrr_stack+27141, dvrr_stack+37794, dvrr_stack+38178, dvrr_stack+1894);

 /* compute (7 0 | 3 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 3;
 vrr_build_xxxx(am,Data,dvrr_stack+148373, dvrr_stack+12135, dvrr_stack+2338, dvrr_stack+52613, dvrr_stack+38328, dvrr_stack+2020);

 /* compute (1 0 | 4 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0g0(Data,dvrr_stack+72550, dvrr_stack+6031, dvrr_stack+11737, NULL, NULL, dvrr_stack+6021);

 /* compute (2 0 | 4 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0g0(Data,dvrr_stack+52613, dvrr_stack+51895, dvrr_stack+72550, dvrr_stack+2841, dvrr_stack+6031, dvrr_stack+27051);

 /* compute (3 0 | 4 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0g0(Data,dvrr_stack+12135, dvrr_stack+55671, dvrr_stack+52613, dvrr_stack+51850, dvrr_stack+51895, dvrr_stack+27081);

 /* compute (4 0 | 4 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0g0(Data,dvrr_stack+12285, dvrr_stack+38538, dvrr_stack+12135, dvrr_stack+50230, dvrr_stack+55671, dvrr_stack+51940);

 /* compute (5 0 | 4 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0g0(Data,dvrr_stack+38078, dvrr_stack+11448, dvrr_stack+12285, dvrr_stack+18639, dvrr_stack+38538, dvrr_stack+2188);

 /* compute (6 0 | 4 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0g0(Data,dvrr_stack+257085, dvrr_stack+19899, dvrr_stack+38078, dvrr_stack+52823, dvrr_stack+11448, dvrr_stack+27141);

 /* compute (7 0 | 4 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+257505, dvrr_stack+274373, dvrr_stack+257085, dvrr_stack+53048, dvrr_stack+19899, dvrr_stack+2338);

 /* compute (8 0 | 4 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 4;
 vrr_build_xxxx(am,Data,dvrr_stack+258045, dvrr_stack+274793, dvrr_stack+257505, dvrr_stack+53363, dvrr_stack+274373, dvrr_stack+148373);

 /* compute (1 0 | 5 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0h0(Data,dvrr_stack+148373, dvrr_stack+11752, dvrr_stack+18802, NULL, NULL, dvrr_stack+11737);

 /* compute (2 0 | 5 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0h0(Data,dvrr_stack+148436, dvrr_stack+52550, dvrr_stack+148373, dvrr_stack+6046, dvrr_stack+11752, dvrr_stack+72550);

 /* compute (3 0 | 5 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0h0(Data,dvrr_stack+274373, dvrr_stack+56011, dvrr_stack+148436, dvrr_stack+52040, dvrr_stack+52550, dvrr_stack+52613);

 /* compute (4 0 | 5 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0h0(Data,dvrr_stack+19899, dvrr_stack+56137, dvrr_stack+274373, dvrr_stack+4662, dvrr_stack+56011, dvrr_stack+12135);

 /* compute (5 0 | 5 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0h0(Data,dvrr_stack+274583, dvrr_stack+275333, dvrr_stack+19899, dvrr_stack+52103, dvrr_stack+56137, dvrr_stack+12285);

 /* compute (6 0 | 5 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0h0(Data,dvrr_stack+12135, dvrr_stack+275648, dvrr_stack+274583, dvrr_stack+53783, dvrr_stack+275333, dvrr_stack+38078);

 /* compute (7 0 | 5 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+258720, dvrr_stack+276089, dvrr_stack+12135, dvrr_stack+54098, dvrr_stack+275648, dvrr_stack+257085);

 /* compute (8 0 | 5 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+275024, dvrr_stack+276677, dvrr_stack+258720, dvrr_stack+54539, dvrr_stack+276089, dvrr_stack+257505);

 /* compute (9 0 | 5 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 5;
 vrr_build_xxxx(am,Data,dvrr_stack+259476, dvrr_stack+277433, dvrr_stack+275024, dvrr_stack+6382, dvrr_stack+276677, dvrr_stack+258045);

 /* compute (1 0 | 6 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_p0i0(Data,dvrr_stack+257085, dvrr_stack+18823, dvrr_stack+27502, NULL, NULL, dvrr_stack+18802);

 /* compute (2 0 | 6 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_d0i0(Data,dvrr_stack+257169, dvrr_stack+49794, dvrr_stack+257085, dvrr_stack+11773, dvrr_stack+18823, dvrr_stack+148373);

 /* compute (3 0 | 6 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_f0i0(Data,dvrr_stack+257337, dvrr_stack+933, dvrr_stack+257169, dvrr_stack+50320, dvrr_stack+49794, dvrr_stack+148436);

 /* compute (4 0 | 6 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_g0i0(Data,dvrr_stack+49794, dvrr_stack+50572, dvrr_stack+257337, dvrr_stack+50404, dvrr_stack+933, dvrr_stack+274373);

 /* compute (5 0 | 6 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_h0i0(Data,dvrr_stack+257617, dvrr_stack+50852, dvrr_stack+49794, dvrr_stack+55127, dvrr_stack+50572, dvrr_stack+19899);

 /* compute (6 0 | 6 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 _BUILD_i0i0(Data,dvrr_stack+275969, dvrr_stack+278378, dvrr_stack+257617, dvrr_stack+42102, dvrr_stack+50852, dvrr_stack+274583);

 /* compute (7 0 | 6 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+50214, dvrr_stack+278966, dvrr_stack+275969, dvrr_stack+28223, dvrr_stack+278378, dvrr_stack+12135);

 /* compute (8 0 | 6 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+51222, dvrr_stack+279750, dvrr_stack+50214, dvrr_stack+188331, dvrr_stack+278966, dvrr_stack+258720);

 /* compute (9 0 | 6 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+52482, dvrr_stack+280758, dvrr_stack+51222, dvrr_stack+189115, dvrr_stack+279750, dvrr_stack+275024);

 /* compute (10 0 | 6 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 6;
 vrr_build_xxxx(am,Data,dvrr_stack+54022, dvrr_stack+282018, dvrr_stack+52482, dvrr_stack+190123, dvrr_stack+280758, dvrr_stack+259476);

 /* compute (1 0 | 7 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+188331, dvrr_stack+27530, dvrr_stack+37997, NULL, NULL, dvrr_stack+27502);

 /* compute (2 0 | 7 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+188439, dvrr_stack+118835, dvrr_stack+188331, dvrr_stack+18851, dvrr_stack+27530, dvrr_stack+257085);

 /* compute (3 0 | 7 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+148373, dvrr_stack+5796, dvrr_stack+188439, dvrr_stack+63717, dvrr_stack+118835, dvrr_stack+257169);

 /* compute (4 0 | 7 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+188655, dvrr_stack+118943, dvrr_stack+148373, dvrr_stack+63825, dvrr_stack+5796, dvrr_stack+257337);

 /* compute (5 0 | 7 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+189195, dvrr_stack+119303, dvrr_stack+188655, dvrr_stack+64041, dvrr_stack+118943, dvrr_stack+49794);

 /* compute (6 0 | 7 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+274373, dvrr_stack+283558, dvrr_stack+189195, dvrr_stack+191383, dvrr_stack+119303, dvrr_stack+257617);

 /* compute (7 0 | 7 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+257085, dvrr_stack+284314, dvrr_stack+274373, dvrr_stack+191923, dvrr_stack+283558, dvrr_stack+275969);

 /* compute (8 0 | 7 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+258381, dvrr_stack+285322, dvrr_stack+257085, dvrr_stack+192679, dvrr_stack+284314, dvrr_stack+50214);

 /* compute (9 0 | 7 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+191383, dvrr_stack+119843, dvrr_stack+258381, dvrr_stack+193687, dvrr_stack+285322, dvrr_stack+51222);

 /* compute (10 0 | 7 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 7;
 vrr_build_xxxx(am,Data,dvrr_stack+283558, dvrr_stack+286618, dvrr_stack+191383, dvrr_stack+65509, dvrr_stack+119843, dvrr_stack+52482);

 /* compute (1 0 | 8 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+285934, dvrr_stack+38033, dvrr_stack+237, NULL, NULL, dvrr_stack+37997);

 /* compute (2 0 | 8 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+286069, dvrr_stack+29147, dvrr_stack+285934, dvrr_stack+27566, dvrr_stack+38033, dvrr_stack+188331);

 /* compute (3 0 | 8 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+193363, dvrr_stack+121463, dvrr_stack+286069, dvrr_stack+2996, dvrr_stack+29147, dvrr_stack+188439);

 /* compute (4 0 | 8 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+193813, dvrr_stack+121733, dvrr_stack+193363, dvrr_stack+64401, dvrr_stack+121463, dvrr_stack+148373);

 /* compute (5 0 | 8 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+49794, dvrr_stack+293218, dvrr_stack+193813, dvrr_stack+19449, dvrr_stack+121733, dvrr_stack+188655);

 /* compute (6 0 | 8 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+50739, dvrr_stack+293893, dvrr_stack+49794, dvrr_stack+198763, dvrr_stack+293218, dvrr_stack+189195);

 /* compute (7 0 | 8 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+188331, dvrr_stack+294838, dvrr_stack+50739, dvrr_stack+199438, dvrr_stack+293893, dvrr_stack+274373);

 /* compute (8 0 | 8 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+274373, dvrr_stack+296098, dvrr_stack+188331, dvrr_stack+200383, dvrr_stack+294838, dvrr_stack+257085);

 /* compute (9 0 | 8 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+276398, dvrr_stack+297718, dvrr_stack+274373, dvrr_stack+201643, dvrr_stack+296098, dvrr_stack+258381);

 /* compute (10 0 | 8 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 8;
 vrr_build_xxxx(am,Data,dvrr_stack+257085, dvrr_stack+126831, dvrr_stack+276398, dvrr_stack+70525, dvrr_stack+297718, dvrr_stack+191383);

 /* compute (1 0 | 9 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+191383, dvrr_stack+37504, dvrr_stack+11882, NULL, NULL, dvrr_stack+237);

 /* compute (2 0 | 9 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+191548, dvrr_stack+129306, dvrr_stack+191383, dvrr_stack+2941, dvrr_stack+37504, dvrr_stack+285934);

 /* compute (3 0 | 9 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+191878, dvrr_stack+38688, dvrr_stack+191548, dvrr_stack+6112, dvrr_stack+129306, dvrr_stack+286069);

 /* compute (4 0 | 9 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+192428, dvrr_stack+7138, dvrr_stack+191878, dvrr_stack+28811, dvrr_stack+38688, dvrr_stack+193363);

 /* compute (5 0 | 9 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+260055, dvrr_stack+305683, dvrr_stack+192428, dvrr_stack+208123, dvrr_stack+7138, dvrr_stack+193813);

 /* compute (6 0 | 9 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+193253, dvrr_stack+306508, dvrr_stack+260055, dvrr_stack+208673, dvrr_stack+305683, dvrr_stack+49794);

 /* compute (7 0 | 9 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+261210, dvrr_stack+307663, dvrr_stack+193253, dvrr_stack+209498, dvrr_stack+306508, dvrr_stack+50739);

 /* compute (8 0 | 9 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+49794, dvrr_stack+309203, dvrr_stack+261210, dvrr_stack+210653, dvrr_stack+307663, dvrr_stack+188331);

 /* compute (9 0 | 9 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+305683, dvrr_stack+133599, dvrr_stack+49794, dvrr_stack+212193, dvrr_stack+309203, dvrr_stack+274373);

 /* compute (10 0 | 9 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 9;
 vrr_build_xxxx(am,Data,dvrr_stack+208123, dvrr_stack+311183, dvrr_stack+305683, dvrr_stack+76879, dvrr_stack+133599, dvrr_stack+276398);

 /* compute (1 0 | 10 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+133599, dvrr_stack+18987, dvrr_stack+87699, NULL, NULL, dvrr_stack+11882);

 /* compute (2 0 | 10 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+133797, dvrr_stack+18441, dvrr_stack+133599, dvrr_stack+37559, dvrr_stack+18987, dvrr_stack+191383);

 /* compute (3 0 | 10 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+134193, dvrr_stack+136074, dvrr_stack+133797, dvrr_stack+11937, dvrr_stack+18441, dvrr_stack+191548);

 /* compute (4 0 | 10 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+134853, dvrr_stack+136470, dvrr_stack+134193, dvrr_stack+220248, dvrr_stack+136074, dvrr_stack+191878);

 /* compute (5 0 | 10 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+274373, dvrr_stack+321633, dvrr_stack+134853, dvrr_stack+220644, dvrr_stack+136470, dvrr_stack+192428);

 /* compute (6 0 | 10 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+191383, dvrr_stack+322623, dvrr_stack+274373, dvrr_stack+221304, dvrr_stack+321633, dvrr_stack+260055);

 /* compute (7 0 | 10 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+275759, dvrr_stack+324009, dvrr_stack+191383, dvrr_stack+222294, dvrr_stack+322623, dvrr_stack+193253);

 /* compute (8 0 | 10 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+220248, dvrr_stack+325857, dvrr_stack+275759, dvrr_stack+223680, dvrr_stack+324009, dvrr_stack+261210);

 /* compute (9 0 | 10 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+260055, dvrr_stack+328233, dvrr_stack+220248, dvrr_stack+225528, dvrr_stack+325857, dvrr_stack+49794);

 /* compute (10 0 | 10 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 10;
 vrr_build_xxxx(am,Data,dvrr_stack+321633, dvrr_stack+144509, dvrr_stack+260055, dvrr_stack+84729, dvrr_stack+328233, dvrr_stack+305683);

 /* compute (1 0 | 11 0) m=9 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 1;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+305683, dvrr_stack+97743, dvrr_stack+37625, NULL, NULL, dvrr_stack+87699);

 /* compute (2 0 | 11 0) m=8 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 2;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+305917, dvrr_stack+148139, dvrr_stack+305683, dvrr_stack+27677, dvrr_stack+97743, dvrr_stack+133599);

 /* compute (3 0 | 11 0) m=7 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 3;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+306385, dvrr_stack+137130, dvrr_stack+305917, dvrr_stack+19053, dvrr_stack+148139, dvrr_stack+133797);

 /* compute (4 0 | 11 0) m=6 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 4;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+307165, dvrr_stack+20214, dvrr_stack+306385, dvrr_stack+235329, dvrr_stack+137130, dvrr_stack+134193);

 /* compute (5 0 | 11 0) m=5 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 5;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+308335, dvrr_stack+340278, dvrr_stack+307165, dvrr_stack+235797, dvrr_stack+20214, dvrr_stack+134853);

 /* compute (6 0 | 11 0) m=4 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 6;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+133599, dvrr_stack+341448, dvrr_stack+308335, dvrr_stack+236577, dvrr_stack+340278, dvrr_stack+274373);

 /* compute (7 0 | 11 0) m=3 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 7;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+305683, dvrr_stack+343086, dvrr_stack+133599, dvrr_stack+237747, dvrr_stack+341448, dvrr_stack+191383);

 /* compute (8 0 | 11 0) m=2 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 8;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+191383, dvrr_stack+345270, dvrr_stack+305683, dvrr_stack+239385, dvrr_stack+343086, dvrr_stack+275759);

 /* compute (9 0 | 11 0) m=1 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 9;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+305683, dvrr_stack+348078, dvrr_stack+191383, dvrr_stack+241569, dvrr_stack+345270, dvrr_stack+220248);

 /* compute (10 0 | 11 0) m=0 deriv level 0 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 0 */
 am[0] = 10;  am[1] = 11;
 vrr_build_xxxx(am,Data,dvrr_stack+220248, dvrr_stack+351588, dvrr_stack+305683, dvrr_stack+94233, dvrr_stack+348078, dvrr_stack+260055);

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,588,dvrr_stack+260055, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 260055;
 target_ptr = Libderiv->deriv_classes[5][6][11];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,756,dvrr_stack+260643, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 260643;
 target_ptr = Libderiv->deriv_classes[5][7][11];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,945,dvrr_stack+261399, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 261399;
 target_ptr = Libderiv->deriv_classes[5][8][11];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1155,dvrr_stack+262344, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 262344;
 target_ptr = Libderiv->deriv_classes[5][9][11];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1386,dvrr_stack+305683, dvrr_stack+45636, NULL);
 tmp = dvrr_stack + 305683;
 target_ptr = Libderiv->deriv_classes[5][10][11];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1638,dvrr_stack+307069, dvrr_stack+58803, NULL);
 tmp = dvrr_stack + 307069;
 target_ptr = Libderiv->deriv_classes[5][11][11];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,784,dvrr_stack+308707, dvrr_stack+68173, NULL);
 tmp = dvrr_stack + 308707;
 target_ptr = Libderiv->deriv_classes[6][6][11];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+63717, dvrr_stack+73855, NULL);
 tmp = dvrr_stack + 63717;
 target_ptr = Libderiv->deriv_classes[6][7][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+309491, dvrr_stack+80949, NULL);
 tmp = dvrr_stack + 309491;
 target_ptr = Libderiv->deriv_classes[6][8][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+225396, dvrr_stack+89613, NULL);
 tmp = dvrr_stack + 225396;
 target_ptr = Libderiv->deriv_classes[6][9][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1848,dvrr_stack+191383, dvrr_stack+100005, NULL);
 tmp = dvrr_stack + 191383;
 target_ptr = Libderiv->deriv_classes[6][10][11];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2184,dvrr_stack+133599, dvrr_stack+112283, NULL);
 tmp = dvrr_stack + 133599;
 target_ptr = Libderiv->deriv_classes[6][11][11];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1008,dvrr_stack+193231, dvrr_stack+123807, NULL);
 tmp = dvrr_stack + 193231;
 target_ptr = Libderiv->deriv_classes[7][6][11];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1296,dvrr_stack+135783, dvrr_stack+129711, NULL);
 tmp = dvrr_stack + 135783;
 target_ptr = Libderiv->deriv_classes[7][7][11];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+274373, dvrr_stack+139649, NULL);
 tmp = dvrr_stack + 274373;
 target_ptr = Libderiv->deriv_classes[7][8][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+275993, dvrr_stack+151109, NULL);
 tmp = dvrr_stack + 275993;
 target_ptr = Libderiv->deriv_classes[7][9][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2376,dvrr_stack+277973, dvrr_stack+163679, NULL);
 tmp = dvrr_stack + 277973;
 target_ptr = Libderiv->deriv_classes[7][10][11];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2808,dvrr_stack+340278, dvrr_stack+179907, NULL);
 tmp = dvrr_stack + 340278;
 target_ptr = Libderiv->deriv_classes[7][11][11];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1260,dvrr_stack+280349, dvrr_stack+194983, NULL);
 tmp = dvrr_stack + 280349;
 target_ptr = Libderiv->deriv_classes[8][6][11];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1620,dvrr_stack+343086, dvrr_stack+203263, NULL);
 tmp = dvrr_stack + 343086;
 target_ptr = Libderiv->deriv_classes[8][7][11];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2025,dvrr_stack+344706, dvrr_stack+214173, NULL);
 tmp = dvrr_stack + 344706;
 target_ptr = Libderiv->deriv_classes[8][8][11];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+346731, dvrr_stack+227904, NULL);
 tmp = dvrr_stack + 346731;
 target_ptr = Libderiv->deriv_classes[8][9][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2970,dvrr_stack+235329, dvrr_stack+244377, NULL);
 tmp = dvrr_stack + 235329;
 target_ptr = Libderiv->deriv_classes[8][10][11];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3510,dvrr_stack+238299, dvrr_stack+263843, NULL);
 tmp = dvrr_stack + 238299;
 target_ptr = Libderiv->deriv_classes[8][11][11];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1540,dvrr_stack+349206, dvrr_stack+288598, NULL);
 tmp = dvrr_stack + 349206;
 target_ptr = Libderiv->deriv_classes[9][6][11];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,1980,dvrr_stack+241809, dvrr_stack+299743, NULL);
 tmp = dvrr_stack + 241809;
 target_ptr = Libderiv->deriv_classes[9][7][11];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,2475,dvrr_stack+49794, dvrr_stack+314208, NULL);
 tmp = dvrr_stack + 49794;
 target_ptr = Libderiv->deriv_classes[9][8][11];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3025,dvrr_stack+325989, dvrr_stack+331203, NULL);
 tmp = dvrr_stack + 325989;
 target_ptr = Libderiv->deriv_classes[9][9][11];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,3630,dvrr_stack+18441, dvrr_stack+355878, NULL);
 tmp = dvrr_stack + 18441;
 target_ptr = Libderiv->deriv_classes[9][10][11];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 0 1 */
 deriv_build_DZ_0(Data,4290,dvrr_stack+293218, dvrr_stack+366768, NULL);
 tmp = dvrr_stack + 293218;
 target_ptr = Libderiv->deriv_classes[9][11][11];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,588,dvrr_stack+243789, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 243789;
 target_ptr = Libderiv->deriv_classes[5][6][10];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,756,dvrr_stack+226936, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 226936;
 target_ptr = Libderiv->deriv_classes[5][7][10];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,945,dvrr_stack+52269, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 52269;
 target_ptr = Libderiv->deriv_classes[5][8][10];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1155,dvrr_stack+329014, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 329014;
 target_ptr = Libderiv->deriv_classes[5][9][10];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1386,dvrr_stack+188331, dvrr_stack+45636, NULL);
 tmp = dvrr_stack + 188331;
 target_ptr = Libderiv->deriv_classes[5][10][10];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1638,dvrr_stack+211753, dvrr_stack+58803, NULL);
 tmp = dvrr_stack + 211753;
 target_ptr = Libderiv->deriv_classes[5][11][10];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,784,dvrr_stack+350746, dvrr_stack+68173, NULL);
 tmp = dvrr_stack + 350746;
 target_ptr = Libderiv->deriv_classes[6][6][10];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+330169, dvrr_stack+73855, NULL);
 tmp = dvrr_stack + 330169;
 target_ptr = Libderiv->deriv_classes[6][7][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+297508, dvrr_stack+80949, NULL);
 tmp = dvrr_stack + 297508;
 target_ptr = Libderiv->deriv_classes[6][8][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+198763, dvrr_stack+89613, NULL);
 tmp = dvrr_stack + 198763;
 target_ptr = Libderiv->deriv_classes[6][9][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1848,dvrr_stack+200303, dvrr_stack+100005, NULL);
 tmp = dvrr_stack + 200303;
 target_ptr = Libderiv->deriv_classes[6][10][10];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2184,dvrr_stack+5796, dvrr_stack+112283, NULL);
 tmp = dvrr_stack + 5796;
 target_ptr = Libderiv->deriv_classes[6][11][10];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1008,dvrr_stack+202151, dvrr_stack+123807, NULL);
 tmp = dvrr_stack + 202151;
 target_ptr = Libderiv->deriv_classes[7][6][10];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1296,dvrr_stack+118835, dvrr_stack+129711, NULL);
 tmp = dvrr_stack + 118835;
 target_ptr = Libderiv->deriv_classes[7][7][10];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+120131, dvrr_stack+139649, NULL);
 tmp = dvrr_stack + 120131;
 target_ptr = Libderiv->deriv_classes[7][8][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+27051, dvrr_stack+151109, NULL);
 tmp = dvrr_stack + 27051;
 target_ptr = Libderiv->deriv_classes[7][9][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2376,dvrr_stack+29031, dvrr_stack+163679, NULL);
 tmp = dvrr_stack + 29031;
 target_ptr = Libderiv->deriv_classes[7][10][10];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2808,dvrr_stack+157049, dvrr_stack+179907, NULL);
 tmp = dvrr_stack + 157049;
 target_ptr = Libderiv->deriv_classes[7][11][10];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1260,dvrr_stack+11448, dvrr_stack+194983, NULL);
 tmp = dvrr_stack + 11448;
 target_ptr = Libderiv->deriv_classes[8][6][10];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1620,dvrr_stack+1542, dvrr_stack+203263, NULL);
 tmp = dvrr_stack + 1542;
 target_ptr = Libderiv->deriv_classes[8][7][10];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2025,dvrr_stack+37446, dvrr_stack+214173, NULL);
 tmp = dvrr_stack + 37446;
 target_ptr = Libderiv->deriv_classes[8][8][10];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+39471, dvrr_stack+227904, NULL);
 tmp = dvrr_stack + 39471;
 target_ptr = Libderiv->deriv_classes[8][9][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2970,dvrr_stack+379638, dvrr_stack+244377, NULL);
 tmp = dvrr_stack + 379638;
 target_ptr = Libderiv->deriv_classes[8][10][10];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3510,dvrr_stack+382608, dvrr_stack+263843, NULL);
 tmp = dvrr_stack + 382608;
 target_ptr = Libderiv->deriv_classes[8][11][10];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1540,dvrr_stack+386118, dvrr_stack+288598, NULL);
 tmp = dvrr_stack + 386118;
 target_ptr = Libderiv->deriv_classes[9][6][10];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,1980,dvrr_stack+387658, dvrr_stack+299743, NULL);
 tmp = dvrr_stack + 387658;
 target_ptr = Libderiv->deriv_classes[9][7][10];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,2475,dvrr_stack+389638, dvrr_stack+314208, NULL);
 tmp = dvrr_stack + 389638;
 target_ptr = Libderiv->deriv_classes[9][8][10];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3025,dvrr_stack+392113, dvrr_stack+331203, NULL);
 tmp = dvrr_stack + 392113;
 target_ptr = Libderiv->deriv_classes[9][9][10];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,3630,dvrr_stack+395138, dvrr_stack+355878, NULL);
 tmp = dvrr_stack + 395138;
 target_ptr = Libderiv->deriv_classes[9][10][10];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  0 1 0 */
 deriv_build_DY_0(Data,4290,dvrr_stack+398768, dvrr_stack+366768, NULL);
 tmp = dvrr_stack + 398768;
 target_ptr = Libderiv->deriv_classes[9][11][10];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,588,dvrr_stack+194239, dvrr_stack+9684, NULL);
 tmp = dvrr_stack + 194239;
 target_ptr = Libderiv->deriv_classes[5][6][9];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,756,dvrr_stack+9684, dvrr_stack+16173, NULL);
 tmp = dvrr_stack + 9684;
 target_ptr = Libderiv->deriv_classes[5][7][9];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,945,dvrr_stack+16173, dvrr_stack+24216, NULL);
 tmp = dvrr_stack + 16173;
 target_ptr = Libderiv->deriv_classes[5][8][9];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1155,dvrr_stack+24216, dvrr_stack+33981, NULL);
 tmp = dvrr_stack + 24216;
 target_ptr = Libderiv->deriv_classes[5][9][9];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1386,dvrr_stack+33981, dvrr_stack+45636, NULL);
 tmp = dvrr_stack + 33981;
 target_ptr = Libderiv->deriv_classes[5][10][9];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1638,dvrr_stack+45636, dvrr_stack+58803, NULL);
 tmp = dvrr_stack + 45636;
 target_ptr = Libderiv->deriv_classes[5][11][9];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,784,dvrr_stack+58803, dvrr_stack+68173, NULL);
 tmp = dvrr_stack + 58803;
 target_ptr = Libderiv->deriv_classes[6][6][9];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+10440, dvrr_stack+73855, NULL);
 tmp = dvrr_stack + 10440;
 target_ptr = Libderiv->deriv_classes[6][7][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+73855, dvrr_stack+80949, NULL);
 tmp = dvrr_stack + 73855;
 target_ptr = Libderiv->deriv_classes[6][8][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+80949, dvrr_stack+89613, NULL);
 tmp = dvrr_stack + 80949;
 target_ptr = Libderiv->deriv_classes[6][9][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1848,dvrr_stack+89613, dvrr_stack+100005, NULL);
 tmp = dvrr_stack + 89613;
 target_ptr = Libderiv->deriv_classes[6][10][9];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2184,dvrr_stack+100005, dvrr_stack+112283, NULL);
 tmp = dvrr_stack + 100005;
 target_ptr = Libderiv->deriv_classes[6][11][9];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1008,dvrr_stack+112283, dvrr_stack+123807, NULL);
 tmp = dvrr_stack + 112283;
 target_ptr = Libderiv->deriv_classes[7][6][9];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1296,dvrr_stack+123807, dvrr_stack+129711, NULL);
 tmp = dvrr_stack + 123807;
 target_ptr = Libderiv->deriv_classes[7][7][9];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+125103, dvrr_stack+139649, NULL);
 tmp = dvrr_stack + 125103;
 target_ptr = Libderiv->deriv_classes[7][8][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+139649, dvrr_stack+151109, NULL);
 tmp = dvrr_stack + 139649;
 target_ptr = Libderiv->deriv_classes[7][9][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2376,dvrr_stack+151109, dvrr_stack+163679, NULL);
 tmp = dvrr_stack + 151109;
 target_ptr = Libderiv->deriv_classes[7][10][9];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2808,dvrr_stack+163679, dvrr_stack+179907, NULL);
 tmp = dvrr_stack + 163679;
 target_ptr = Libderiv->deriv_classes[7][11][9];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1260,dvrr_stack+179907, dvrr_stack+194983, NULL);
 tmp = dvrr_stack + 179907;
 target_ptr = Libderiv->deriv_classes[8][6][9];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1620,dvrr_stack+181167, dvrr_stack+203263, NULL);
 tmp = dvrr_stack + 181167;
 target_ptr = Libderiv->deriv_classes[8][7][9];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2025,dvrr_stack+182787, dvrr_stack+214173, NULL);
 tmp = dvrr_stack + 182787;
 target_ptr = Libderiv->deriv_classes[8][8][9];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+184812, dvrr_stack+227904, NULL);
 tmp = dvrr_stack + 184812;
 target_ptr = Libderiv->deriv_classes[8][9][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2970,dvrr_stack+166487, dvrr_stack+244377, NULL);
 tmp = dvrr_stack + 166487;
 target_ptr = Libderiv->deriv_classes[8][10][9];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3510,dvrr_stack+244377, dvrr_stack+263843, NULL);
 tmp = dvrr_stack + 244377;
 target_ptr = Libderiv->deriv_classes[8][11][9];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1540,dvrr_stack+247887, dvrr_stack+288598, NULL);
 tmp = dvrr_stack + 247887;
 target_ptr = Libderiv->deriv_classes[9][6][9];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,1980,dvrr_stack+288598, dvrr_stack+299743, NULL);
 tmp = dvrr_stack + 288598;
 target_ptr = Libderiv->deriv_classes[9][7][9];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,2475,dvrr_stack+290578, dvrr_stack+314208, NULL);
 tmp = dvrr_stack + 290578;
 target_ptr = Libderiv->deriv_classes[9][8][9];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3025,dvrr_stack+314208, dvrr_stack+331203, NULL);
 tmp = dvrr_stack + 314208;
 target_ptr = Libderiv->deriv_classes[9][9][9];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,3630,dvrr_stack+317233, dvrr_stack+355878, NULL);
 tmp = dvrr_stack + 317233;
 target_ptr = Libderiv->deriv_classes[9][10][9];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 0  1 0 0 */
 deriv_build_DX_0(Data,4290,dvrr_stack+355878, dvrr_stack+366768, NULL);
 tmp = dvrr_stack + 355878;
 target_ptr = Libderiv->deriv_classes[9][11][9];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,21,1,dvrr_stack+360168, dvrr_stack+8928, dvrr_stack+1101);
 tmp = dvrr_stack + 360168;
 target_ptr = Libderiv->deriv_classes[5][6][8];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,21,1,dvrr_stack+360756, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 360756;
 target_ptr = Libderiv->deriv_classes[5][7][8];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,21,1,dvrr_stack+361512, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 361512;
 target_ptr = Libderiv->deriv_classes[5][8][8];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,21,1,dvrr_stack+362457, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 362457;
 target_ptr = Libderiv->deriv_classes[5][9][8];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,21,1,dvrr_stack+363612, dvrr_stack+43998, dvrr_stack+23061);
 tmp = dvrr_stack + 363612;
 target_ptr = Libderiv->deriv_classes[5][10][8];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,21,1,dvrr_stack+364998, dvrr_stack+56892, dvrr_stack+32595);
 tmp = dvrr_stack + 364998;
 target_ptr = Libderiv->deriv_classes[5][11][8];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,28,1,dvrr_stack+366636, dvrr_stack+67165, dvrr_stack+254796);
 tmp = dvrr_stack + 366636;
 target_ptr = Libderiv->deriv_classes[6][6][8];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,28,1,dvrr_stack+367420, dvrr_stack+72595, dvrr_stack+64725);
 tmp = dvrr_stack + 367420;
 target_ptr = Libderiv->deriv_classes[6][7][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,28,1,dvrr_stack+368428, dvrr_stack+79409, dvrr_stack+67165);
 tmp = dvrr_stack + 368428;
 target_ptr = Libderiv->deriv_classes[6][8][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,28,1,dvrr_stack+369688, dvrr_stack+87765, dvrr_stack+72595);
 tmp = dvrr_stack + 369688;
 target_ptr = Libderiv->deriv_classes[6][9][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,28,1,dvrr_stack+371228, dvrr_stack+97821, dvrr_stack+79409);
 tmp = dvrr_stack + 371228;
 target_ptr = Libderiv->deriv_classes[6][10][8];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,28,1,dvrr_stack+373076, dvrr_stack+109735, dvrr_stack+87765);
 tmp = dvrr_stack + 373076;
 target_ptr = Libderiv->deriv_classes[6][11][8];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,36,1,dvrr_stack+375260, dvrr_stack+122511, dvrr_stack+255384);
 tmp = dvrr_stack + 375260;
 target_ptr = Libderiv->deriv_classes[7][6][8];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,36,1,dvrr_stack+376268, dvrr_stack+12793, dvrr_stack+3654);
 tmp = dvrr_stack + 376268;
 target_ptr = Libderiv->deriv_classes[7][7][8];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,36,1,dvrr_stack+377564, dvrr_stack+137669, dvrr_stack+122511);
 tmp = dvrr_stack + 377564;
 target_ptr = Libderiv->deriv_classes[7][8][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,36,1,dvrr_stack+249427, dvrr_stack+148733, dvrr_stack+12793);
 tmp = dvrr_stack + 249427;
 target_ptr = Libderiv->deriv_classes[7][9][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,36,1,dvrr_stack+153485, dvrr_stack+160871, dvrr_stack+137669);
 tmp = dvrr_stack + 153485;
 target_ptr = Libderiv->deriv_classes[7][10][8];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,36,1,dvrr_stack+141629, dvrr_stack+176631, dvrr_stack+148733);
 tmp = dvrr_stack + 141629;
 target_ptr = Libderiv->deriv_classes[7][11][8];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,45,1,dvrr_stack+251407, dvrr_stack+65509, dvrr_stack+256140);
 tmp = dvrr_stack + 251407;
 target_ptr = Libderiv->deriv_classes[8][6][8];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,45,1,dvrr_stack+113291, dvrr_stack+70525, dvrr_stack+190123);
 tmp = dvrr_stack + 113291;
 target_ptr = Libderiv->deriv_classes[8][7][8];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,45,1,dvrr_stack+114911, dvrr_stack+76879, dvrr_stack+65509);
 tmp = dvrr_stack + 114911;
 target_ptr = Libderiv->deriv_classes[8][8][8];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,45,1,dvrr_stack+102189, dvrr_stack+84729, dvrr_stack+70525);
 tmp = dvrr_stack + 102189;
 target_ptr = Libderiv->deriv_classes[8][9][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,45,1,dvrr_stack+59587, dvrr_stack+94233, dvrr_stack+76879);
 tmp = dvrr_stack + 59587;
 target_ptr = Libderiv->deriv_classes[8][10][8];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,45,1,dvrr_stack+263499, dvrr_stack+105549, dvrr_stack+84729);
 tmp = dvrr_stack + 263499;
 target_ptr = Libderiv->deriv_classes[8][11][8];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_i(Data,55,1,dvrr_stack+116936, dvrr_stack+286618, dvrr_stack+253287);
 tmp = dvrr_stack + 116936;
 target_ptr = Libderiv->deriv_classes[9][6][8];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_k(Data,55,1,dvrr_stack+91461, dvrr_stack+126831, dvrr_stack+282018);
 tmp = dvrr_stack + 91461;
 target_ptr = Libderiv->deriv_classes[9][7][8];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_l(Data,55,1,dvrr_stack+47274, dvrr_stack+311183, dvrr_stack+286618);
 tmp = dvrr_stack + 47274;
 target_ptr = Libderiv->deriv_classes[9][8][8];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_m(Data,55,1,dvrr_stack+267009, dvrr_stack+144509, dvrr_stack+126831);
 tmp = dvrr_stack + 267009;
 target_ptr = Libderiv->deriv_classes[9][9][8];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_n(Data,55,1,dvrr_stack+270034, dvrr_stack+351588, dvrr_stack+311183);
 tmp = dvrr_stack + 270034;
 target_ptr = Libderiv->deriv_classes[9][10][8];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 0 1  0 0 0 */
 deriv_build_CZ_o(Data,55,1,dvrr_stack+227692, dvrr_stack+170807, dvrr_stack+144509);
 tmp = dvrr_stack + 227692;
 target_ptr = Libderiv->deriv_classes[9][11][8];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,21,1,dvrr_stack+320863, dvrr_stack+8928, dvrr_stack+1101);
 tmp = dvrr_stack + 320863;
 target_ptr = Libderiv->deriv_classes[5][6][7];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,21,1,dvrr_stack+187287, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 187287;
 target_ptr = Libderiv->deriv_classes[5][7][7];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,21,1,dvrr_stack+169457, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 169457;
 target_ptr = Libderiv->deriv_classes[5][8][7];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,21,1,dvrr_stack+155861, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 155861;
 target_ptr = Libderiv->deriv_classes[5][9][7];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,21,1,dvrr_stack+82489, dvrr_stack+43998, dvrr_stack+23061);
 tmp = dvrr_stack + 82489;
 target_ptr = Libderiv->deriv_classes[5][10][7];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,21,1,dvrr_stack+75115, dvrr_stack+56892, dvrr_stack+32595);
 tmp = dvrr_stack + 75115;
 target_ptr = Libderiv->deriv_classes[5][11][7];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,28,1,dvrr_stack+104664, dvrr_stack+67165, dvrr_stack+254796);
 tmp = dvrr_stack + 104664;
 target_ptr = Libderiv->deriv_classes[6][6][7];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,28,1,dvrr_stack+68173, dvrr_stack+72595, dvrr_stack+64725);
 tmp = dvrr_stack + 68173;
 target_ptr = Libderiv->deriv_classes[6][7][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,28,1,dvrr_stack+69181, dvrr_stack+79409, dvrr_stack+67165);
 tmp = dvrr_stack + 69181;
 target_ptr = Libderiv->deriv_classes[6][8][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,28,1,dvrr_stack+35367, dvrr_stack+87765, dvrr_stack+72595);
 tmp = dvrr_stack + 35367;
 target_ptr = Libderiv->deriv_classes[6][9][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,28,1,dvrr_stack+231982, dvrr_stack+97821, dvrr_stack+79409);
 tmp = dvrr_stack + 231982;
 target_ptr = Libderiv->deriv_classes[6][10][7];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,28,1,dvrr_stack+194827, dvrr_stack+109735, dvrr_stack+87765);
 tmp = dvrr_stack + 194827;
 target_ptr = Libderiv->deriv_classes[6][11][7];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,36,1,dvrr_stack+62557, dvrr_stack+122511, dvrr_stack+255384);
 tmp = dvrr_stack + 62557;
 target_ptr = Libderiv->deriv_classes[7][6][7];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,36,1,dvrr_stack+25371, dvrr_stack+12793, dvrr_stack+3654);
 tmp = dvrr_stack + 25371;
 target_ptr = Libderiv->deriv_classes[7][7][7];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,36,1,dvrr_stack+197011, dvrr_stack+137669, dvrr_stack+122511);
 tmp = dvrr_stack + 197011;
 target_ptr = Libderiv->deriv_classes[7][8][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,36,1,dvrr_stack+331177, dvrr_stack+148733, dvrr_stack+12793);
 tmp = dvrr_stack + 331177;
 target_ptr = Libderiv->deriv_classes[7][9][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,36,1,dvrr_stack+333157, dvrr_stack+160871, dvrr_stack+137669);
 tmp = dvrr_stack + 333157;
 target_ptr = Libderiv->deriv_classes[7][10][7];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,36,1,dvrr_stack+335533, dvrr_stack+176631, dvrr_stack+148733);
 tmp = dvrr_stack + 335533;
 target_ptr = Libderiv->deriv_classes[7][11][7];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,45,1,dvrr_stack+17118, dvrr_stack+65509, dvrr_stack+256140);
 tmp = dvrr_stack + 17118;
 target_ptr = Libderiv->deriv_classes[8][6][7];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,45,1,dvrr_stack+338341, dvrr_stack+70525, dvrr_stack+190123);
 tmp = dvrr_stack + 338341;
 target_ptr = Libderiv->deriv_classes[8][7][7];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,45,1,dvrr_stack+213391, dvrr_stack+76879, dvrr_stack+65509);
 tmp = dvrr_stack + 213391;
 target_ptr = Libderiv->deriv_classes[8][8][7];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,45,1,dvrr_stack+215416, dvrr_stack+84729, dvrr_stack+70525);
 tmp = dvrr_stack + 215416;
 target_ptr = Libderiv->deriv_classes[8][9][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,45,1,dvrr_stack+129306, dvrr_stack+94233, dvrr_stack+76879);
 tmp = dvrr_stack + 129306;
 target_ptr = Libderiv->deriv_classes[8][10][7];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,45,1,dvrr_stack+298768, dvrr_stack+105549, dvrr_stack+84729);
 tmp = dvrr_stack + 298768;
 target_ptr = Libderiv->deriv_classes[8][11][7];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_i(Data,55,1,dvrr_stack+217891, dvrr_stack+286618, dvrr_stack+253287);
 tmp = dvrr_stack + 217891;
 target_ptr = Libderiv->deriv_classes[9][6][7];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_k(Data,55,1,dvrr_stack+302278, dvrr_stack+126831, dvrr_stack+282018);
 tmp = dvrr_stack + 302278;
 target_ptr = Libderiv->deriv_classes[9][7][7];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_l(Data,55,1,dvrr_stack+203159, dvrr_stack+311183, dvrr_stack+286618);
 tmp = dvrr_stack + 203159;
 target_ptr = Libderiv->deriv_classes[9][8][7];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_m(Data,55,1,dvrr_stack+403058, dvrr_stack+144509, dvrr_stack+126831);
 tmp = dvrr_stack + 403058;
 target_ptr = Libderiv->deriv_classes[9][9][7];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_n(Data,55,1,dvrr_stack+406083, dvrr_stack+351588, dvrr_stack+311183);
 tmp = dvrr_stack + 406083;
 target_ptr = Libderiv->deriv_classes[9][10][7];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  0 1 0  0 0 0 */
 deriv_build_CY_o(Data,55,1,dvrr_stack+409713, dvrr_stack+170807, dvrr_stack+144509);
 tmp = dvrr_stack + 409713;
 target_ptr = Libderiv->deriv_classes[9][11][7];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,21,1,dvrr_stack+252667, dvrr_stack+8928, dvrr_stack+1101);
 tmp = dvrr_stack + 252667;
 target_ptr = Libderiv->deriv_classes[5][6][6];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,21,1,dvrr_stack+93441, dvrr_stack+15228, dvrr_stack+5208);
 tmp = dvrr_stack + 93441;
 target_ptr = Libderiv->deriv_classes[5][7][6];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,21,1,dvrr_stack+233830, dvrr_stack+23061, dvrr_stack+8928);
 tmp = dvrr_stack + 233830;
 target_ptr = Libderiv->deriv_classes[5][8][6];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,21,1,dvrr_stack+132276, dvrr_stack+32595, dvrr_stack+15228);
 tmp = dvrr_stack + 132276;
 target_ptr = Libderiv->deriv_classes[5][9][6];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,21,1,dvrr_stack+304258, dvrr_stack+43998, dvrr_stack+23061);
 tmp = dvrr_stack + 304258;
 target_ptr = Libderiv->deriv_classes[5][10][6];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,21,1,dvrr_stack+205634, dvrr_stack+56892, dvrr_stack+32595);
 tmp = dvrr_stack + 205634;
 target_ptr = Libderiv->deriv_classes[5][11][6];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,28,1,dvrr_stack+83875, dvrr_stack+67165, dvrr_stack+254796);
 tmp = dvrr_stack + 83875;
 target_ptr = Libderiv->deriv_classes[6][6][6];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,28,1,dvrr_stack+55870, dvrr_stack+72595, dvrr_stack+64725);
 tmp = dvrr_stack + 55870;
 target_ptr = Libderiv->deriv_classes[6][7][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,28,1,dvrr_stack+56878, dvrr_stack+79409, dvrr_stack+67165);
 tmp = dvrr_stack + 56878;
 target_ptr = Libderiv->deriv_classes[6][8][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,28,1,dvrr_stack+0, dvrr_stack+87765, dvrr_stack+72595);
 tmp = dvrr_stack + 0;
 target_ptr = Libderiv->deriv_classes[6][9][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,28,1,dvrr_stack+414003, dvrr_stack+97821, dvrr_stack+79409);
 tmp = dvrr_stack + 414003;
 target_ptr = Libderiv->deriv_classes[6][10][6];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,28,1,dvrr_stack+415851, dvrr_stack+109735, dvrr_stack+87765);
 tmp = dvrr_stack + 415851;
 target_ptr = Libderiv->deriv_classes[6][11][6];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,36,1,dvrr_stack+109644, dvrr_stack+122511, dvrr_stack+255384);
 tmp = dvrr_stack + 109644;
 target_ptr = Libderiv->deriv_classes[7][6][6];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,36,1,dvrr_stack+110652, dvrr_stack+12793, dvrr_stack+3654);
 tmp = dvrr_stack + 110652;
 target_ptr = Libderiv->deriv_classes[7][7][6];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,36,1,dvrr_stack+254442, dvrr_stack+137669, dvrr_stack+122511);
 tmp = dvrr_stack + 254442;
 target_ptr = Libderiv->deriv_classes[7][8][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,36,1,dvrr_stack+418035, dvrr_stack+148733, dvrr_stack+12793);
 tmp = dvrr_stack + 418035;
 target_ptr = Libderiv->deriv_classes[7][9][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,36,1,dvrr_stack+420015, dvrr_stack+160871, dvrr_stack+137669);
 tmp = dvrr_stack + 420015;
 target_ptr = Libderiv->deriv_classes[7][10][6];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,36,1,dvrr_stack+422391, dvrr_stack+176631, dvrr_stack+148733);
 tmp = dvrr_stack + 422391;
 target_ptr = Libderiv->deriv_classes[7][11][6];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,45,1,dvrr_stack+175812, dvrr_stack+65509, dvrr_stack+256140);
 tmp = dvrr_stack + 175812;
 target_ptr = Libderiv->deriv_classes[8][6][6];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,45,1,dvrr_stack+177072, dvrr_stack+70525, dvrr_stack+190123);
 tmp = dvrr_stack + 177072;
 target_ptr = Libderiv->deriv_classes[8][7][6];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,45,1,dvrr_stack+425199, dvrr_stack+76879, dvrr_stack+65509);
 tmp = dvrr_stack + 425199;
 target_ptr = Libderiv->deriv_classes[8][8][6];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,45,1,dvrr_stack+427224, dvrr_stack+84729, dvrr_stack+70525);
 tmp = dvrr_stack + 427224;
 target_ptr = Libderiv->deriv_classes[8][9][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,45,1,dvrr_stack+429699, dvrr_stack+94233, dvrr_stack+76879);
 tmp = dvrr_stack + 429699;
 target_ptr = Libderiv->deriv_classes[8][10][6];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,45,1,dvrr_stack+432669, dvrr_stack+105549, dvrr_stack+84729);
 tmp = dvrr_stack + 432669;
 target_ptr = Libderiv->deriv_classes[8][11][6];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_i(Data,55,1,dvrr_stack+105448, dvrr_stack+286618, dvrr_stack+253287);
 tmp = dvrr_stack + 105448;
 target_ptr = Libderiv->deriv_classes[9][6][6];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_k(Data,55,1,dvrr_stack+106988, dvrr_stack+126831, dvrr_stack+282018);
 tmp = dvrr_stack + 106988;
 target_ptr = Libderiv->deriv_classes[9][7][6];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_l(Data,55,1,dvrr_stack+436179, dvrr_stack+311183, dvrr_stack+286618);
 tmp = dvrr_stack + 436179;
 target_ptr = Libderiv->deriv_classes[9][8][6];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_m(Data,55,1,dvrr_stack+438654, dvrr_stack+144509, dvrr_stack+126831);
 tmp = dvrr_stack + 438654;
 target_ptr = Libderiv->deriv_classes[9][9][6];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_n(Data,55,1,dvrr_stack+441679, dvrr_stack+351588, dvrr_stack+311183);
 tmp = dvrr_stack + 441679;
 target_ptr = Libderiv->deriv_classes[9][10][6];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 0  0 0 0  1 0 0  0 0 0 */
 deriv_build_CX_o(Data,55,1,dvrr_stack+445309, dvrr_stack+170807, dvrr_stack+144509);
 tmp = dvrr_stack + 445309;
 target_ptr = Libderiv->deriv_classes[9][11][6];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,28,dvrr_stack+253255, dvrr_stack+64725, dvrr_stack+4788);
 tmp = dvrr_stack + 253255;
 target_ptr = Libderiv->deriv_classes[5][6][2];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,36,dvrr_stack+170402, dvrr_stack+67165, dvrr_stack+8388);
 tmp = dvrr_stack + 170402;
 target_ptr = Libderiv->deriv_classes[5][7][2];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,45,dvrr_stack+171158, dvrr_stack+72595, dvrr_stack+14553);
 tmp = dvrr_stack + 171158;
 target_ptr = Libderiv->deriv_classes[5][8][2];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,55,dvrr_stack+172103, dvrr_stack+79409, dvrr_stack+22236);
 tmp = dvrr_stack + 172103;
 target_ptr = Libderiv->deriv_classes[5][9][2];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,66,dvrr_stack+173258, dvrr_stack+87765, dvrr_stack+31605);
 tmp = dvrr_stack + 173258;
 target_ptr = Libderiv->deriv_classes[5][10][2];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_h(Data,78,dvrr_stack+449599, dvrr_stack+97821, dvrr_stack+42828);
 tmp = dvrr_stack + 449599;
 target_ptr = Libderiv->deriv_classes[5][11][2];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,28,dvrr_stack+174644, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 174644;
 target_ptr = Libderiv->deriv_classes[6][6][2];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,36,dvrr_stack+256062, dvrr_stack+122511, dvrr_stack+8928);
 tmp = dvrr_stack + 256062;
 target_ptr = Libderiv->deriv_classes[6][7][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,45,dvrr_stack+451237, dvrr_stack+12793, dvrr_stack+15228);
 tmp = dvrr_stack + 451237;
 target_ptr = Libderiv->deriv_classes[6][8][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,55,dvrr_stack+452497, dvrr_stack+137669, dvrr_stack+23061);
 tmp = dvrr_stack + 452497;
 target_ptr = Libderiv->deriv_classes[6][9][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,66,dvrr_stack+454037, dvrr_stack+148733, dvrr_stack+32595);
 tmp = dvrr_stack + 454037;
 target_ptr = Libderiv->deriv_classes[6][10][2];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_i(Data,78,dvrr_stack+455885, dvrr_stack+160871, dvrr_stack+43998);
 tmp = dvrr_stack + 455885;
 target_ptr = Libderiv->deriv_classes[6][11][2];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,28,dvrr_stack+159857, dvrr_stack+190123, dvrr_stack+64725);
 tmp = dvrr_stack + 159857;
 target_ptr = Libderiv->deriv_classes[7][6][2];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,36,dvrr_stack+458069, dvrr_stack+65509, dvrr_stack+67165);
 tmp = dvrr_stack + 458069;
 target_ptr = Libderiv->deriv_classes[7][7][2];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,45,dvrr_stack+459365, dvrr_stack+70525, dvrr_stack+72595);
 tmp = dvrr_stack + 459365;
 target_ptr = Libderiv->deriv_classes[7][8][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,55,dvrr_stack+460985, dvrr_stack+76879, dvrr_stack+79409);
 tmp = dvrr_stack + 460985;
 target_ptr = Libderiv->deriv_classes[7][9][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,66,dvrr_stack+462965, dvrr_stack+84729, dvrr_stack+87765);
 tmp = dvrr_stack + 462965;
 target_ptr = Libderiv->deriv_classes[7][10][2];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_k(Data,78,dvrr_stack+465341, dvrr_stack+94233, dvrr_stack+97821);
 tmp = dvrr_stack + 465341;
 target_ptr = Libderiv->deriv_classes[7][11][2];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,28,dvrr_stack+468149, dvrr_stack+282018, dvrr_stack+3654);
 tmp = dvrr_stack + 468149;
 target_ptr = Libderiv->deriv_classes[8][6][2];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,36,dvrr_stack+469409, dvrr_stack+286618, dvrr_stack+122511);
 tmp = dvrr_stack + 469409;
 target_ptr = Libderiv->deriv_classes[8][7][2];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,45,dvrr_stack+471029, dvrr_stack+126831, dvrr_stack+12793);
 tmp = dvrr_stack + 471029;
 target_ptr = Libderiv->deriv_classes[8][8][2];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,55,dvrr_stack+473054, dvrr_stack+311183, dvrr_stack+137669);
 tmp = dvrr_stack + 473054;
 target_ptr = Libderiv->deriv_classes[8][9][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,66,dvrr_stack+475529, dvrr_stack+144509, dvrr_stack+148733);
 tmp = dvrr_stack + 475529;
 target_ptr = Libderiv->deriv_classes[8][10][2];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_l(Data,78,dvrr_stack+478499, dvrr_stack+351588, dvrr_stack+160871);
 tmp = dvrr_stack + 478499;
 target_ptr = Libderiv->deriv_classes[8][11][2];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,28,dvrr_stack+482009, dvrr_stack+54022, dvrr_stack+190123);
 tmp = dvrr_stack + 482009;
 target_ptr = Libderiv->deriv_classes[9][6][2];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,36,dvrr_stack+483549, dvrr_stack+283558, dvrr_stack+65509);
 tmp = dvrr_stack + 483549;
 target_ptr = Libderiv->deriv_classes[9][7][2];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,45,dvrr_stack+485529, dvrr_stack+257085, dvrr_stack+70525);
 tmp = dvrr_stack + 485529;
 target_ptr = Libderiv->deriv_classes[9][8][2];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,55,dvrr_stack+488004, dvrr_stack+208123, dvrr_stack+76879);
 tmp = dvrr_stack + 488004;
 target_ptr = Libderiv->deriv_classes[9][9][2];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,66,dvrr_stack+491029, dvrr_stack+321633, dvrr_stack+84729);
 tmp = dvrr_stack + 491029;
 target_ptr = Libderiv->deriv_classes[9][10][2];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 0 1  0 0 0  0 0 0  0 0 0 */
 deriv_build_AZ_m(Data,78,dvrr_stack+494659, dvrr_stack+220248, dvrr_stack+94233);
 tmp = dvrr_stack + 494659;
 target_ptr = Libderiv->deriv_classes[9][11][2];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,28,dvrr_stack+253843, dvrr_stack+64725, dvrr_stack+4788);
 tmp = dvrr_stack + 253843;
 target_ptr = Libderiv->deriv_classes[5][6][1];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,36,dvrr_stack+53214, dvrr_stack+67165, dvrr_stack+8388);
 tmp = dvrr_stack + 53214;
 target_ptr = Libderiv->deriv_classes[5][7][1];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,45,dvrr_stack+178692, dvrr_stack+72595, dvrr_stack+14553);
 tmp = dvrr_stack + 178692;
 target_ptr = Libderiv->deriv_classes[5][8][1];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,55,dvrr_stack+498949, dvrr_stack+79409, dvrr_stack+22236);
 tmp = dvrr_stack + 498949;
 target_ptr = Libderiv->deriv_classes[5][9][1];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,66,dvrr_stack+500104, dvrr_stack+87765, dvrr_stack+31605);
 tmp = dvrr_stack + 500104;
 target_ptr = Libderiv->deriv_classes[5][10][1];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_h(Data,78,dvrr_stack+501490, dvrr_stack+97821, dvrr_stack+42828);
 tmp = dvrr_stack + 501490;
 target_ptr = Libderiv->deriv_classes[5][11][1];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,28,dvrr_stack+219431, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 219431;
 target_ptr = Libderiv->deriv_classes[6][6][1];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,36,dvrr_stack+503128, dvrr_stack+122511, dvrr_stack+8928);
 tmp = dvrr_stack + 503128;
 target_ptr = Libderiv->deriv_classes[6][7][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,45,dvrr_stack+504136, dvrr_stack+12793, dvrr_stack+15228);
 tmp = dvrr_stack + 504136;
 target_ptr = Libderiv->deriv_classes[6][8][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,55,dvrr_stack+505396, dvrr_stack+137669, dvrr_stack+23061);
 tmp = dvrr_stack + 505396;
 target_ptr = Libderiv->deriv_classes[6][9][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,66,dvrr_stack+506936, dvrr_stack+148733, dvrr_stack+32595);
 tmp = dvrr_stack + 506936;
 target_ptr = Libderiv->deriv_classes[6][10][1];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_i(Data,78,dvrr_stack+508784, dvrr_stack+160871, dvrr_stack+43998);
 tmp = dvrr_stack + 508784;
 target_ptr = Libderiv->deriv_classes[6][11][1];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,28,dvrr_stack+510968, dvrr_stack+190123, dvrr_stack+64725);
 tmp = dvrr_stack + 510968;
 target_ptr = Libderiv->deriv_classes[7][6][1];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,36,dvrr_stack+511976, dvrr_stack+65509, dvrr_stack+67165);
 tmp = dvrr_stack + 511976;
 target_ptr = Libderiv->deriv_classes[7][7][1];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,45,dvrr_stack+513272, dvrr_stack+70525, dvrr_stack+72595);
 tmp = dvrr_stack + 513272;
 target_ptr = Libderiv->deriv_classes[7][8][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,55,dvrr_stack+514892, dvrr_stack+76879, dvrr_stack+79409);
 tmp = dvrr_stack + 514892;
 target_ptr = Libderiv->deriv_classes[7][9][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,66,dvrr_stack+516872, dvrr_stack+84729, dvrr_stack+87765);
 tmp = dvrr_stack + 516872;
 target_ptr = Libderiv->deriv_classes[7][10][1];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_k(Data,78,dvrr_stack+519248, dvrr_stack+94233, dvrr_stack+97821);
 tmp = dvrr_stack + 519248;
 target_ptr = Libderiv->deriv_classes[7][11][1];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,28,dvrr_stack+522056, dvrr_stack+282018, dvrr_stack+3654);
 tmp = dvrr_stack + 522056;
 target_ptr = Libderiv->deriv_classes[8][6][1];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,36,dvrr_stack+523316, dvrr_stack+286618, dvrr_stack+122511);
 tmp = dvrr_stack + 523316;
 target_ptr = Libderiv->deriv_classes[8][7][1];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,45,dvrr_stack+524936, dvrr_stack+126831, dvrr_stack+12793);
 tmp = dvrr_stack + 524936;
 target_ptr = Libderiv->deriv_classes[8][8][1];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,55,dvrr_stack+526961, dvrr_stack+311183, dvrr_stack+137669);
 tmp = dvrr_stack + 526961;
 target_ptr = Libderiv->deriv_classes[8][9][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,66,dvrr_stack+529436, dvrr_stack+144509, dvrr_stack+148733);
 tmp = dvrr_stack + 529436;
 target_ptr = Libderiv->deriv_classes[8][10][1];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_l(Data,78,dvrr_stack+532406, dvrr_stack+351588, dvrr_stack+160871);
 tmp = dvrr_stack + 532406;
 target_ptr = Libderiv->deriv_classes[8][11][1];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,28,dvrr_stack+535916, dvrr_stack+54022, dvrr_stack+190123);
 tmp = dvrr_stack + 535916;
 target_ptr = Libderiv->deriv_classes[9][6][1];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,36,dvrr_stack+537456, dvrr_stack+283558, dvrr_stack+65509);
 tmp = dvrr_stack + 537456;
 target_ptr = Libderiv->deriv_classes[9][7][1];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,45,dvrr_stack+539436, dvrr_stack+257085, dvrr_stack+70525);
 tmp = dvrr_stack + 539436;
 target_ptr = Libderiv->deriv_classes[9][8][1];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,55,dvrr_stack+541911, dvrr_stack+208123, dvrr_stack+76879);
 tmp = dvrr_stack + 541911;
 target_ptr = Libderiv->deriv_classes[9][9][1];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,66,dvrr_stack+544936, dvrr_stack+321633, dvrr_stack+84729);
 tmp = dvrr_stack + 544936;
 target_ptr = Libderiv->deriv_classes[9][10][1];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 0 1 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AY_m(Data,78,dvrr_stack+548566, dvrr_stack+220248, dvrr_stack+94233);
 tmp = dvrr_stack + 548566;
 target_ptr = Libderiv->deriv_classes[9][11][1];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,28,dvrr_stack+108968, dvrr_stack+64725, dvrr_stack+4788);
 tmp = dvrr_stack + 108968;
 target_ptr = Libderiv->deriv_classes[5][6][0];
 for(i=0;i<588;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,36,dvrr_stack+207272, dvrr_stack+67165, dvrr_stack+8388);
 tmp = dvrr_stack + 207272;
 target_ptr = Libderiv->deriv_classes[5][7][0];
 for(i=0;i<756;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,45,dvrr_stack+7980, dvrr_stack+72595, dvrr_stack+14553);
 tmp = dvrr_stack + 7980;
 target_ptr = Libderiv->deriv_classes[5][8][0];
 for(i=0;i<945;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,55,dvrr_stack+552856, dvrr_stack+79409, dvrr_stack+22236);
 tmp = dvrr_stack + 552856;
 target_ptr = Libderiv->deriv_classes[5][9][0];
 for(i=0;i<1155;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,66,dvrr_stack+554011, dvrr_stack+87765, dvrr_stack+31605);
 tmp = dvrr_stack + 554011;
 target_ptr = Libderiv->deriv_classes[5][10][0];
 for(i=0;i<1386;i++)
   target_ptr[i] += tmp[i];

 /* compute (5 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_h(Data,78,dvrr_stack+555397, dvrr_stack+97821, dvrr_stack+42828);
 tmp = dvrr_stack + 555397;
 target_ptr = Libderiv->deriv_classes[5][11][0];
 for(i=0;i<1638;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,28,dvrr_stack+22071, dvrr_stack+3654, dvrr_stack+5208);
 tmp = dvrr_stack + 22071;
 target_ptr = Libderiv->deriv_classes[6][6][0];
 for(i=0;i<784;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,36,dvrr_stack+4662, dvrr_stack+122511, dvrr_stack+8928);
 tmp = dvrr_stack + 4662;
 target_ptr = Libderiv->deriv_classes[6][7][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,45,dvrr_stack+41946, dvrr_stack+12793, dvrr_stack+15228);
 tmp = dvrr_stack + 41946;
 target_ptr = Libderiv->deriv_classes[6][8][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,55,dvrr_stack+14413, dvrr_stack+137669, dvrr_stack+23061);
 tmp = dvrr_stack + 14413;
 target_ptr = Libderiv->deriv_classes[6][9][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,66,dvrr_stack+557035, dvrr_stack+148733, dvrr_stack+32595);
 tmp = dvrr_stack + 557035;
 target_ptr = Libderiv->deriv_classes[6][10][0];
 for(i=0;i<1848;i++)
   target_ptr[i] += tmp[i];

 /* compute (6 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_i(Data,78,dvrr_stack+31407, dvrr_stack+160871, dvrr_stack+43998);
 tmp = dvrr_stack + 31407;
 target_ptr = Libderiv->deriv_classes[6][11][0];
 for(i=0;i<2184;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,28,dvrr_stack+22855, dvrr_stack+190123, dvrr_stack+64725);
 tmp = dvrr_stack + 22855;
 target_ptr = Libderiv->deriv_classes[7][6][0];
 for(i=0;i<1008;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,36,dvrr_stack+43206, dvrr_stack+65509, dvrr_stack+67165);
 tmp = dvrr_stack + 43206;
 target_ptr = Libderiv->deriv_classes[7][7][0];
 for(i=0;i<1296;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,45,dvrr_stack+558883, dvrr_stack+70525, dvrr_stack+72595);
 tmp = dvrr_stack + 558883;
 target_ptr = Libderiv->deriv_classes[7][8][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,55,dvrr_stack+560503, dvrr_stack+76879, dvrr_stack+79409);
 tmp = dvrr_stack + 560503;
 target_ptr = Libderiv->deriv_classes[7][9][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,66,dvrr_stack+562483, dvrr_stack+84729, dvrr_stack+87765);
 tmp = dvrr_stack + 562483;
 target_ptr = Libderiv->deriv_classes[7][10][0];
 for(i=0;i<2376;i++)
   target_ptr[i] += tmp[i];

 /* compute (7 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_k(Data,78,dvrr_stack+564859, dvrr_stack+94233, dvrr_stack+97821);
 tmp = dvrr_stack + 564859;
 target_ptr = Libderiv->deriv_classes[7][11][0];
 for(i=0;i<2808;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,28,dvrr_stack+97743, dvrr_stack+282018, dvrr_stack+3654);
 tmp = dvrr_stack + 97743;
 target_ptr = Libderiv->deriv_classes[8][6][0];
 for(i=0;i<1260;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,36,dvrr_stack+281609, dvrr_stack+286618, dvrr_stack+122511);
 tmp = dvrr_stack + 281609;
 target_ptr = Libderiv->deriv_classes[8][7][0];
 for(i=0;i<1620;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,45,dvrr_stack+285934, dvrr_stack+126831, dvrr_stack+12793);
 tmp = dvrr_stack + 285934;
 target_ptr = Libderiv->deriv_classes[8][8][0];
 for(i=0;i<2025;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,55,dvrr_stack+126723, dvrr_stack+311183, dvrr_stack+137669);
 tmp = dvrr_stack + 126723;
 target_ptr = Libderiv->deriv_classes[8][9][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,66,dvrr_stack+310751, dvrr_stack+144509, dvrr_stack+148733);
 tmp = dvrr_stack + 310751;
 target_ptr = Libderiv->deriv_classes[8][10][0];
 for(i=0;i<2970;i++)
   target_ptr[i] += tmp[i];

 /* compute (8 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_l(Data,78,dvrr_stack+144437, dvrr_stack+351588, dvrr_stack+160871);
 tmp = dvrr_stack + 144437;
 target_ptr = Libderiv->deriv_classes[8][11][0];
 for(i=0;i<3510;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 6 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,28,dvrr_stack+147947, dvrr_stack+54022, dvrr_stack+190123);
 tmp = dvrr_stack + 147947;
 target_ptr = Libderiv->deriv_classes[9][6][0];
 for(i=0;i<1540;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 7 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,36,dvrr_stack+137079, dvrr_stack+283558, dvrr_stack+65509);
 tmp = dvrr_stack + 137079;
 target_ptr = Libderiv->deriv_classes[9][7][0];
 for(i=0;i<1980;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 8 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,45,dvrr_stack+64725, dvrr_stack+257085, dvrr_stack+70525);
 tmp = dvrr_stack + 64725;
 target_ptr = Libderiv->deriv_classes[9][8][0];
 for(i=0;i<2475;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 9 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,55,dvrr_stack+70441, dvrr_stack+208123, dvrr_stack+76879);
 tmp = dvrr_stack + 70441;
 target_ptr = Libderiv->deriv_classes[9][9][0];
 for(i=0;i<3025;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 10 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,66,dvrr_stack+76753, dvrr_stack+321633, dvrr_stack+84729);
 tmp = dvrr_stack + 76753;
 target_ptr = Libderiv->deriv_classes[9][10][0];
 for(i=0;i<3630;i++)
   target_ptr[i] += tmp[i];

 /* compute (9 0 | 11 0) m=0 deriv level 1 */
 /* deriv_ind: 1 0 0  0 0 0  0 0 0  0 0 0 */
 deriv_build_AX_m(Data,78,dvrr_stack+321451, dvrr_stack+220248, dvrr_stack+94233);
 tmp = dvrr_stack + 321451;
 target_ptr = Libderiv->deriv_classes[9][11][0];
 for(i=0;i<4290;i++)
   target_ptr[i] += tmp[i];


}

